use Test::More;
use Lingua::EN::Inflexion;

is verb(q{bites})->past_part, q{bitten}  => q{past_part 'bites' --> 'bitten'};
is verb(q{overtaking})->past_part, q{overtaken}  => q{past_part 'overtaking' --> 'overtaken'};
is verb(q{avalanche})->past_part, q{avalanched}  => q{past_part 'avalanche' --> 'avalanched'};
is verb(q{stride})->past_part, q{strode}  => q{past_part 'stride' --> 'strode'};
is verb(q{forgive})->past_part, q{forgiven}  => q{past_part 'forgive' --> 'forgiven'};
is verb(q{insist})->past_part, q{insisted}  => q{past_part 'insist' --> 'insisted'};
is verb(q{singing})->past_part, q{sung}  => q{past_part 'singing' --> 'sung'};
is verb(q{sweat})->past_part, q{sweated}  => q{past_part 'sweat' --> 'sweated'};
is verb(q{shitting})->past_part, q{shitted}  => q{past_part 'shitting' --> 'shitted'};
is verb(q{overhearing})->past_part, q{overheard}  => q{past_part 'overhearing' --> 'overheard'};
is verb(q{fights})->past_part, q{fought}  => q{past_part 'fights' --> 'fought'};
is verb(q{remains})->past_part, q{remained}  => q{past_part 'remains' --> 'remained'};
is verb(q{overhear})->past_part, q{overheard}  => q{past_part 'overhear' --> 'overheard'};
is verb(q{died})->past_part, q{died}  => q{past_part 'died' --> 'died'};
is verb(q{forgave})->past_part, q{forgiven}  => q{past_part 'forgave' --> 'forgiven'};
is verb(q{gilds})->past_part, q{gilded}  => q{past_part 'gilds' --> 'gilded'};
is verb(q{strew})->past_part, q{strewn}  => q{past_part 'strew' --> 'strewn'};
is verb(q{kept})->past_part, q{kept}  => q{past_part 'kept' --> 'kept'};
is verb(q{winning})->past_part, q{won}  => q{past_part 'winning' --> 'won'};
is verb(q{vexing})->past_part, q{vexed}  => q{past_part 'vexing' --> 'vexed'};
is verb(q{swam})->past_part, q{swum}  => q{past_part 'swam' --> 'swum'};
is verb(q{swims})->past_part, q{swum}  => q{past_part 'swims' --> 'swum'};
is verb(q{stopped})->past_part, q{stopped}  => q{past_part 'stopped' --> 'stopped'};
is verb(q{awoken})->past_part, q{awoken}  => q{past_part 'awoken' --> 'awoken'};
is verb(q{sought})->past_part, q{sought}  => q{past_part 'sought' --> 'sought'};
is verb(q{insisted})->past_part, q{insisted}  => q{past_part 'insisted' --> 'insisted'};
is verb(q{stave})->past_part, q{staved}  => q{past_part 'stave' --> 'staved'};
is verb(q{has})->past_part, q{had}  => q{past_part 'has' --> 'had'};
is verb(q{awake})->past_part, q{awoken}  => q{past_part 'awake' --> 'awoken'};
is verb(q{wins})->past_part, q{won}  => q{past_part 'wins' --> 'won'};
is verb(q{eaten})->past_part, q{eaten}  => q{past_part 'eaten' --> 'eaten'};
is verb(q{sings})->past_part, q{sung}  => q{past_part 'sings' --> 'sung'};
is verb(q{keep})->past_part, q{kept}  => q{past_part 'keep' --> 'kept'};
is verb(q{loves})->past_part, q{loved}  => q{past_part 'loves' --> 'loved'};
is verb(q{hits})->past_part, q{hit}  => q{past_part 'hits' --> 'hit'};
is verb(q{strewing})->past_part, q{strewn}  => q{past_part 'strewing' --> 'strewn'};
is verb(q{choosing})->past_part, q{chosen}  => q{past_part 'choosing' --> 'chosen'};
is verb(q{sweating})->past_part, q{sweated}  => q{past_part 'sweating' --> 'sweated'};
is verb(q{gilding})->past_part, q{gilded}  => q{past_part 'gilding' --> 'gilded'};
is verb(q{begets})->past_part, q{begotten}  => q{past_part 'begets' --> 'begotten'};
is verb(q{shed})->past_part, q{shed}  => q{past_part 'shed' --> 'shed'};
is verb(q{walk})->past_part, q{walked}  => q{past_part 'walk' --> 'walked'};
is verb(q{slide})->past_part, q{slid}  => q{past_part 'slide' --> 'slid'};
is verb(q{forsakes})->past_part, q{forsaken}  => q{past_part 'forsakes' --> 'forsaken'};
is verb(q{asks})->past_part, q{asked}  => q{past_part 'asks' --> 'asked'};
is verb(q{stop})->past_part, q{stopped}  => q{past_part 'stop' --> 'stopped'};
is verb(q{drank})->past_part, q{drunk}  => q{past_part 'drank' --> 'drunk'};
is verb(q{understands})->past_part, q{understood}  => q{past_part 'understands' --> 'understood'};
is verb(q{forbidding})->past_part, q{forbidden}  => q{past_part 'forbidding' --> 'forbidden'};
is verb(q{leans})->past_part, q{leaned}  => q{past_part 'leans' --> 'leaned'};
is verb(q{remain})->past_part, q{remained}  => q{past_part 'remain' --> 'remained'};
is verb(q{menu})->past_part, q{menued}  => q{past_part 'menu' --> 'menued'};
is verb(q{blitzes})->past_part, q{blitzed}  => q{past_part 'blitzes' --> 'blitzed'};
is verb(q{shows})->past_part, q{shown}  => q{past_part 'shows' --> 'shown'};
is verb(q{insists})->past_part, q{insisted}  => q{past_part 'insists' --> 'insisted'};
is verb(q{undertake})->past_part, q{undertaken}  => q{past_part 'undertake' --> 'undertaken'};
is verb(q{holds})->past_part, q{held}  => q{past_part 'holds' --> 'held'};
is verb(q{expecting})->past_part, q{expected}  => q{past_part 'expecting' --> 'expected'};
is verb(q{strides})->past_part, q{strode}  => q{past_part 'strides' --> 'strode'};
is verb(q{swearing})->past_part, q{sworn}  => q{past_part 'swearing' --> 'sworn'};
is verb(q{speed})->past_part, q{sped}  => q{past_part 'speed' --> 'sped'};
is verb(q{fled})->past_part, q{fled}  => q{past_part 'fled' --> 'fled'};
is verb(q{reaches})->past_part, q{reached}  => q{past_part 'reaches' --> 'reached'};
is verb(q{rising})->past_part, q{risen}  => q{past_part 'rising' --> 'risen'};
is verb(q{slays})->past_part, q{slain}  => q{past_part 'slays' --> 'slain'};
is verb(q{sneak})->past_part, q{sneaked}  => q{past_part 'sneak' --> 'sneaked'};
is verb(q{having})->past_part, q{had}  => q{past_part 'having' --> 'had'};
is verb(q{weeping})->past_part, q{wept}  => q{past_part 'weeping' --> 'wept'};
is verb(q{dream})->past_part, q{dreamed}  => q{past_part 'dream' --> 'dreamed'};
is verb(q{strove})->past_part, q{strived}  => q{past_part 'strove' --> 'strived'};
is verb(q{smelling})->past_part, q{smelled}  => q{past_part 'smelling' --> 'smelled'};
is verb(q{wanted})->past_part, q{wanted}  => q{past_part 'wanted' --> 'wanted'};
is verb(q{wrings})->past_part, q{wrung}  => q{past_part 'wrings' --> 'wrung'};
is verb(q{looks})->past_part, q{looked}  => q{past_part 'looks' --> 'looked'};
is verb(q{upset})->past_part, q{upset}  => q{past_part 'upset' --> 'upset'};
is verb(q{withstands})->past_part, q{withstood}  => q{past_part 'withstands' --> 'withstood'};
is verb(q{met})->past_part, q{met}  => q{past_part 'met' --> 'met'};
is verb(q{mistook})->past_part, q{mistaken}  => q{past_part 'mistook' --> 'mistaken'};
is verb(q{knits})->past_part, q{knitted}  => q{past_part 'knits' --> 'knitted'};
is verb(q{sweeping})->past_part, q{swept}  => q{past_part 'sweeping' --> 'swept'};
is verb(q{forgiving})->past_part, q{forgiven}  => q{past_part 'forgiving' --> 'forgiven'};
is verb(q{skiing})->past_part, q{skied}  => q{past_part 'skiing' --> 'skied'};
is verb(q{leaning})->past_part, q{leaned}  => q{past_part 'leaning' --> 'leaned'};
is verb(q{beginning})->past_part, q{begun}  => q{past_part 'beginning' --> 'begun'};
is verb(q{smitten})->past_part, q{smitten}  => q{past_part 'smitten' --> 'smitten'};
is verb(q{asked})->past_part, q{asked}  => q{past_part 'asked' --> 'asked'};
is verb(q{remained})->past_part, q{remained}  => q{past_part 'remained' --> 'remained'};
is verb(q{sweep})->past_part, q{swept}  => q{past_part 'sweep' --> 'swept'};
is verb(q{showing})->past_part, q{shown}  => q{past_part 'showing' --> 'shown'};
is verb(q{holding})->past_part, q{held}  => q{past_part 'holding' --> 'held'};
is verb(q{dreaming})->past_part, q{dreamed}  => q{past_part 'dreaming' --> 'dreamed'};
is verb(q{smell})->past_part, q{smelled}  => q{past_part 'smell' --> 'smelled'};
is verb(q{sneaking})->past_part, q{sneaked}  => q{past_part 'sneaking' --> 'sneaked'};
is verb(q{meant})->past_part, q{meant}  => q{past_part 'meant' --> 'meant'};
is verb(q{known})->past_part, q{known}  => q{past_part 'known' --> 'known'};
is verb(q{left})->past_part, q{left}  => q{past_part 'left' --> 'left'};
is verb(q{understood})->past_part, q{understood}  => q{past_part 'understood' --> 'understood'};
is verb(q{are})->past_part, q{been}  => q{past_part 'are' --> 'been'};
is verb(q{sliding})->past_part, q{slid}  => q{past_part 'sliding' --> 'slid'};
is verb(q{slaying})->past_part, q{slain}  => q{past_part 'slaying' --> 'slain'};
is verb(q{weeps})->past_part, q{wept}  => q{past_part 'weeps' --> 'wept'};
is verb(q{sank})->past_part, q{sunk}  => q{past_part 'sank' --> 'sunk'};
is verb(q{speeding})->past_part, q{sped}  => q{past_part 'speeding' --> 'sped'};
is verb(q{sits})->past_part, q{sat}  => q{past_part 'sits' --> 'sat'};
is verb(q{swear})->past_part, q{sworn}  => q{past_part 'swear' --> 'sworn'};
is verb(q{looking})->past_part, q{looked}  => q{past_part 'looking' --> 'looked'};
is verb(q{puts})->past_part, q{put}  => q{past_part 'puts' --> 'put'};
is verb(q{strips})->past_part, q{stripped}  => q{past_part 'strips' --> 'stripped'};
is verb(q{daring})->past_part, q{dared}  => q{past_part 'daring' --> 'dared'};
is verb(q{spoke})->past_part, q{spoken}  => q{past_part 'spoke' --> 'spoken'};
is verb(q{staving})->past_part, q{staved}  => q{past_part 'staving' --> 'staved'};
is verb(q{forbade})->past_part, q{forbidden}  => q{past_part 'forbade' --> 'forbidden'};
is verb(q{deal})->past_part, q{dealt}  => q{past_part 'deal' --> 'dealt'};
is verb(q{continue})->past_part, q{continued}  => q{past_part 'continue' --> 'continued'};
is verb(q{smites})->past_part, q{smitten}  => q{past_part 'smites' --> 'smitten'};
is verb(q{bursts})->past_part, q{burst}  => q{past_part 'bursts' --> 'burst'};
is verb(q{quit})->past_part, q{quit}  => q{past_part 'quit' --> 'quit'};
is verb(q{shrank})->past_part, q{shrunk}  => q{past_part 'shrank' --> 'shrunk'};
is verb(q{ask})->past_part, q{asked}  => q{past_part 'ask' --> 'asked'};
is verb(q{come})->past_part, q{come}  => q{past_part 'come' --> 'come'};
is verb(q{abide})->past_part, q{abided}  => q{past_part 'abide' --> 'abided'};
is verb(q{forbids})->past_part, q{forbidden}  => q{past_part 'forbids' --> 'forbidden'};
is verb(q{changing})->past_part, q{changed}  => q{past_part 'changing' --> 'changed'};
is verb(q{slunk})->past_part, q{slunk}  => q{past_part 'slunk' --> 'slunk'};
is verb(q{slit})->past_part, q{slit}  => q{past_part 'slit' --> 'slit'};
is verb(q{lain})->past_part, q{lain}  => q{past_part 'lain' --> 'lain'};
is verb(q{dived})->past_part, q{dived}  => q{past_part 'dived' --> 'dived'};
is verb(q{withholds})->past_part, q{withheld}  => q{past_part 'withholds' --> 'withheld'};
is verb(q{tread})->past_part, q{trodden}  => q{past_part 'tread' --> 'trodden'};
is verb(q{undergoing})->past_part, q{undergone}  => q{past_part 'undergoing' --> 'undergone'};
is verb(q{forsaking})->past_part, q{forsaken}  => q{past_part 'forsaking' --> 'forsaken'};
is verb(q{expected})->past_part, q{expected}  => q{past_part 'expected' --> 'expected'};
is verb(q{slew})->past_part, q{slain}  => q{past_part 'slew' --> 'slain'};
is verb(q{swells})->past_part, q{swollen}  => q{past_part 'swells' --> 'swollen'};
is verb(q{ache})->past_part, q{ached}  => q{past_part 'ache' --> 'ached'};
is verb(q{rises})->past_part, q{risen}  => q{past_part 'rises' --> 'risen'};
is verb(q{hit})->past_part, q{hit}  => q{past_part 'hit' --> 'hit'};
is verb(q{swollen})->past_part, q{swollen}  => q{past_part 'swollen' --> 'swollen'};
is verb(q{burn})->past_part, q{burnt}  => q{past_part 'burn' --> 'burnt'};
is verb(q{win})->past_part, q{won}  => q{past_part 'win' --> 'won'};
is verb(q{dwelling})->past_part, q{dwelt}  => q{past_part 'dwelling' --> 'dwelt'};
is verb(q{bellyached})->past_part, q{bellyached}  => q{past_part 'bellyached' --> 'bellyached'};
is verb(q{reached})->past_part, q{reached}  => q{past_part 'reached' --> 'reached'};
is verb(q{dares})->past_part, q{dared}  => q{past_part 'dares' --> 'dared'};
is verb(q{dwell})->past_part, q{dwelt}  => q{past_part 'dwell' --> 'dwelt'};
is verb(q{shaved})->past_part, q{shaved}  => q{past_part 'shaved' --> 'shaved'};
is verb(q{misunderstand})->past_part, q{misunderstood}  => q{past_part 'misunderstand' --> 'misunderstood'};
is verb(q{blitzed})->past_part, q{blitzed}  => q{past_part 'blitzed' --> 'blitzed'};
is verb(q{undertaking})->past_part, q{undertaken}  => q{past_part 'undertaking' --> 'undertaken'};
is verb(q{flung})->past_part, q{flung}  => q{past_part 'flung' --> 'flung'};
is verb(q{bled})->past_part, q{bled}  => q{past_part 'bled' --> 'bled'};
is verb(q{proves})->past_part, q{proven}  => q{past_part 'proves' --> 'proven'};
is verb(q{leaves})->past_part, q{left}  => q{past_part 'leaves' --> 'left'};
is verb(q{begetting})->past_part, q{begotten}  => q{past_part 'begetting' --> 'begotten'};
is verb(q{remember})->past_part, q{remembered}  => q{past_part 'remember' --> 'remembered'};
is verb(q{remembering})->past_part, q{remembered}  => q{past_part 'remembering' --> 'remembered'};
is verb(q{treading})->past_part, q{trodden}  => q{past_part 'treading' --> 'trodden'};
is verb(q{expect})->past_part, q{expected}  => q{past_part 'expect' --> 'expected'};
is verb(q{undergo})->past_part, q{undergone}  => q{past_part 'undergo' --> 'undergone'};
is verb(q{getting})->past_part, q{gotten}  => q{past_part 'getting' --> 'gotten'};
is verb(q{sang})->past_part, q{sung}  => q{past_part 'sang' --> 'sung'};
is verb(q{remaining})->past_part, q{remained}  => q{past_part 'remaining' --> 'remained'};
is verb(q{need})->past_part, q{needed}  => q{past_part 'need' --> 'needed'};
is verb(q{tore})->past_part, q{torn}  => q{past_part 'tore' --> 'torn'};
is verb(q{vexes})->past_part, q{vexed}  => q{past_part 'vexes' --> 'vexed'};
is verb(q{sown})->past_part, q{sown}  => q{past_part 'sown' --> 'sown'};
is verb(q{sinking})->past_part, q{sunk}  => q{past_part 'sinking' --> 'sunk'};
is verb(q{shrunk})->past_part, q{shrunk}  => q{past_part 'shrunk' --> 'shrunk'};
is verb(q{felt})->past_part, q{felt}  => q{past_part 'felt' --> 'felt'};
is verb(q{fleeing})->past_part, q{fled}  => q{past_part 'fleeing' --> 'fled'};
is verb(q{forbid})->past_part, q{forbidden}  => q{past_part 'forbid' --> 'forbidden'};
is verb(q{put})->past_part, q{put}  => q{past_part 'put' --> 'put'};
is verb(q{forsake})->past_part, q{forsaken}  => q{past_part 'forsake' --> 'forsaken'};
is verb(q{creching})->past_part, q{creched}  => q{past_part 'creching' --> 'creched'};
is verb(q{drives})->past_part, q{driven}  => q{past_part 'drives' --> 'driven'};
is verb(q{hurt})->past_part, q{hurt}  => q{past_part 'hurt' --> 'hurt'};
is verb(q{gone})->past_part, q{gone}  => q{past_part 'gone' --> 'gone'};
is verb(q{built})->past_part, q{built}  => q{past_part 'built' --> 'built'};
is verb(q{got})->past_part, q{gotten}  => q{past_part 'got' --> 'gotten'};
is verb(q{sit})->past_part, q{sat}  => q{past_part 'sit' --> 'sat'};
is verb(q{stay})->past_part, q{stayed}  => q{past_part 'stay' --> 'stayed'};
is verb(q{stinks})->past_part, q{stunk}  => q{past_part 'stinks' --> 'stunk'};
is verb(q{wearing})->past_part, q{worn}  => q{past_part 'wearing' --> 'worn'};
is verb(q{rived})->past_part, q{riven}  => q{past_part 'rived' --> 'riven'};
is verb(q{biting})->past_part, q{bitten}  => q{past_part 'biting' --> 'bitten'};
is verb(q{sworn})->past_part, q{sworn}  => q{past_part 'sworn' --> 'sworn'};
is verb(q{abiding})->past_part, q{abided}  => q{past_part 'abiding' --> 'abided'};
is verb(q{blows})->past_part, q{blown}  => q{past_part 'blows' --> 'blown'};
is verb(q{woke})->past_part, q{woken}  => q{past_part 'woke' --> 'woken'};
is verb(q{sinks})->past_part, q{sunk}  => q{past_part 'sinks' --> 'sunk'};
is verb(q{striving})->past_part, q{strived}  => q{past_part 'striving' --> 'strived'};
is verb(q{flees})->past_part, q{fled}  => q{past_part 'flees' --> 'fled'};
is verb(q{avalanching})->past_part, q{avalanched}  => q{past_part 'avalanching' --> 'avalanched'};
is verb(q{bred})->past_part, q{bred}  => q{past_part 'bred' --> 'bred'};
is verb(q{spit})->past_part, q{spat}  => q{past_part 'spit' --> 'spat'};
is verb(q{leapt})->past_part, q{leapt}  => q{past_part 'leapt' --> 'leapt'};
is verb(q{loving})->past_part, q{loved}  => q{past_part 'loving' --> 'loved'};
is verb(q{speaks})->past_part, q{spoken}  => q{past_part 'speaks' --> 'spoken'};
is verb(q{forgives})->past_part, q{forgiven}  => q{past_part 'forgives' --> 'forgiven'};
is verb(q{learned})->past_part, q{learned}  => q{past_part 'learned' --> 'learned'};
is verb(q{shaves})->past_part, q{shaved}  => q{past_part 'shaves' --> 'shaved'};
is verb(q{insisting})->past_part, q{insisted}  => q{past_part 'insisting' --> 'insisted'};
is verb(q{wears})->past_part, q{worn}  => q{past_part 'wears' --> 'worn'};
is verb(q{expects})->past_part, q{expected}  => q{past_part 'expects' --> 'expected'};
is verb(q{shakes})->past_part, q{shaken}  => q{past_part 'shakes' --> 'shaken'};
is verb(q{proved})->past_part, q{proven}  => q{past_part 'proved' --> 'proven'};
is verb(q{clings})->past_part, q{clung}  => q{past_part 'clings' --> 'clung'};
is verb(q{go})->past_part, q{gone}  => q{past_part 'go' --> 'gone'};
is verb(q{blowing})->past_part, q{blown}  => q{past_part 'blowing' --> 'blown'};
is verb(q{spitting})->past_part, q{spat}  => q{past_part 'spitting' --> 'spat'};
is verb(q{skis})->past_part, q{skied}  => q{past_part 'skis' --> 'skied'};
is verb(q{fallen})->past_part, q{fallen}  => q{past_part 'fallen' --> 'fallen'};
is verb(q{understand})->past_part, q{understood}  => q{past_part 'understand' --> 'understood'};
is verb(q{rives})->past_part, q{riven}  => q{past_part 'rives' --> 'riven'};
is verb(q{sublets})->past_part, q{sublet}  => q{past_part 'sublets' --> 'sublet'};
is verb(q{mistaking})->past_part, q{mistaken}  => q{past_part 'mistaking' --> 'mistaken'};
is verb(q{dying})->past_part, q{died}  => q{past_part 'dying' --> 'died'};
is verb(q{waiting})->past_part, q{waited}  => q{past_part 'waiting' --> 'waited'};
is verb(q{learning})->past_part, q{learned}  => q{past_part 'learning' --> 'learned'};
is verb(q{sawn})->past_part, q{sawn}  => q{past_part 'sawn' --> 'sawn'};
is verb(q{swings})->past_part, q{swung}  => q{past_part 'swings' --> 'swung'};
is verb(q{helps})->past_part, q{helped}  => q{past_part 'helps' --> 'helped'};
is verb(q{wake})->past_part, q{woken}  => q{past_part 'wake' --> 'woken'};
is verb(q{thrusting})->past_part, q{thrust}  => q{past_part 'thrusting' --> 'thrust'};
is verb(q{foreseen})->past_part, q{foreseen}  => q{past_part 'foreseen' --> 'foreseen'};
is verb(q{stands})->past_part, q{stood}  => q{past_part 'stands' --> 'stood'};
is verb(q{misleading})->past_part, q{misled}  => q{past_part 'misleading' --> 'misled'};
is verb(q{niche})->past_part, q{niched}  => q{past_part 'niche' --> 'niched'};
is verb(q{arose})->past_part, q{arisen}  => q{past_part 'arose' --> 'arisen'};
is verb(q{proven})->past_part, q{proven}  => q{past_part 'proven' --> 'proven'};
is verb(q{vexed})->past_part, q{vexed}  => q{past_part 'vexed' --> 'vexed'};
is verb(q{drinks})->past_part, q{drunk}  => q{past_part 'drinks' --> 'drunk'};
is verb(q{underwent})->past_part, q{undergone}  => q{past_part 'underwent' --> 'undergone'};
is verb(q{strived})->past_part, q{strived}  => q{past_part 'strived' --> 'strived'};
is verb(q{gives})->past_part, q{given}  => q{past_part 'gives' --> 'given'};
is verb(q{subletting})->past_part, q{sublet}  => q{past_part 'subletting' --> 'sublet'};
is verb(q{provides})->past_part, q{provided}  => q{past_part 'provides' --> 'provided'};
is verb(q{fell})->past_part, q{fallen}  => q{past_part 'fell' --> 'fallen'};
is verb(q{stole})->past_part, q{stolen}  => q{past_part 'stole' --> 'stolen'};
is verb(q{breaks})->past_part, q{broken}  => q{past_part 'breaks' --> 'broken'};
is verb(q{shoe})->past_part, q{shod}  => q{past_part 'shoe' --> 'shod'};
is verb(q{begins})->past_part, q{begun}  => q{past_part 'begins' --> 'begun'};
is verb(q{waits})->past_part, q{waited}  => q{past_part 'waits' --> 'waited'};
is verb(q{nicheing})->past_part, q{niched}  => q{past_part 'nicheing' --> 'niched'};
is verb(q{tear})->past_part, q{torn}  => q{past_part 'tear' --> 'torn'};
is verb(q{helping})->past_part, q{helped}  => q{past_part 'helping' --> 'helped'};
is verb(q{creched})->past_part, q{creched}  => q{past_part 'creched' --> 'creched'};
is verb(q{learn})->past_part, q{learned}  => q{past_part 'learn' --> 'learned'};
is verb(q{fought})->past_part, q{fought}  => q{past_part 'fought' --> 'fought'};
is verb(q{walked})->past_part, q{walked}  => q{past_part 'walked' --> 'walked'};
is verb(q{misunderstood})->past_part, q{misunderstood}  => q{past_part 'misunderstood' --> 'misunderstood'};
is verb(q{dies})->past_part, q{died}  => q{past_part 'dies' --> 'died'};
is verb(q{chooses})->past_part, q{chosen}  => q{past_part 'chooses' --> 'chosen'};
is verb(q{bit})->past_part, q{bitten}  => q{past_part 'bit' --> 'bitten'};
is verb(q{leap})->past_part, q{leapt}  => q{past_part 'leap' --> 'leapt'};
is verb(q{sunk})->past_part, q{sunk}  => q{past_part 'sunk' --> 'sunk'};
is verb(q{mislead})->past_part, q{misled}  => q{past_part 'mislead' --> 'misled'};
is verb(q{sped})->past_part, q{sped}  => q{past_part 'sped' --> 'sped'};
is verb(q{dig})->past_part, q{dug}  => q{past_part 'dig' --> 'dug'};
is verb(q{sublet})->past_part, q{sublet}  => q{past_part 'sublet' --> 'sublet'};
is verb(q{fling})->past_part, q{flung}  => q{past_part 'fling' --> 'flung'};
is verb(q{came})->past_part, q{come}  => q{past_part 'came' --> 'come'};
is verb(q{feeling})->past_part, q{felt}  => q{past_part 'feeling' --> 'felt'};
is verb(q{woken})->past_part, q{woken}  => q{past_part 'woken' --> 'woken'};
is verb(q{burnt})->past_part, q{burnt}  => q{past_part 'burnt' --> 'burnt'};
is verb(q{shaken})->past_part, q{shaken}  => q{past_part 'shaken' --> 'shaken'};
is verb(q{menued})->past_part, q{menued}  => q{past_part 'menued' --> 'menued'};
is verb(q{torn})->past_part, q{torn}  => q{past_part 'torn' --> 'torn'};
is verb(q{drags})->past_part, q{dragged}  => q{past_part 'drags' --> 'dragged'};
is verb(q{meet})->past_part, q{met}  => q{past_part 'meet' --> 'met'};
is verb(q{slinking})->past_part, q{slunk}  => q{past_part 'slinking' --> 'slunk'};
is verb(q{blitzing})->past_part, q{blitzed}  => q{past_part 'blitzing' --> 'blitzed'};
is verb(q{wends})->past_part, q{wended}  => q{past_part 'wends' --> 'wended'};
is verb(q{dives})->past_part, q{dived}  => q{past_part 'dives' --> 'dived'};
is verb(q{mistake})->past_part, q{mistaken}  => q{past_part 'mistake' --> 'mistaken'};
is verb(q{trodden})->past_part, q{trodden}  => q{past_part 'trodden' --> 'trodden'};
is verb(q{finding})->past_part, q{found}  => q{past_part 'finding' --> 'found'};
is verb(q{reaching})->past_part, q{reached}  => q{past_part 'reaching' --> 'reached'};
is verb(q{seeming})->past_part, q{seemed}  => q{past_part 'seeming' --> 'seemed'};
is verb(q{remembers})->past_part, q{remembered}  => q{past_part 'remembers' --> 'remembered'};
is verb(q{skied})->past_part, q{skied}  => q{past_part 'skied' --> 'skied'};
is verb(q{striding})->past_part, q{strode}  => q{past_part 'striding' --> 'strode'};
is verb(q{ridding})->past_part, q{rid}  => q{past_part 'ridding' --> 'rid'};
is verb(q{kills})->past_part, q{killed}  => q{past_part 'kills' --> 'killed'};
is verb(q{rending})->past_part, q{rent}  => q{past_part 'rending' --> 'rent'};
is verb(q{want})->past_part, q{wanted}  => q{past_part 'want' --> 'wanted'};
is verb(q{beating})->past_part, q{beaten}  => q{past_part 'beating' --> 'beaten'};
is verb(q{reach})->past_part, q{reached}  => q{past_part 'reach' --> 'reached'};
is verb(q{losing})->past_part, q{lost}  => q{past_part 'losing' --> 'lost'};
is verb(q{withhold})->past_part, q{withheld}  => q{past_part 'withhold' --> 'withheld'};
is verb(q{slitting})->past_part, q{slit}  => q{past_part 'slitting' --> 'slit'};
is verb(q{blew})->past_part, q{blown}  => q{past_part 'blew' --> 'blown'};
is verb(q{cost})->past_part, q{cost}  => q{past_part 'cost' --> 'cost'};
is verb(q{withholding})->past_part, q{withheld}  => q{past_part 'withholding' --> 'withheld'};
is verb(q{asking})->past_part, q{asked}  => q{past_part 'asking' --> 'asked'};
is verb(q{slink})->past_part, q{slunk}  => q{past_part 'slink' --> 'slunk'};
is verb(q{blitz})->past_part, q{blitzed}  => q{past_part 'blitz' --> 'blitzed'};
is verb(q{forgot})->past_part, q{forgotten}  => q{past_part 'forgot' --> 'forgotten'};
is verb(q{feels})->past_part, q{felt}  => q{past_part 'feels' --> 'felt'};
is verb(q{ring})->past_part, q{rung}  => q{past_part 'ring' --> 'rung'};
is verb(q{provided})->past_part, q{provided}  => q{past_part 'provided' --> 'provided'};
is verb(q{irising})->past_part, q{irised}  => q{past_part 'irising' --> 'irised'};
is verb(q{flinging})->past_part, q{flung}  => q{past_part 'flinging' --> 'flung'};
is verb(q{changed})->past_part, q{changed}  => q{past_part 'changed' --> 'changed'};
is verb(q{wending})->past_part, q{wended}  => q{past_part 'wending' --> 'wended'};
is verb(q{live})->past_part, q{lived}  => q{past_part 'live' --> 'lived'};
is verb(q{finds})->past_part, q{found}  => q{past_part 'finds' --> 'found'};
is verb(q{choose})->past_part, q{chosen}  => q{past_part 'choose' --> 'chosen'};
is verb(q{gets})->past_part, q{gotten}  => q{past_part 'gets' --> 'gotten'};
is verb(q{knelt})->past_part, q{knelt}  => q{past_part 'knelt' --> 'knelt'};
is verb(q{shrinking})->past_part, q{shrunk}  => q{past_part 'shrinking' --> 'shrunk'};
is verb(q{dared})->past_part, q{dared}  => q{past_part 'dared' --> 'dared'};
is verb(q{seems})->past_part, q{seemed}  => q{past_part 'seems' --> 'seemed'};
is verb(q{rends})->past_part, q{rent}  => q{past_part 'rends' --> 'rent'};
is verb(q{killing})->past_part, q{killed}  => q{past_part 'killing' --> 'killed'};
is verb(q{driven})->past_part, q{driven}  => q{past_part 'driven' --> 'driven'};
is verb(q{lead})->past_part, q{led}  => q{past_part 'lead' --> 'led'};
is verb(q{beats})->past_part, q{beaten}  => q{past_part 'beats' --> 'beaten'};
is verb(q{withheld})->past_part, q{withheld}  => q{past_part 'withheld' --> 'withheld'};
is verb(q{die})->past_part, q{died}  => q{past_part 'die' --> 'died'};
is verb(q{shrink})->past_part, q{shrunk}  => q{past_part 'shrink' --> 'shrunk'};
is verb(q{flew})->past_part, q{flown}  => q{past_part 'flew' --> 'flown'};
is verb(q{claps})->past_part, q{clapped}  => q{past_part 'claps' --> 'clapped'};
is verb(q{diving})->past_part, q{dived}  => q{past_part 'diving' --> 'dived'};
is verb(q{grinding})->past_part, q{ground}  => q{past_part 'grinding' --> 'ground'};
is verb(q{shook})->past_part, q{shaken}  => q{past_part 'shook' --> 'shaken'};
is verb(q{gave})->past_part, q{given}  => q{past_part 'gave' --> 'given'};
is verb(q{creche})->past_part, q{creched}  => q{past_part 'creche' --> 'creched'};
is verb(q{spoilt})->past_part, q{spoiled}  => q{past_part 'spoilt' --> 'spoiled'};
is verb(q{sneaked})->past_part, q{sneaked}  => q{past_part 'sneaked' --> 'sneaked'};
is verb(q{dreamed})->past_part, q{dreamed}  => q{past_part 'dreamed' --> 'dreamed'};
is verb(q{binds})->past_part, q{bound}  => q{past_part 'binds' --> 'bound'};
is verb(q{busts})->past_part, q{bust}  => q{past_part 'busts' --> 'bust'};
is verb(q{went})->past_part, q{gone}  => q{past_part 'went' --> 'gone'};
is verb(q{continues})->past_part, q{continued}  => q{past_part 'continues' --> 'continued'};
is verb(q{quitting})->past_part, q{quit}  => q{past_part 'quitting' --> 'quit'};
is verb(q{breed})->past_part, q{bred}  => q{past_part 'breed' --> 'bred'};
is verb(q{changes})->past_part, q{changed}  => q{past_part 'changes' --> 'changed'};
is verb(q{hewn})->past_part, q{hewn}  => q{past_part 'hewn' --> 'hewn'};
is verb(q{inlays})->past_part, q{inlaid}  => q{past_part 'inlays' --> 'inlaid'};
is verb(q{mistakes})->past_part, q{mistaken}  => q{past_part 'mistakes' --> 'mistaken'};
is verb(q{breeding})->past_part, q{bred}  => q{past_part 'breeding' --> 'bred'};
is verb(q{thrusts})->past_part, q{thrust}  => q{past_part 'thrusts' --> 'thrust'};
is verb(q{smelled})->past_part, q{smelled}  => q{past_part 'smelled' --> 'smelled'};
is verb(q{being})->past_part, q{been}  => q{past_part 'being' --> 'been'};
is verb(q{dealt})->past_part, q{dealt}  => q{past_part 'dealt' --> 'dealt'};
is verb(q{ground})->past_part, q{ground}  => q{past_part 'ground' --> 'ground'};
is verb(q{steals})->past_part, q{stolen}  => q{past_part 'steals' --> 'stolen'};
is verb(q{broke})->past_part, q{broken}  => q{past_part 'broke' --> 'broken'};
is verb(q{grind})->past_part, q{ground}  => q{past_part 'grind' --> 'ground'};
is verb(q{needed})->past_part, q{needed}  => q{past_part 'needed' --> 'needed'};
is verb(q{binding})->past_part, q{bound}  => q{past_part 'binding' --> 'bound'};
is verb(q{busting})->past_part, q{bust}  => q{past_part 'busting' --> 'bust'};
is verb(q{providing})->past_part, q{provided}  => q{past_part 'providing' --> 'provided'};
is verb(q{mean})->past_part, q{meant}  => q{past_part 'mean' --> 'meant'};
is verb(q{arise})->past_part, q{arisen}  => q{past_part 'arise' --> 'arisen'};
is verb(q{stood})->past_part, q{stood}  => q{past_part 'stood' --> 'stood'};
is verb(q{loses})->past_part, q{lost}  => q{past_part 'loses' --> 'lost'};
is verb(q{putting})->past_part, q{put}  => q{past_part 'putting' --> 'put'};
is verb(q{rent})->past_part, q{rent}  => q{past_part 'rent' --> 'rent'};
is verb(q{kneels})->past_part, q{knelt}  => q{past_part 'kneels' --> 'knelt'};
is verb(q{ski})->past_part, q{skied}  => q{past_part 'ski' --> 'skied'};
is verb(q{sitting})->past_part, q{sat}  => q{past_part 'sitting' --> 'sat'};
is verb(q{strive})->past_part, q{strived}  => q{past_part 'strive' --> 'strived'};
is verb(q{caching})->past_part, q{cached}  => q{past_part 'caching' --> 'cached'};
is verb(q{forsook})->past_part, q{forsaken}  => q{past_part 'forsook' --> 'forsaken'};
is verb(q{talking})->past_part, q{talked}  => q{past_part 'talking' --> 'talked'};
is verb(q{giving})->past_part, q{given}  => q{past_part 'giving' --> 'given'};
is verb(q{get})->past_part, q{gotten}  => q{past_part 'get' --> 'gotten'};
is verb(q{shrinks})->past_part, q{shrunk}  => q{past_part 'shrinks' --> 'shrunk'};
is verb(q{rose})->past_part, q{risen}  => q{past_part 'rose' --> 'risen'};
is verb(q{bend})->past_part, q{bent}  => q{past_part 'bend' --> 'bent'};
is verb(q{sweated})->past_part, q{sweated}  => q{past_part 'sweated' --> 'sweated'};
is verb(q{chosen})->past_part, q{chosen}  => q{past_part 'chosen' --> 'chosen'};
is verb(q{misleads})->past_part, q{misled}  => q{past_part 'misleads' --> 'misled'};
is verb(q{move})->past_part, q{moved}  => q{past_part 'move' --> 'moved'};
is verb(q{ride})->past_part, q{ridden}  => q{past_part 'ride' --> 'ridden'};
is verb(q{bringing})->past_part, q{brought}  => q{past_part 'bringing' --> 'brought'};
is verb(q{change})->past_part, q{changed}  => q{past_part 'change' --> 'changed'};
is verb(q{creep})->past_part, q{crept}  => q{past_part 'creep' --> 'crept'};
is verb(q{strewed})->past_part, q{strewn}  => q{past_part 'strewed' --> 'strewn'};
is verb(q{bleed})->past_part, q{bled}  => q{past_part 'bleed' --> 'bled'};
is verb(q{stayed})->past_part, q{stayed}  => q{past_part 'stayed' --> 'stayed'};
is verb(q{seek})->past_part, q{sought}  => q{past_part 'seek' --> 'sought'};
is verb(q{spend})->past_part, q{spent}  => q{past_part 'spend' --> 'spent'};
is verb(q{creches})->past_part, q{creched}  => q{past_part 'creches' --> 'creched'};
is verb(q{riving})->past_part, q{riven}  => q{past_part 'riving' --> 'riven'};
is verb(q{like})->past_part, q{liked}  => q{past_part 'like' --> 'liked'};
is verb(q{stings})->past_part, q{stung}  => q{past_part 'stings' --> 'stung'};
is verb(q{stopping})->past_part, q{stopped}  => q{past_part 'stopping' --> 'stopped'};
is verb(q{bellyaches})->past_part, q{bellyached}  => q{past_part 'bellyaches' --> 'bellyached'};
is verb(q{bleeding})->past_part, q{bled}  => q{past_part 'bleeding' --> 'bled'};
is verb(q{builds})->past_part, q{built}  => q{past_part 'builds' --> 'built'};
is verb(q{shit})->past_part, q{shitted}  => q{past_part 'shit' --> 'shitted'};
is verb(q{spending})->past_part, q{spent}  => q{past_part 'spending' --> 'spent'};
is verb(q{arising})->past_part, q{arisen}  => q{past_part 'arising' --> 'arisen'};
is verb(q{talks})->past_part, q{talked}  => q{past_part 'talks' --> 'talked'};
is verb(q{hitting})->past_part, q{hit}  => q{past_part 'hitting' --> 'hit'};
is verb(q{overhears})->past_part, q{overheard}  => q{past_part 'overhears' --> 'overheard'};
is verb(q{cache})->past_part, q{cached}  => q{past_part 'cache' --> 'cached'};
is verb(q{strode})->past_part, q{strode}  => q{past_part 'strode' --> 'strode'};
is verb(q{thrust})->past_part, q{thrust}  => q{past_part 'thrust' --> 'thrust'};
is verb(q{creeping})->past_part, q{crept}  => q{past_part 'creeping' --> 'crept'};
is verb(q{fall})->past_part, q{fallen}  => q{past_part 'fall' --> 'fallen'};
is verb(q{bring})->past_part, q{brought}  => q{past_part 'bring' --> 'brought'};
is verb(q{provide})->past_part, q{provided}  => q{past_part 'provide' --> 'provided'};
is verb(q{spoils})->past_part, q{spoiled}  => q{past_part 'spoils' --> 'spoiled'};
is verb(q{strives})->past_part, q{strived}  => q{past_part 'strives' --> 'strived'};
is verb(q{shitted})->past_part, q{shitted}  => q{past_part 'shitted' --> 'shitted'};
is verb(q{stank})->past_part, q{stunk}  => q{past_part 'stank' --> 'stunk'};
is verb(q{loved})->past_part, q{loved}  => q{past_part 'loved' --> 'loved'};
is verb(q{sung})->past_part, q{sung}  => q{past_part 'sung' --> 'sung'};
is verb(q{vex})->past_part, q{vexed}  => q{past_part 'vex' --> 'vexed'};
is verb(q{know})->past_part, q{known}  => q{past_part 'know' --> 'known'};
is verb(q{digs})->past_part, q{dug}  => q{past_part 'digs' --> 'dug'};
is verb(q{knitting})->past_part, q{knitted}  => q{past_part 'knitting' --> 'knitted'};
is verb(q{swell})->past_part, q{swollen}  => q{past_part 'swell' --> 'swollen'};
is verb(q{laid})->past_part, q{laid}  => q{past_part 'laid' --> 'laid'};
is verb(q{driving})->past_part, q{driven}  => q{past_part 'driving' --> 'driven'};
is verb(q{stolen})->past_part, q{stolen}  => q{past_part 'stolen' --> 'stolen'};
is verb(q{forgiven})->past_part, q{forgiven}  => q{past_part 'forgiven' --> 'forgiven'};
is verb(q{dragged})->past_part, q{dragged}  => q{past_part 'dragged' --> 'dragged'};
is verb(q{means})->past_part, q{meant}  => q{past_part 'means' --> 'meant'};
is verb(q{bound})->past_part, q{bound}  => q{past_part 'bound' --> 'bound'};
is verb(q{psyches})->past_part, q{psyched}  => q{past_part 'psyches' --> 'psyched'};
is verb(q{lose})->past_part, q{lost}  => q{past_part 'lose' --> 'lost'};
is verb(q{saw})->past_part, q{sawn}  => q{past_part 'saw' --> 'sawn'};
is verb(q{begot})->past_part, q{begotten}  => q{past_part 'begot' --> 'begotten'};
is verb(q{abides})->past_part, q{abided}  => q{past_part 'abides' --> 'abided'};
is verb(q{lie})->past_part, q{lain}  => q{past_part 'lie' --> 'lain'};
is verb(q{brought})->past_part, q{brought}  => q{past_part 'brought' --> 'brought'};
is verb(q{living})->past_part, q{lived}  => q{past_part 'living' --> 'lived'};
is verb(q{clapped})->past_part, q{clapped}  => q{past_part 'clapped' --> 'clapped'};
is verb(q{flying})->past_part, q{flown}  => q{past_part 'flying' --> 'flown'};
is verb(q{thriving})->past_part, q{thrived}  => q{past_part 'thriving' --> 'thrived'};
is verb(q{flown})->past_part, q{flown}  => q{past_part 'flown' --> 'flown'};
is verb(q{treads})->past_part, q{trodden}  => q{past_part 'treads' --> 'trodden'};
is verb(q{continuing})->past_part, q{continued}  => q{past_part 'continuing' --> 'continued'};
is verb(q{bust})->past_part, q{bust}  => q{past_part 'bust' --> 'bust'};
is verb(q{been})->past_part, q{been}  => q{past_part 'been' --> 'been'};
is verb(q{ridden})->past_part, q{ridden}  => q{past_part 'ridden' --> 'ridden'};
is verb(q{beaten})->past_part, q{beaten}  => q{past_part 'beaten' --> 'beaten'};
is verb(q{happens})->past_part, q{happened}  => q{past_part 'happens' --> 'happened'};
is verb(q{bind})->past_part, q{bound}  => q{past_part 'bind' --> 'bound'};
is verb(q{quizzes})->past_part, q{quizzed}  => q{past_part 'quizzes' --> 'quizzed'};
is verb(q{misled})->past_part, q{misled}  => q{past_part 'misled' --> 'misled'};
is verb(q{meaning})->past_part, q{meant}  => q{past_part 'meaning' --> 'meant'};
is verb(q{becoming})->past_part, q{become}  => q{past_part 'becoming' --> 'become'};
is verb(q{shaking})->past_part, q{shaken}  => q{past_part 'shaking' --> 'shaken'};
is verb(q{dwells})->past_part, q{dwelt}  => q{past_part 'dwells' --> 'dwelt'};
is verb(q{withstanding})->past_part, q{withstood}  => q{past_part 'withstanding' --> 'withstood'};
is verb(q{swelling})->past_part, q{swollen}  => q{past_part 'swelling' --> 'swollen'};
is verb(q{behold})->past_part, q{beheld}  => q{past_part 'behold' --> 'beheld'};
is verb(q{clap})->past_part, q{clapped}  => q{past_part 'clap' --> 'clapped'};
is verb(q{sowing})->past_part, q{sown}  => q{past_part 'sowing' --> 'sown'};
is verb(q{hews})->past_part, q{hewn}  => q{past_part 'hews' --> 'hewn'};
is verb(q{shod})->past_part, q{shod}  => q{past_part 'shod' --> 'shod'};
is verb(q{springs})->past_part, q{sprung}  => q{past_part 'springs' --> 'sprung'};
is verb(q{shaving})->past_part, q{shaved}  => q{past_part 'shaving' --> 'shaved'};
is verb(q{leave})->past_part, q{left}  => q{past_part 'leave' --> 'left'};
is verb(q{prove})->past_part, q{proven}  => q{past_part 'prove' --> 'proven'};
is verb(q{smote})->past_part, q{smitten}  => q{past_part 'smote' --> 'smitten'};
is verb(q{psyche})->past_part, q{psyched}  => q{past_part 'psyche' --> 'psyched'};
is verb(q{flies})->past_part, q{flown}  => q{past_part 'flies' --> 'flown'};
is verb(q{upsetting})->past_part, q{upset}  => q{past_part 'upsetting' --> 'upset'};
is verb(q{stink})->past_part, q{stunk}  => q{past_part 'stink' --> 'stunk'};
is verb(q{abided})->past_part, q{abided}  => q{past_part 'abided' --> 'abided'};
is verb(q{happened})->past_part, q{happened}  => q{past_part 'happened' --> 'happened'};
is verb(q{rang})->past_part, q{rung}  => q{past_part 'rang' --> 'rung'};
is verb(q{swum})->past_part, q{swum}  => q{past_part 'swum' --> 'swum'};
is verb(q{misunderstands})->past_part, q{misunderstood}  => q{past_part 'misunderstands' --> 'misunderstood'};
is verb(q{seeking})->past_part, q{sought}  => q{past_part 'seeking' --> 'sought'};
is verb(q{knows})->past_part, q{known}  => q{past_part 'knows' --> 'known'};
is verb(q{running})->past_part, q{run}  => q{past_part 'running' --> 'run'};
is verb(q{begotten})->past_part, q{begotten}  => q{past_part 'begotten' --> 'begotten'};
is verb(q{undergone})->past_part, q{undergone}  => q{past_part 'undergone' --> 'undergone'};
is verb(q{watches})->past_part, q{watched}  => q{past_part 'watches' --> 'watched'};
is verb(q{shits})->past_part, q{shitted}  => q{past_part 'shits' --> 'shitted'};
is verb(q{clinging})->past_part, q{clung}  => q{past_part 'clinging' --> 'clung'};
is verb(q{shat})->past_part, q{shitted}  => q{past_part 'shat' --> 'shitted'};
is verb(q{undertaken})->past_part, q{undertaken}  => q{past_part 'undertaken' --> 'undertaken'};
is verb(q{talk})->past_part, q{talked}  => q{past_part 'talk' --> 'talked'};
is verb(q{speaking})->past_part, q{spoken}  => q{past_part 'speaking' --> 'spoken'};
is verb(q{drive})->past_part, q{driven}  => q{past_part 'drive' --> 'driven'};
is verb(q{overtake})->past_part, q{overtaken}  => q{past_part 'overtake' --> 'overtaken'};
is verb(q{foretelling})->past_part, q{foretold}  => q{past_part 'foretelling' --> 'foretold'};
is verb(q{foretell})->past_part, q{foretold}  => q{past_part 'foretell' --> 'foretold'};
is verb(q{bending})->past_part, q{bent}  => q{past_part 'bending' --> 'bent'};
is verb(q{douching})->past_part, q{douched}  => q{past_part 'douching' --> 'douched'};
is verb(q{falls})->past_part, q{fallen}  => q{past_part 'falls' --> 'fallen'};
is verb(q{am})->past_part, q{been}  => q{past_part 'am' --> 'been'};
is verb(q{sunburns})->past_part, q{sunburned}  => q{past_part 'sunburns' --> 'sunburned'};
is verb(q{hewed})->past_part, q{hewn}  => q{past_part 'hewed' --> 'hewn'};
is verb(q{shedding})->past_part, q{shed}  => q{past_part 'shedding' --> 'shed'};
is verb(q{speak})->past_part, q{spoken}  => q{past_part 'speak' --> 'spoken'};
is verb(q{shown})->past_part, q{shown}  => q{past_part 'shown' --> 'shown'};
is verb(q{moves})->past_part, q{moved}  => q{past_part 'moves' --> 'moved'};
is verb(q{runs})->past_part, q{run}  => q{past_part 'runs' --> 'run'};
is verb(q{shave})->past_part, q{shaved}  => q{past_part 'shave' --> 'shaved'};
is verb(q{rides})->past_part, q{ridden}  => q{past_part 'rides' --> 'ridden'};
is verb(q{leaving})->past_part, q{left}  => q{past_part 'leaving' --> 'left'};
is verb(q{lost})->past_part, q{lost}  => q{past_part 'lost' --> 'lost'};
is verb(q{proving})->past_part, q{proven}  => q{past_part 'proving' --> 'proven'};
is verb(q{overdrew})->past_part, q{overdrawn}  => q{past_part 'overdrew' --> 'overdrawn'};
is verb(q{spent})->past_part, q{spent}  => q{past_part 'spent' --> 'spent'};
is verb(q{shake})->past_part, q{shaken}  => q{past_part 'shake' --> 'shaken'};
is verb(q{drunk})->past_part, q{drunk}  => q{past_part 'drunk' --> 'drunk'};
is verb(q{likes})->past_part, q{liked}  => q{past_part 'likes' --> 'liked'};
is verb(q{happen})->past_part, q{happened}  => q{past_part 'happen' --> 'happened'};
is verb(q{bets})->past_part, q{bet}  => q{past_part 'bets' --> 'bet'};
is verb(q{seeks})->past_part, q{sought}  => q{past_part 'seeks' --> 'sought'};
is verb(q{knowing})->past_part, q{known}  => q{past_part 'knowing' --> 'known'};
is verb(q{cling})->past_part, q{clung}  => q{past_part 'cling' --> 'clung'};
is verb(q{spring})->past_part, q{sprung}  => q{past_part 'spring' --> 'sprung'};
is verb(q{beholds})->past_part, q{beheld}  => q{past_part 'beholds' --> 'beheld'};
is verb(q{won})->past_part, q{won}  => q{past_part 'won' --> 'won'};
is verb(q{stinking})->past_part, q{stunk}  => q{past_part 'stinking' --> 'stunk'};
is verb(q{waking})->past_part, q{woken}  => q{past_part 'waking' --> 'woken'};
is verb(q{bends})->past_part, q{bent}  => q{past_part 'bends' --> 'bent'};
is verb(q{falling})->past_part, q{fallen}  => q{past_part 'falling' --> 'fallen'};
is verb(q{swung})->past_part, q{swung}  => q{past_part 'swung' --> 'swung'};
is verb(q{hew})->past_part, q{hewn}  => q{past_part 'hew' --> 'hewn'};
is verb(q{swore})->past_part, q{sworn}  => q{past_part 'swore' --> 'sworn'};
is verb(q{strews})->past_part, q{strewn}  => q{past_part 'strews' --> 'strewn'};
is verb(q{overdrawn})->past_part, q{overdrawn}  => q{past_part 'overdrawn' --> 'overdrawn'};
is verb(q{broken})->past_part, q{broken}  => q{past_part 'broken' --> 'broken'};
is verb(q{leaps})->past_part, q{leapt}  => q{past_part 'leaps' --> 'leapt'};
is verb(q{beheld})->past_part, q{beheld}  => q{past_part 'beheld' --> 'beheld'};
is verb(q{springing})->past_part, q{sprung}  => q{past_part 'springing' --> 'sprung'};
is verb(q{withdraw})->past_part, q{withdrawn}  => q{past_part 'withdraw' --> 'withdrawn'};
is verb(q{is})->past_part, q{been}  => q{past_part 'is' --> 'been'};
is verb(q{stung})->past_part, q{stung}  => q{past_part 'stung' --> 'stung'};
is verb(q{sunburn})->past_part, q{sunburned}  => q{past_part 'sunburn' --> 'sunburned'};
is verb(q{withdrawing})->past_part, q{withdrawn}  => q{past_part 'withdrawing' --> 'withdrawn'};
is verb(q{happening})->past_part, q{happened}  => q{past_part 'happening' --> 'happened'};
is verb(q{shoes})->past_part, q{shod}  => q{past_part 'shoes' --> 'shod'};
is verb(q{lying})->past_part, q{lain}  => q{past_part 'lying' --> 'lain'};
is verb(q{wait})->past_part, q{waited}  => q{past_part 'wait' --> 'waited'};
is verb(q{tears})->past_part, q{torn}  => q{past_part 'tears' --> 'torn'};
is verb(q{sweats})->past_part, q{sweated}  => q{past_part 'sweats' --> 'sweated'};
is verb(q{fight})->past_part, q{fought}  => q{past_part 'fight' --> 'fought'};
is verb(q{arisen})->past_part, q{arisen}  => q{past_part 'arisen' --> 'arisen'};
is verb(q{beget})->past_part, q{begotten}  => q{past_part 'beget' --> 'begotten'};
is verb(q{wore})->past_part, q{worn}  => q{past_part 'wore' --> 'worn'};
is verb(q{was})->past_part, q{been}  => q{past_part 'was' --> 'been'};
is verb(q{fighting})->past_part, q{fought}  => q{past_part 'fighting' --> 'fought'};
is verb(q{wakes})->past_part, q{woken}  => q{past_part 'wakes' --> 'woken'};
is verb(q{slides})->past_part, q{slid}  => q{past_part 'slides' --> 'slid'};
is verb(q{gilded})->past_part, q{gilded}  => q{past_part 'gilded' --> 'gilded'};
is verb(q{leaping})->past_part, q{leapt}  => q{past_part 'leaping' --> 'leapt'};
is verb(q{lies})->past_part, q{lain}  => q{past_part 'lies' --> 'lain'};
is verb(q{give})->past_part, q{given}  => q{past_part 'give' --> 'given'};
is verb(q{saws})->past_part, q{sawn}  => q{past_part 'saws' --> 'sawn'};
is verb(q{rive})->past_part, q{riven}  => q{past_part 'rive' --> 'riven'};
is verb(q{awakes})->past_part, q{awoken}  => q{past_part 'awakes' --> 'awoken'};
is verb(q{liking})->past_part, q{liked}  => q{past_part 'liking' --> 'liked'};
is verb(q{staves})->past_part, q{staved}  => q{past_part 'staves' --> 'staved'};
is verb(q{risen})->past_part, q{risen}  => q{past_part 'risen' --> 'risen'};
is verb(q{shoeing})->past_part, q{shod}  => q{past_part 'shoeing' --> 'shod'};
is verb(q{avalanches})->past_part, q{avalanched}  => q{past_part 'avalanches' --> 'avalanched'};
is verb(q{smiting})->past_part, q{smitten}  => q{past_part 'smiting' --> 'smitten'};
is verb(q{catches})->past_part, q{caught}  => q{past_part 'catches' --> 'caught'};
is verb(q{bent})->past_part, q{bent}  => q{past_part 'bent' --> 'bent'};
is verb(q{crept})->past_part, q{crept}  => q{past_part 'crept' --> 'crept'};
is verb(q{sunburning})->past_part, q{sunburned}  => q{past_part 'sunburning' --> 'sunburned'};
is verb(q{help})->past_part, q{helped}  => q{past_part 'help' --> 'helped'};
is verb(q{watched})->past_part, q{watched}  => q{past_part 'watched' --> 'watched'};
is verb(q{tearing})->past_part, q{torn}  => q{past_part 'tearing' --> 'torn'};
is verb(q{began})->past_part, q{begun}  => q{past_part 'began' --> 'begun'};
is verb(q{riding})->past_part, q{ridden}  => q{past_part 'riding' --> 'ridden'};
is verb(q{moving})->past_part, q{moved}  => q{past_part 'moving' --> 'moved'};
is verb(q{spoiled})->past_part, q{spoiled}  => q{past_part 'spoiled' --> 'spoiled'};
is verb(q{find})->past_part, q{found}  => q{past_part 'find' --> 'found'};
is verb(q{gotten})->past_part, q{gotten}  => q{past_part 'gotten' --> 'gotten'};
is verb(q{lives})->past_part, q{lived}  => q{past_part 'lives' --> 'lived'};
is verb(q{sneaks})->past_part, q{sneaked}  => q{past_part 'sneaks' --> 'sneaked'};
is verb(q{dreams})->past_part, q{dreamed}  => q{past_part 'dreams' --> 'dreamed'};
is verb(q{beholding})->past_part, q{beheld}  => q{past_part 'beholding' --> 'beheld'};
is verb(q{forsaken})->past_part, q{forsaken}  => q{past_part 'forsaken' --> 'forsaken'};
is verb(q{meeting})->past_part, q{met}  => q{past_part 'meeting' --> 'met'};
is verb(q{upsets})->past_part, q{upset}  => q{past_part 'upsets' --> 'upset'};
is verb(q{wring})->past_part, q{wrung}  => q{past_part 'wring' --> 'wrung'};
is verb(q{quizzed})->past_part, q{quizzed}  => q{past_part 'quizzed' --> 'quizzed'};
is verb(q{rend})->past_part, q{rent}  => q{past_part 'rend' --> 'rent'};
is verb(q{leads})->past_part, q{led}  => q{past_part 'leads' --> 'led'};
is verb(q{wanting})->past_part, q{wanted}  => q{past_part 'wanting' --> 'wanted'};
is verb(q{beat})->past_part, q{beaten}  => q{past_part 'beat' --> 'beaten'};
is verb(q{seem})->past_part, q{seemed}  => q{past_part 'seem' --> 'seemed'};
is verb(q{foresaw})->past_part, q{foreseen}  => q{past_part 'foresaw' --> 'foreseen'};
is verb(q{bet})->past_part, q{bet}  => q{past_part 'bet' --> 'bet'};
is verb(q{had})->past_part, q{had}  => q{past_part 'had' --> 'had'};
is verb(q{bursting})->past_part, q{burst}  => q{past_part 'bursting' --> 'burst'};
is verb(q{costs})->past_part, q{cost}  => q{past_part 'costs' --> 'cost'};
is verb(q{run})->past_part, q{run}  => q{past_part 'run' --> 'run'};
is verb(q{feel})->past_part, q{felt}  => q{past_part 'feel' --> 'felt'};
is verb(q{rings})->past_part, q{rung}  => q{past_part 'rings' --> 'rung'};
is verb(q{speeds})->past_part, q{sped}  => q{past_part 'speeds' --> 'sped'};
is verb(q{eating})->past_part, q{eaten}  => q{past_part 'eating' --> 'eaten'};
is verb(q{swears})->past_part, q{sworn}  => q{past_part 'swears' --> 'sworn'};
is verb(q{staved})->past_part, q{staved}  => q{past_part 'staved' --> 'staved'};
is verb(q{psyched})->past_part, q{psyched}  => q{past_part 'psyched' --> 'psyched'};
is verb(q{drag})->past_part, q{dragged}  => q{past_part 'drag' --> 'dragged'};
is verb(q{withstand})->past_part, q{withstood}  => q{past_part 'withstand' --> 'withstood'};
is verb(q{meets})->past_part, q{met}  => q{past_part 'meets' --> 'met'};
is verb(q{dive})->past_part, q{dived}  => q{past_part 'dive' --> 'dived'};
is verb(q{wend})->past_part, q{wended}  => q{past_part 'wend' --> 'wended'};
is verb(q{kill})->past_part, q{killed}  => q{past_part 'kill' --> 'killed'};
is verb(q{wants})->past_part, q{wanted}  => q{past_part 'wants' --> 'wanted'};
is verb(q{leading})->past_part, q{led}  => q{past_part 'leading' --> 'led'};
is verb(q{found})->past_part, q{found}  => q{past_part 'found' --> 'found'};
is verb(q{chose})->past_part, q{chosen}  => q{past_part 'chose' --> 'chosen'};
is verb(q{strip})->past_part, q{stripped}  => q{past_part 'strip' --> 'stripped'};
is verb(q{looked})->past_part, q{looked}  => q{past_part 'looked' --> 'looked'};
is verb(q{burst})->past_part, q{burst}  => q{past_part 'burst' --> 'burst'};
is verb(q{smite})->past_part, q{smitten}  => q{past_part 'smite' --> 'smitten'};
is verb(q{interlaying})->past_part, q{interlaid}  => q{past_part 'interlaying' --> 'interlaid'};
is verb(q{sawed})->past_part, q{sawn}  => q{past_part 'sawed' --> 'sawn'};
is verb(q{overtook})->past_part, q{overtaken}  => q{past_part 'overtook' --> 'overtaken'};
is verb(q{laying})->past_part, q{laid}  => q{past_part 'laying' --> 'laid'};
is verb(q{interlay})->past_part, q{interlaid}  => q{past_part 'interlay' --> 'interlaid'};
is verb(q{costing})->past_part, q{cost}  => q{past_part 'costing' --> 'cost'};
is verb(q{drove})->past_part, q{driven}  => q{past_part 'drove' --> 'driven'};
is verb(q{sweeps})->past_part, q{swept}  => q{past_part 'sweeps' --> 'swept'};
is verb(q{blown})->past_part, q{blown}  => q{past_part 'blown' --> 'blown'};
is verb(q{ringing})->past_part, q{rung}  => q{past_part 'ringing' --> 'rung'};
is verb(q{ached})->past_part, q{ached}  => q{past_part 'ached' --> 'ached'};
is verb(q{smells})->past_part, q{smelled}  => q{past_part 'smells' --> 'smelled'};
is verb(q{undertakes})->past_part, q{undertaken}  => q{past_part 'undertakes' --> 'undertaken'};
is verb(q{overdraws})->past_part, q{overdrawn}  => q{past_part 'overdraws' --> 'overdrawn'};
is verb(q{leaned})->past_part, q{leaned}  => q{past_part 'leaned' --> 'leaned'};
is verb(q{held})->past_part, q{held}  => q{past_part 'held' --> 'held'};
is verb(q{begun})->past_part, q{begun}  => q{past_part 'begun' --> 'begun'};
is verb(q{iris})->past_part, q{irised}  => q{past_part 'iris' --> 'irised'};
is verb(q{forgotten})->past_part, q{forgotten}  => q{past_part 'forgotten' --> 'forgotten'};
is verb(q{wringing})->past_part, q{wrung}  => q{past_part 'wringing' --> 'wrung'};
is verb(q{showed})->past_part, q{shown}  => q{past_part 'showed' --> 'shown'};
is verb(q{understanding})->past_part, q{understood}  => q{past_part 'understanding' --> 'understood'};
is verb(q{ate})->past_part, q{eaten}  => q{past_part 'ate' --> 'eaten'};
is verb(q{douche})->past_part, q{douched}  => q{past_part 'douche' --> 'douched'};
is verb(q{rung})->past_part, q{rung}  => q{past_part 'rung' --> 'rung'};
is verb(q{stealing})->past_part, q{stolen}  => q{past_part 'stealing' --> 'stolen'};
is verb(q{thrives})->past_part, q{thrived}  => q{past_part 'thrives' --> 'thrived'};
is verb(q{withdrawn})->past_part, q{withdrawn}  => q{past_part 'withdrawn' --> 'withdrawn'};
is verb(q{burning})->past_part, q{burnt}  => q{past_part 'burning' --> 'burnt'};
is verb(q{needs})->past_part, q{needed}  => q{past_part 'needs' --> 'needed'};
is verb(q{inlay})->past_part, q{inlaid}  => q{past_part 'inlay' --> 'inlaid'};
is verb(q{digging})->past_part, q{dug}  => q{past_part 'digging' --> 'dug'};
is verb(q{breeds})->past_part, q{bred}  => q{past_part 'breeds' --> 'bred'};
is verb(q{swept})->past_part, q{swept}  => q{past_part 'swept' --> 'swept'};
is verb(q{overdraw})->past_part, q{overdrawn}  => q{past_part 'overdraw' --> 'overdrawn'};
is verb(q{lay})->past_part, q{laid}  => q{past_part 'lay' --> 'laid'};
is verb(q{overdrawing})->past_part, q{overdrawn}  => q{past_part 'overdrawing' --> 'overdrawn'};
is verb(q{kneeling})->past_part, q{knelt}  => q{past_part 'kneeling' --> 'knelt'};
is verb(q{dare})->past_part, q{dared}  => q{past_part 'dare' --> 'dared'};
is verb(q{psyching})->past_part, q{psyched}  => q{past_part 'psyching' --> 'psyched'};
is verb(q{interlays})->past_part, q{interlaid}  => q{past_part 'interlays' --> 'interlaid'};
is verb(q{lived})->past_part, q{lived}  => q{past_part 'lived' --> 'lived'};
is verb(q{forget})->past_part, q{forgotten}  => q{past_part 'forget' --> 'forgotten'};
is verb(q{quiz})->past_part, q{quizzed}  => q{past_part 'quiz' --> 'quizzed'};
is verb(q{foresee})->past_part, q{foreseen}  => q{past_part 'foresee' --> 'foreseen'};
is verb(q{rise})->past_part, q{risen}  => q{past_part 'rise' --> 'risen'};
is verb(q{aches})->past_part, q{ached}  => q{past_part 'aches' --> 'ached'};
is verb(q{grinds})->past_part, q{ground}  => q{past_part 'grinds' --> 'ground'};
is verb(q{riven})->past_part, q{riven}  => q{past_part 'riven' --> 'riven'};
is verb(q{becomes})->past_part, q{become}  => q{past_part 'becomes' --> 'become'};
is verb(q{wrung})->past_part, q{wrung}  => q{past_part 'wrung' --> 'wrung'};
is verb(q{undergoes})->past_part, q{undergone}  => q{past_part 'undergoes' --> 'undergone'};
is verb(q{cached})->past_part, q{cached}  => q{past_part 'cached' --> 'cached'};
is verb(q{interlaid})->past_part, q{interlaid}  => q{past_part 'interlaid' --> 'interlaid'};
is verb(q{burns})->past_part, q{burnt}  => q{past_part 'burns' --> 'burnt'};
is verb(q{needing})->past_part, q{needed}  => q{past_part 'needing' --> 'needed'};
is verb(q{presetting})->past_part, q{preset}  => q{past_part 'presetting' --> 'preset'};
is verb(q{arises})->past_part, q{arisen}  => q{past_part 'arises' --> 'arisen'};
is verb(q{dug})->past_part, q{dug}  => q{past_part 'dug' --> 'dug'};
is verb(q{kneel})->past_part, q{knelt}  => q{past_part 'kneel' --> 'knelt'};
is verb(q{sunburned})->past_part, q{sunburned}  => q{past_part 'sunburned' --> 'sunburned'};
is verb(q{comes})->past_part, q{come}  => q{past_part 'comes' --> 'come'};
is verb(q{following})->past_part, q{followed}  => q{past_part 'following' --> 'followed'};
is verb(q{sprung})->past_part, q{sprung}  => q{past_part 'sprung' --> 'sprung'};
is verb(q{quizzing})->past_part, q{quizzed}  => q{past_part 'quizzing' --> 'quizzed'};
is verb(q{strewn})->past_part, q{strewn}  => q{past_part 'strewn' --> 'strewn'};
is verb(q{presets})->past_part, q{preset}  => q{past_part 'presets' --> 'preset'};
is verb(q{worn})->past_part, q{worn}  => q{past_part 'worn' --> 'worn'};
is verb(q{foreseeing})->past_part, q{foreseen}  => q{past_part 'foreseeing' --> 'foreseen'};
is verb(q{bitten})->past_part, q{bitten}  => q{past_part 'bitten' --> 'bitten'};
is verb(q{inlaying})->past_part, q{inlaid}  => q{past_part 'inlaying' --> 'inlaid'};
is verb(q{given})->past_part, q{given}  => q{past_part 'given' --> 'given'};
is verb(q{awoke})->past_part, q{awoken}  => q{past_part 'awoke' --> 'awoken'};
is verb(q{rode})->past_part, q{ridden}  => q{past_part 'rode' --> 'ridden'};
is verb(q{eat})->past_part, q{eaten}  => q{past_part 'eat' --> 'eaten'};
is verb(q{swimming})->past_part, q{swum}  => q{past_part 'swimming' --> 'swum'};
is verb(q{slits})->past_part, q{slit}  => q{past_part 'slits' --> 'slit'};
is verb(q{sowed})->past_part, q{sown}  => q{past_part 'sowed' --> 'sown'};
is verb(q{steal})->past_part, q{stolen}  => q{past_part 'steal' --> 'stolen'};
is verb(q{have})->past_part, q{had}  => q{past_part 'have' --> 'had'};
is verb(q{watching})->past_part, q{watched}  => q{past_part 'watching' --> 'watched'};
is verb(q{creeps})->past_part, q{crept}  => q{past_part 'creeps' --> 'crept'};
is verb(q{staying})->past_part, q{stayed}  => q{past_part 'staying' --> 'stayed'};
is verb(q{spoiling})->past_part, q{spoiled}  => q{past_part 'spoiling' --> 'spoiled'};
is verb(q{thrive})->past_part, q{thrived}  => q{past_part 'thrive' --> 'thrived'};
is verb(q{spends})->past_part, q{spent}  => q{past_part 'spends' --> 'spent'};
is verb(q{building})->past_part, q{built}  => q{past_part 'building' --> 'built'};
is verb(q{douches})->past_part, q{douched}  => q{past_part 'douches' --> 'douched'};
is verb(q{bleeds})->past_part, q{bled}  => q{past_part 'bleeds' --> 'bled'};
is verb(q{stinging})->past_part, q{stung}  => q{past_part 'stinging' --> 'stung'};
is verb(q{wear})->past_part, q{worn}  => q{past_part 'wear' --> 'worn'};
is verb(q{forgetting})->past_part, q{forgotten}  => q{past_part 'forgetting' --> 'forgotten'};
is verb(q{flee})->past_part, q{fled}  => q{past_part 'flee' --> 'fled'};
is verb(q{bellyache})->past_part, q{bellyached}  => q{past_part 'bellyache' --> 'bellyached'};
is verb(q{forgets})->past_part, q{forgotten}  => q{past_part 'forgets' --> 'forgotten'};
is verb(q{sink})->past_part, q{sunk}  => q{past_part 'sink' --> 'sunk'};
is verb(q{hurting})->past_part, q{hurt}  => q{past_part 'hurting' --> 'hurt'};
is verb(q{withstood})->past_part, q{withstood}  => q{past_part 'withstood' --> 'withstood'};
is verb(q{talked})->past_part, q{talked}  => q{past_part 'talked' --> 'talked'};
is verb(q{mistaken})->past_part, q{mistaken}  => q{past_part 'mistaken' --> 'mistaken'};
is verb(q{rid})->past_part, q{rid}  => q{past_part 'rid' --> 'rid'};
is verb(q{spat})->past_part, q{spat}  => q{past_part 'spat' --> 'spat'};
is verb(q{spits})->past_part, q{spat}  => q{past_part 'spits' --> 'spat'};
is verb(q{spoken})->past_part, q{spoken}  => q{past_part 'spoken' --> 'spoken'};
is verb(q{stays})->past_part, q{stayed}  => q{past_part 'stays' --> 'stayed'};
is verb(q{hewing})->past_part, q{hewn}  => q{past_part 'hewing' --> 'hewn'};
is verb(q{stripping})->past_part, q{stripped}  => q{past_part 'stripping' --> 'stripped'};
is verb(q{sows})->past_part, q{sown}  => q{past_part 'sows' --> 'sown'};
is verb(q{inlaid})->past_part, q{inlaid}  => q{past_part 'inlaid' --> 'inlaid'};
is verb(q{become})->past_part, q{become}  => q{past_part 'become' --> 'become'};
is verb(q{blow})->past_part, q{blown}  => q{past_part 'blow' --> 'blown'};
is verb(q{sting})->past_part, q{stung}  => q{past_part 'sting' --> 'stung'};
is verb(q{build})->past_part, q{built}  => q{past_part 'build' --> 'built'};
is verb(q{led})->past_part, q{led}  => q{past_part 'led' --> 'led'};
is verb(q{sprang})->past_part, q{sprung}  => q{past_part 'sprang' --> 'sprung'};
is verb(q{caches})->past_part, q{cached}  => q{past_part 'caches' --> 'cached'};
is verb(q{hurts})->past_part, q{hurt}  => q{past_part 'hurts' --> 'hurt'};
is verb(q{watch})->past_part, q{watched}  => q{past_part 'watch' --> 'watched'};
is verb(q{brings})->past_part, q{brought}  => q{past_part 'brings' --> 'brought'};
is verb(q{withdraws})->past_part, q{withdrawn}  => q{past_part 'withdraws' --> 'withdrawn'};
is verb(q{preset})->past_part, q{preset}  => q{past_part 'preset' --> 'preset'};
is verb(q{spoil})->past_part, q{spoiled}  => q{past_part 'spoil' --> 'spoiled'};
is verb(q{dwelt})->past_part, q{dwelt}  => q{past_part 'dwelt' --> 'dwelt'};
is verb(q{follows})->past_part, q{followed}  => q{past_part 'follows' --> 'followed'};
is verb(q{walks})->past_part, q{walked}  => q{past_part 'walks' --> 'walked'};
is verb(q{sheds})->past_part, q{shed}  => q{past_part 'sheds' --> 'shed'};
is verb(q{eats})->past_part, q{eaten}  => q{past_part 'eats' --> 'eaten'};
is verb(q{became})->past_part, q{become}  => q{past_part 'became' --> 'become'};
is verb(q{forbidden})->past_part, q{forbidden}  => q{past_part 'forbidden' --> 'forbidden'};
is verb(q{stand})->past_part, q{stood}  => q{past_part 'stand' --> 'stood'};
is verb(q{niches})->past_part, q{niched}  => q{past_part 'niches' --> 'niched'};
is verb(q{drink})->past_part, q{drunk}  => q{past_part 'drink' --> 'drunk'};
is verb(q{clung})->past_part, q{clung}  => q{past_part 'clung' --> 'clung'};
is verb(q{misunderstanding})->past_part, q{misunderstood}  => q{past_part 'misunderstanding' --> 'misunderstood'};
is verb(q{stops})->past_part, q{stopped}  => q{past_part 'stops' --> 'stopped'};
is verb(q{breaking})->past_part, q{broken}  => q{past_part 'breaking' --> 'broken'};
is verb(q{catch})->past_part, q{caught}  => q{past_part 'catch' --> 'caught'};
is verb(q{waited})->past_part, q{waited}  => q{past_part 'waited' --> 'waited'};
is verb(q{ran})->past_part, q{run}  => q{past_part 'ran' --> 'run'};
is verb(q{slain})->past_part, q{slain}  => q{past_part 'slain' --> 'slain'};
is verb(q{sing})->past_part, q{sung}  => q{past_part 'sing' --> 'sung'};
is verb(q{swing})->past_part, q{swung}  => q{past_part 'swing' --> 'swung'};
is verb(q{love})->past_part, q{loved}  => q{past_part 'love' --> 'loved'};
is verb(q{keeps})->past_part, q{kept}  => q{past_part 'keeps' --> 'kept'};
is verb(q{goes})->past_part, q{gone}  => q{past_part 'goes' --> 'gone'};
is verb(q{walking})->past_part, q{walked}  => q{past_part 'walking' --> 'walked'};
is verb(q{remembered})->past_part, q{remembered}  => q{past_part 'remembered' --> 'remembered'};
is verb(q{betting})->past_part, q{bet}  => q{past_part 'betting' --> 'bet'};
is verb(q{swinging})->past_part, q{swung}  => q{past_part 'swinging' --> 'swung'};
is verb(q{douched})->past_part, q{douched}  => q{past_part 'douched' --> 'douched'};
is verb(q{were})->past_part, q{been}  => q{past_part 'were' --> 'been'};
is verb(q{gild})->past_part, q{gilded}  => q{past_part 'gild' --> 'gilded'};
is verb(q{learns})->past_part, q{learned}  => q{past_part 'learns' --> 'learned'};
is verb(q{irises})->past_part, q{irised}  => q{past_part 'irises' --> 'irised'};
is verb(q{stunk})->past_part, q{stunk}  => q{past_part 'stunk' --> 'stunk'};
is verb(q{lays})->past_part, q{laid}  => q{past_part 'lays' --> 'laid'};
is verb(q{trod})->past_part, q{trodden}  => q{past_part 'trod' --> 'trodden'};
is verb(q{catching})->past_part, q{caught}  => q{past_part 'catching' --> 'caught'};
is verb(q{swim})->past_part, q{swum}  => q{past_part 'swim' --> 'swum'};
is verb(q{overtakes})->past_part, q{overtaken}  => q{past_part 'overtakes' --> 'overtaken'};
is verb(q{bite})->past_part, q{bitten}  => q{past_part 'bite' --> 'bitten'};
is verb(q{drinking})->past_part, q{drunk}  => q{past_part 'drinking' --> 'drunk'};
is verb(q{liked})->past_part, q{liked}  => q{past_part 'liked' --> 'liked'};
is verb(q{bellyaching})->past_part, q{bellyached}  => q{past_part 'bellyaching' --> 'bellyached'};
is verb(q{going})->past_part, q{gone}  => q{past_part 'going' --> 'gone'};
is verb(q{continued})->past_part, q{continued}  => q{past_part 'continued' --> 'continued'};
is verb(q{foretells})->past_part, q{foretold}  => q{past_part 'foretells' --> 'foretold'};
is verb(q{break})->past_part, q{broken}  => q{past_part 'break' --> 'broken'};
is verb(q{helped})->past_part, q{helped}  => q{past_part 'helped' --> 'helped'};
is verb(q{begin})->past_part, q{begun}  => q{past_part 'begin' --> 'begun'};
is verb(q{stripped})->past_part, q{stripped}  => q{past_part 'stripped' --> 'stripped'};
is verb(q{standing})->past_part, q{stood}  => q{past_part 'standing' --> 'stood'};
is verb(q{moved})->past_part, q{moved}  => q{past_part 'moved' --> 'moved'};
is verb(q{keeping})->past_part, q{kept}  => q{past_part 'keeping' --> 'kept'};
is verb(q{overtaken})->past_part, q{overtaken}  => q{past_part 'overtaken' --> 'overtaken'};
is verb(q{swelled})->past_part, q{swollen}  => q{past_part 'swelled' --> 'swollen'};
is verb(q{seemed})->past_part, q{seemed}  => q{past_part 'seemed' --> 'seemed'};
is verb(q{weep})->past_part, q{wept}  => q{past_part 'weep' --> 'wept'};
is verb(q{overheard})->past_part, q{overheard}  => q{past_part 'overheard' --> 'overheard'};
is verb(q{quits})->past_part, q{quit}  => q{past_part 'quits' --> 'quit'};
is verb(q{deals})->past_part, q{dealt}  => q{past_part 'deals' --> 'dealt'};
is verb(q{follow})->past_part, q{followed}  => q{past_part 'follow' --> 'followed'};
is verb(q{niched})->past_part, q{niched}  => q{past_part 'niched' --> 'niched'};
is verb(q{menuing})->past_part, q{menued}  => q{past_part 'menuing' --> 'menued'};
is verb(q{flings})->past_part, q{flung}  => q{past_part 'flings' --> 'flung'};
is verb(q{sow})->past_part, q{sown}  => q{past_part 'sow' --> 'sown'};
is verb(q{caught})->past_part, q{caught}  => q{past_part 'caught' --> 'caught'};
is verb(q{look})->past_part, q{looked}  => q{past_part 'look' --> 'looked'};
is verb(q{rids})->past_part, q{rid}  => q{past_part 'rids' --> 'rid'};
is verb(q{killed})->past_part, q{killed}  => q{past_part 'killed' --> 'killed'};
is verb(q{withdrew})->past_part, q{withdrawn}  => q{past_part 'withdrew' --> 'withdrawn'};
is verb(q{thrived})->past_part, q{thrived}  => q{past_part 'thrived' --> 'thrived'};
is verb(q{clapping})->past_part, q{clapped}  => q{past_part 'clapping' --> 'clapped'};
is verb(q{followed})->past_part, q{followed}  => q{past_part 'followed' --> 'followed'};
is verb(q{foresees})->past_part, q{foreseen}  => q{past_part 'foresees' --> 'foreseen'};
is verb(q{knit})->past_part, q{knitted}  => q{past_part 'knit' --> 'knitted'};
is verb(q{sat})->past_part, q{sat}  => q{past_part 'sat' --> 'sat'};
is verb(q{wended})->past_part, q{wended}  => q{past_part 'wended' --> 'wended'};
is verb(q{coming})->past_part, q{come}  => q{past_part 'coming' --> 'come'};
is verb(q{foretold})->past_part, q{foretold}  => q{past_part 'foretold' --> 'foretold'};
is verb(q{dealing})->past_part, q{dealt}  => q{past_part 'dealing' --> 'dealt'};
is verb(q{sawing})->past_part, q{sawn}  => q{past_part 'sawing' --> 'sawn'};
is verb(q{undertook})->past_part, q{undertaken}  => q{past_part 'undertook' --> 'undertaken'};
is verb(q{show})->past_part, q{shown}  => q{past_part 'show' --> 'shown'};
is verb(q{knew})->past_part, q{known}  => q{past_part 'knew' --> 'known'};
is verb(q{dragging})->past_part, q{dragged}  => q{past_part 'dragging' --> 'dragged'};
is verb(q{avalanched})->past_part, q{avalanched}  => q{past_part 'avalanched' --> 'avalanched'};
is verb(q{lean})->past_part, q{leaned}  => q{past_part 'lean' --> 'leaned'};
is verb(q{irised})->past_part, q{irised}  => q{past_part 'irised' --> 'irised'};
is verb(q{menus})->past_part, q{menued}  => q{past_part 'menus' --> 'menued'};
is verb(q{slinks})->past_part, q{slunk}  => q{past_part 'slinks' --> 'slunk'};
is verb(q{awakening})->past_part, q{awoken}  => q{past_part 'awakening' --> 'awoken'};
is verb(q{knitted})->past_part, q{knitted}  => q{past_part 'knitted' --> 'knitted'};
is verb(q{slid})->past_part, q{slid}  => q{past_part 'slid' --> 'slid'};
is verb(q{wept})->past_part, q{wept}  => q{past_part 'wept' --> 'wept'};
is verb(q{slay})->past_part, q{slain}  => q{past_part 'slay' --> 'slain'};
is verb(q{aching})->past_part, q{ached}  => q{past_part 'aching' --> 'ached'};
is verb(q{hold})->past_part, q{held}  => q{past_part 'hold' --> 'held'};
is verb(q{fly})->past_part, q{flown}  => q{past_part 'fly' --> 'flown'};

done_testing();
