use Test::More;
use Lingua::EN::Inflexion;

is verb(q{remembers})->plural,   q{remember}  => q{plural: 'remembers' --> 'remember'};
is verb(q{remember})->plural, q{remember}  => q{plural: 'remember' --> 'remember'};
is verb(q{daren't})->plural,   q{daren't}  => q{plural: 'daren't' --> 'daren't'};
is verb(q{may})->plural,   q{may}  => q{plural: 'may' --> 'may'};
is verb(q{am})->plural,   q{are}  => q{plural: 'am' --> 'are'};
is verb(q{are})->plural, q{are}  => q{plural: 'are' --> 'are'};
is verb(q{falls})->plural,   q{fall}  => q{plural: 'falls' --> 'fall'};
is verb(q{fall})->plural, q{fall}  => q{plural: 'fall' --> 'fall'};
is verb(q{spits})->plural,   q{spit}  => q{plural: 'spits' --> 'spit'};
is verb(q{spit})->plural, q{spit}  => q{plural: 'spit' --> 'spit'};
is verb(q{kills})->plural,   q{kill}  => q{plural: 'kills' --> 'kill'};
is verb(q{kill})->plural, q{kill}  => q{plural: 'kill' --> 'kill'};
is verb(q{knits})->plural,   q{knit}  => q{plural: 'knits' --> 'knit'};
is verb(q{knit})->plural, q{knit}  => q{plural: 'knit' --> 'knit'};
is verb(q{wends})->plural,   q{wend}  => q{plural: 'wends' --> 'wend'};
is verb(q{wend})->plural, q{wend}  => q{plural: 'wend' --> 'wend'};
is verb(q{dives})->plural,   q{dive}  => q{plural: 'dives' --> 'dive'};
is verb(q{dive})->plural, q{dive}  => q{plural: 'dive' --> 'dive'};
is verb(q{drags})->plural,   q{drag}  => q{plural: 'drags' --> 'drag'};
is verb(q{drag})->plural, q{drag}  => q{plural: 'drag' --> 'drag'};
is verb(q{withstands})->plural,   q{withstand}  => q{plural: 'withstands' --> 'withstand'};
is verb(q{withstand})->plural, q{withstand}  => q{plural: 'withstand' --> 'withstand'};
is verb(q{forgets})->plural,   q{forget}  => q{plural: 'forgets' --> 'forget'};
is verb(q{forget})->plural, q{forget}  => q{plural: 'forget' --> 'forget'};
is verb(q{shits})->plural,   q{shit}  => q{plural: 'shits' --> 'shit'};
is verb(q{shit})->plural, q{shit}  => q{plural: 'shit' --> 'shit'};
is verb(q{can})->plural,   q{can}  => q{plural: 'can' --> 'can'};
is verb(q{watches})->plural,   q{watch}  => q{plural: 'watches' --> 'watch'};
is verb(q{watch})->plural, q{watch}  => q{plural: 'watch' --> 'watch'};
is verb(q{looks})->plural,   q{look}  => q{plural: 'looks' --> 'look'};
is verb(q{look})->plural, q{look}  => q{plural: 'look' --> 'look'};
is verb(q{wrings})->plural,   q{wring}  => q{plural: 'wrings' --> 'wring'};
is verb(q{wring})->plural, q{wring}  => q{plural: 'wring' --> 'wring'};
is verb(q{bleeds})->plural,   q{bleed}  => q{plural: 'bleeds' --> 'bleed'};
is verb(q{bleed})->plural, q{bleed}  => q{plural: 'bleed' --> 'bleed'};
is verb(q{douches})->plural,   q{douche}  => q{plural: 'douches' --> 'douche'};
is verb(q{douche})->plural, q{douche}  => q{plural: 'douche' --> 'douche'};
is verb(q{strides})->plural,   q{stride}  => q{plural: 'strides' --> 'stride'};
is verb(q{stride})->plural, q{stride}  => q{plural: 'stride' --> 'stride'};
is verb(q{spends})->plural,   q{spend}  => q{plural: 'spends' --> 'spend'};
is verb(q{spend})->plural, q{spend}  => q{plural: 'spend' --> 'spend'};
is verb(q{holds})->plural,   q{hold}  => q{plural: 'holds' --> 'hold'};
is verb(q{hold})->plural, q{hold}  => q{plural: 'hold' --> 'hold'};
is verb(q{insists})->plural,   q{insist}  => q{plural: 'insists' --> 'insist'};
is verb(q{insist})->plural, q{insist}  => q{plural: 'insist' --> 'insist'};
is verb(q{slays})->plural,   q{slay}  => q{plural: 'slays' --> 'slay'};
is verb(q{slay})->plural, q{slay}  => q{plural: 'slay' --> 'slay'};
is verb(q{knows})->plural,   q{know}  => q{plural: 'knows' --> 'know'};
is verb(q{know})->plural, q{know}  => q{plural: 'know' --> 'know'};
is verb(q{misunderstands})->plural,   q{misunderstand}  => q{plural: 'misunderstands' --> 'misunderstand'};
is verb(q{misunderstand})->plural, q{misunderstand}  => q{plural: 'misunderstand' --> 'misunderstand'};
is verb(q{reaches})->plural,   q{reach}  => q{plural: 'reaches' --> 'reach'};
is verb(q{reach})->plural, q{reach}  => q{plural: 'reach' --> 'reach'};
is verb(q{leans})->plural,   q{lean}  => q{plural: 'leans' --> 'lean'};
is verb(q{lean})->plural, q{lean}  => q{plural: 'lean' --> 'lean'};
is verb(q{flies})->plural,   q{fly}  => q{plural: 'flies' --> 'fly'};
is verb(q{fly})->plural, q{fly}  => q{plural: 'fly' --> 'fly'};
is verb(q{creeps})->plural,   q{creep}  => q{plural: 'creeps' --> 'creep'};
is verb(q{creep})->plural, q{creep}  => q{plural: 'creep' --> 'creep'};
is verb(q{shows})->plural,   q{show}  => q{plural: 'shows' --> 'show'};
is verb(q{show})->plural, q{show}  => q{plural: 'show' --> 'show'};
is verb(q{blitzes})->plural,   q{blitz}  => q{plural: 'blitzes' --> 'blitz'};
is verb(q{blitz})->plural, q{blitz}  => q{plural: 'blitz' --> 'blitz'};
is verb(q{seems})->plural,   q{seem}  => q{plural: 'seems' --> 'seem'};
is verb(q{seem})->plural, q{seem}  => q{plural: 'seem' --> 'seem'};
is verb(q{withdraws})->plural,   q{withdraw}  => q{plural: 'withdraws' --> 'withdraw'};
is verb(q{withdraw})->plural, q{withdraw}  => q{plural: 'withdraw' --> 'withdraw'};
is verb(q{brings})->plural,   q{bring}  => q{plural: 'brings' --> 'bring'};
is verb(q{bring})->plural, q{bring}  => q{plural: 'bring' --> 'bring'};
is verb(q{strips})->plural,   q{strip}  => q{plural: 'strips' --> 'strip'};
is verb(q{strip})->plural, q{strip}  => q{plural: 'strip' --> 'strip'};
is verb(q{hurts})->plural,   q{hurt}  => q{plural: 'hurts' --> 'hurt'};
is verb(q{hurt})->plural, q{hurt}  => q{plural: 'hurt' --> 'hurt'};
is verb(q{beats})->plural,   q{beat}  => q{plural: 'beats' --> 'beat'};
is verb(q{beat})->plural, q{beat}  => q{plural: 'beat' --> 'beat'};
is verb(q{bursts})->plural,   q{burst}  => q{plural: 'bursts' --> 'burst'};
is verb(q{burst})->plural, q{burst}  => q{plural: 'burst' --> 'burst'};
is verb(q{bends})->plural,   q{bend}  => q{plural: 'bends' --> 'bend'};
is verb(q{bend})->plural, q{bend}  => q{plural: 'bend' --> 'bend'};
is verb(q{rends})->plural,   q{rend}  => q{plural: 'rends' --> 'rend'};
is verb(q{rend})->plural, q{rend}  => q{plural: 'rend' --> 'rend'};
is verb(q{smites})->plural,   q{smite}  => q{plural: 'smites' --> 'smite'};
is verb(q{smite})->plural, q{smite}  => q{plural: 'smite' --> 'smite'};
is verb(q{sits})->plural,   q{sit}  => q{plural: 'sits' --> 'sit'};
is verb(q{sit})->plural, q{sit}  => q{plural: 'sit' --> 'sit'};
is verb(q{haven't})->plural,   q{haven't}  => q{plural: 'haven't' --> 'haven't'};
is verb(q{weeps})->plural,   q{weep}  => q{plural: 'weeps' --> 'weep'};
is verb(q{weep})->plural, q{weep}  => q{plural: 'weep' --> 'weep'};
is verb(q{caches})->plural,   q{cache}  => q{plural: 'caches' --> 'cache'};
is verb(q{cache})->plural, q{cache}  => q{plural: 'cache' --> 'cache'};
is verb(q{puts})->plural,   q{put}  => q{plural: 'puts' --> 'put'};
is verb(q{put})->plural, q{put}  => q{plural: 'put' --> 'put'};
is verb(q{gets})->plural,   q{get}  => q{plural: 'gets' --> 'get'};
is verb(q{get})->plural, q{get}  => q{plural: 'get' --> 'get'};
is verb(q{finds})->plural,   q{find}  => q{plural: 'finds' --> 'find'};
is verb(q{find})->plural, q{find}  => q{plural: 'find' --> 'find'};
is verb(q{beholds})->plural,   q{behold}  => q{plural: 'beholds' --> 'behold'};
is verb(q{behold})->plural, q{behold}  => q{plural: 'behold' --> 'behold'};
is verb(q{likes})->plural,   q{like}  => q{plural: 'likes' --> 'like'};
is verb(q{like})->plural, q{like}  => q{plural: 'like' --> 'like'};
is verb(q{are})->plural,   q{are}  => q{plural: 'are' --> 'are'};
is verb(q{are})->plural, q{are}  => q{plural: 'are' --> 'are'};
is verb(q{seeks})->plural,   q{seek}  => q{plural: 'seeks' --> 'seek'};
is verb(q{seek})->plural, q{seek}  => q{plural: 'seek' --> 'seek'};
is verb(q{feels})->plural,   q{feel}  => q{plural: 'feels' --> 'feel'};
is verb(q{feel})->plural, q{feel}  => q{plural: 'feel' --> 'feel'};
is verb(q{bets})->plural,   q{bet}  => q{plural: 'bets' --> 'bet'};
is verb(q{bet})->plural, q{bet}  => q{plural: 'bet' --> 'bet'};
is verb(q{sows})->plural,   q{sow}  => q{plural: 'sows' --> 'sow'};
is verb(q{sow})->plural, q{sow}  => q{plural: 'sow' --> 'sow'};
is verb(q{stays})->plural,   q{stay}  => q{plural: 'stays' --> 'stay'};
is verb(q{stay})->plural, q{stay}  => q{plural: 'stay' --> 'stay'};
is verb(q{sunburns})->plural,   q{sunburn}  => q{plural: 'sunburns' --> 'sunburn'};
is verb(q{sunburn})->plural, q{sunburn}  => q{plural: 'sunburn' --> 'sunburn'};
is verb(q{runs})->plural,   q{run}  => q{plural: 'runs' --> 'run'};
is verb(q{run})->plural, q{run}  => q{plural: 'run' --> 'run'};
is verb(q{rides})->plural,   q{ride}  => q{plural: 'rides' --> 'ride'};
is verb(q{ride})->plural, q{ride}  => q{plural: 'ride' --> 'ride'};
is verb(q{moves})->plural,   q{move}  => q{plural: 'moves' --> 'move'};
is verb(q{move})->plural, q{move}  => q{plural: 'move' --> 'move'};
is verb(q{swims})->plural,   q{swim}  => q{plural: 'swims' --> 'swim'};
is verb(q{swim})->plural, q{swim}  => q{plural: 'swim' --> 'swim'};
is verb(q{drinks})->plural,   q{drink}  => q{plural: 'drinks' --> 'drink'};
is verb(q{drink})->plural, q{drink}  => q{plural: 'drink' --> 'drink'};
is verb(q{interlays})->plural,   q{interlay}  => q{plural: 'interlays' --> 'interlay'};
is verb(q{interlay})->plural, q{interlay}  => q{plural: 'interlay' --> 'interlay'};
is verb(q{provides})->plural,   q{provide}  => q{plural: 'provides' --> 'provide'};
is verb(q{provide})->plural, q{provide}  => q{plural: 'provide' --> 'provide'};
is verb(q{treads})->plural,   q{tread}  => q{plural: 'treads' --> 'tread'};
is verb(q{tread})->plural, q{tread}  => q{plural: 'tread' --> 'tread'};
is verb(q{gives})->plural,   q{give}  => q{plural: 'gives' --> 'give'};
is verb(q{give})->plural, q{give}  => q{plural: 'give' --> 'give'};
is verb(q{gilds})->plural,   q{gild}  => q{plural: 'gilds' --> 'gild'};
is verb(q{gild})->plural, q{gild}  => q{plural: 'gild' --> 'gild'};
is verb(q{abides})->plural,   q{abide}  => q{plural: 'abides' --> 'abide'};
is verb(q{abide})->plural, q{abide}  => q{plural: 'abide' --> 'abide'};
is verb(q{stands})->plural,   q{stand}  => q{plural: 'stands' --> 'stand'};
is verb(q{stand})->plural, q{stand}  => q{plural: 'stand' --> 'stand'};
is verb(q{needs})->plural,   q{need}  => q{plural: 'needs' --> 'need'};
is verb(q{need})->plural, q{need}  => q{plural: 'need' --> 'need'};
is verb(q{ought})->plural,   q{ought}  => q{plural: 'ought' --> 'ought'};
is verb(q{thrives})->plural,   q{thrive}  => q{plural: 'thrives' --> 'thrive'};
is verb(q{thrive})->plural, q{thrive}  => q{plural: 'thrive' --> 'thrive'};
is verb(q{helps})->plural,   q{help}  => q{plural: 'helps' --> 'help'};
is verb(q{help})->plural, q{help}  => q{plural: 'help' --> 'help'};
is verb(q{swings})->plural,   q{swing}  => q{plural: 'swings' --> 'swing'};
is verb(q{swing})->plural, q{swing}  => q{plural: 'swing' --> 'swing'};
is verb(q{breeds})->plural,   q{breed}  => q{plural: 'breeds' --> 'breed'};
is verb(q{breed})->plural, q{breed}  => q{plural: 'breed' --> 'breed'};
is verb(q{psyches})->plural,   q{psyche}  => q{plural: 'psyches' --> 'psyche'};
is verb(q{psyche})->plural, q{psyche}  => q{plural: 'psyche' --> 'psyche'};
is verb(q{remains})->plural,   q{remain}  => q{plural: 'remains' --> 'remain'};
is verb(q{remain})->plural, q{remain}  => q{plural: 'remain' --> 'remain'};
is verb(q{fights})->plural,   q{fight}  => q{plural: 'fights' --> 'fight'};
is verb(q{fight})->plural, q{fight}  => q{plural: 'fight' --> 'fight'};
is verb(q{means})->plural,   q{mean}  => q{plural: 'means' --> 'mean'};
is verb(q{mean})->plural, q{mean}  => q{plural: 'mean' --> 'mean'};
is verb(q{skis})->plural,   q{ski}  => q{plural: 'skis' --> 'ski'};
is verb(q{ski})->plural, q{ski}  => q{plural: 'ski' --> 'ski'};
is verb(q{sublets})->plural,   q{sublet}  => q{plural: 'sublets' --> 'sublet'};
is verb(q{sublet})->plural, q{sublet}  => q{plural: 'sublet' --> 'sublet'};
is verb(q{will})->plural,   q{will}  => q{plural: 'will' --> 'will'};
is verb(q{bites})->plural,   q{bite}  => q{plural: 'bites' --> 'bite'};
is verb(q{bite})->plural, q{bite}  => q{plural: 'bite' --> 'bite'};
is verb(q{rives})->plural,   q{rive}  => q{plural: 'rives' --> 'rive'};
is verb(q{rive})->plural, q{rive}  => q{plural: 'rive' --> 'rive'};
is verb(q{chooses})->plural,   q{choose}  => q{plural: 'chooses' --> 'choose'};
is verb(q{choose})->plural, q{choose}  => q{plural: 'choose' --> 'choose'};
is verb(q{dies})->plural,   q{die}  => q{plural: 'dies' --> 'die'};
is verb(q{die})->plural, q{die}  => q{plural: 'die' --> 'die'};
is verb(q{asks})->plural,   q{ask}  => q{plural: 'asks' --> 'ask'};
is verb(q{ask})->plural, q{ask}  => q{plural: 'ask' --> 'ask'};
is verb(q{forsakes})->plural,   q{forsake}  => q{plural: 'forsakes' --> 'forsake'};
is verb(q{forsake})->plural, q{forsake}  => q{plural: 'forsake' --> 'forsake'};
is verb(q{understands})->plural,   q{understand}  => q{plural: 'understands' --> 'understand'};
is verb(q{understand})->plural, q{understand}  => q{plural: 'understand' --> 'understand'};
is verb(q{springs})->plural,   q{spring}  => q{plural: 'springs' --> 'spring'};
is verb(q{spring})->plural, q{spring}  => q{plural: 'spring' --> 'spring'};
is verb(q{hews})->plural,   q{hew}  => q{plural: 'hews' --> 'hew'};
is verb(q{hew})->plural, q{hew}  => q{plural: 'hew' --> 'hew'};
is verb(q{slits})->plural,   q{slit}  => q{plural: 'slits' --> 'slit'};
is verb(q{slit})->plural, q{slit}  => q{plural: 'slit' --> 'slit'};
is verb(q{shan't})->plural,   q{shan't}  => q{plural: 'shan't' --> 'shan't'};
is verb(q{presets})->plural,   q{preset}  => q{plural: 'presets' --> 'preset'};
is verb(q{preset})->plural, q{preset}  => q{plural: 'preset' --> 'preset'};
is verb(q{begets})->plural,   q{beget}  => q{plural: 'begets' --> 'beget'};
is verb(q{beget})->plural, q{beget}  => q{plural: 'beget' --> 'beget'};
is verb(q{comes})->plural,   q{come}  => q{plural: 'comes' --> 'come'};
is verb(q{come})->plural, q{come}  => q{plural: 'come' --> 'come'};
is verb(q{dwells})->plural,   q{dwell}  => q{plural: 'dwells' --> 'dwell'};
is verb(q{dwell})->plural, q{dwell}  => q{plural: 'dwell' --> 'dwell'};
is verb(q{arises})->plural,   q{arise}  => q{plural: 'arises' --> 'arise'};
is verb(q{arise})->plural, q{arise}  => q{plural: 'arise' --> 'arise'};
is verb(q{hits})->plural,   q{hit}  => q{plural: 'hits' --> 'hit'};
is verb(q{hit})->plural, q{hit}  => q{plural: 'hit' --> 'hit'};
is verb(q{loves})->plural,   q{love}  => q{plural: 'loves' --> 'love'};
is verb(q{love})->plural, q{love}  => q{plural: 'love' --> 'love'};
is verb(q{sings})->plural,   q{sing}  => q{plural: 'sings' --> 'sing'};
is verb(q{sing})->plural, q{sing}  => q{plural: 'sing' --> 'sing'};
is verb(q{burns})->plural,   q{burn}  => q{plural: 'burns' --> 'burn'};
is verb(q{burn})->plural, q{burn}  => q{plural: 'burn' --> 'burn'};
is verb(q{begins})->plural,   q{begin}  => q{plural: 'begins' --> 'begin'};
is verb(q{begin})->plural, q{begin}  => q{plural: 'begin' --> 'begin'};
is verb(q{waits})->plural,   q{wait}  => q{plural: 'waits' --> 'wait'};
is verb(q{wait})->plural, q{wait}  => q{plural: 'wait' --> 'wait'};
is verb(q{happens})->plural,   q{happen}  => q{plural: 'happens' --> 'happen'};
is verb(q{happen})->plural, q{happen}  => q{plural: 'happen' --> 'happen'};
is verb(q{wins})->plural,   q{win}  => q{plural: 'wins' --> 'win'};
is verb(q{win})->plural, q{win}  => q{plural: 'win' --> 'win'};
is verb(q{has})->plural,   q{have}  => q{plural: 'has' --> 'have'};
is verb(q{have})->plural, q{have}  => q{plural: 'have' --> 'have'};
is verb(q{grinds})->plural,   q{grind}  => q{plural: 'grinds' --> 'grind'};
is verb(q{grind})->plural, q{grind}  => q{plural: 'grind' --> 'grind'};
is verb(q{aches})->plural,   q{ache}  => q{plural: 'aches' --> 'ache'};
is verb(q{ache})->plural, q{ache}  => q{plural: 'ache' --> 'ache'};
is verb(q{quizzes})->plural,   q{quiz}  => q{plural: 'quizzes' --> 'quiz'};
is verb(q{quiz})->plural, q{quiz}  => q{plural: 'quiz' --> 'quiz'};
is verb(q{undergoes})->plural,   q{undergo}  => q{plural: 'undergoes' --> 'undergo'};
is verb(q{undergo})->plural, q{undergo}  => q{plural: 'undergo' --> 'undergo'};
is verb(q{becomes})->plural,   q{become}  => q{plural: 'becomes' --> 'become'};
is verb(q{become})->plural, q{become}  => q{plural: 'become' --> 'become'};
is verb(q{breaks})->plural,   q{break}  => q{plural: 'breaks' --> 'break'};
is verb(q{break})->plural, q{break}  => q{plural: 'break' --> 'break'};
is verb(q{flings})->plural,   q{fling}  => q{plural: 'flings' --> 'fling'};
is verb(q{fling})->plural, q{fling}  => q{plural: 'fling' --> 'fling'};
is verb(q{speeds})->plural,   q{speed}  => q{plural: 'speeds' --> 'speed'};
is verb(q{speed})->plural, q{speed}  => q{plural: 'speed' --> 'speed'};
is verb(q{rings})->plural,   q{ring}  => q{plural: 'rings' --> 'ring'};
is verb(q{ring})->plural, q{ring}  => q{plural: 'ring' --> 'ring'};
is verb(q{blows})->plural,   q{blow}  => q{plural: 'blows' --> 'blow'};
is verb(q{blow})->plural, q{blow}  => q{plural: 'blow' --> 'blow'};
is verb(q{creches})->plural,   q{creche}  => q{plural: 'creches' --> 'creche'};
is verb(q{creche})->plural, q{creche}  => q{plural: 'creche' --> 'creche'};
is verb(q{mayn't})->plural,   q{mayn't}  => q{plural: 'mayn't' --> 'mayn't'};
is verb(q{could})->plural,   q{could}  => q{plural: 'could' --> 'could'};
is verb(q{won't})->plural,   q{won't}  => q{plural: 'won't' --> 'won't'};
is verb(q{stinks})->plural,   q{stink}  => q{plural: 'stinks' --> 'stink'};
is verb(q{stink})->plural, q{stink}  => q{plural: 'stink' --> 'stink'};
is verb(q{costs})->plural,   q{cost}  => q{plural: 'costs' --> 'cost'};
is verb(q{cost})->plural, q{cost}  => q{plural: 'cost' --> 'cost'};
is verb(q{quits})->plural,   q{quit}  => q{plural: 'quits' --> 'quit'};
is verb(q{quit})->plural, q{quit}  => q{plural: 'quit' --> 'quit'};
is verb(q{drives})->plural,   q{drive}  => q{plural: 'drives' --> 'drive'};
is verb(q{drive})->plural, q{drive}  => q{plural: 'drive' --> 'drive'};
is verb(q{leads})->plural,   q{lead}  => q{plural: 'leads' --> 'lead'};
is verb(q{lead})->plural, q{lead}  => q{plural: 'lead' --> 'lead'};
is verb(q{shrinks})->plural,   q{shrink}  => q{plural: 'shrinks' --> 'shrink'};
is verb(q{shrink})->plural, q{shrink}  => q{plural: 'shrink' --> 'shrink'};
is verb(q{deals})->plural,   q{deal}  => q{plural: 'deals' --> 'deal'};
is verb(q{deal})->plural, q{deal}  => q{plural: 'deal' --> 'deal'};
is verb(q{n't})->plural,   q{n't}  => q{plural: 'n't' --> 'n't'};
is verb(q{misleads})->plural,   q{mislead}  => q{plural: 'misleads' --> 'mislead'};
is verb(q{mislead})->plural, q{mislead}  => q{plural: 'mislead' --> 'mislead'};
is verb(q{dreams})->plural,   q{dream}  => q{plural: 'dreams' --> 'dream'};
is verb(q{dream})->plural, q{dream}  => q{plural: 'dream' --> 'dream'};
is verb(q{sneaks})->plural,   q{sneak}  => q{plural: 'sneaks' --> 'sneak'};
is verb(q{sneak})->plural, q{sneak}  => q{plural: 'sneak' --> 'sneak'};
is verb(q{vexes})->plural,   q{vex}  => q{plural: 'vexes' --> 'vex'};
is verb(q{vex})->plural, q{vex}  => q{plural: 'vex' --> 'vex'};
is verb(q{oughtn't})->plural,   q{oughtn't}  => q{plural: 'oughtn't' --> 'oughtn't'};
is verb(q{lives})->plural,   q{live}  => q{plural: 'lives' --> 'live'};
is verb(q{live})->plural, q{live}  => q{plural: 'live' --> 'live'};
is verb(q{upsets})->plural,   q{upset}  => q{plural: 'upsets' --> 'upset'};
is verb(q{upset})->plural, q{upset}  => q{plural: 'upset' --> 'upset'};
is verb(q{shakes})->plural,   q{shake}  => q{plural: 'shakes' --> 'shake'};
is verb(q{shake})->plural, q{shake}  => q{plural: 'shake' --> 'shake'};
is verb(q{overdraws})->plural,   q{overdraw}  => q{plural: 'overdraws' --> 'overdraw'};
is verb(q{overdraw})->plural, q{overdraw}  => q{plural: 'overdraw' --> 'overdraw'};
is verb(q{smells})->plural,   q{smell}  => q{plural: 'smells' --> 'smell'};
is verb(q{smell})->plural, q{smell}  => q{plural: 'smell' --> 'smell'};
is verb(q{undertakes})->plural,   q{undertake}  => q{plural: 'undertakes' --> 'undertake'};
is verb(q{undertake})->plural, q{undertake}  => q{plural: 'undertake' --> 'undertake'};
is verb(q{digs})->plural,   q{dig}  => q{plural: 'digs' --> 'dig'};
is verb(q{dig})->plural, q{dig}  => q{plural: 'dig' --> 'dig'};
is verb(q{slinks})->plural,   q{slink}  => q{plural: 'slinks' --> 'slink'};
is verb(q{slink})->plural, q{slink}  => q{plural: 'slink' --> 'slink'};
is verb(q{expects})->plural,   q{expect}  => q{plural: 'expects' --> 'expect'};
is verb(q{expect})->plural, q{expect}  => q{plural: 'expect' --> 'expect'};
is verb(q{wears})->plural,   q{wear}  => q{plural: 'wears' --> 'wear'};
is verb(q{wear})->plural, q{wear}  => q{plural: 'wear' --> 'wear'};
is verb(q{clings})->plural,   q{cling}  => q{plural: 'clings' --> 'cling'};
is verb(q{cling})->plural, q{cling}  => q{plural: 'cling' --> 'cling'};
is verb(q{can't})->plural,   q{can't}  => q{plural: 'can't' --> 'can't'};
is verb(q{speaks})->plural,   q{speak}  => q{plural: 'speaks' --> 'speak'};
is verb(q{speak})->plural, q{speak}  => q{plural: 'speak' --> 'speak'};
is verb(q{needn't})->plural,   q{needn't}  => q{plural: 'needn't' --> 'needn't'};
is verb(q{might})->plural,   q{might}  => q{plural: 'might' --> 'might'};
is verb(q{strives})->plural,   q{strive}  => q{plural: 'strives' --> 'strive'};
is verb(q{strive})->plural, q{strive}  => q{plural: 'strive' --> 'strive'};
is verb(q{sweeps})->plural,   q{sweep}  => q{plural: 'sweeps' --> 'sweep'};
is verb(q{sweep})->plural, q{sweep}  => q{plural: 'sweep' --> 'sweep'};
is verb(q{shaves})->plural,   q{shave}  => q{plural: 'shaves' --> 'shave'};
is verb(q{shave})->plural, q{shave}  => q{plural: 'shave' --> 'shave'};
is verb(q{menus})->plural,   q{menu}  => q{plural: 'menus' --> 'menu'};
is verb(q{menu})->plural, q{menu}  => q{plural: 'menu' --> 'menu'};
is verb(q{forgives})->plural,   q{forgive}  => q{plural: 'forgives' --> 'forgive'};
is verb(q{forgive})->plural, q{forgive}  => q{plural: 'forgive' --> 'forgive'};
is verb(q{wants})->plural,   q{want}  => q{plural: 'wants' --> 'want'};
is verb(q{want})->plural, q{want}  => q{plural: 'want' --> 'want'};
is verb(q{foresees})->plural,   q{foresee}  => q{plural: 'foresees' --> 'foresee'};
is verb(q{foresee})->plural, q{foresee}  => q{plural: 'foresee' --> 'foresee'};
is verb(q{spoils})->plural,   q{spoil}  => q{plural: 'spoils' --> 'spoil'};
is verb(q{spoil})->plural, q{spoil}  => q{plural: 'spoil' --> 'spoil'};
is verb(q{aren't})->plural,   q{aren't}  => q{plural: 'aren't' --> 'aren't'};
is verb(q{talks})->plural,   q{talk}  => q{plural: 'talks' --> 'talk'};
is verb(q{talk})->plural, q{talk}  => q{plural: 'talk' --> 'talk'};
is verb(q{sinks})->plural,   q{sink}  => q{plural: 'sinks' --> 'sink'};
is verb(q{sink})->plural, q{sink}  => q{plural: 'sink' --> 'sink'};
is verb(q{swears})->plural,   q{swear}  => q{plural: 'swears' --> 'swear'};
is verb(q{swear})->plural, q{swear}  => q{plural: 'swear' --> 'swear'};
is verb(q{rids})->plural,   q{rid}  => q{plural: 'rids' --> 'rid'};
is verb(q{rid})->plural, q{rid}  => q{plural: 'rid' --> 'rid'};
is verb(q{builds})->plural,   q{build}  => q{plural: 'builds' --> 'build'};
is verb(q{build})->plural, q{build}  => q{plural: 'build' --> 'build'};
is verb(q{bellyaches})->plural,   q{bellyache}  => q{plural: 'bellyaches' --> 'bellyache'};
is verb(q{bellyache})->plural, q{bellyache}  => q{plural: 'bellyache' --> 'bellyache'};
is verb(q{stings})->plural,   q{sting}  => q{plural: 'stings' --> 'sting'};
is verb(q{sting})->plural, q{sting}  => q{plural: 'sting' --> 'sting'};
is verb(q{meets})->plural,   q{meet}  => q{plural: 'meets' --> 'meet'};
is verb(q{meet})->plural, q{meet}  => q{plural: 'meet' --> 'meet'};
is verb(q{mustn't})->plural,   q{mustn't}  => q{plural: 'mustn't' --> 'mustn't'};
is verb(q{flees})->plural,   q{flee}  => q{plural: 'flees' --> 'flee'};
is verb(q{flee})->plural, q{flee}  => q{plural: 'flee' --> 'flee'};
is verb(q{overhears})->plural,   q{overhear}  => q{plural: 'overhears' --> 'overhear'};
is verb(q{overhear})->plural, q{overhear}  => q{plural: 'overhear' --> 'overhear'};
is verb(q{tears})->plural,   q{tear}  => q{plural: 'tears' --> 'tear'};
is verb(q{tear})->plural, q{tear}  => q{plural: 'tear' --> 'tear'};
is verb(q{sweats})->plural,   q{sweat}  => q{plural: 'sweats' --> 'sweat'};
is verb(q{sweat})->plural, q{sweat}  => q{plural: 'sweat' --> 'sweat'};
is verb(q{s})->plural,   q{}  => q{plural: 's' --> ''};
is verb(q{})->plural, q{}  => q{plural: '' --> ''};
is verb(q{keeps})->plural,   q{keep}  => q{plural: 'keeps' --> 'keep'};
is verb(q{keep})->plural, q{keep}  => q{plural: 'keep' --> 'keep'};
is verb(q{inlays})->plural,   q{inlay}  => q{plural: 'inlays' --> 'inlay'};
is verb(q{inlay})->plural, q{inlay}  => q{plural: 'inlay' --> 'inlay'};
is verb(q{goes})->plural,   q{go}  => q{plural: 'goes' --> 'go'};
is verb(q{go})->plural, q{go}  => q{plural: 'go' --> 'go'};
is verb(q{doesn't})->plural,   q{don't}  => q{plural: 'doesn't' --> 'don't'};
is verb(q{changes})->plural,   q{change}  => q{plural: 'changes' --> 'change'};
is verb(q{change})->plural, q{change}  => q{plural: 'change' --> 'change'};
is verb(q{shoes})->plural,   q{shoe}  => q{plural: 'shoes' --> 'shoe'};
is verb(q{shoe})->plural, q{shoe}  => q{plural: 'shoe' --> 'shoe'};
is verb(q{swells})->plural,   q{swell}  => q{plural: 'swells' --> 'swell'};
is verb(q{swell})->plural, q{swell}  => q{plural: 'swell' --> 'swell'};
is verb(q{binds})->plural,   q{bind}  => q{plural: 'binds' --> 'bind'};
is verb(q{bind})->plural, q{bind}  => q{plural: 'bind' --> 'bind'};
is verb(q{is})->plural,   q{are}  => q{plural: 'is' --> 'are'};
is verb(q{are})->plural, q{are}  => q{plural: 'are' --> 'are'};
is verb(q{continues})->plural,   q{continue}  => q{plural: 'continues' --> 'continue'};
is verb(q{continue})->plural, q{continue}  => q{plural: 'continue' --> 'continue'};
is verb(q{rises})->plural,   q{rise}  => q{plural: 'rises' --> 'rise'};
is verb(q{rise})->plural, q{rise}  => q{plural: 'rise' --> 'rise'};
is verb(q{busts})->plural,   q{bust}  => q{plural: 'busts' --> 'bust'};
is verb(q{bust})->plural, q{bust}  => q{plural: 'bust' --> 'bust'};
is verb(q{withholds})->plural,   q{withhold}  => q{plural: 'withholds' --> 'withhold'};
is verb(q{withhold})->plural, q{withhold}  => q{plural: 'withhold' --> 'withhold'};
is verb(q{leaps})->plural,   q{leap}  => q{plural: 'leaps' --> 'leap'};
is verb(q{leap})->plural, q{leap}  => q{plural: 'leap' --> 'leap'};
is verb(q{claps})->plural,   q{clap}  => q{plural: 'claps' --> 'clap'};
is verb(q{clap})->plural, q{clap}  => q{plural: 'clap' --> 'clap'};
is verb(q{sha'n't})->plural,   q{sha'n't}  => q{plural: 'sha'n't' --> 'sha'n't'};
is verb(q{isn't})->plural,   q{aren't}  => q{plural: 'isn't' --> 'aren't'};
is verb(q{stops})->plural,   q{stop}  => q{plural: 'stops' --> 'stop'};
is verb(q{stop})->plural, q{stop}  => q{plural: 'stop' --> 'stop'};
is verb(q{eats})->plural,   q{eat}  => q{plural: 'eats' --> 'eat'};
is verb(q{eat})->plural, q{eat}  => q{plural: 'eat' --> 'eat'};
is verb(q{walks})->plural,   q{walk}  => q{plural: 'walks' --> 'walk'};
is verb(q{walk})->plural, q{walk}  => q{plural: 'walk' --> 'walk'};
is verb(q{sheds})->plural,   q{shed}  => q{plural: 'sheds' --> 'shed'};
is verb(q{shed})->plural, q{shed}  => q{plural: 'shed' --> 'shed'};
is verb(q{follows})->plural,   q{follow}  => q{plural: 'follows' --> 'follow'};
is verb(q{follow})->plural, q{follow}  => q{plural: 'follow' --> 'follow'};
is verb(q{forbids})->plural,   q{forbid}  => q{plural: 'forbids' --> 'forbid'};
is verb(q{forbid})->plural, q{forbid}  => q{plural: 'forbid' --> 'forbid'};
is verb(q{strews})->plural,   q{strew}  => q{plural: 'strews' --> 'strew'};
is verb(q{strew})->plural, q{strew}  => q{plural: 'strew' --> 'strew'};
is verb(q{niches})->plural,   q{niche}  => q{plural: 'niches' --> 'niche'};
is verb(q{niche})->plural, q{niche}  => q{plural: 'niche' --> 'niche'};
is verb(q{shall})->plural,   q{shall}  => q{plural: 'shall' --> 'shall'};
is verb(q{loses})->plural,   q{lose}  => q{plural: 'loses' --> 'lose'};
is verb(q{lose})->plural, q{lose}  => q{plural: 'lose' --> 'lose'};
is verb(q{catches})->plural,   q{catch}  => q{plural: 'catches' --> 'catch'};
is verb(q{catch})->plural, q{catch}  => q{plural: 'catch' --> 'catch'};
is verb(q{kneels})->plural,   q{kneel}  => q{plural: 'kneels' --> 'kneel'};
is verb(q{kneel})->plural, q{kneel}  => q{plural: 'kneel' --> 'kneel'};
is verb(q{staves})->plural,   q{stave}  => q{plural: 'staves' --> 'stave'};
is verb(q{stave})->plural, q{stave}  => q{plural: 'stave' --> 'stave'};
is verb(q{overtakes})->plural,   q{overtake}  => q{plural: 'overtakes' --> 'overtake'};
is verb(q{overtake})->plural, q{overtake}  => q{plural: 'overtake' --> 'overtake'};
is verb(q{awakes})->plural,   q{awake}  => q{plural: 'awakes' --> 'awake'};
is verb(q{awake})->plural, q{awake}  => q{plural: 'awake' --> 'awake'};
is verb(q{avalanches})->plural,   q{avalanche}  => q{plural: 'avalanches' --> 'avalanche'};
is verb(q{avalanche})->plural, q{avalanche}  => q{plural: 'avalanche' --> 'avalanche'};
is verb(q{foretells})->plural,   q{foretell}  => q{plural: 'foretells' --> 'foretell'};
is verb(q{foretell})->plural, q{foretell}  => q{plural: 'foretell' --> 'foretell'};
is verb(q{don't})->plural,   q{don't}  => q{plural: 'don't' --> 'don't'};
is verb(q{lies})->plural,   q{lie}  => q{plural: 'lies' --> 'lie'};
is verb(q{lie})->plural, q{lie}  => q{plural: 'lie' --> 'lie'};
is verb(q{must})->plural,   q{must}  => q{plural: 'must' --> 'must'};
is verb(q{saws})->plural,   q{saw}  => q{plural: 'saws' --> 'saw'};
is verb(q{saw})->plural, q{saw}  => q{plural: 'saw' --> 'saw'};
is verb(q{leaves})->plural,   q{leave}  => q{plural: 'leaves' --> 'leave'};
is verb(q{leave})->plural, q{leave}  => q{plural: 'leave' --> 'leave'};
is verb(q{proves})->plural,   q{prove}  => q{plural: 'proves' --> 'prove'};
is verb(q{prove})->plural, q{prove}  => q{plural: 'prove' --> 'prove'};
is verb(q{steals})->plural,   q{steal}  => q{plural: 'steals' --> 'steal'};
is verb(q{steal})->plural, q{steal}  => q{plural: 'steal' --> 'steal'};
is verb(q{lays})->plural,   q{lay}  => q{plural: 'lays' --> 'lay'};
is verb(q{lay})->plural, q{lay}  => q{plural: 'lay' --> 'lay'};
is verb(q{dares})->plural,   q{dare}  => q{plural: 'dares' --> 'dare'};
is verb(q{dare})->plural, q{dare}  => q{plural: 'dare' --> 'dare'};
is verb(q{hasn't})->plural,   q{haven't}  => q{plural: 'hasn't' --> 'haven't'};
is verb(q{mistakes})->plural,   q{mistake}  => q{plural: 'mistakes' --> 'mistake'};
is verb(q{mistake})->plural, q{mistake}  => q{plural: 'mistake' --> 'mistake'};
is verb(q{slides})->plural,   q{slide}  => q{plural: 'slides' --> 'slide'};
is verb(q{slide})->plural, q{slide}  => q{plural: 'slide' --> 'slide'};
is verb(q{irises})->plural,   q{iris}  => q{plural: 'irises' --> 'iris'};
is verb(q{iris})->plural, q{iris}  => q{plural: 'iris' --> 'iris'};
is verb(q{wakes})->plural,   q{wake}  => q{plural: 'wakes' --> 'wake'};
is verb(q{wake})->plural, q{wake}  => q{plural: 'wake' --> 'wake'};
is verb(q{learns})->plural,   q{learn}  => q{plural: 'learns' --> 'learn'};
is verb(q{learn})->plural, q{learn}  => q{plural: 'learn' --> 'learn'};
is verb(q{thrusts})->plural,   q{thrust}  => q{plural: 'thrusts' --> 'thrust'};
is verb(q{thrust})->plural, q{thrust}  => q{plural: 'thrust' --> 'thrust'};
is verb(q{was})->plural,   q{were}  => q{plural: 'was' --> 'were'};
is verb(q{were})->plural, q{were}  => q{plural: 'were' --> 'were'};

done_testing();
