use Test::More;
use Lingua::EN::Inflexion;

is verb(q{misunderstanding})->pres_part, q{misunderstanding}  => q{pres_part 'misunderstanding' --> 'misunderstanding'};
is verb(q{clung})->pres_part, q{clinging}  => q{pres_part 'clung' --> 'clinging'};
is verb(q{breaking})->pres_part, q{breaking}  => q{pres_part 'breaking' --> 'breaking'};
is verb(q{stops})->pres_part, q{stopping}  => q{pres_part 'stops' --> 'stopping'};
is verb(q{drink})->pres_part, q{drinking}  => q{pres_part 'drink' --> 'drinking'};
is verb(q{niches})->pres_part, q{nicheing}  => q{pres_part 'niches' --> 'nicheing'};
is verb(q{stand})->pres_part, q{standing}  => q{pres_part 'stand' --> 'standing'};
is verb(q{forbidden})->pres_part, q{forbidding}  => q{pres_part 'forbidden' --> 'forbidding'};
is verb(q{eats})->pres_part, q{eating}  => q{pres_part 'eats' --> 'eating'};
is verb(q{walks})->pres_part, q{walking}  => q{pres_part 'walks' --> 'walking'};
is verb(q{sheds})->pres_part, q{shedding}  => q{pres_part 'sheds' --> 'shedding'};
is verb(q{follows})->pres_part, q{following}  => q{pres_part 'follows' --> 'following'};
is verb(q{became})->pres_part, q{becoming}  => q{pres_part 'became' --> 'becoming'};
is verb(q{swing})->pres_part, q{swinging}  => q{pres_part 'swing' --> 'swinging'};
is verb(q{sing})->pres_part, q{singing}  => q{pres_part 'sing' --> 'singing'};
is verb(q{slain})->pres_part, q{slaying}  => q{pres_part 'slain' --> 'slaying'};
is verb(q{keeps})->pres_part, q{keeping}  => q{pres_part 'keeps' --> 'keeping'};
is verb(q{love})->pres_part, q{loving}  => q{pres_part 'love' --> 'loving'};
is verb(q{goes})->pres_part, q{going}  => q{pres_part 'goes' --> 'going'};
is verb(q{waited})->pres_part, q{waiting}  => q{pres_part 'waited' --> 'waiting'};
is verb(q{catch})->pres_part, q{catching}  => q{pres_part 'catch' --> 'catching'};
is verb(q{ran})->pres_part, q{running}  => q{pres_part 'ran' --> 'running'};
is verb(q{catching})->pres_part, q{catching}  => q{pres_part 'catching' --> 'catching'};
is verb(q{trod})->pres_part, q{treading}  => q{pres_part 'trod' --> 'treading'};
is verb(q{lays})->pres_part, q{laying}  => q{pres_part 'lays' --> 'laying'};
is verb(q{swim})->pres_part, q{swimming}  => q{pres_part 'swim' --> 'swimming'};
is verb(q{were})->pres_part, q{being}  => q{pres_part 'were' --> 'being'};
is verb(q{gild})->pres_part, q{gilding}  => q{pres_part 'gild' --> 'gilding'};
is verb(q{swinging})->pres_part, q{swinging}  => q{pres_part 'swinging' --> 'swinging'};
is verb(q{douched})->pres_part, q{douching}  => q{pres_part 'douched' --> 'douching'};
is verb(q{stunk})->pres_part, q{stinking}  => q{pres_part 'stunk' --> 'stinking'};
is verb(q{irises})->pres_part, q{irising}  => q{pres_part 'irises' --> 'irising'};
is verb(q{learns})->pres_part, q{learning}  => q{pres_part 'learns' --> 'learning'};
is verb(q{walking})->pres_part, q{walking}  => q{pres_part 'walking' --> 'walking'};
is verb(q{remembered})->pres_part, q{remembering}  => q{pres_part 'remembered' --> 'remembering'};
is verb(q{betting})->pres_part, q{betting}  => q{pres_part 'betting' --> 'betting'};
is verb(q{standing})->pres_part, q{standing}  => q{pres_part 'standing' --> 'standing'};
is verb(q{moved})->pres_part, q{moving}  => q{pres_part 'moved' --> 'moving'};
is verb(q{keeping})->pres_part, q{keeping}  => q{pres_part 'keeping' --> 'keeping'};
is verb(q{stripped})->pres_part, q{stripping}  => q{pres_part 'stripped' --> 'stripping'};
is verb(q{begin})->pres_part, q{beginning}  => q{pres_part 'begin' --> 'beginning'};
is verb(q{foretells})->pres_part, q{foretelling}  => q{pres_part 'foretells' --> 'foretelling'};
is verb(q{continued})->pres_part, q{continuing}  => q{pres_part 'continued' --> 'continuing'};
is verb(q{going})->pres_part, q{going}  => q{pres_part 'going' --> 'going'};
is verb(q{helped})->pres_part, q{helping}  => q{pres_part 'helped' --> 'helping'};
is verb(q{break})->pres_part, q{breaking}  => q{pres_part 'break' --> 'breaking'};
is verb(q{drinking})->pres_part, q{drinking}  => q{pres_part 'drinking' --> 'drinking'};
is verb(q{bite})->pres_part, q{biting}  => q{pres_part 'bite' --> 'biting'};
is verb(q{overtakes})->pres_part, q{overtaking}  => q{pres_part 'overtakes' --> 'overtaking'};
is verb(q{bellyaching})->pres_part, q{bellyaching}  => q{pres_part 'bellyaching' --> 'bellyaching'};
is verb(q{liked})->pres_part, q{liking}  => q{pres_part 'liked' --> 'liking'};
is verb(q{follow})->pres_part, q{following}  => q{pres_part 'follow' --> 'following'};
is verb(q{deals})->pres_part, q{dealing}  => q{pres_part 'deals' --> 'dealing'};
is verb(q{quits})->pres_part, q{quitting}  => q{pres_part 'quits' --> 'quitting'};
is verb(q{weep})->pres_part, q{weeping}  => q{pres_part 'weep' --> 'weeping'};
is verb(q{overheard})->pres_part, q{overhearing}  => q{pres_part 'overheard' --> 'overhearing'};
is verb(q{seemed})->pres_part, q{seeming}  => q{pres_part 'seemed' --> 'seeming'};
is verb(q{swelled})->pres_part, q{swelling}  => q{pres_part 'swelled' --> 'swelling'};
is verb(q{overtaken})->pres_part, q{overtaking}  => q{pres_part 'overtaken' --> 'overtaking'};
is verb(q{caught})->pres_part, q{catching}  => q{pres_part 'caught' --> 'catching'};
is verb(q{sow})->pres_part, q{sowing}  => q{pres_part 'sow' --> 'sowing'};
is verb(q{flings})->pres_part, q{flinging}  => q{pres_part 'flings' --> 'flinging'};
is verb(q{niched})->pres_part, q{nicheing}  => q{pres_part 'niched' --> 'nicheing'};
is verb(q{menuing})->pres_part, q{menuing}  => q{pres_part 'menuing' --> 'menuing'};
is verb(q{foretold})->pres_part, q{foretelling}  => q{pres_part 'foretold' --> 'foretelling'};
is verb(q{dealing})->pres_part, q{dealing}  => q{pres_part 'dealing' --> 'dealing'};
is verb(q{sat})->pres_part, q{sitting}  => q{pres_part 'sat' --> 'sitting'};
is verb(q{knit})->pres_part, q{knitting}  => q{pres_part 'knit' --> 'knitting'};
is verb(q{foresees})->pres_part, q{foreseeing}  => q{pres_part 'foresees' --> 'foreseeing'};
is verb(q{followed})->pres_part, q{following}  => q{pres_part 'followed' --> 'following'};
is verb(q{coming})->pres_part, q{coming}  => q{pres_part 'coming' --> 'coming'};
is verb(q{wended})->pres_part, q{wending}  => q{pres_part 'wended' --> 'wending'};
is verb(q{withdrew})->pres_part, q{withdrawing}  => q{pres_part 'withdrew' --> 'withdrawing'};
is verb(q{killed})->pres_part, q{killing}  => q{pres_part 'killed' --> 'killing'};
is verb(q{clapping})->pres_part, q{clapping}  => q{pres_part 'clapping' --> 'clapping'};
is verb(q{thrived})->pres_part, q{thriving}  => q{pres_part 'thrived' --> 'thriving'};
is verb(q{rids})->pres_part, q{ridding}  => q{pres_part 'rids' --> 'ridding'};
is verb(q{look})->pres_part, q{looking}  => q{pres_part 'look' --> 'looking'};
is verb(q{hold})->pres_part, q{holding}  => q{pres_part 'hold' --> 'holding'};
is verb(q{fly})->pres_part, q{flying}  => q{pres_part 'fly' --> 'flying'};
is verb(q{slinks})->pres_part, q{slinking}  => q{pres_part 'slinks' --> 'slinking'};
is verb(q{slid})->pres_part, q{sliding}  => q{pres_part 'slid' --> 'sliding'};
is verb(q{knitted})->pres_part, q{knitting}  => q{pres_part 'knitted' --> 'knitting'};
is verb(q{wept})->pres_part, q{weeping}  => q{pres_part 'wept' --> 'weeping'};
is verb(q{slay})->pres_part, q{slaying}  => q{pres_part 'slay' --> 'slaying'};
is verb(q{aching})->pres_part, q{aching}  => q{pres_part 'aching' --> 'aching'};
is verb(q{awakening})->pres_part, q{awakening}  => q{pres_part 'awakening' --> 'awakening'};
is verb(q{irised})->pres_part, q{irising}  => q{pres_part 'irised' --> 'irising'};
is verb(q{menus})->pres_part, q{menuing}  => q{pres_part 'menus' --> 'menuing'};
is verb(q{lean})->pres_part, q{leaning}  => q{pres_part 'lean' --> 'leaning'};
is verb(q{avalanched})->pres_part, q{avalanching}  => q{pres_part 'avalanched' --> 'avalanching'};
is verb(q{undertook})->pres_part, q{undertaking}  => q{pres_part 'undertook' --> 'undertaking'};
is verb(q{sawing})->pres_part, q{sawing}  => q{pres_part 'sawing' --> 'sawing'};
is verb(q{dragging})->pres_part, q{dragging}  => q{pres_part 'dragging' --> 'dragging'};
is verb(q{show})->pres_part, q{showing}  => q{pres_part 'show' --> 'showing'};
is verb(q{knew})->pres_part, q{knowing}  => q{pres_part 'knew' --> 'knowing'};
is verb(q{digging})->pres_part, q{digging}  => q{pres_part 'digging' --> 'digging'};
is verb(q{inlay})->pres_part, q{inlaying}  => q{pres_part 'inlay' --> 'inlaying'};
is verb(q{swept})->pres_part, q{sweeping}  => q{pres_part 'swept' --> 'sweeping'};
is verb(q{breeds})->pres_part, q{breeding}  => q{pres_part 'breeds' --> 'breeding'};
is verb(q{needs})->pres_part, q{needing}  => q{pres_part 'needs' --> 'needing'};
is verb(q{withdrawn})->pres_part, q{withdrawing}  => q{pres_part 'withdrawn' --> 'withdrawing'};
is verb(q{thrives})->pres_part, q{thriving}  => q{pres_part 'thrives' --> 'thriving'};
is verb(q{burning})->pres_part, q{burning}  => q{pres_part 'burning' --> 'burning'};
is verb(q{rung})->pres_part, q{ringing}  => q{pres_part 'rung' --> 'ringing'};
is verb(q{douche})->pres_part, q{douching}  => q{pres_part 'douche' --> 'douching'};
is verb(q{ate})->pres_part, q{eating}  => q{pres_part 'ate' --> 'eating'};
is verb(q{stealing})->pres_part, q{stealing}  => q{pres_part 'stealing' --> 'stealing'};
is verb(q{understanding})->pres_part, q{understanding}  => q{pres_part 'understanding' --> 'understanding'};
is verb(q{forget})->pres_part, q{forgetting}  => q{pres_part 'forget' --> 'forgetting'};
is verb(q{lived})->pres_part, q{living}  => q{pres_part 'lived' --> 'living'};
is verb(q{interlays})->pres_part, q{interlaying}  => q{pres_part 'interlays' --> 'interlaying'};
is verb(q{psyching})->pres_part, q{psyching}  => q{pres_part 'psyching' --> 'psyching'};
is verb(q{quiz})->pres_part, q{quizzing}  => q{pres_part 'quiz' --> 'quizzing'};
is verb(q{foresee})->pres_part, q{foreseeing}  => q{pres_part 'foresee' --> 'foreseeing'};
is verb(q{kneeling})->pres_part, q{kneeling}  => q{pres_part 'kneeling' --> 'kneeling'};
is verb(q{dare})->pres_part, q{daring}  => q{pres_part 'dare' --> 'daring'};
is verb(q{lay})->pres_part, q{laying}  => q{pres_part 'lay' --> 'laying'};
is verb(q{overdraw})->pres_part, q{overdrawing}  => q{pres_part 'overdraw' --> 'overdrawing'};
is verb(q{overdrawing})->pres_part, q{overdrawing}  => q{pres_part 'overdrawing' --> 'overdrawing'};
is verb(q{dug})->pres_part, q{digging}  => q{pres_part 'dug' --> 'digging'};
is verb(q{sunburned})->pres_part, q{sunburning}  => q{pres_part 'sunburned' --> 'sunburning'};
is verb(q{kneel})->pres_part, q{kneeling}  => q{pres_part 'kneel' --> 'kneeling'};
is verb(q{needing})->pres_part, q{needing}  => q{pres_part 'needing' --> 'needing'};
is verb(q{interlaid})->pres_part, q{interlaying}  => q{pres_part 'interlaid' --> 'interlaying'};
is verb(q{burns})->pres_part, q{burning}  => q{pres_part 'burns' --> 'burning'};
is verb(q{arises})->pres_part, q{arising}  => q{pres_part 'arises' --> 'arising'};
is verb(q{presetting})->pres_part, q{presetting}  => q{pres_part 'presetting' --> 'presetting'};
is verb(q{becomes})->pres_part, q{becoming}  => q{pres_part 'becomes' --> 'becoming'};
is verb(q{wrung})->pres_part, q{wringing}  => q{pres_part 'wrung' --> 'wringing'};
is verb(q{cached})->pres_part, q{caching}  => q{pres_part 'cached' --> 'caching'};
is verb(q{undergoes})->pres_part, q{undergoing}  => q{pres_part 'undergoes' --> 'undergoing'};
is verb(q{aches})->pres_part, q{aching}  => q{pres_part 'aches' --> 'aching'};
is verb(q{rise})->pres_part, q{rising}  => q{pres_part 'rise' --> 'rising'};
is verb(q{riven})->pres_part, q{riving}  => q{pres_part 'riven' --> 'riving'};
is verb(q{grinds})->pres_part, q{grinding}  => q{pres_part 'grinds' --> 'grinding'};
is verb(q{slits})->pres_part, q{slitting}  => q{pres_part 'slits' --> 'slitting'};
is verb(q{swimming})->pres_part, q{swimming}  => q{pres_part 'swimming' --> 'swimming'};
is verb(q{eat})->pres_part, q{eating}  => q{pres_part 'eat' --> 'eating'};
is verb(q{have})->pres_part, q{having}  => q{pres_part 'have' --> 'having'};
is verb(q{steal})->pres_part, q{stealing}  => q{pres_part 'steal' --> 'stealing'};
is verb(q{sowed})->pres_part, q{sowing}  => q{pres_part 'sowed' --> 'sowing'};
is verb(q{awoke})->pres_part, q{awakening}  => q{pres_part 'awoke' --> 'awakening'};
is verb(q{given})->pres_part, q{giving}  => q{pres_part 'given' --> 'giving'};
is verb(q{rode})->pres_part, q{riding}  => q{pres_part 'rode' --> 'riding'};
is verb(q{inlaying})->pres_part, q{inlaying}  => q{pres_part 'inlaying' --> 'inlaying'};
is verb(q{sprung})->pres_part, q{springing}  => q{pres_part 'sprung' --> 'springing'};
is verb(q{comes})->pres_part, q{coming}  => q{pres_part 'comes' --> 'coming'};
is verb(q{following})->pres_part, q{following}  => q{pres_part 'following' --> 'following'};
is verb(q{foreseeing})->pres_part, q{foreseeing}  => q{pres_part 'foreseeing' --> 'foreseeing'};
is verb(q{bitten})->pres_part, q{biting}  => q{pres_part 'bitten' --> 'biting'};
is verb(q{presets})->pres_part, q{presetting}  => q{pres_part 'presets' --> 'presetting'};
is verb(q{worn})->pres_part, q{wearing}  => q{pres_part 'worn' --> 'wearing'};
is verb(q{quizzing})->pres_part, q{quizzing}  => q{pres_part 'quizzing' --> 'quizzing'};
is verb(q{strewn})->pres_part, q{strewing}  => q{pres_part 'strewn' --> 'strewing'};
is verb(q{wear})->pres_part, q{wearing}  => q{pres_part 'wear' --> 'wearing'};
is verb(q{forgetting})->pres_part, q{forgetting}  => q{pres_part 'forgetting' --> 'forgetting'};
is verb(q{spends})->pres_part, q{spending}  => q{pres_part 'spends' --> 'spending'};
is verb(q{stinging})->pres_part, q{stinging}  => q{pres_part 'stinging' --> 'stinging'};
is verb(q{douches})->pres_part, q{douching}  => q{pres_part 'douches' --> 'douching'};
is verb(q{bleeds})->pres_part, q{bleeding}  => q{pres_part 'bleeds' --> 'bleeding'};
is verb(q{building})->pres_part, q{building}  => q{pres_part 'building' --> 'building'};
is verb(q{spoiling})->pres_part, q{spoiling}  => q{pres_part 'spoiling' --> 'spoiling'};
is verb(q{thrive})->pres_part, q{thriving}  => q{pres_part 'thrive' --> 'thriving'};
is verb(q{staying})->pres_part, q{staying}  => q{pres_part 'staying' --> 'staying'};
is verb(q{creeps})->pres_part, q{creeping}  => q{pres_part 'creeps' --> 'creeping'};
is verb(q{watching})->pres_part, q{watching}  => q{pres_part 'watching' --> 'watching'};
is verb(q{spits})->pres_part, q{spitting}  => q{pres_part 'spits' --> 'spitting'};
is verb(q{spat})->pres_part, q{spitting}  => q{pres_part 'spat' --> 'spitting'};
is verb(q{rid})->pres_part, q{ridding}  => q{pres_part 'rid' --> 'ridding'};
is verb(q{mistaken})->pres_part, q{mistaking}  => q{pres_part 'mistaken' --> 'mistaking'};
is verb(q{spoken})->pres_part, q{speaking}  => q{pres_part 'spoken' --> 'speaking'};
is verb(q{hurting})->pres_part, q{hurting}  => q{pres_part 'hurting' --> 'hurting'};
is verb(q{withstood})->pres_part, q{withstanding}  => q{pres_part 'withstood' --> 'withstanding'};
is verb(q{talked})->pres_part, q{talking}  => q{pres_part 'talked' --> 'talking'};
is verb(q{sink})->pres_part, q{sinking}  => q{pres_part 'sink' --> 'sinking'};
is verb(q{forgets})->pres_part, q{forgetting}  => q{pres_part 'forgets' --> 'forgetting'};
is verb(q{flee})->pres_part, q{fleeing}  => q{pres_part 'flee' --> 'fleeing'};
is verb(q{bellyache})->pres_part, q{bellyaching}  => q{pres_part 'bellyache' --> 'bellyaching'};
is verb(q{blow})->pres_part, q{blowing}  => q{pres_part 'blow' --> 'blowing'};
is verb(q{become})->pres_part, q{becoming}  => q{pres_part 'become' --> 'becoming'};
is verb(q{inlaid})->pres_part, q{inlaying}  => q{pres_part 'inlaid' --> 'inlaying'};
is verb(q{stays})->pres_part, q{staying}  => q{pres_part 'stays' --> 'staying'};
is verb(q{sows})->pres_part, q{sowing}  => q{pres_part 'sows' --> 'sowing'};
is verb(q{stripping})->pres_part, q{stripping}  => q{pres_part 'stripping' --> 'stripping'};
is verb(q{hewing})->pres_part, q{hewing}  => q{pres_part 'hewing' --> 'hewing'};
is verb(q{spoil})->pres_part, q{spoiling}  => q{pres_part 'spoil' --> 'spoiling'};
is verb(q{preset})->pres_part, q{presetting}  => q{pres_part 'preset' --> 'presetting'};
is verb(q{dwelt})->pres_part, q{dwelling}  => q{pres_part 'dwelt' --> 'dwelling'};
is verb(q{brings})->pres_part, q{bringing}  => q{pres_part 'brings' --> 'bringing'};
is verb(q{watch})->pres_part, q{watching}  => q{pres_part 'watch' --> 'watching'};
is verb(q{hurts})->pres_part, q{hurting}  => q{pres_part 'hurts' --> 'hurting'};
is verb(q{withdraws})->pres_part, q{withdrawing}  => q{pres_part 'withdraws' --> 'withdrawing'};
is verb(q{led})->pres_part, q{leading}  => q{pres_part 'led' --> 'leading'};
is verb(q{caches})->pres_part, q{caching}  => q{pres_part 'caches' --> 'caching'};
is verb(q{sprang})->pres_part, q{springing}  => q{pres_part 'sprang' --> 'springing'};
is verb(q{build})->pres_part, q{building}  => q{pres_part 'build' --> 'building'};
is verb(q{sting})->pres_part, q{stinging}  => q{pres_part 'sting' --> 'stinging'};
is verb(q{beheld})->pres_part, q{beholding}  => q{pres_part 'beheld' --> 'beholding'};
is verb(q{springing})->pres_part, q{springing}  => q{pres_part 'springing' --> 'springing'};
is verb(q{broken})->pres_part, q{breaking}  => q{pres_part 'broken' --> 'breaking'};
is verb(q{overdrawn})->pres_part, q{overdrawing}  => q{pres_part 'overdrawn' --> 'overdrawing'};
is verb(q{leaps})->pres_part, q{leaping}  => q{pres_part 'leaps' --> 'leaping'};
is verb(q{strews})->pres_part, q{strewing}  => q{pres_part 'strews' --> 'strewing'};
is verb(q{hew})->pres_part, q{hewing}  => q{pres_part 'hew' --> 'hewing'};
is verb(q{swore})->pres_part, q{swearing}  => q{pres_part 'swore' --> 'swearing'};
is verb(q{fight})->pres_part, q{fighting}  => q{pres_part 'fight' --> 'fighting'};
is verb(q{arisen})->pres_part, q{arising}  => q{pres_part 'arisen' --> 'arising'};
is verb(q{wait})->pres_part, q{waiting}  => q{pres_part 'wait' --> 'waiting'};
is verb(q{lying})->pres_part, q{lying}  => q{pres_part 'lying' --> 'lying'};
is verb(q{sweats})->pres_part, q{sweating}  => q{pres_part 'sweats' --> 'sweating'};
is verb(q{tears})->pres_part, q{tearing}  => q{pres_part 'tears' --> 'tearing'};
is verb(q{stung})->pres_part, q{stinging}  => q{pres_part 'stung' --> 'stinging'};
is verb(q{is})->pres_part, q{being}  => q{pres_part 'is' --> 'being'};
is verb(q{withdraw})->pres_part, q{withdrawing}  => q{pres_part 'withdraw' --> 'withdrawing'};
is verb(q{withdrawing})->pres_part, q{withdrawing}  => q{pres_part 'withdrawing' --> 'withdrawing'};
is verb(q{happening})->pres_part, q{happening}  => q{pres_part 'happening' --> 'happening'};
is verb(q{shoes})->pres_part, q{shoeing}  => q{pres_part 'shoes' --> 'shoeing'};
is verb(q{sunburn})->pres_part, q{sunburning}  => q{pres_part 'sunburn' --> 'sunburning'};
is verb(q{saws})->pres_part, q{sawing}  => q{pres_part 'saws' --> 'sawing'};
is verb(q{gilded})->pres_part, q{gilding}  => q{pres_part 'gilded' --> 'gilding'};
is verb(q{give})->pres_part, q{giving}  => q{pres_part 'give' --> 'giving'};
is verb(q{lies})->pres_part, q{lying}  => q{pres_part 'lies' --> 'lying'};
is verb(q{leaping})->pres_part, q{leaping}  => q{pres_part 'leaping' --> 'leaping'};
is verb(q{was})->pres_part, q{being}  => q{pres_part 'was' --> 'being'};
is verb(q{slides})->pres_part, q{sliding}  => q{pres_part 'slides' --> 'sliding'};
is verb(q{fighting})->pres_part, q{fighting}  => q{pres_part 'fighting' --> 'fighting'};
is verb(q{wakes})->pres_part, q{waking}  => q{pres_part 'wakes' --> 'waking'};
is verb(q{beget})->pres_part, q{begetting}  => q{pres_part 'beget' --> 'begetting'};
is verb(q{wore})->pres_part, q{wearing}  => q{pres_part 'wore' --> 'wearing'};
is verb(q{began})->pres_part, q{beginning}  => q{pres_part 'began' --> 'beginning'};
is verb(q{spoiled})->pres_part, q{spoiling}  => q{pres_part 'spoiled' --> 'spoiling'};
is verb(q{moving})->pres_part, q{moving}  => q{pres_part 'moving' --> 'moving'};
is verb(q{riding})->pres_part, q{riding}  => q{pres_part 'riding' --> 'riding'};
is verb(q{crept})->pres_part, q{creeping}  => q{pres_part 'crept' --> 'creeping'};
is verb(q{catches})->pres_part, q{catching}  => q{pres_part 'catches' --> 'catching'};
is verb(q{bent})->pres_part, q{bending}  => q{pres_part 'bent' --> 'bending'};
is verb(q{watched})->pres_part, q{watching}  => q{pres_part 'watched' --> 'watching'};
is verb(q{tearing})->pres_part, q{tearing}  => q{pres_part 'tearing' --> 'tearing'};
is verb(q{help})->pres_part, q{helping}  => q{pres_part 'help' --> 'helping'};
is verb(q{sunburning})->pres_part, q{sunburning}  => q{pres_part 'sunburning' --> 'sunburning'};
is verb(q{smiting})->pres_part, q{smiting}  => q{pres_part 'smiting' --> 'smiting'};
is verb(q{avalanches})->pres_part, q{avalanching}  => q{pres_part 'avalanches' --> 'avalanching'};
is verb(q{liking})->pres_part, q{liking}  => q{pres_part 'liking' --> 'liking'};
is verb(q{awakes})->pres_part, q{awakening}  => q{pres_part 'awakes' --> 'awakening'};
is verb(q{rive})->pres_part, q{riving}  => q{pres_part 'rive' --> 'riving'};
is verb(q{shoeing})->pres_part, q{shoeing}  => q{pres_part 'shoeing' --> 'shoeing'};
is verb(q{risen})->pres_part, q{rising}  => q{pres_part 'risen' --> 'rising'};
is verb(q{staves})->pres_part, q{staving}  => q{pres_part 'staves' --> 'staving'};
is verb(q{seem})->pres_part, q{seeming}  => q{pres_part 'seem' --> 'seeming'};
is verb(q{rend})->pres_part, q{rending}  => q{pres_part 'rend' --> 'rending'};
is verb(q{quizzed})->pres_part, q{quizzing}  => q{pres_part 'quizzed' --> 'quizzing'};
is verb(q{beat})->pres_part, q{beating}  => q{pres_part 'beat' --> 'beating'};
is verb(q{wanting})->pres_part, q{wanting}  => q{pres_part 'wanting' --> 'wanting'};
is verb(q{leads})->pres_part, q{leading}  => q{pres_part 'leads' --> 'leading'};
is verb(q{forsaken})->pres_part, q{forsaking}  => q{pres_part 'forsaken' --> 'forsaking'};
is verb(q{beholding})->pres_part, q{beholding}  => q{pres_part 'beholding' --> 'beholding'};
is verb(q{wring})->pres_part, q{wringing}  => q{pres_part 'wring' --> 'wringing'};
is verb(q{upsets})->pres_part, q{upsetting}  => q{pres_part 'upsets' --> 'upsetting'};
is verb(q{meeting})->pres_part, q{meeting}  => q{pres_part 'meeting' --> 'meeting'};
is verb(q{lives})->pres_part, q{living}  => q{pres_part 'lives' --> 'living'};
is verb(q{gotten})->pres_part, q{getting}  => q{pres_part 'gotten' --> 'getting'};
is verb(q{find})->pres_part, q{finding}  => q{pres_part 'find' --> 'finding'};
is verb(q{dreams})->pres_part, q{dreaming}  => q{pres_part 'dreams' --> 'dreaming'};
is verb(q{sneaks})->pres_part, q{sneaking}  => q{pres_part 'sneaks' --> 'sneaking'};
is verb(q{eating})->pres_part, q{eating}  => q{pres_part 'eating' --> 'eating'};
is verb(q{speeds})->pres_part, q{speeding}  => q{pres_part 'speeds' --> 'speeding'};
is verb(q{rings})->pres_part, q{ringing}  => q{pres_part 'rings' --> 'ringing'};
is verb(q{feel})->pres_part, q{feeling}  => q{pres_part 'feel' --> 'feeling'};
is verb(q{run})->pres_part, q{running}  => q{pres_part 'run' --> 'running'};
is verb(q{bursting})->pres_part, q{bursting}  => q{pres_part 'bursting' --> 'bursting'};
is verb(q{costs})->pres_part, q{costing}  => q{pres_part 'costs' --> 'costing'};
is verb(q{bet})->pres_part, q{betting}  => q{pres_part 'bet' --> 'betting'};
is verb(q{foresaw})->pres_part, q{foreseeing}  => q{pres_part 'foresaw' --> 'foreseeing'};
is verb(q{had})->pres_part, q{having}  => q{pres_part 'had' --> 'having'};
is verb(q{looked})->pres_part, q{looking}  => q{pres_part 'looked' --> 'looking'};
is verb(q{burst})->pres_part, q{bursting}  => q{pres_part 'burst' --> 'bursting'};
is verb(q{smite})->pres_part, q{smiting}  => q{pres_part 'smite' --> 'smiting'};
is verb(q{kill})->pres_part, q{killing}  => q{pres_part 'kill' --> 'killing'};
is verb(q{strip})->pres_part, q{stripping}  => q{pres_part 'strip' --> 'stripping'};
is verb(q{leading})->pres_part, q{leading}  => q{pres_part 'leading' --> 'leading'};
is verb(q{wants})->pres_part, q{wanting}  => q{pres_part 'wants' --> 'wanting'};
is verb(q{chose})->pres_part, q{choosing}  => q{pres_part 'chose' --> 'choosing'};
is verb(q{found})->pres_part, q{finding}  => q{pres_part 'found' --> 'finding'};
is verb(q{withstand})->pres_part, q{withstanding}  => q{pres_part 'withstand' --> 'withstanding'};
is verb(q{drag})->pres_part, q{dragging}  => q{pres_part 'drag' --> 'dragging'};
is verb(q{wend})->pres_part, q{wending}  => q{pres_part 'wend' --> 'wending'};
is verb(q{dive})->pres_part, q{diving}  => q{pres_part 'dive' --> 'diving'};
is verb(q{meets})->pres_part, q{meeting}  => q{pres_part 'meets' --> 'meeting'};
is verb(q{swears})->pres_part, q{swearing}  => q{pres_part 'swears' --> 'swearing'};
is verb(q{psyched})->pres_part, q{psyching}  => q{pres_part 'psyched' --> 'psyching'};
is verb(q{staved})->pres_part, q{staving}  => q{pres_part 'staved' --> 'staving'};
is verb(q{showed})->pres_part, q{showing}  => q{pres_part 'showed' --> 'showing'};
is verb(q{wringing})->pres_part, q{wringing}  => q{pres_part 'wringing' --> 'wringing'};
is verb(q{forgotten})->pres_part, q{forgetting}  => q{pres_part 'forgotten' --> 'forgetting'};
is verb(q{ringing})->pres_part, q{ringing}  => q{pres_part 'ringing' --> 'ringing'};
is verb(q{ached})->pres_part, q{aching}  => q{pres_part 'ached' --> 'aching'};
is verb(q{blown})->pres_part, q{blowing}  => q{pres_part 'blown' --> 'blowing'};
is verb(q{iris})->pres_part, q{irising}  => q{pres_part 'iris' --> 'irising'};
is verb(q{begun})->pres_part, q{beginning}  => q{pres_part 'begun' --> 'beginning'};
is verb(q{held})->pres_part, q{holding}  => q{pres_part 'held' --> 'holding'};
is verb(q{leaned})->pres_part, q{leaning}  => q{pres_part 'leaned' --> 'leaning'};
is verb(q{overdraws})->pres_part, q{overdrawing}  => q{pres_part 'overdraws' --> 'overdrawing'};
is verb(q{smells})->pres_part, q{smelling}  => q{pres_part 'smells' --> 'smelling'};
is verb(q{undertakes})->pres_part, q{undertaking}  => q{pres_part 'undertakes' --> 'undertaking'};
is verb(q{sweeps})->pres_part, q{sweeping}  => q{pres_part 'sweeps' --> 'sweeping'};
is verb(q{drove})->pres_part, q{driving}  => q{pres_part 'drove' --> 'driving'};
is verb(q{costing})->pres_part, q{costing}  => q{pres_part 'costing' --> 'costing'};
is verb(q{interlaying})->pres_part, q{interlaying}  => q{pres_part 'interlaying' --> 'interlaying'};
is verb(q{interlay})->pres_part, q{interlaying}  => q{pres_part 'interlay' --> 'interlaying'};
is verb(q{laying})->pres_part, q{laying}  => q{pres_part 'laying' --> 'laying'};
is verb(q{overtook})->pres_part, q{overtaking}  => q{pres_part 'overtook' --> 'overtaking'};
is verb(q{sawed})->pres_part, q{sawing}  => q{pres_part 'sawed' --> 'sawing'};
is verb(q{psyches})->pres_part, q{psyching}  => q{pres_part 'psyches' --> 'psyching'};
is verb(q{bound})->pres_part, q{binding}  => q{pres_part 'bound' --> 'binding'};
is verb(q{means})->pres_part, q{meaning}  => q{pres_part 'means' --> 'meaning'};
is verb(q{lose})->pres_part, q{losing}  => q{pres_part 'lose' --> 'losing'};
is verb(q{dragged})->pres_part, q{dragging}  => q{pres_part 'dragged' --> 'dragging'};
is verb(q{forgiven})->pres_part, q{forgiving}  => q{pres_part 'forgiven' --> 'forgiving'};
is verb(q{stolen})->pres_part, q{stealing}  => q{pres_part 'stolen' --> 'stealing'};
is verb(q{laid})->pres_part, q{laying}  => q{pres_part 'laid' --> 'laying'};
is verb(q{swell})->pres_part, q{swelling}  => q{pres_part 'swell' --> 'swelling'};
is verb(q{knitting})->pres_part, q{knitting}  => q{pres_part 'knitting' --> 'knitting'};
is verb(q{driving})->pres_part, q{driving}  => q{pres_part 'driving' --> 'driving'};
is verb(q{thriving})->pres_part, q{thriving}  => q{pres_part 'thriving' --> 'thriving'};
is verb(q{flying})->pres_part, q{flying}  => q{pres_part 'flying' --> 'flying'};
is verb(q{clapped})->pres_part, q{clapping}  => q{pres_part 'clapped' --> 'clapping'};
is verb(q{treads})->pres_part, q{treading}  => q{pres_part 'treads' --> 'treading'};
is verb(q{flown})->pres_part, q{flying}  => q{pres_part 'flown' --> 'flying'};
is verb(q{brought})->pres_part, q{bringing}  => q{pres_part 'brought' --> 'bringing'};
is verb(q{living})->pres_part, q{living}  => q{pres_part 'living' --> 'living'};
is verb(q{abides})->pres_part, q{abiding}  => q{pres_part 'abides' --> 'abiding'};
is verb(q{lie})->pres_part, q{lying}  => q{pres_part 'lie' --> 'lying'};
is verb(q{begot})->pres_part, q{begetting}  => q{pres_part 'begot' --> 'begetting'};
is verb(q{saw})->pres_part, q{sawing}  => q{pres_part 'saw' --> 'sawing'};
is verb(q{meaning})->pres_part, q{meaning}  => q{pres_part 'meaning' --> 'meaning'};
is verb(q{misled})->pres_part, q{misleading}  => q{pres_part 'misled' --> 'misleading'};
is verb(q{quizzes})->pres_part, q{quizzing}  => q{pres_part 'quizzes' --> 'quizzing'};
is verb(q{bind})->pres_part, q{binding}  => q{pres_part 'bind' --> 'binding'};
is verb(q{ridden})->pres_part, q{riding}  => q{pres_part 'ridden' --> 'riding'};
is verb(q{been})->pres_part, q{being}  => q{pres_part 'been' --> 'being'};
is verb(q{bust})->pres_part, q{busting}  => q{pres_part 'bust' --> 'busting'};
is verb(q{continuing})->pres_part, q{continuing}  => q{pres_part 'continuing' --> 'continuing'};
is verb(q{happens})->pres_part, q{happening}  => q{pres_part 'happens' --> 'happening'};
is verb(q{beaten})->pres_part, q{beating}  => q{pres_part 'beaten' --> 'beating'};
is verb(q{hews})->pres_part, q{hewing}  => q{pres_part 'hews' --> 'hewing'};
is verb(q{sowing})->pres_part, q{sowing}  => q{pres_part 'sowing' --> 'sowing'};
is verb(q{clap})->pres_part, q{clapping}  => q{pres_part 'clap' --> 'clapping'};
is verb(q{prove})->pres_part, q{proving}  => q{pres_part 'prove' --> 'proving'};
is verb(q{shaving})->pres_part, q{shaving}  => q{pres_part 'shaving' --> 'shaving'};
is verb(q{leave})->pres_part, q{leaving}  => q{pres_part 'leave' --> 'leaving'};
is verb(q{springs})->pres_part, q{springing}  => q{pres_part 'springs' --> 'springing'};
is verb(q{shod})->pres_part, q{shoeing}  => q{pres_part 'shod' --> 'shoeing'};
is verb(q{swelling})->pres_part, q{swelling}  => q{pres_part 'swelling' --> 'swelling'};
is verb(q{behold})->pres_part, q{beholding}  => q{pres_part 'behold' --> 'beholding'};
is verb(q{dwells})->pres_part, q{dwelling}  => q{pres_part 'dwells' --> 'dwelling'};
is verb(q{withstanding})->pres_part, q{withstanding}  => q{pres_part 'withstanding' --> 'withstanding'};
is verb(q{becoming})->pres_part, q{becoming}  => q{pres_part 'becoming' --> 'becoming'};
is verb(q{shaking})->pres_part, q{shaking}  => q{pres_part 'shaking' --> 'shaking'};
is verb(q{seeking})->pres_part, q{seeking}  => q{pres_part 'seeking' --> 'seeking'};
is verb(q{knows})->pres_part, q{knowing}  => q{pres_part 'knows' --> 'knowing'};
is verb(q{misunderstands})->pres_part, q{misunderstanding}  => q{pres_part 'misunderstands' --> 'misunderstanding'};
is verb(q{swum})->pres_part, q{swimming}  => q{pres_part 'swum' --> 'swimming'};
is verb(q{happened})->pres_part, q{happening}  => q{pres_part 'happened' --> 'happening'};
is verb(q{rang})->pres_part, q{ringing}  => q{pres_part 'rang' --> 'ringing'};
is verb(q{stink})->pres_part, q{stinking}  => q{pres_part 'stink' --> 'stinking'};
is verb(q{upsetting})->pres_part, q{upsetting}  => q{pres_part 'upsetting' --> 'upsetting'};
is verb(q{abided})->pres_part, q{abiding}  => q{pres_part 'abided' --> 'abiding'};
is verb(q{smote})->pres_part, q{smiting}  => q{pres_part 'smote' --> 'smiting'};
is verb(q{flies})->pres_part, q{flying}  => q{pres_part 'flies' --> 'flying'};
is verb(q{psyche})->pres_part, q{psyching}  => q{pres_part 'psyche' --> 'psyching'};
is verb(q{foretelling})->pres_part, q{foretelling}  => q{pres_part 'foretelling' --> 'foretelling'};
is verb(q{am})->pres_part, q{being}  => q{pres_part 'am' --> 'being'};
is verb(q{falls})->pres_part, q{falling}  => q{pres_part 'falls' --> 'falling'};
is verb(q{douching})->pres_part, q{douching}  => q{pres_part 'douching' --> 'douching'};
is verb(q{bending})->pres_part, q{bending}  => q{pres_part 'bending' --> 'bending'};
is verb(q{foretell})->pres_part, q{foretelling}  => q{pres_part 'foretell' --> 'foretelling'};
is verb(q{drive})->pres_part, q{driving}  => q{pres_part 'drive' --> 'driving'};
is verb(q{speaking})->pres_part, q{speaking}  => q{pres_part 'speaking' --> 'speaking'};
is verb(q{overtake})->pres_part, q{overtaking}  => q{pres_part 'overtake' --> 'overtaking'};
is verb(q{watches})->pres_part, q{watching}  => q{pres_part 'watches' --> 'watching'};
is verb(q{undergone})->pres_part, q{undergoing}  => q{pres_part 'undergone' --> 'undergoing'};
is verb(q{talk})->pres_part, q{talking}  => q{pres_part 'talk' --> 'talking'};
is verb(q{undertaken})->pres_part, q{undertaking}  => q{pres_part 'undertaken' --> 'undertaking'};
is verb(q{shat})->pres_part, q{shitting}  => q{pres_part 'shat' --> 'shitting'};
is verb(q{clinging})->pres_part, q{clinging}  => q{pres_part 'clinging' --> 'clinging'};
is verb(q{shits})->pres_part, q{shitting}  => q{pres_part 'shits' --> 'shitting'};
is verb(q{running})->pres_part, q{running}  => q{pres_part 'running' --> 'running'};
is verb(q{begotten})->pres_part, q{begetting}  => q{pres_part 'begotten' --> 'begetting'};
is verb(q{seeks})->pres_part, q{seeking}  => q{pres_part 'seeks' --> 'seeking'};
is verb(q{knowing})->pres_part, q{knowing}  => q{pres_part 'knowing' --> 'knowing'};
is verb(q{bets})->pres_part, q{betting}  => q{pres_part 'bets' --> 'betting'};
is verb(q{happen})->pres_part, q{happening}  => q{pres_part 'happen' --> 'happening'};
is verb(q{cling})->pres_part, q{clinging}  => q{pres_part 'cling' --> 'clinging'};
is verb(q{shake})->pres_part, q{shaking}  => q{pres_part 'shake' --> 'shaking'};
is verb(q{likes})->pres_part, q{liking}  => q{pres_part 'likes' --> 'liking'};
is verb(q{drunk})->pres_part, q{drinking}  => q{pres_part 'drunk' --> 'drinking'};
is verb(q{proving})->pres_part, q{proving}  => q{pres_part 'proving' --> 'proving'};
is verb(q{lost})->pres_part, q{losing}  => q{pres_part 'lost' --> 'losing'};
is verb(q{overdrew})->pres_part, q{overdrawing}  => q{pres_part 'overdrew' --> 'overdrawing'};
is verb(q{leaving})->pres_part, q{leaving}  => q{pres_part 'leaving' --> 'leaving'};
is verb(q{shave})->pres_part, q{shaving}  => q{pres_part 'shave' --> 'shaving'};
is verb(q{runs})->pres_part, q{running}  => q{pres_part 'runs' --> 'running'};
is verb(q{rides})->pres_part, q{riding}  => q{pres_part 'rides' --> 'riding'};
is verb(q{moves})->pres_part, q{moving}  => q{pres_part 'moves' --> 'moving'};
is verb(q{spent})->pres_part, q{spending}  => q{pres_part 'spent' --> 'spending'};
is verb(q{shown})->pres_part, q{showing}  => q{pres_part 'shown' --> 'showing'};
is verb(q{speak})->pres_part, q{speaking}  => q{pres_part 'speak' --> 'speaking'};
is verb(q{shedding})->pres_part, q{shedding}  => q{pres_part 'shedding' --> 'shedding'};
is verb(q{sunburns})->pres_part, q{sunburning}  => q{pres_part 'sunburns' --> 'sunburning'};
is verb(q{hewed})->pres_part, q{hewing}  => q{pres_part 'hewed' --> 'hewing'};
is verb(q{stinking})->pres_part, q{stinking}  => q{pres_part 'stinking' --> 'stinking'};
is verb(q{waking})->pres_part, q{waking}  => q{pres_part 'waking' --> 'waking'};
is verb(q{swung})->pres_part, q{swinging}  => q{pres_part 'swung' --> 'swinging'};
is verb(q{falling})->pres_part, q{falling}  => q{pres_part 'falling' --> 'falling'};
is verb(q{bends})->pres_part, q{bending}  => q{pres_part 'bends' --> 'bending'};
is verb(q{won})->pres_part, q{winning}  => q{pres_part 'won' --> 'winning'};
is verb(q{beholds})->pres_part, q{beholding}  => q{pres_part 'beholds' --> 'beholding'};
is verb(q{spring})->pres_part, q{springing}  => q{pres_part 'spring' --> 'springing'};
is verb(q{gave})->pres_part, q{giving}  => q{pres_part 'gave' --> 'giving'};
is verb(q{grinding})->pres_part, q{grinding}  => q{pres_part 'grinding' --> 'grinding'};
is verb(q{shook})->pres_part, q{shaking}  => q{pres_part 'shook' --> 'shaking'};
is verb(q{diving})->pres_part, q{diving}  => q{pres_part 'diving' --> 'diving'};
is verb(q{claps})->pres_part, q{clapping}  => q{pres_part 'claps' --> 'clapping'};
is verb(q{shrink})->pres_part, q{shrinking}  => q{pres_part 'shrink' --> 'shrinking'};
is verb(q{die})->pres_part, q{dying}  => q{pres_part 'die' --> 'dying'};
is verb(q{flew})->pres_part, q{flying}  => q{pres_part 'flew' --> 'flying'};
is verb(q{withheld})->pres_part, q{withholding}  => q{pres_part 'withheld' --> 'withholding'};
is verb(q{changes})->pres_part, q{changing}  => q{pres_part 'changes' --> 'changing'};
is verb(q{hewn})->pres_part, q{hewing}  => q{pres_part 'hewn' --> 'hewing'};
is verb(q{breed})->pres_part, q{breeding}  => q{pres_part 'breed' --> 'breeding'};
is verb(q{inlays})->pres_part, q{inlaying}  => q{pres_part 'inlays' --> 'inlaying'};
is verb(q{went})->pres_part, q{going}  => q{pres_part 'went' --> 'going'};
is verb(q{busts})->pres_part, q{busting}  => q{pres_part 'busts' --> 'busting'};
is verb(q{quitting})->pres_part, q{quitting}  => q{pres_part 'quitting' --> 'quitting'};
is verb(q{continues})->pres_part, q{continuing}  => q{pres_part 'continues' --> 'continuing'};
is verb(q{creche})->pres_part, q{creching}  => q{pres_part 'creche' --> 'creching'};
is verb(q{binds})->pres_part, q{binding}  => q{pres_part 'binds' --> 'binding'};
is verb(q{dreamed})->pres_part, q{dreaming}  => q{pres_part 'dreamed' --> 'dreaming'};
is verb(q{sneaked})->pres_part, q{sneaking}  => q{pres_part 'sneaked' --> 'sneaking'};
is verb(q{spoilt})->pres_part, q{spoiling}  => q{pres_part 'spoilt' --> 'spoiling'};
is verb(q{steals})->pres_part, q{stealing}  => q{pres_part 'steals' --> 'stealing'};
is verb(q{broke})->pres_part, q{breaking}  => q{pres_part 'broke' --> 'breaking'};
is verb(q{ground})->pres_part, q{grinding}  => q{pres_part 'ground' --> 'grinding'};
is verb(q{dealt})->pres_part, q{dealing}  => q{pres_part 'dealt' --> 'dealing'};
is verb(q{smelled})->pres_part, q{smelling}  => q{pres_part 'smelled' --> 'smelling'};
is verb(q{being})->pres_part, q{being}  => q{pres_part 'being' --> 'being'};
is verb(q{thrusts})->pres_part, q{thrusting}  => q{pres_part 'thrusts' --> 'thrusting'};
is verb(q{breeding})->pres_part, q{breeding}  => q{pres_part 'breeding' --> 'breeding'};
is verb(q{mistakes})->pres_part, q{mistaking}  => q{pres_part 'mistakes' --> 'mistaking'};
is verb(q{sitting})->pres_part, q{sitting}  => q{pres_part 'sitting' --> 'sitting'};
is verb(q{ski})->pres_part, q{skiing}  => q{pres_part 'ski' --> 'skiing'};
is verb(q{kneels})->pres_part, q{kneeling}  => q{pres_part 'kneels' --> 'kneeling'};
is verb(q{caching})->pres_part, q{caching}  => q{pres_part 'caching' --> 'caching'};
is verb(q{strive})->pres_part, q{striving}  => q{pres_part 'strive' --> 'striving'};
is verb(q{stood})->pres_part, q{standing}  => q{pres_part 'stood' --> 'standing'};
is verb(q{arise})->pres_part, q{arising}  => q{pres_part 'arise' --> 'arising'};
is verb(q{mean})->pres_part, q{meaning}  => q{pres_part 'mean' --> 'meaning'};
is verb(q{rent})->pres_part, q{rending}  => q{pres_part 'rent' --> 'rending'};
is verb(q{putting})->pres_part, q{putting}  => q{pres_part 'putting' --> 'putting'};
is verb(q{loses})->pres_part, q{losing}  => q{pres_part 'loses' --> 'losing'};
is verb(q{busting})->pres_part, q{busting}  => q{pres_part 'busting' --> 'busting'};
is verb(q{providing})->pres_part, q{providing}  => q{pres_part 'providing' --> 'providing'};
is verb(q{needed})->pres_part, q{needing}  => q{pres_part 'needed' --> 'needing'};
is verb(q{grind})->pres_part, q{grinding}  => q{pres_part 'grind' --> 'grinding'};
is verb(q{binding})->pres_part, q{binding}  => q{pres_part 'binding' --> 'binding'};
is verb(q{misleads})->pres_part, q{misleading}  => q{pres_part 'misleads' --> 'misleading'};
is verb(q{chosen})->pres_part, q{choosing}  => q{pres_part 'chosen' --> 'choosing'};
is verb(q{get})->pres_part, q{getting}  => q{pres_part 'get' --> 'getting'};
is verb(q{sweated})->pres_part, q{sweating}  => q{pres_part 'sweated' --> 'sweating'};
is verb(q{bend})->pres_part, q{bending}  => q{pres_part 'bend' --> 'bending'};
is verb(q{shrinks})->pres_part, q{shrinking}  => q{pres_part 'shrinks' --> 'shrinking'};
is verb(q{rose})->pres_part, q{rising}  => q{pres_part 'rose' --> 'rising'};
is verb(q{giving})->pres_part, q{giving}  => q{pres_part 'giving' --> 'giving'};
is verb(q{talking})->pres_part, q{talking}  => q{pres_part 'talking' --> 'talking'};
is verb(q{forsook})->pres_part, q{forsaking}  => q{pres_part 'forsook' --> 'forsaking'};
is verb(q{like})->pres_part, q{liking}  => q{pres_part 'like' --> 'liking'};
is verb(q{riving})->pres_part, q{riving}  => q{pres_part 'riving' --> 'riving'};
is verb(q{creches})->pres_part, q{creching}  => q{pres_part 'creches' --> 'creching'};
is verb(q{seek})->pres_part, q{seeking}  => q{pres_part 'seek' --> 'seeking'};
is verb(q{stayed})->pres_part, q{staying}  => q{pres_part 'stayed' --> 'staying'};
is verb(q{bleed})->pres_part, q{bleeding}  => q{pres_part 'bleed' --> 'bleeding'};
is verb(q{spend})->pres_part, q{spending}  => q{pres_part 'spend' --> 'spending'};
is verb(q{strewed})->pres_part, q{strewing}  => q{pres_part 'strewed' --> 'strewing'};
is verb(q{ride})->pres_part, q{riding}  => q{pres_part 'ride' --> 'riding'};
is verb(q{move})->pres_part, q{moving}  => q{pres_part 'move' --> 'moving'};
is verb(q{creep})->pres_part, q{creeping}  => q{pres_part 'creep' --> 'creeping'};
is verb(q{change})->pres_part, q{changing}  => q{pres_part 'change' --> 'changing'};
is verb(q{bringing})->pres_part, q{bringing}  => q{pres_part 'bringing' --> 'bringing'};
is verb(q{provide})->pres_part, q{providing}  => q{pres_part 'provide' --> 'providing'};
is verb(q{spoils})->pres_part, q{spoiling}  => q{pres_part 'spoils' --> 'spoiling'};
is verb(q{strode})->pres_part, q{striding}  => q{pres_part 'strode' --> 'striding'};
is verb(q{bring})->pres_part, q{bringing}  => q{pres_part 'bring' --> 'bringing'};
is verb(q{fall})->pres_part, q{falling}  => q{pres_part 'fall' --> 'falling'};
is verb(q{creeping})->pres_part, q{creeping}  => q{pres_part 'creeping' --> 'creeping'};
is verb(q{thrust})->pres_part, q{thrusting}  => q{pres_part 'thrust' --> 'thrusting'};
is verb(q{cache})->pres_part, q{caching}  => q{pres_part 'cache' --> 'caching'};
is verb(q{overhears})->pres_part, q{overhearing}  => q{pres_part 'overhears' --> 'overhearing'};
is verb(q{hitting})->pres_part, q{hitting}  => q{pres_part 'hitting' --> 'hitting'};
is verb(q{builds})->pres_part, q{building}  => q{pres_part 'builds' --> 'building'};
is verb(q{bleeding})->pres_part, q{bleeding}  => q{pres_part 'bleeding' --> 'bleeding'};
is verb(q{bellyaches})->pres_part, q{bellyaching}  => q{pres_part 'bellyaches' --> 'bellyaching'};
is verb(q{stopping})->pres_part, q{stopping}  => q{pres_part 'stopping' --> 'stopping'};
is verb(q{stings})->pres_part, q{stinging}  => q{pres_part 'stings' --> 'stinging'};
is verb(q{talks})->pres_part, q{talking}  => q{pres_part 'talks' --> 'talking'};
is verb(q{spending})->pres_part, q{spending}  => q{pres_part 'spending' --> 'spending'};
is verb(q{arising})->pres_part, q{arising}  => q{pres_part 'arising' --> 'arising'};
is verb(q{shit})->pres_part, q{shitting}  => q{pres_part 'shit' --> 'shitting'};
is verb(q{digs})->pres_part, q{digging}  => q{pres_part 'digs' --> 'digging'};
is verb(q{know})->pres_part, q{knowing}  => q{pres_part 'know' --> 'knowing'};
is verb(q{vex})->pres_part, q{vexing}  => q{pres_part 'vex' --> 'vexing'};
is verb(q{sung})->pres_part, q{singing}  => q{pres_part 'sung' --> 'singing'};
is verb(q{stank})->pres_part, q{stinking}  => q{pres_part 'stank' --> 'stinking'};
is verb(q{shitted})->pres_part, q{shitting}  => q{pres_part 'shitted' --> 'shitting'};
is verb(q{strives})->pres_part, q{striving}  => q{pres_part 'strives' --> 'striving'};
is verb(q{loved})->pres_part, q{loving}  => q{pres_part 'loved' --> 'loving'};
is verb(q{learning})->pres_part, q{learning}  => q{pres_part 'learning' --> 'learning'};
is verb(q{waiting})->pres_part, q{waiting}  => q{pres_part 'waiting' --> 'waiting'};
is verb(q{swings})->pres_part, q{swinging}  => q{pres_part 'swings' --> 'swinging'};
is verb(q{helps})->pres_part, q{helping}  => q{pres_part 'helps' --> 'helping'};
is verb(q{sawn})->pres_part, q{sawing}  => q{pres_part 'sawn' --> 'sawing'};
is verb(q{mistaking})->pres_part, q{mistaking}  => q{pres_part 'mistaking' --> 'mistaking'};
is verb(q{dying})->pres_part, q{dying}  => q{pres_part 'dying' --> 'dying'};
is verb(q{rives})->pres_part, q{riving}  => q{pres_part 'rives' --> 'riving'};
is verb(q{sublets})->pres_part, q{subletting}  => q{pres_part 'sublets' --> 'subletting'};
is verb(q{skis})->pres_part, q{skiing}  => q{pres_part 'skis' --> 'skiing'};
is verb(q{spitting})->pres_part, q{spitting}  => q{pres_part 'spitting' --> 'spitting'};
is verb(q{understand})->pres_part, q{understanding}  => q{pres_part 'understand' --> 'understanding'};
is verb(q{fallen})->pres_part, q{falling}  => q{pres_part 'fallen' --> 'falling'};
is verb(q{underwent})->pres_part, q{undergoing}  => q{pres_part 'underwent' --> 'undergoing'};
is verb(q{provides})->pres_part, q{providing}  => q{pres_part 'provides' --> 'providing'};
is verb(q{subletting})->pres_part, q{subletting}  => q{pres_part 'subletting' --> 'subletting'};
is verb(q{strived})->pres_part, q{striving}  => q{pres_part 'strived' --> 'striving'};
is verb(q{gives})->pres_part, q{giving}  => q{pres_part 'gives' --> 'giving'};
is verb(q{proven})->pres_part, q{proving}  => q{pres_part 'proven' --> 'proving'};
is verb(q{vexed})->pres_part, q{vexing}  => q{pres_part 'vexed' --> 'vexing'};
is verb(q{drinks})->pres_part, q{drinking}  => q{pres_part 'drinks' --> 'drinking'};
is verb(q{foreseen})->pres_part, q{foreseeing}  => q{pres_part 'foreseen' --> 'foreseeing'};
is verb(q{thrusting})->pres_part, q{thrusting}  => q{pres_part 'thrusting' --> 'thrusting'};
is verb(q{arose})->pres_part, q{arising}  => q{pres_part 'arose' --> 'arising'};
is verb(q{niche})->pres_part, q{nicheing}  => q{pres_part 'niche' --> 'nicheing'};
is verb(q{stands})->pres_part, q{standing}  => q{pres_part 'stands' --> 'standing'};
is verb(q{misleading})->pres_part, q{misleading}  => q{pres_part 'misleading' --> 'misleading'};
is verb(q{wake})->pres_part, q{waking}  => q{pres_part 'wake' --> 'waking'};
is verb(q{waits})->pres_part, q{waiting}  => q{pres_part 'waits' --> 'waiting'};
is verb(q{tear})->pres_part, q{tearing}  => q{pres_part 'tear' --> 'tearing'};
is verb(q{helping})->pres_part, q{helping}  => q{pres_part 'helping' --> 'helping'};
is verb(q{nicheing})->pres_part, q{nicheing}  => q{pres_part 'nicheing' --> 'nicheing'};
is verb(q{begins})->pres_part, q{beginning}  => q{pres_part 'begins' --> 'beginning'};
is verb(q{breaks})->pres_part, q{breaking}  => q{pres_part 'breaks' --> 'breaking'};
is verb(q{shoe})->pres_part, q{shoeing}  => q{pres_part 'shoe' --> 'shoeing'};
is verb(q{fell})->pres_part, q{falling}  => q{pres_part 'fell' --> 'falling'};
is verb(q{stole})->pres_part, q{stealing}  => q{pres_part 'stole' --> 'stealing'};
is verb(q{bit})->pres_part, q{biting}  => q{pres_part 'bit' --> 'biting'};
is verb(q{sped})->pres_part, q{speeding}  => q{pres_part 'sped' --> 'speeding'};
is verb(q{mislead})->pres_part, q{misleading}  => q{pres_part 'mislead' --> 'misleading'};
is verb(q{sunk})->pres_part, q{sinking}  => q{pres_part 'sunk' --> 'sinking'};
is verb(q{leap})->pres_part, q{leaping}  => q{pres_part 'leap' --> 'leaping'};
is verb(q{dies})->pres_part, q{dying}  => q{pres_part 'dies' --> 'dying'};
is verb(q{misunderstood})->pres_part, q{misunderstanding}  => q{pres_part 'misunderstood' --> 'misunderstanding'};
is verb(q{walked})->pres_part, q{walking}  => q{pres_part 'walked' --> 'walking'};
is verb(q{chooses})->pres_part, q{choosing}  => q{pres_part 'chooses' --> 'choosing'};
is verb(q{fought})->pres_part, q{fighting}  => q{pres_part 'fought' --> 'fighting'};
is verb(q{learn})->pres_part, q{learning}  => q{pres_part 'learn' --> 'learning'};
is verb(q{creched})->pres_part, q{creching}  => q{pres_part 'creched' --> 'creching'};
is verb(q{woken})->pres_part, q{waking}  => q{pres_part 'woken' --> 'waking'};
is verb(q{burnt})->pres_part, q{burning}  => q{pres_part 'burnt' --> 'burning'};
is verb(q{feeling})->pres_part, q{feeling}  => q{pres_part 'feeling' --> 'feeling'};
is verb(q{menued})->pres_part, q{menuing}  => q{pres_part 'menued' --> 'menuing'};
is verb(q{shaken})->pres_part, q{shaking}  => q{pres_part 'shaken' --> 'shaking'};
is verb(q{fling})->pres_part, q{flinging}  => q{pres_part 'fling' --> 'flinging'};
is verb(q{came})->pres_part, q{coming}  => q{pres_part 'came' --> 'coming'};
is verb(q{sublet})->pres_part, q{subletting}  => q{pres_part 'sublet' --> 'subletting'};
is verb(q{dig})->pres_part, q{digging}  => q{pres_part 'dig' --> 'digging'};
is verb(q{rending})->pres_part, q{rending}  => q{pres_part 'rending' --> 'rending'};
is verb(q{kills})->pres_part, q{killing}  => q{pres_part 'kills' --> 'killing'};
is verb(q{striding})->pres_part, q{striding}  => q{pres_part 'striding' --> 'striding'};
is verb(q{ridding})->pres_part, q{ridding}  => q{pres_part 'ridding' --> 'ridding'};
is verb(q{skied})->pres_part, q{skiing}  => q{pres_part 'skied' --> 'skiing'};
is verb(q{beating})->pres_part, q{beating}  => q{pres_part 'beating' --> 'beating'};
is verb(q{want})->pres_part, q{wanting}  => q{pres_part 'want' --> 'wanting'};
is verb(q{reaching})->pres_part, q{reaching}  => q{pres_part 'reaching' --> 'reaching'};
is verb(q{remembers})->pres_part, q{remembering}  => q{pres_part 'remembers' --> 'remembering'};
is verb(q{seeming})->pres_part, q{seeming}  => q{pres_part 'seeming' --> 'seeming'};
is verb(q{finding})->pres_part, q{finding}  => q{pres_part 'finding' --> 'finding'};
is verb(q{drags})->pres_part, q{dragging}  => q{pres_part 'drags' --> 'dragging'};
is verb(q{torn})->pres_part, q{tearing}  => q{pres_part 'torn' --> 'tearing'};
is verb(q{mistake})->pres_part, q{mistaking}  => q{pres_part 'mistake' --> 'mistaking'};
is verb(q{wends})->pres_part, q{wending}  => q{pres_part 'wends' --> 'wending'};
is verb(q{dives})->pres_part, q{diving}  => q{pres_part 'dives' --> 'diving'};
is verb(q{trodden})->pres_part, q{treading}  => q{pres_part 'trodden' --> 'treading'};
is verb(q{blitzing})->pres_part, q{blitzing}  => q{pres_part 'blitzing' --> 'blitzing'};
is verb(q{slinking})->pres_part, q{slinking}  => q{pres_part 'slinking' --> 'slinking'};
is verb(q{meet})->pres_part, q{meeting}  => q{pres_part 'meet' --> 'meeting'};
is verb(q{ring})->pres_part, q{ringing}  => q{pres_part 'ring' --> 'ringing'};
is verb(q{feels})->pres_part, q{feeling}  => q{pres_part 'feels' --> 'feeling'};
is verb(q{forgot})->pres_part, q{forgetting}  => q{pres_part 'forgot' --> 'forgetting'};
is verb(q{irising})->pres_part, q{irising}  => q{pres_part 'irising' --> 'irising'};
is verb(q{provided})->pres_part, q{providing}  => q{pres_part 'provided' --> 'providing'};
is verb(q{blitz})->pres_part, q{blitzing}  => q{pres_part 'blitz' --> 'blitzing'};
is verb(q{slink})->pres_part, q{slinking}  => q{pres_part 'slink' --> 'slinking'};
is verb(q{asking})->pres_part, q{asking}  => q{pres_part 'asking' --> 'asking'};
is verb(q{blew})->pres_part, q{blowing}  => q{pres_part 'blew' --> 'blowing'};
is verb(q{slitting})->pres_part, q{slitting}  => q{pres_part 'slitting' --> 'slitting'};
is verb(q{losing})->pres_part, q{losing}  => q{pres_part 'losing' --> 'losing'};
is verb(q{withhold})->pres_part, q{withholding}  => q{pres_part 'withhold' --> 'withholding'};
is verb(q{reach})->pres_part, q{reaching}  => q{pres_part 'reach' --> 'reaching'};
is verb(q{withholding})->pres_part, q{withholding}  => q{pres_part 'withholding' --> 'withholding'};
is verb(q{cost})->pres_part, q{costing}  => q{pres_part 'cost' --> 'costing'};
is verb(q{killing})->pres_part, q{killing}  => q{pres_part 'killing' --> 'killing'};
is verb(q{rends})->pres_part, q{rending}  => q{pres_part 'rends' --> 'rending'};
is verb(q{beats})->pres_part, q{beating}  => q{pres_part 'beats' --> 'beating'};
is verb(q{lead})->pres_part, q{leading}  => q{pres_part 'lead' --> 'leading'};
is verb(q{driven})->pres_part, q{driving}  => q{pres_part 'driven' --> 'driving'};
is verb(q{knelt})->pres_part, q{kneeling}  => q{pres_part 'knelt' --> 'kneeling'};
is verb(q{seems})->pres_part, q{seeming}  => q{pres_part 'seems' --> 'seeming'};
is verb(q{shrinking})->pres_part, q{shrinking}  => q{pres_part 'shrinking' --> 'shrinking'};
is verb(q{dared})->pres_part, q{daring}  => q{pres_part 'dared' --> 'daring'};
is verb(q{choose})->pres_part, q{choosing}  => q{pres_part 'choose' --> 'choosing'};
is verb(q{gets})->pres_part, q{getting}  => q{pres_part 'gets' --> 'getting'};
is verb(q{finds})->pres_part, q{finding}  => q{pres_part 'finds' --> 'finding'};
is verb(q{live})->pres_part, q{living}  => q{pres_part 'live' --> 'living'};
is verb(q{flinging})->pres_part, q{flinging}  => q{pres_part 'flinging' --> 'flinging'};
is verb(q{wending})->pres_part, q{wending}  => q{pres_part 'wending' --> 'wending'};
is verb(q{changed})->pres_part, q{changing}  => q{pres_part 'changed' --> 'changing'};
is verb(q{tread})->pres_part, q{treading}  => q{pres_part 'tread' --> 'treading'};
is verb(q{slit})->pres_part, q{slitting}  => q{pres_part 'slit' --> 'slitting'};
is verb(q{lain})->pres_part, q{lying}  => q{pres_part 'lain' --> 'lying'};
is verb(q{changing})->pres_part, q{changing}  => q{pres_part 'changing' --> 'changing'};
is verb(q{slunk})->pres_part, q{slinking}  => q{pres_part 'slunk' --> 'slinking'};
is verb(q{withholds})->pres_part, q{withholding}  => q{pres_part 'withholds' --> 'withholding'};
is verb(q{dived})->pres_part, q{diving}  => q{pres_part 'dived' --> 'diving'};
is verb(q{abide})->pres_part, q{abiding}  => q{pres_part 'abide' --> 'abiding'};
is verb(q{come})->pres_part, q{coming}  => q{pres_part 'come' --> 'coming'};
is verb(q{ask})->pres_part, q{asking}  => q{pres_part 'ask' --> 'asking'};
is verb(q{forbids})->pres_part, q{forbidding}  => q{pres_part 'forbids' --> 'forbidding'};
is verb(q{shrank})->pres_part, q{shrinking}  => q{pres_part 'shrank' --> 'shrinking'};
is verb(q{burn})->pres_part, q{burning}  => q{pres_part 'burn' --> 'burning'};
is verb(q{dwelling})->pres_part, q{dwelling}  => q{pres_part 'dwelling' --> 'dwelling'};
is verb(q{win})->pres_part, q{winning}  => q{pres_part 'win' --> 'winning'};
is verb(q{swollen})->pres_part, q{swelling}  => q{pres_part 'swollen' --> 'swelling'};
is verb(q{rises})->pres_part, q{rising}  => q{pres_part 'rises' --> 'rising'};
is verb(q{ache})->pres_part, q{aching}  => q{pres_part 'ache' --> 'aching'};
is verb(q{hit})->pres_part, q{hitting}  => q{pres_part 'hit' --> 'hitting'};
is verb(q{expected})->pres_part, q{expecting}  => q{pres_part 'expected' --> 'expecting'};
is verb(q{forsaking})->pres_part, q{forsaking}  => q{pres_part 'forsaking' --> 'forsaking'};
is verb(q{undergoing})->pres_part, q{undergoing}  => q{pres_part 'undergoing' --> 'undergoing'};
is verb(q{swells})->pres_part, q{swelling}  => q{pres_part 'swells' --> 'swelling'};
is verb(q{slew})->pres_part, q{slaying}  => q{pres_part 'slew' --> 'slaying'};
is verb(q{leaves})->pres_part, q{leaving}  => q{pres_part 'leaves' --> 'leaving'};
is verb(q{proves})->pres_part, q{proving}  => q{pres_part 'proves' --> 'proving'};
is verb(q{bled})->pres_part, q{bleeding}  => q{pres_part 'bled' --> 'bleeding'};
is verb(q{undertaking})->pres_part, q{undertaking}  => q{pres_part 'undertaking' --> 'undertaking'};
is verb(q{blitzed})->pres_part, q{blitzing}  => q{pres_part 'blitzed' --> 'blitzing'};
is verb(q{flung})->pres_part, q{flinging}  => q{pres_part 'flung' --> 'flinging'};
is verb(q{shaved})->pres_part, q{shaving}  => q{pres_part 'shaved' --> 'shaving'};
is verb(q{misunderstand})->pres_part, q{misunderstanding}  => q{pres_part 'misunderstand' --> 'misunderstanding'};
is verb(q{dwell})->pres_part, q{dwelling}  => q{pres_part 'dwell' --> 'dwelling'};
is verb(q{dares})->pres_part, q{daring}  => q{pres_part 'dares' --> 'daring'};
is verb(q{reached})->pres_part, q{reaching}  => q{pres_part 'reached' --> 'reaching'};
is verb(q{bellyached})->pres_part, q{bellyaching}  => q{pres_part 'bellyached' --> 'bellyaching'};
is verb(q{need})->pres_part, q{needing}  => q{pres_part 'need' --> 'needing'};
is verb(q{remaining})->pres_part, q{remaining}  => q{pres_part 'remaining' --> 'remaining'};
is verb(q{undergo})->pres_part, q{undergoing}  => q{pres_part 'undergo' --> 'undergoing'};
is verb(q{sang})->pres_part, q{singing}  => q{pres_part 'sang' --> 'singing'};
is verb(q{getting})->pres_part, q{getting}  => q{pres_part 'getting' --> 'getting'};
is verb(q{treading})->pres_part, q{treading}  => q{pres_part 'treading' --> 'treading'};
is verb(q{expect})->pres_part, q{expecting}  => q{pres_part 'expect' --> 'expecting'};
is verb(q{remember})->pres_part, q{remembering}  => q{pres_part 'remember' --> 'remembering'};
is verb(q{begetting})->pres_part, q{begetting}  => q{pres_part 'begetting' --> 'begetting'};
is verb(q{remembering})->pres_part, q{remembering}  => q{pres_part 'remembering' --> 'remembering'};
is verb(q{gone})->pres_part, q{going}  => q{pres_part 'gone' --> 'going'};
is verb(q{hurt})->pres_part, q{hurting}  => q{pres_part 'hurt' --> 'hurting'};
is verb(q{got})->pres_part, q{getting}  => q{pres_part 'got' --> 'getting'};
is verb(q{built})->pres_part, q{building}  => q{pres_part 'built' --> 'building'};
is verb(q{sit})->pres_part, q{sitting}  => q{pres_part 'sit' --> 'sitting'};
is verb(q{put})->pres_part, q{putting}  => q{pres_part 'put' --> 'putting'};
is verb(q{forbid})->pres_part, q{forbidding}  => q{pres_part 'forbid' --> 'forbidding'};
is verb(q{drives})->pres_part, q{driving}  => q{pres_part 'drives' --> 'driving'};
is verb(q{creching})->pres_part, q{creching}  => q{pres_part 'creching' --> 'creching'};
is verb(q{forsake})->pres_part, q{forsaking}  => q{pres_part 'forsake' --> 'forsaking'};
is verb(q{felt})->pres_part, q{feeling}  => q{pres_part 'felt' --> 'feeling'};
is verb(q{shrunk})->pres_part, q{shrinking}  => q{pres_part 'shrunk' --> 'shrinking'};
is verb(q{fleeing})->pres_part, q{fleeing}  => q{pres_part 'fleeing' --> 'fleeing'};
is verb(q{vexes})->pres_part, q{vexing}  => q{pres_part 'vexes' --> 'vexing'};
is verb(q{tore})->pres_part, q{tearing}  => q{pres_part 'tore' --> 'tearing'};
is verb(q{sinking})->pres_part, q{sinking}  => q{pres_part 'sinking' --> 'sinking'};
is verb(q{sown})->pres_part, q{sowing}  => q{pres_part 'sown' --> 'sowing'};
is verb(q{rived})->pres_part, q{riving}  => q{pres_part 'rived' --> 'riving'};
is verb(q{woke})->pres_part, q{waking}  => q{pres_part 'woke' --> 'waking'};
is verb(q{blows})->pres_part, q{blowing}  => q{pres_part 'blows' --> 'blowing'};
is verb(q{abiding})->pres_part, q{abiding}  => q{pres_part 'abiding' --> 'abiding'};
is verb(q{sworn})->pres_part, q{swearing}  => q{pres_part 'sworn' --> 'swearing'};
is verb(q{biting})->pres_part, q{biting}  => q{pres_part 'biting' --> 'biting'};
is verb(q{wearing})->pres_part, q{wearing}  => q{pres_part 'wearing' --> 'wearing'};
is verb(q{stay})->pres_part, q{staying}  => q{pres_part 'stay' --> 'staying'};
is verb(q{stinks})->pres_part, q{stinking}  => q{pres_part 'stinks' --> 'stinking'};
is verb(q{leapt})->pres_part, q{leaping}  => q{pres_part 'leapt' --> 'leaping'};
is verb(q{spit})->pres_part, q{spitting}  => q{pres_part 'spit' --> 'spitting'};
is verb(q{bred})->pres_part, q{breeding}  => q{pres_part 'bred' --> 'breeding'};
is verb(q{striving})->pres_part, q{striving}  => q{pres_part 'striving' --> 'striving'};
is verb(q{avalanching})->pres_part, q{avalanching}  => q{pres_part 'avalanching' --> 'avalanching'};
is verb(q{flees})->pres_part, q{fleeing}  => q{pres_part 'flees' --> 'fleeing'};
is verb(q{sinks})->pres_part, q{sinking}  => q{pres_part 'sinks' --> 'sinking'};
is verb(q{clings})->pres_part, q{clinging}  => q{pres_part 'clings' --> 'clinging'};
is verb(q{proved})->pres_part, q{proving}  => q{pres_part 'proved' --> 'proving'};
is verb(q{blowing})->pres_part, q{blowing}  => q{pres_part 'blowing' --> 'blowing'};
is verb(q{go})->pres_part, q{going}  => q{pres_part 'go' --> 'going'};
is verb(q{expects})->pres_part, q{expecting}  => q{pres_part 'expects' --> 'expecting'};
is verb(q{wears})->pres_part, q{wearing}  => q{pres_part 'wears' --> 'wearing'};
is verb(q{insisting})->pres_part, q{insisting}  => q{pres_part 'insisting' --> 'insisting'};
is verb(q{shakes})->pres_part, q{shaking}  => q{pres_part 'shakes' --> 'shaking'};
is verb(q{forgives})->pres_part, q{forgiving}  => q{pres_part 'forgives' --> 'forgiving'};
is verb(q{shaves})->pres_part, q{shaving}  => q{pres_part 'shaves' --> 'shaving'};
is verb(q{learned})->pres_part, q{learning}  => q{pres_part 'learned' --> 'learning'};
is verb(q{loving})->pres_part, q{loving}  => q{pres_part 'loving' --> 'loving'};
is verb(q{speaks})->pres_part, q{speaking}  => q{pres_part 'speaks' --> 'speaking'};
is verb(q{remains})->pres_part, q{remaining}  => q{pres_part 'remains' --> 'remaining'};
is verb(q{fights})->pres_part, q{fighting}  => q{pres_part 'fights' --> 'fighting'};
is verb(q{overhearing})->pres_part, q{overhearing}  => q{pres_part 'overhearing' --> 'overhearing'};
is verb(q{overhear})->pres_part, q{overhearing}  => q{pres_part 'overhear' --> 'overhearing'};
is verb(q{sweat})->pres_part, q{sweating}  => q{pres_part 'sweat' --> 'sweating'};
is verb(q{singing})->pres_part, q{singing}  => q{pres_part 'singing' --> 'singing'};
is verb(q{shitting})->pres_part, q{shitting}  => q{pres_part 'shitting' --> 'shitting'};
is verb(q{bites})->pres_part, q{biting}  => q{pres_part 'bites' --> 'biting'};
is verb(q{insist})->pres_part, q{insisting}  => q{pres_part 'insist' --> 'insisting'};
is verb(q{forgive})->pres_part, q{forgiving}  => q{pres_part 'forgive' --> 'forgiving'};
is verb(q{stride})->pres_part, q{striding}  => q{pres_part 'stride' --> 'striding'};
is verb(q{avalanche})->pres_part, q{avalanching}  => q{pres_part 'avalanche' --> 'avalanching'};
is verb(q{overtaking})->pres_part, q{overtaking}  => q{pres_part 'overtaking' --> 'overtaking'};
is verb(q{awoken})->pres_part, q{awakening}  => q{pres_part 'awoken' --> 'awakening'};
is verb(q{stopped})->pres_part, q{stopping}  => q{pres_part 'stopped' --> 'stopping'};
is verb(q{swims})->pres_part, q{swimming}  => q{pres_part 'swims' --> 'swimming'};
is verb(q{swam})->pres_part, q{swimming}  => q{pres_part 'swam' --> 'swimming'};
is verb(q{vexing})->pres_part, q{vexing}  => q{pres_part 'vexing' --> 'vexing'};
is verb(q{kept})->pres_part, q{keeping}  => q{pres_part 'kept' --> 'keeping'};
is verb(q{strew})->pres_part, q{strewing}  => q{pres_part 'strew' --> 'strewing'};
is verb(q{winning})->pres_part, q{winning}  => q{pres_part 'winning' --> 'winning'};
is verb(q{gilds})->pres_part, q{gilding}  => q{pres_part 'gilds' --> 'gilding'};
is verb(q{forgave})->pres_part, q{forgiving}  => q{pres_part 'forgave' --> 'forgiving'};
is verb(q{died})->pres_part, q{dying}  => q{pres_part 'died' --> 'dying'};
is verb(q{strewing})->pres_part, q{strewing}  => q{pres_part 'strewing' --> 'strewing'};
is verb(q{choosing})->pres_part, q{choosing}  => q{pres_part 'choosing' --> 'choosing'};
is verb(q{sings})->pres_part, q{singing}  => q{pres_part 'sings' --> 'singing'};
is verb(q{hits})->pres_part, q{hitting}  => q{pres_part 'hits' --> 'hitting'};
is verb(q{loves})->pres_part, q{loving}  => q{pres_part 'loves' --> 'loving'};
is verb(q{keep})->pres_part, q{keeping}  => q{pres_part 'keep' --> 'keeping'};
is verb(q{stave})->pres_part, q{staving}  => q{pres_part 'stave' --> 'staving'};
is verb(q{insisted})->pres_part, q{insisting}  => q{pres_part 'insisted' --> 'insisting'};
is verb(q{sought})->pres_part, q{seeking}  => q{pres_part 'sought' --> 'seeking'};
is verb(q{eaten})->pres_part, q{eating}  => q{pres_part 'eaten' --> 'eating'};
is verb(q{wins})->pres_part, q{winning}  => q{pres_part 'wins' --> 'winning'};
is verb(q{awake})->pres_part, q{awakening}  => q{pres_part 'awake' --> 'awakening'};
is verb(q{has})->pres_part, q{having}  => q{pres_part 'has' --> 'having'};
is verb(q{drank})->pres_part, q{drinking}  => q{pres_part 'drank' --> 'drinking'};
is verb(q{understands})->pres_part, q{understanding}  => q{pres_part 'understands' --> 'understanding'};
is verb(q{asks})->pres_part, q{asking}  => q{pres_part 'asks' --> 'asking'};
is verb(q{forsakes})->pres_part, q{forsaking}  => q{pres_part 'forsakes' --> 'forsaking'};
is verb(q{stop})->pres_part, q{stopping}  => q{pres_part 'stop' --> 'stopping'};
is verb(q{slide})->pres_part, q{sliding}  => q{pres_part 'slide' --> 'sliding'};
is verb(q{shed})->pres_part, q{shedding}  => q{pres_part 'shed' --> 'shedding'};
is verb(q{walk})->pres_part, q{walking}  => q{pres_part 'walk' --> 'walking'};
is verb(q{gilding})->pres_part, q{gilding}  => q{pres_part 'gilding' --> 'gilding'};
is verb(q{sweating})->pres_part, q{sweating}  => q{pres_part 'sweating' --> 'sweating'};
is verb(q{begets})->pres_part, q{begetting}  => q{pres_part 'begets' --> 'begetting'};
is verb(q{reaches})->pres_part, q{reaching}  => q{pres_part 'reaches' --> 'reaching'};
is verb(q{slays})->pres_part, q{slaying}  => q{pres_part 'slays' --> 'slaying'};
is verb(q{rising})->pres_part, q{rising}  => q{pres_part 'rising' --> 'rising'};
is verb(q{expecting})->pres_part, q{expecting}  => q{pres_part 'expecting' --> 'expecting'};
is verb(q{strides})->pres_part, q{striding}  => q{pres_part 'strides' --> 'striding'};
is verb(q{holds})->pres_part, q{holding}  => q{pres_part 'holds' --> 'holding'};
is verb(q{undertake})->pres_part, q{undertaking}  => q{pres_part 'undertake' --> 'undertaking'};
is verb(q{insists})->pres_part, q{insisting}  => q{pres_part 'insists' --> 'insisting'};
is verb(q{fled})->pres_part, q{fleeing}  => q{pres_part 'fled' --> 'fleeing'};
is verb(q{speed})->pres_part, q{speeding}  => q{pres_part 'speed' --> 'speeding'};
is verb(q{swearing})->pres_part, q{swearing}  => q{pres_part 'swearing' --> 'swearing'};
is verb(q{shows})->pres_part, q{showing}  => q{pres_part 'shows' --> 'showing'};
is verb(q{blitzes})->pres_part, q{blitzing}  => q{pres_part 'blitzes' --> 'blitzing'};
is verb(q{forbidding})->pres_part, q{forbidding}  => q{pres_part 'forbidding' --> 'forbidding'};
is verb(q{menu})->pres_part, q{menuing}  => q{pres_part 'menu' --> 'menuing'};
is verb(q{remain})->pres_part, q{remaining}  => q{pres_part 'remain' --> 'remaining'};
is verb(q{leans})->pres_part, q{leaning}  => q{pres_part 'leans' --> 'leaning'};
is verb(q{forgiving})->pres_part, q{forgiving}  => q{pres_part 'forgiving' --> 'forgiving'};
is verb(q{knits})->pres_part, q{knitting}  => q{pres_part 'knits' --> 'knitting'};
is verb(q{sweeping})->pres_part, q{sweeping}  => q{pres_part 'sweeping' --> 'sweeping'};
is verb(q{skiing})->pres_part, q{skiing}  => q{pres_part 'skiing' --> 'skiing'};
is verb(q{met})->pres_part, q{meeting}  => q{pres_part 'met' --> 'meeting'};
is verb(q{mistook})->pres_part, q{mistaking}  => q{pres_part 'mistook' --> 'mistaking'};
is verb(q{upset})->pres_part, q{upsetting}  => q{pres_part 'upset' --> 'upsetting'};
is verb(q{looks})->pres_part, q{looking}  => q{pres_part 'looks' --> 'looking'};
is verb(q{wrings})->pres_part, q{wringing}  => q{pres_part 'wrings' --> 'wringing'};
is verb(q{withstands})->pres_part, q{withstanding}  => q{pres_part 'withstands' --> 'withstanding'};
is verb(q{smelling})->pres_part, q{smelling}  => q{pres_part 'smelling' --> 'smelling'};
is verb(q{strove})->pres_part, q{striving}  => q{pres_part 'strove' --> 'striving'};
is verb(q{dream})->pres_part, q{dreaming}  => q{pres_part 'dream' --> 'dreaming'};
is verb(q{sneak})->pres_part, q{sneaking}  => q{pres_part 'sneak' --> 'sneaking'};
is verb(q{weeping})->pres_part, q{weeping}  => q{pres_part 'weeping' --> 'weeping'};
is verb(q{having})->pres_part, q{having}  => q{pres_part 'having' --> 'having'};
is verb(q{wanted})->pres_part, q{wanting}  => q{pres_part 'wanted' --> 'wanting'};
is verb(q{understood})->pres_part, q{understanding}  => q{pres_part 'understood' --> 'understanding'};
is verb(q{slaying})->pres_part, q{slaying}  => q{pres_part 'slaying' --> 'slaying'};
is verb(q{sliding})->pres_part, q{sliding}  => q{pres_part 'sliding' --> 'sliding'};
is verb(q{are})->pres_part, q{being}  => q{pres_part 'are' --> 'being'};
is verb(q{meant})->pres_part, q{meaning}  => q{pres_part 'meant' --> 'meaning'};
is verb(q{sneaking})->pres_part, q{sneaking}  => q{pres_part 'sneaking' --> 'sneaking'};
is verb(q{smell})->pres_part, q{smelling}  => q{pres_part 'smell' --> 'smelling'};
is verb(q{holding})->pres_part, q{holding}  => q{pres_part 'holding' --> 'holding'};
is verb(q{dreaming})->pres_part, q{dreaming}  => q{pres_part 'dreaming' --> 'dreaming'};
is verb(q{known})->pres_part, q{knowing}  => q{pres_part 'known' --> 'knowing'};
is verb(q{left})->pres_part, q{leaving}  => q{pres_part 'left' --> 'leaving'};
is verb(q{sweep})->pres_part, q{sweeping}  => q{pres_part 'sweep' --> 'sweeping'};
is verb(q{remained})->pres_part, q{remaining}  => q{pres_part 'remained' --> 'remaining'};
is verb(q{asked})->pres_part, q{asking}  => q{pres_part 'asked' --> 'asking'};
is verb(q{showing})->pres_part, q{showing}  => q{pres_part 'showing' --> 'showing'};
is verb(q{beginning})->pres_part, q{beginning}  => q{pres_part 'beginning' --> 'beginning'};
is verb(q{smitten})->pres_part, q{smiting}  => q{pres_part 'smitten' --> 'smiting'};
is verb(q{leaning})->pres_part, q{leaning}  => q{pres_part 'leaning' --> 'leaning'};
is verb(q{smites})->pres_part, q{smiting}  => q{pres_part 'smites' --> 'smiting'};
is verb(q{continue})->pres_part, q{continuing}  => q{pres_part 'continue' --> 'continuing'};
is verb(q{quit})->pres_part, q{quitting}  => q{pres_part 'quit' --> 'quitting'};
is verb(q{bursts})->pres_part, q{bursting}  => q{pres_part 'bursts' --> 'bursting'};
is verb(q{spoke})->pres_part, q{speaking}  => q{pres_part 'spoke' --> 'speaking'};
is verb(q{daring})->pres_part, q{daring}  => q{pres_part 'daring' --> 'daring'};
is verb(q{strips})->pres_part, q{stripping}  => q{pres_part 'strips' --> 'stripping'};
is verb(q{deal})->pres_part, q{dealing}  => q{pres_part 'deal' --> 'dealing'};
is verb(q{forbade})->pres_part, q{forbidding}  => q{pres_part 'forbade' --> 'forbidding'};
is verb(q{staving})->pres_part, q{staving}  => q{pres_part 'staving' --> 'staving'};
is verb(q{puts})->pres_part, q{putting}  => q{pres_part 'puts' --> 'putting'};
is verb(q{looking})->pres_part, q{looking}  => q{pres_part 'looking' --> 'looking'};
is verb(q{sank})->pres_part, q{sinking}  => q{pres_part 'sank' --> 'sinking'};
is verb(q{weeps})->pres_part, q{weeping}  => q{pres_part 'weeps' --> 'weeping'};
is verb(q{swear})->pres_part, q{swearing}  => q{pres_part 'swear' --> 'swearing'};
is verb(q{sits})->pres_part, q{sitting}  => q{pres_part 'sits' --> 'sitting'};
is verb(q{speeding})->pres_part, q{speeding}  => q{pres_part 'speeding' --> 'speeding'};

done_testing();
