use Test::More;
use Lingua::EN::Inflexion;

is verb(q{slide})->singular, q{slides}  => q{singular: 'slide' --> 'slides'};
is verb(q{slides})->singular,   q{slides}  => q{singular: 'slides' --> 'slides'};
is verb(q{shed})->singular, q{sheds}  => q{singular: 'shed' --> 'sheds'};
is verb(q{sheds})->singular,   q{sheds}  => q{singular: 'sheds' --> 'sheds'};
is verb(q{walk})->singular, q{walks}  => q{singular: 'walk' --> 'walks'};
is verb(q{walks})->singular,   q{walks}  => q{singular: 'walks' --> 'walks'};
is verb(q{learn})->singular, q{learns}  => q{singular: 'learn' --> 'learns'};
is verb(q{learns})->singular,   q{learns}  => q{singular: 'learns' --> 'learns'};
is verb(q{shan't})->singular, q{shan't}  => q{singular: 'shan't' --> 'shan't'};
is verb(q{eat})->singular, q{eats}  => q{singular: 'eat' --> 'eats'};
is verb(q{eats})->singular,   q{eats}  => q{singular: 'eats' --> 'eats'};
is verb(q{clap})->singular, q{claps}  => q{singular: 'clap' --> 'claps'};
is verb(q{claps})->singular,   q{claps}  => q{singular: 'claps' --> 'claps'};
is verb(q{mislead})->singular, q{misleads}  => q{singular: 'mislead' --> 'misleads'};
is verb(q{misleads})->singular,   q{misleads}  => q{singular: 'misleads' --> 'misleads'};
is verb(q{prove})->singular, q{proves}  => q{singular: 'prove' --> 'proves'};
is verb(q{proves})->singular,   q{proves}  => q{singular: 'proves' --> 'proves'};
is verb(q{have})->singular, q{has}  => q{singular: 'have' --> 'has'};
is verb(q{has})->singular,   q{has}  => q{singular: 'has' --> 'has'};
is verb(q{leave})->singular, q{leaves}  => q{singular: 'leave' --> 'leaves'};
is verb(q{leaves})->singular,   q{leaves}  => q{singular: 'leaves' --> 'leaves'};
is verb(q{steal})->singular, q{steals}  => q{singular: 'steal' --> 'steals'};
is verb(q{steals})->singular,   q{steals}  => q{singular: 'steals' --> 'steals'};
is verb(q{leap})->singular, q{leaps}  => q{singular: 'leap' --> 'leaps'};
is verb(q{leaps})->singular,   q{leaps}  => q{singular: 'leaps' --> 'leaps'};
is verb(q{behold})->singular, q{beholds}  => q{singular: 'behold' --> 'beholds'};
is verb(q{beholds})->singular,   q{beholds}  => q{singular: 'beholds' --> 'beholds'};
is verb(q{stop})->singular, q{stops}  => q{singular: 'stop' --> 'stops'};
is verb(q{stops})->singular,   q{stops}  => q{singular: 'stops' --> 'stops'};
is verb(q{bind})->singular, q{binds}  => q{singular: 'bind' --> 'binds'};
is verb(q{binds})->singular,   q{binds}  => q{singular: 'binds' --> 'binds'};
is verb(q{shoe})->singular, q{shoes}  => q{singular: 'shoe' --> 'shoes'};
is verb(q{shoes})->singular,   q{shoes}  => q{singular: 'shoes' --> 'shoes'};
is verb(q{stave})->singular, q{staves}  => q{singular: 'stave' --> 'staves'};
is verb(q{staves})->singular,   q{staves}  => q{singular: 'staves' --> 'staves'};
is verb(q{bust})->singular, q{busts}  => q{singular: 'bust' --> 'busts'};
is verb(q{busts})->singular,   q{busts}  => q{singular: 'busts' --> 'busts'};
is verb(q{rise})->singular, q{rises}  => q{singular: 'rise' --> 'rises'};
is verb(q{rises})->singular,   q{rises}  => q{singular: 'rises' --> 'rises'};
is verb(q{awake})->singular, q{awakes}  => q{singular: 'awake' --> 'awakes'};
is verb(q{awakes})->singular,   q{awakes}  => q{singular: 'awakes' --> 'awakes'};
is verb(q{tear})->singular, q{tears}  => q{singular: 'tear' --> 'tears'};
is verb(q{tears})->singular,   q{tears}  => q{singular: 'tears' --> 'tears'};
is verb(q{kneel})->singular, q{kneels}  => q{singular: 'kneel' --> 'kneels'};
is verb(q{kneels})->singular,   q{kneels}  => q{singular: 'kneels' --> 'kneels'};
is verb(q{keep})->singular, q{keeps}  => q{singular: 'keep' --> 'keeps'};
is verb(q{keeps})->singular,   q{keeps}  => q{singular: 'keeps' --> 'keeps'};
is verb(q{strew})->singular, q{strews}  => q{singular: 'strew' --> 'strews'};
is verb(q{strews})->singular,   q{strews}  => q{singular: 'strews' --> 'strews'};
is verb(q{lie})->singular, q{lies}  => q{singular: 'lie' --> 'lies'};
is verb(q{lies})->singular,   q{lies}  => q{singular: 'lies' --> 'lies'};
is verb(q{dare})->singular, q{dares}  => q{singular: 'dare' --> 'dares'};
is verb(q{dares})->singular,   q{dares}  => q{singular: 'dares' --> 'dares'};
is verb(q{niche})->singular, q{niches}  => q{singular: 'niche' --> 'niches'};
is verb(q{niches})->singular,   q{niches}  => q{singular: 'niches' --> 'niches'};
is verb(q{lay})->singular, q{lays}  => q{singular: 'lay' --> 'lays'};
is verb(q{lays})->singular,   q{lays}  => q{singular: 'lays' --> 'lays'};
is verb(q{overdraw})->singular, q{overdraws}  => q{singular: 'overdraw' --> 'overdraws'};
is verb(q{overdraws})->singular,   q{overdraws}  => q{singular: 'overdraws' --> 'overdraws'};
is verb(q{wake})->singular, q{wakes}  => q{singular: 'wake' --> 'wakes'};
is verb(q{wakes})->singular,   q{wakes}  => q{singular: 'wakes' --> 'wakes'};
is verb(q{saw})->singular, q{saws}  => q{singular: 'saw' --> 'saws'};
is verb(q{saws})->singular,   q{saws}  => q{singular: 'saws' --> 'saws'};
is verb(q{forget})->singular, q{forgets}  => q{singular: 'forget' --> 'forgets'};
is verb(q{forgets})->singular,   q{forgets}  => q{singular: 'forgets' --> 'forgets'};
is verb(q{quiz})->singular, q{quizzes}  => q{singular: 'quiz' --> 'quizzes'};
is verb(q{quizzes})->singular,   q{quizzes}  => q{singular: 'quizzes' --> 'quizzes'};
is verb(q{foresee})->singular, q{foresees}  => q{singular: 'foresee' --> 'foresees'};
is verb(q{foresees})->singular,   q{foresees}  => q{singular: 'foresees' --> 'foresees'};
is verb(q{douche})->singular, q{douches}  => q{singular: 'douche' --> 'douches'};
is verb(q{douches})->singular,   q{douches}  => q{singular: 'douches' --> 'douches'};
is verb(q{insist})->singular, q{insists}  => q{singular: 'insist' --> 'insists'};
is verb(q{insists})->singular,   q{insists}  => q{singular: 'insists' --> 'insists'};
is verb(q{will})->singular, q{will}  => q{singular: 'will' --> 'will'};
is verb(q{forgive})->singular, q{forgives}  => q{singular: 'forgive' --> 'forgives'};
is verb(q{forgives})->singular,   q{forgives}  => q{singular: 'forgives' --> 'forgives'};
is verb(q{stride})->singular, q{strides}  => q{singular: 'stride' --> 'strides'};
is verb(q{strides})->singular,   q{strides}  => q{singular: 'strides' --> 'strides'};
is verb(q{avalanche})->singular, q{avalanches}  => q{singular: 'avalanche' --> 'avalanches'};
is verb(q{avalanches})->singular,   q{avalanches}  => q{singular: 'avalanches' --> 'avalanches'};
is verb(q{swell})->singular, q{swells}  => q{singular: 'swell' --> 'swells'};
is verb(q{swells})->singular,   q{swells}  => q{singular: 'swells' --> 'swells'};
is verb(q{understand})->singular, q{understands}  => q{singular: 'understand' --> 'understands'};
is verb(q{understands})->singular,   q{understands}  => q{singular: 'understands' --> 'understands'};
is verb(q{inlay})->singular, q{inlays}  => q{singular: 'inlay' --> 'inlays'};
is verb(q{inlays})->singular,   q{inlays}  => q{singular: 'inlays' --> 'inlays'};
is verb(q{overhear})->singular, q{overhears}  => q{singular: 'overhear' --> 'overhears'};
is verb(q{overhears})->singular,   q{overhears}  => q{singular: 'overhears' --> 'overhears'};
is verb(q{lose})->singular, q{loses}  => q{singular: 'lose' --> 'loses'};
is verb(q{loses})->singular,   q{loses}  => q{singular: 'loses' --> 'loses'};
is verb(q{sweat})->singular, q{sweats}  => q{singular: 'sweat' --> 'sweats'};
is verb(q{sweats})->singular,   q{sweats}  => q{singular: 'sweats' --> 'sweats'};
is verb(q{ought})->singular, q{ought}  => q{singular: 'ought' --> 'ought'};
is verb(q{choose})->singular, q{chooses}  => q{singular: 'choose' --> 'chooses'};
is verb(q{chooses})->singular,   q{chooses}  => q{singular: 'chooses' --> 'chooses'};
is verb(q{live})->singular, q{lives}  => q{singular: 'live' --> 'lives'};
is verb(q{lives})->singular,   q{lives}  => q{singular: 'lives' --> 'lives'};
is verb(q{spring})->singular, q{springs}  => q{singular: 'spring' --> 'springs'};
is verb(q{springs})->singular,   q{springs}  => q{singular: 'springs' --> 'springs'};
is verb(q{haven't})->singular, q{hasn't}  => q{singular: 'haven't' --> 'hasn't'};
is verb(q{hasn't})->singular,   q{hasn't}  => q{singular: 'hasn't' --> 'hasn't'};
is verb(q{swear})->singular, q{swears}  => q{singular: 'swear' --> 'swears'};
is verb(q{swears})->singular,   q{swears}  => q{singular: 'swears' --> 'swears'};
is verb(q{build})->singular, q{builds}  => q{singular: 'build' --> 'builds'};
is verb(q{builds})->singular,   q{builds}  => q{singular: 'builds' --> 'builds'};
is verb(q{sting})->singular, q{stings}  => q{singular: 'sting' --> 'stings'};
is verb(q{stings})->singular,   q{stings}  => q{singular: 'stings' --> 'stings'};
is verb(q{spoil})->singular, q{spoils}  => q{singular: 'spoil' --> 'spoils'};
is verb(q{spoils})->singular,   q{spoils}  => q{singular: 'spoils' --> 'spoils'};
is verb(q{preset})->singular, q{presets}  => q{singular: 'preset' --> 'presets'};
is verb(q{presets})->singular,   q{presets}  => q{singular: 'presets' --> 'presets'};
is verb(q{continue})->singular, q{continues}  => q{singular: 'continue' --> 'continues'};
is verb(q{continues})->singular,   q{continues}  => q{singular: 'continues' --> 'continues'};
is verb(q{quit})->singular, q{quits}  => q{singular: 'quit' --> 'quits'};
is verb(q{quits})->singular,   q{quits}  => q{singular: 'quits' --> 'quits'};
is verb(q{lead})->singular, q{leads}  => q{singular: 'lead' --> 'leads'};
is verb(q{leads})->singular,   q{leads}  => q{singular: 'leads' --> 'leads'};
is verb(q{watch})->singular, q{watches}  => q{singular: 'watch' --> 'watches'};
is verb(q{watches})->singular,   q{watches}  => q{singular: 'watches' --> 'watches'};
is verb(q{deal})->singular, q{deals}  => q{singular: 'deal' --> 'deals'};
is verb(q{deals})->singular,   q{deals}  => q{singular: 'deals' --> 'deals'};
is verb(q{shave})->singular, q{shaves}  => q{singular: 'shave' --> 'shaves'};
is verb(q{shaves})->singular,   q{shaves}  => q{singular: 'shaves' --> 'shaves'};
is verb(q{sweep})->singular, q{sweeps}  => q{singular: 'sweep' --> 'sweeps'};
is verb(q{sweeps})->singular,   q{sweeps}  => q{singular: 'sweeps' --> 'sweeps'};
is verb(q{speak})->singular, q{speaks}  => q{singular: 'speak' --> 'speaks'};
is verb(q{speaks})->singular,   q{speaks}  => q{singular: 'speaks' --> 'speaks'};
is verb(q{withhold})->singular, q{withholds}  => q{singular: 'withhold' --> 'withholds'};
is verb(q{withholds})->singular,   q{withholds}  => q{singular: 'withholds' --> 'withholds'};
is verb(q{reach})->singular, q{reaches}  => q{singular: 'reach' --> 'reaches'};
is verb(q{reaches})->singular,   q{reaches}  => q{singular: 'reaches' --> 'reaches'};
is verb(q{cost})->singular, q{costs}  => q{singular: 'cost' --> 'costs'};
is verb(q{costs})->singular,   q{costs}  => q{singular: 'costs' --> 'costs'};
is verb(q{ring})->singular, q{rings}  => q{singular: 'ring' --> 'rings'};
is verb(q{rings})->singular,   q{rings}  => q{singular: 'rings' --> 'rings'};
is verb(q{happen})->singular, q{happens}  => q{singular: 'happen' --> 'happens'};
is verb(q{happens})->singular,   q{happens}  => q{singular: 'happens' --> 'happens'};
is verb(q{cling})->singular, q{clings}  => q{singular: 'cling' --> 'clings'};
is verb(q{clings})->singular,   q{clings}  => q{singular: 'clings' --> 'clings'};
is verb(q{shake})->singular, q{shakes}  => q{singular: 'shake' --> 'shakes'};
is verb(q{shakes})->singular,   q{shakes}  => q{singular: 'shakes' --> 'shakes'};
is verb(q{smell})->singular, q{smells}  => q{singular: 'smell' --> 'smells'};
is verb(q{smells})->singular,   q{smells}  => q{singular: 'smells' --> 'smells'};
is verb(q{blitz})->singular, q{blitzes}  => q{singular: 'blitz' --> 'blitzes'};
is verb(q{blitzes})->singular,   q{blitzes}  => q{singular: 'blitzes' --> 'blitzes'};
is verb(q{blow})->singular, q{blows}  => q{singular: 'blow' --> 'blows'};
is verb(q{blows})->singular,   q{blows}  => q{singular: 'blows' --> 'blows'};
is verb(q{become})->singular, q{becomes}  => q{singular: 'become' --> 'becomes'};
is verb(q{becomes})->singular,   q{becomes}  => q{singular: 'becomes' --> 'becomes'};
is verb(q{slink})->singular, q{slinks}  => q{singular: 'slink' --> 'slinks'};
is verb(q{slinks})->singular,   q{slinks}  => q{singular: 'slinks' --> 'slinks'};
is verb(q{can})->singular, q{can}  => q{singular: 'can' --> 'can'};
is verb(q{upset})->singular, q{upsets}  => q{singular: 'upset' --> 'upsets'};
is verb(q{upsets})->singular,   q{upsets}  => q{singular: 'upsets' --> 'upsets'};
is verb(q{sink})->singular, q{sinks}  => q{singular: 'sink' --> 'sinks'};
is verb(q{sinks})->singular,   q{sinks}  => q{singular: 'sinks' --> 'sinks'};
is verb(q{talk})->singular, q{talks}  => q{singular: 'talk' --> 'talks'};
is verb(q{talks})->singular,   q{talks}  => q{singular: 'talks' --> 'talks'};
is verb(q{dream})->singular, q{dreams}  => q{singular: 'dream' --> 'dreams'};
is verb(q{dreams})->singular,   q{dreams}  => q{singular: 'dreams' --> 'dreams'};
is verb(q{sneak})->singular, q{sneaks}  => q{singular: 'sneak' --> 'sneaks'};
is verb(q{sneaks})->singular,   q{sneaks}  => q{singular: 'sneaks' --> 'sneaks'};
is verb(q{mistake})->singular, q{mistakes}  => q{singular: 'mistake' --> 'mistakes'};
is verb(q{mistakes})->singular,   q{mistakes}  => q{singular: 'mistakes' --> 'mistakes'};
is verb(q{flee})->singular, q{flees}  => q{singular: 'flee' --> 'flees'};
is verb(q{flees})->singular,   q{flees}  => q{singular: 'flees' --> 'flees'};
is verb(q{bellyache})->singular, q{bellyaches}  => q{singular: 'bellyache' --> 'bellyaches'};
is verb(q{bellyaches})->singular,   q{bellyaches}  => q{singular: 'bellyaches' --> 'bellyaches'};
is verb(q{meet})->singular, q{meets}  => q{singular: 'meet' --> 'meets'};
is verb(q{meets})->singular,   q{meets}  => q{singular: 'meets' --> 'meets'};
is verb(q{rid})->singular, q{rids}  => q{singular: 'rid' --> 'rids'};
is verb(q{rids})->singular,   q{rids}  => q{singular: 'rids' --> 'rids'};
is verb(q{may})->singular, q{may}  => q{singular: 'may' --> 'may'};
is verb(q{want})->singular, q{wants}  => q{singular: 'want' --> 'wants'};
is verb(q{wants})->singular,   q{wants}  => q{singular: 'wants' --> 'wants'};
is verb(q{})->singular, q{s}  => q{singular: '' --> 's'};
is verb(q{s})->singular,   q{s}  => q{singular: 's' --> 's'};
is verb(q{foretell})->singular, q{foretells}  => q{singular: 'foretell' --> 'foretells'};
is verb(q{foretells})->singular,   q{foretells}  => q{singular: 'foretells' --> 'foretells'};
is verb(q{drive})->singular, q{drives}  => q{singular: 'drive' --> 'drives'};
is verb(q{drives})->singular,   q{drives}  => q{singular: 'drives' --> 'drives'};
is verb(q{daren't})->singular, q{daren't}  => q{singular: 'daren't' --> 'daren't'};
is verb(q{overtake})->singular, q{overtakes}  => q{singular: 'overtake' --> 'overtakes'};
is verb(q{overtakes})->singular,   q{overtakes}  => q{singular: 'overtakes' --> 'overtakes'};
is verb(q{stink})->singular, q{stinks}  => q{singular: 'stink' --> 'stinks'};
is verb(q{stinks})->singular,   q{stinks}  => q{singular: 'stinks' --> 'stinks'};
is verb(q{dig})->singular, q{digs}  => q{singular: 'dig' --> 'digs'};
is verb(q{digs})->singular,   q{digs}  => q{singular: 'digs' --> 'digs'};
is verb(q{thrive})->singular, q{thrives}  => q{singular: 'thrive' --> 'thrives'};
is verb(q{thrives})->singular,   q{thrives}  => q{singular: 'thrives' --> 'thrives'};
is verb(q{menu})->singular, q{menus}  => q{singular: 'menu' --> 'menus'};
is verb(q{menus})->singular,   q{menus}  => q{singular: 'menus' --> 'menus'};
is verb(q{remain})->singular, q{remains}  => q{singular: 'remain' --> 'remains'};
is verb(q{remains})->singular,   q{remains}  => q{singular: 'remains' --> 'remains'};
is verb(q{psyche})->singular, q{psyches}  => q{singular: 'psyche' --> 'psyches'};
is verb(q{psyches})->singular,   q{psyches}  => q{singular: 'psyches' --> 'psyches'};
is verb(q{wear})->singular, q{wears}  => q{singular: 'wear' --> 'wears'};
is verb(q{wears})->singular,   q{wears}  => q{singular: 'wears' --> 'wears'};
is verb(q{fling})->singular, q{flings}  => q{singular: 'fling' --> 'flings'};
is verb(q{flings})->singular,   q{flings}  => q{singular: 'flings' --> 'flings'};
is verb(q{sublet})->singular, q{sublets}  => q{singular: 'sublet' --> 'sublets'};
is verb(q{sublets})->singular,   q{sublets}  => q{singular: 'sublets' --> 'sublets'};
is verb(q{undertake})->singular, q{undertakes}  => q{singular: 'undertake' --> 'undertakes'};
is verb(q{undertakes})->singular,   q{undertakes}  => q{singular: 'undertakes' --> 'undertakes'};
is verb(q{speed})->singular, q{speeds}  => q{singular: 'speed' --> 'speeds'};
is verb(q{speeds})->singular,   q{speeds}  => q{singular: 'speeds' --> 'speeds'};
is verb(q{break})->singular, q{breaks}  => q{singular: 'break' --> 'breaks'};
is verb(q{breaks})->singular,   q{breaks}  => q{singular: 'breaks' --> 'breaks'};
is verb(q{expect})->singular, q{expects}  => q{singular: 'expect' --> 'expects'};
is verb(q{expects})->singular,   q{expects}  => q{singular: 'expects' --> 'expects'};
is verb(q{remember})->singular, q{remembers}  => q{singular: 'remember' --> 'remembers'};
is verb(q{remembers})->singular,   q{remembers}  => q{singular: 'remembers' --> 'remembers'};
is verb(q{bite})->singular, q{bites}  => q{singular: 'bite' --> 'bites'};
is verb(q{bites})->singular,   q{bites}  => q{singular: 'bites' --> 'bites'};
is verb(q{grind})->singular, q{grinds}  => q{singular: 'grind' --> 'grinds'};
is verb(q{grinds})->singular,   q{grinds}  => q{singular: 'grinds' --> 'grinds'};
is verb(q{rive})->singular, q{rives}  => q{singular: 'rive' --> 'rives'};
is verb(q{rives})->singular,   q{rives}  => q{singular: 'rives' --> 'rives'};
is verb(q{need})->singular, q{needs}  => q{singular: 'need' --> 'needs'};
is verb(q{needs})->singular,   q{needs}  => q{singular: 'needs' --> 'needs'};
is verb(q{ski})->singular, q{skis}  => q{singular: 'ski' --> 'skis'};
is verb(q{skis})->singular,   q{skis}  => q{singular: 'skis' --> 'skis'};
is verb(q{strive})->singular, q{strives}  => q{singular: 'strive' --> 'strives'};
is verb(q{strives})->singular,   q{strives}  => q{singular: 'strives' --> 'strives'};
is verb(q{arise})->singular, q{arises}  => q{singular: 'arise' --> 'arises'};
is verb(q{arises})->singular,   q{arises}  => q{singular: 'arises' --> 'arises'};
is verb(q{undergo})->singular, q{undergoes}  => q{singular: 'undergo' --> 'undergoes'};
is verb(q{undergoes})->singular,   q{undergoes}  => q{singular: 'undergoes' --> 'undergoes'};
is verb(q{mean})->singular, q{means}  => q{singular: 'mean' --> 'means'};
is verb(q{means})->singular,   q{means}  => q{singular: 'means' --> 'means'};
is verb(q{help})->singular, q{helps}  => q{singular: 'help' --> 'helps'};
is verb(q{helps})->singular,   q{helps}  => q{singular: 'helps' --> 'helps'};
is verb(q{shall})->singular, q{shall}  => q{singular: 'shall' --> 'shall'};
is verb(q{begin})->singular, q{begins}  => q{singular: 'begin' --> 'begins'};
is verb(q{begins})->singular,   q{begins}  => q{singular: 'begins' --> 'begins'};
is verb(q{gild})->singular, q{gilds}  => q{singular: 'gild' --> 'gilds'};
is verb(q{gilds})->singular,   q{gilds}  => q{singular: 'gilds' --> 'gilds'};
is verb(q{were})->singular, q{was}  => q{singular: 'were' --> 'was'};
is verb(q{was})->singular,   q{was}  => q{singular: 'was' --> 'was'};
is verb(q{misunderstand})->singular, q{misunderstands}  => q{singular: 'misunderstand' --> 'misunderstands'};
is verb(q{misunderstands})->singular,   q{misunderstands}  => q{singular: 'misunderstands' --> 'misunderstands'};
is verb(q{dwell})->singular, q{dwells}  => q{singular: 'dwell' --> 'dwells'};
is verb(q{dwells})->singular,   q{dwells}  => q{singular: 'dwells' --> 'dwells'};
is verb(q{beget})->singular, q{begets}  => q{singular: 'beget' --> 'begets'};
is verb(q{begets})->singular,   q{begets}  => q{singular: 'begets' --> 'begets'};
is verb(q{swim})->singular, q{swims}  => q{singular: 'swim' --> 'swims'};
is verb(q{swims})->singular,   q{swims}  => q{singular: 'swims' --> 'swims'};
is verb(q{must})->singular, q{must}  => q{singular: 'must' --> 'must'};
is verb(q{don't})->singular, q{doesn't}  => q{singular: 'don't' --> 'doesn't'};
is verb(q{doesn't})->singular,   q{doesn't}  => q{singular: 'doesn't' --> 'doesn't'};
is verb(q{give})->singular, q{gives}  => q{singular: 'give' --> 'gives'};
is verb(q{gives})->singular,   q{gives}  => q{singular: 'gives' --> 'gives'};
is verb(q{catch})->singular, q{catches}  => q{singular: 'catch' --> 'catches'};
is verb(q{catches})->singular,   q{catches}  => q{singular: 'catches' --> 'catches'};
is verb(q{ache})->singular, q{aches}  => q{singular: 'ache' --> 'aches'};
is verb(q{aches})->singular,   q{aches}  => q{singular: 'aches' --> 'aches'};
is verb(q{hit})->singular, q{hits}  => q{singular: 'hit' --> 'hits'};
is verb(q{hits})->singular,   q{hits}  => q{singular: 'hits' --> 'hits'};
is verb(q{creche})->singular, q{creches}  => q{singular: 'creche' --> 'creches'};
is verb(q{creches})->singular,   q{creches}  => q{singular: 'creches' --> 'creches'};
is verb(q{withdraw})->singular, q{withdraws}  => q{singular: 'withdraw' --> 'withdraws'};
is verb(q{withdraws})->singular,   q{withdraws}  => q{singular: 'withdraws' --> 'withdraws'};
is verb(q{sunburn})->singular, q{sunburns}  => q{singular: 'sunburn' --> 'sunburns'};
is verb(q{sunburns})->singular,   q{sunburns}  => q{singular: 'sunburns' --> 'sunburns'};
is verb(q{swing})->singular, q{swings}  => q{singular: 'swing' --> 'swings'};
is verb(q{swings})->singular,   q{swings}  => q{singular: 'swings' --> 'swings'};
is verb(q{sing})->singular, q{sings}  => q{singular: 'sing' --> 'sings'};
is verb(q{sings})->singular,   q{sings}  => q{singular: 'sings' --> 'sings'};
is verb(q{burn})->singular, q{burns}  => q{singular: 'burn' --> 'burns'};
is verb(q{burns})->singular,   q{burns}  => q{singular: 'burns' --> 'burns'};
is verb(q{breed})->singular, q{breeds}  => q{singular: 'breed' --> 'breeds'};
is verb(q{breeds})->singular,   q{breeds}  => q{singular: 'breeds' --> 'breeds'};
is verb(q{love})->singular, q{loves}  => q{singular: 'love' --> 'loves'};
is verb(q{loves})->singular,   q{loves}  => q{singular: 'loves' --> 'loves'};
is verb(q{fight})->singular, q{fights}  => q{singular: 'fight' --> 'fights'};
is verb(q{fights})->singular,   q{fights}  => q{singular: 'fights' --> 'fights'};
is verb(q{win})->singular, q{wins}  => q{singular: 'win' --> 'wins'};
is verb(q{wins})->singular,   q{wins}  => q{singular: 'wins' --> 'wins'};
is verb(q{wait})->singular, q{waits}  => q{singular: 'wait' --> 'waits'};
is verb(q{waits})->singular,   q{waits}  => q{singular: 'waits' --> 'waits'};
is verb(q{shrink})->singular, q{shrinks}  => q{singular: 'shrink' --> 'shrinks'};
is verb(q{shrinks})->singular,   q{shrinks}  => q{singular: 'shrinks' --> 'shrinks'};
is verb(q{abide})->singular, q{abides}  => q{singular: 'abide' --> 'abides'};
is verb(q{abides})->singular,   q{abides}  => q{singular: 'abides' --> 'abides'};
is verb(q{come})->singular, q{comes}  => q{singular: 'come' --> 'comes'};
is verb(q{comes})->singular,   q{comes}  => q{singular: 'comes' --> 'comes'};
is verb(q{die})->singular, q{dies}  => q{singular: 'die' --> 'dies'};
is verb(q{dies})->singular,   q{dies}  => q{singular: 'dies' --> 'dies'};
is verb(q{ask})->singular, q{asks}  => q{singular: 'ask' --> 'asks'};
is verb(q{asks})->singular,   q{asks}  => q{singular: 'asks' --> 'asks'};
is verb(q{stand})->singular, q{stands}  => q{singular: 'stand' --> 'stands'};
is verb(q{stands})->singular,   q{stands}  => q{singular: 'stands' --> 'stands'};
is verb(q{hew})->singular, q{hews}  => q{singular: 'hew' --> 'hews'};
is verb(q{hews})->singular,   q{hews}  => q{singular: 'hews' --> 'hews'};
is verb(q{tread})->singular, q{treads}  => q{singular: 'tread' --> 'treads'};
is verb(q{treads})->singular,   q{treads}  => q{singular: 'treads' --> 'treads'};
is verb(q{slit})->singular, q{slits}  => q{singular: 'slit' --> 'slits'};
is verb(q{slits})->singular,   q{slits}  => q{singular: 'slits' --> 'slits'};
is verb(q{sha'n't})->singular, q{sha'n't}  => q{singular: 'sha'n't' --> 'sha'n't'};
is verb(q{drink})->singular, q{drinks}  => q{singular: 'drink' --> 'drinks'};
is verb(q{drinks})->singular,   q{drinks}  => q{singular: 'drinks' --> 'drinks'};
is verb(q{lean})->singular, q{leans}  => q{singular: 'lean' --> 'leans'};
is verb(q{leans})->singular,   q{leans}  => q{singular: 'leans' --> 'leans'};
is verb(q{might})->singular, q{might}  => q{singular: 'might' --> 'might'};
is verb(q{interlay})->singular, q{interlays}  => q{singular: 'interlay' --> 'interlays'};
is verb(q{interlays})->singular,   q{interlays}  => q{singular: 'interlays' --> 'interlays'};
is verb(q{can't})->singular, q{can't}  => q{singular: 'can't' --> 'can't'};
is verb(q{show})->singular, q{shows}  => q{singular: 'show' --> 'shows'};
is verb(q{shows})->singular,   q{shows}  => q{singular: 'shows' --> 'shows'};
is verb(q{needn't})->singular, q{needn't}  => q{singular: 'needn't' --> 'needn't'};
is verb(q{hold})->singular, q{holds}  => q{singular: 'hold' --> 'holds'};
is verb(q{holds})->singular,   q{holds}  => q{singular: 'holds' --> 'holds'};
is verb(q{fly})->singular, q{flies}  => q{singular: 'fly' --> 'flies'};
is verb(q{flies})->singular,   q{flies}  => q{singular: 'flies' --> 'flies'};
is verb(q{go})->singular, q{goes}  => q{singular: 'go' --> 'goes'};
is verb(q{goes})->singular,   q{goes}  => q{singular: 'goes' --> 'goes'};
is verb(q{know})->singular, q{knows}  => q{singular: 'know' --> 'knows'};
is verb(q{knows})->singular,   q{knows}  => q{singular: 'knows' --> 'knows'};
is verb(q{vex})->singular, q{vexes}  => q{singular: 'vex' --> 'vexes'};
is verb(q{vexes})->singular,   q{vexes}  => q{singular: 'vexes' --> 'vexes'};
is verb(q{iris})->singular, q{irises}  => q{singular: 'iris' --> 'irises'};
is verb(q{irises})->singular,   q{irises}  => q{singular: 'irises' --> 'irises'};
is verb(q{slay})->singular, q{slays}  => q{singular: 'slay' --> 'slays'};
is verb(q{slays})->singular,   q{slays}  => q{singular: 'slays' --> 'slays'};
is verb(q{withstand})->singular, q{withstands}  => q{singular: 'withstand' --> 'withstands'};
is verb(q{withstands})->singular,   q{withstands}  => q{singular: 'withstands' --> 'withstands'};
is verb(q{cache})->singular, q{caches}  => q{singular: 'cache' --> 'caches'};
is verb(q{caches})->singular,   q{caches}  => q{singular: 'caches' --> 'caches'};
is verb(q{drag})->singular, q{drags}  => q{singular: 'drag' --> 'drags'};
is verb(q{drags})->singular,   q{drags}  => q{singular: 'drags' --> 'drags'};
is verb(q{dive})->singular, q{dives}  => q{singular: 'dive' --> 'dives'};
is verb(q{dives})->singular,   q{dives}  => q{singular: 'dives' --> 'dives'};
is verb(q{wend})->singular, q{wends}  => q{singular: 'wend' --> 'wends'};
is verb(q{wends})->singular,   q{wends}  => q{singular: 'wends' --> 'wends'};
is verb(q{mustn't})->singular, q{mustn't}  => q{singular: 'mustn't' --> 'mustn't'};
is verb(q{look})->singular, q{looks}  => q{singular: 'look' --> 'looks'};
is verb(q{looks})->singular,   q{looks}  => q{singular: 'looks' --> 'looks'};
is verb(q{shit})->singular, q{shits}  => q{singular: 'shit' --> 'shits'};
is verb(q{shits})->singular,   q{shits}  => q{singular: 'shits' --> 'shits'};
is verb(q{provide})->singular, q{provides}  => q{singular: 'provide' --> 'provides'};
is verb(q{provides})->singular,   q{provides}  => q{singular: 'provides' --> 'provides'};
is verb(q{aren't})->singular, q{isn't}  => q{singular: 'aren't' --> 'isn't'};
is verb(q{isn't})->singular,   q{isn't}  => q{singular: 'isn't' --> 'isn't'};
is verb(q{burst})->singular, q{bursts}  => q{singular: 'burst' --> 'bursts'};
is verb(q{bursts})->singular,   q{bursts}  => q{singular: 'bursts' --> 'bursts'};
is verb(q{smite})->singular, q{smites}  => q{singular: 'smite' --> 'smites'};
is verb(q{smites})->singular,   q{smites}  => q{singular: 'smites' --> 'smites'};
is verb(q{kill})->singular, q{kills}  => q{singular: 'kill' --> 'kills'};
is verb(q{kills})->singular,   q{kills}  => q{singular: 'kills' --> 'kills'};
is verb(q{spit})->singular, q{spits}  => q{singular: 'spit' --> 'spits'};
is verb(q{spits})->singular,   q{spits}  => q{singular: 'spits' --> 'spits'};
is verb(q{knit})->singular, q{knits}  => q{singular: 'knit' --> 'knits'};
is verb(q{knits})->singular,   q{knits}  => q{singular: 'knits' --> 'knits'};
is verb(q{bring})->singular, q{brings}  => q{singular: 'bring' --> 'brings'};
is verb(q{brings})->singular,   q{brings}  => q{singular: 'brings' --> 'brings'};
is verb(q{fall})->singular, q{falls}  => q{singular: 'fall' --> 'falls'};
is verb(q{falls})->singular,   q{falls}  => q{singular: 'falls' --> 'falls'};
is verb(q{strip})->singular, q{strips}  => q{singular: 'strip' --> 'strips'};
is verb(q{strips})->singular,   q{strips}  => q{singular: 'strips' --> 'strips'};
is verb(q{thrust})->singular, q{thrusts}  => q{singular: 'thrust' --> 'thrusts'};
is verb(q{thrusts})->singular,   q{thrusts}  => q{singular: 'thrusts' --> 'thrusts'};
is verb(q{stay})->singular, q{stays}  => q{singular: 'stay' --> 'stays'};
is verb(q{stays})->singular,   q{stays}  => q{singular: 'stays' --> 'stays'};
is verb(q{ride})->singular, q{rides}  => q{singular: 'ride' --> 'rides'};
is verb(q{rides})->singular,   q{rides}  => q{singular: 'rides' --> 'rides'};
is verb(q{bet})->singular, q{bets}  => q{singular: 'bet' --> 'bets'};
is verb(q{bets})->singular,   q{bets}  => q{singular: 'bets' --> 'bets'};
is verb(q{move})->singular, q{moves}  => q{singular: 'move' --> 'moves'};
is verb(q{moves})->singular,   q{moves}  => q{singular: 'moves' --> 'moves'};
is verb(q{creep})->singular, q{creeps}  => q{singular: 'creep' --> 'creeps'};
is verb(q{creeps})->singular,   q{creeps}  => q{singular: 'creeps' --> 'creeps'};
is verb(q{could})->singular, q{could}  => q{singular: 'could' --> 'could'};
is verb(q{change})->singular, q{changes}  => q{singular: 'change' --> 'changes'};
is verb(q{changes})->singular,   q{changes}  => q{singular: 'changes' --> 'changes'};
is verb(q{won't})->singular, q{won't}  => q{singular: 'won't' --> 'won't'};
is verb(q{mayn't})->singular, q{mayn't}  => q{singular: 'mayn't' --> 'mayn't'};
is verb(q{like})->singular, q{likes}  => q{singular: 'like' --> 'likes'};
is verb(q{likes})->singular,   q{likes}  => q{singular: 'likes' --> 'likes'};
is verb(q{sow})->singular, q{sows}  => q{singular: 'sow' --> 'sows'};
is verb(q{sows})->singular,   q{sows}  => q{singular: 'sows' --> 'sows'};
is verb(q{seek})->singular, q{seeks}  => q{singular: 'seek' --> 'seeks'};
is verb(q{seeks})->singular,   q{seeks}  => q{singular: 'seeks' --> 'seeks'};
is verb(q{run})->singular, q{runs}  => q{singular: 'run' --> 'runs'};
is verb(q{runs})->singular,   q{runs}  => q{singular: 'runs' --> 'runs'};
is verb(q{bleed})->singular, q{bleeds}  => q{singular: 'bleed' --> 'bleeds'};
is verb(q{bleeds})->singular,   q{bleeds}  => q{singular: 'bleeds' --> 'bleeds'};
is verb(q{feel})->singular, q{feels}  => q{singular: 'feel' --> 'feels'};
is verb(q{feels})->singular,   q{feels}  => q{singular: 'feels' --> 'feels'};
is verb(q{spend})->singular, q{spends}  => q{singular: 'spend' --> 'spends'};
is verb(q{spends})->singular,   q{spends}  => q{singular: 'spends' --> 'spends'};
is verb(q{weep})->singular, q{weeps}  => q{singular: 'weep' --> 'weeps'};
is verb(q{weeps})->singular,   q{weeps}  => q{singular: 'weeps' --> 'weeps'};
is verb(q{wring})->singular, q{wrings}  => q{singular: 'wring' --> 'wrings'};
is verb(q{wrings})->singular,   q{wrings}  => q{singular: 'wrings' --> 'wrings'};
is verb(q{oughtn't})->singular, q{oughtn't}  => q{singular: 'oughtn't' --> 'oughtn't'};
is verb(q{find})->singular, q{finds}  => q{singular: 'find' --> 'finds'};
is verb(q{finds})->singular,   q{finds}  => q{singular: 'finds' --> 'finds'};
is verb(q{n't})->singular, q{n't}  => q{singular: 'n't' --> 'n't'};
is verb(q{hurt})->singular, q{hurts}  => q{singular: 'hurt' --> 'hurts'};
is verb(q{hurts})->singular,   q{hurts}  => q{singular: 'hurts' --> 'hurts'};
is verb(q{sit})->singular, q{sits}  => q{singular: 'sit' --> 'sits'};
is verb(q{sits})->singular,   q{sits}  => q{singular: 'sits' --> 'sits'};
is verb(q{follow})->singular, q{follows}  => q{singular: 'follow' --> 'follows'};
is verb(q{follows})->singular,   q{follows}  => q{singular: 'follows' --> 'follows'};
is verb(q{seem})->singular, q{seems}  => q{singular: 'seem' --> 'seems'};
is verb(q{seems})->singular,   q{seems}  => q{singular: 'seems' --> 'seems'};
is verb(q{rend})->singular, q{rends}  => q{singular: 'rend' --> 'rends'};
is verb(q{rends})->singular,   q{rends}  => q{singular: 'rends' --> 'rends'};
is verb(q{put})->singular, q{puts}  => q{singular: 'put' --> 'puts'};
is verb(q{puts})->singular,   q{puts}  => q{singular: 'puts' --> 'puts'};
is verb(q{forbid})->singular, q{forbids}  => q{singular: 'forbid' --> 'forbids'};
is verb(q{forbids})->singular,   q{forbids}  => q{singular: 'forbids' --> 'forbids'};
is verb(q{get})->singular, q{gets}  => q{singular: 'get' --> 'gets'};
is verb(q{gets})->singular,   q{gets}  => q{singular: 'gets' --> 'gets'};
is verb(q{beat})->singular, q{beats}  => q{singular: 'beat' --> 'beats'};
is verb(q{beats})->singular,   q{beats}  => q{singular: 'beats' --> 'beats'};
is verb(q{bend})->singular, q{bends}  => q{singular: 'bend' --> 'bends'};
is verb(q{bends})->singular,   q{bends}  => q{singular: 'bends' --> 'bends'};
is verb(q{forsake})->singular, q{forsakes}  => q{singular: 'forsake' --> 'forsakes'};
is verb(q{forsakes})->singular,   q{forsakes}  => q{singular: 'forsakes' --> 'forsakes'};

done_testing();
