use Test::More;
use Lingua::EN::Inflexion;

is noun(q{suggesta})->singular, q{suggestum}  => q{singular: 'suggesta' --> 'suggestum'};
is noun(q{suggestum})->singular,   q{suggestum}  => q{singular: 'suggestum' --> 'suggestum'};
is noun(q{actinias})->singular, q{actinia}  => q{singular: 'actinias' --> 'actinia'};
is noun(q{actinia})->singular,   q{actinia}  => q{singular: 'actinia' --> 'actinia'};
is noun(q{gigolos})->singular, q{gigolo}  => q{singular: 'gigolos' --> 'gigolo'};
is noun(q{gigolo})->singular,   q{gigolo}  => q{singular: 'gigolo' --> 'gigolo'};
is noun(q{pseudostomata})->singular, q{pseudostoma}  => q{singular: 'pseudostomata' --> 'pseudostoma'};
is noun(q{pseudostoma})->singular,   q{pseudostoma}  => q{singular: 'pseudostoma' --> 'pseudostoma'};
is noun(q{infos})->singular, q{info}  => q{singular: 'infos' --> 'info'};
is noun(q{info})->singular,   q{info}  => q{singular: 'info' --> 'info'};
is noun(q{pox})->singular, q{pox}  => q{singular: 'pox' --> 'pox'};
is noun(q{aggros})->singular, q{aggro}  => q{singular: 'aggros' --> 'aggro'};
is noun(q{aggro})->singular,   q{aggro}  => q{singular: 'aggro' --> 'aggro'};
is noun(q{lomenta})->singular, q{lomentum}  => q{singular: 'lomenta' --> 'lomentum'};
is noun(q{lomentum})->singular,   q{lomentum}  => q{singular: 'lomentum' --> 'lomentum'};
is noun(q{vagi})->singular, q{vagus}  => q{singular: 'vagi' --> 'vagus'};
is noun(q{vagus})->singular,   q{vagus}  => q{singular: 'vagus' --> 'vagus'};
is noun(q{nebulas})->singular, q{nebula}  => q{singular: 'nebulas' --> 'nebula'};
is noun(q{nebula})->singular,   q{nebula}  => q{singular: 'nebula' --> 'nebula'};
is noun(q{hemangeiomata})->singular, q{hemangeioma}  => q{singular: 'hemangeiomata' --> 'hemangeioma'};
is noun(q{hemangeioma})->singular,   q{hemangeioma}  => q{singular: 'hemangeioma' --> 'hemangeioma'};
is noun(q{plecos})->singular, q{pleco}  => q{singular: 'plecos' --> 'pleco'};
is noun(q{pleco})->singular,   q{pleco}  => q{singular: 'pleco' --> 'pleco'};
is noun(q{dittos})->singular, q{ditto}  => q{singular: 'dittos' --> 'ditto'};
is noun(q{ditto})->singular,   q{ditto}  => q{singular: 'ditto' --> 'ditto'};
is noun(q{epilimnia})->singular, q{epilimnion}  => q{singular: 'epilimnia' --> 'epilimnion'};
is noun(q{epilimnion})->singular,   q{epilimnion}  => q{singular: 'epilimnion' --> 'epilimnion'};
is noun(q{salivaria})->singular, q{salivarium}  => q{singular: 'salivaria' --> 'salivarium'};
is noun(q{salivarium})->singular,   q{salivarium}  => q{singular: 'salivarium' --> 'salivarium'};
is noun(q{lomata})->singular, q{loma}  => q{singular: 'lomata' --> 'loma'};
is noun(q{loma})->singular,   q{loma}  => q{singular: 'loma' --> 'loma'};
is noun(q{Portuguese})->singular, q{Portuguese}  => q{singular: 'Portuguese' --> 'Portuguese'};
is noun(q{fibrae})->singular, q{fibra}  => q{singular: 'fibrae' --> 'fibra'};
is noun(q{fibra})->singular,   q{fibra}  => q{singular: 'fibra' --> 'fibra'};
is noun(q{Galla})->singular, q{Galla}  => q{singular: 'Galla' --> 'Galla'};
is noun(q{Quitos})->singular, q{Quito}  => q{singular: 'Quitos' --> 'Quito'};
is noun(q{Quito})->singular,   q{Quito}  => q{singular: 'Quito' --> 'Quito'};
is noun(q{seraphs})->singular, q{seraph}  => q{singular: 'seraphs' --> 'seraph'};
is noun(q{seraph})->singular,   q{seraph}  => q{singular: 'seraph' --> 'seraph'};
is noun(q{tetrahedra})->singular, q{tetrahedron}  => q{singular: 'tetrahedra' --> 'tetrahedron'};
is noun(q{tetrahedron})->singular,   q{tetrahedron}  => q{singular: 'tetrahedron' --> 'tetrahedron'};
is noun(q{dolphinaria})->singular, q{dolphinarium}  => q{singular: 'dolphinaria' --> 'dolphinarium'};
is noun(q{dolphinarium})->singular,   q{dolphinarium}  => q{singular: 'dolphinarium' --> 'dolphinarium'};
is noun(q{wharfs})->singular, q{wharf}  => q{singular: 'wharfs' --> 'wharf'};
is noun(q{wharf})->singular,   q{wharf}  => q{singular: 'wharf' --> 'wharf'};
is noun(q{somas})->singular, q{soma}  => q{singular: 'somas' --> 'soma'};
is noun(q{soma})->singular,   q{soma}  => q{singular: 'soma' --> 'soma'};
is noun(q{cannabises})->singular, q{cannabis}  => q{singular: 'cannabises' --> 'cannabis'};
is noun(q{cannabis})->singular,   q{cannabis}  => q{singular: 'cannabis' --> 'cannabis'};
is noun(q{proseuchae})->singular, q{proseucha}  => q{singular: 'proseuchae' --> 'proseucha'};
is noun(q{proseucha})->singular,   q{proseucha}  => q{singular: 'proseucha' --> 'proseucha'};
is noun(q{teeth})->singular, q{tooth}  => q{singular: 'teeth' --> 'tooth'};
is noun(q{tooth})->singular,   q{tooth}  => q{singular: 'tooth' --> 'tooth'};
is noun(q{ghettos})->singular, q{ghetto}  => q{singular: 'ghettos' --> 'ghetto'};
is noun(q{ghetto})->singular,   q{ghetto}  => q{singular: 'ghetto' --> 'ghetto'};
is noun(q{ossicula})->singular, q{ossiculum}  => q{singular: 'ossicula' --> 'ossiculum'};
is noun(q{ossiculum})->singular,   q{ossiculum}  => q{singular: 'ossiculum' --> 'ossiculum'};
is noun(q{trockenbeerenauslesen})->singular, q{trockenbeerenauslese}  => q{singular: 'trockenbeerenauslesen' --> 'trockenbeerenauslese'};
is noun(q{trockenbeerenauslese})->singular,   q{trockenbeerenauslese}  => q{singular: 'trockenbeerenauslese' --> 'trockenbeerenauslese'};
is noun(q{antifixes})->singular, q{antefix}  => q{singular: 'antifixes' --> 'antefix'};
is noun(q{antefix})->singular,   q{antefix}  => q{singular: 'antefix' --> 'antefix'};
is noun(q{nodi})->singular, q{nodus}  => q{singular: 'nodi' --> 'nodus'};
is noun(q{nodus})->singular,   q{nodus}  => q{singular: 'nodus' --> 'nodus'};
is noun(q{ischia})->singular, q{ischium}  => q{singular: 'ischia' --> 'ischium'};
is noun(q{ischium})->singular,   q{ischium}  => q{singular: 'ischium' --> 'ischium'};
is noun(q{tenorini})->singular, q{tenorino}  => q{singular: 'tenorini' --> 'tenorino'};
is noun(q{tenorino})->singular,   q{tenorino}  => q{singular: 'tenorino' --> 'tenorino'};
is noun(q{bimbos})->singular, q{bimbo}  => q{singular: 'bimbos' --> 'bimbo'};
is noun(q{bimbo})->singular,   q{bimbo}  => q{singular: 'bimbo' --> 'bimbo'};
is noun(q{interaxes})->singular, q{interaxis}  => q{singular: 'interaxes' --> 'interaxis'};
is noun(q{interaxis})->singular,   q{interaxis}  => q{singular: 'interaxis' --> 'interaxis'};
is noun(q{advisoes})->singular, q{adviso}  => q{singular: 'advisoes' --> 'adviso'};
is noun(q{adviso})->singular,   q{adviso}  => q{singular: 'adviso' --> 'adviso'};
is noun(q{serums})->singular, q{serum}  => q{singular: 'serums' --> 'serum'};
is noun(q{serum})->singular,   q{serum}  => q{singular: 'serum' --> 'serum'};
is noun(q{syrtes})->singular, q{syrtis}  => q{singular: 'syrtes' --> 'syrtis'};
is noun(q{syrtis})->singular,   q{syrtis}  => q{singular: 'syrtis' --> 'syrtis'};
is noun(q{saffi})->singular, q{saffo}  => q{singular: 'saffi' --> 'saffo'};
is noun(q{saffo})->singular,   q{saffo}  => q{singular: 'saffo' --> 'saffo'};
is noun(q{felsenmeere})->singular, q{felsenmeer}  => q{singular: 'felsenmeere' --> 'felsenmeer'};
is noun(q{felsenmeer})->singular,   q{felsenmeer}  => q{singular: 'felsenmeer' --> 'felsenmeer'};
is noun(q{equisetums})->singular, q{equisetum}  => q{singular: 'equisetums' --> 'equisetum'};
is noun(q{equisetum})->singular,   q{equisetum}  => q{singular: 'equisetum' --> 'equisetum'};
is noun(q{prosulae})->singular, q{prosula}  => q{singular: 'prosulae' --> 'prosula'};
is noun(q{prosula})->singular,   q{prosula}  => q{singular: 'prosula' --> 'prosula'};
is noun(q{jambeaux})->singular, q{jambeau}  => q{singular: 'jambeaux' --> 'jambeau'};
is noun(q{jambeau})->singular,   q{jambeau}  => q{singular: 'jambeau' --> 'jambeau'};
is noun(q{debris})->singular, q{debris}  => q{singular: 'debris' --> 'debris'};
is noun(q{competentes})->singular, q{competent}  => q{singular: 'competentes' --> 'competent'};
is noun(q{competent})->singular,   q{competent}  => q{singular: 'competent' --> 'competent'};
is noun(q{serir})->singular, q{serir}  => q{singular: 'serir' --> 'serir'};
is noun(q{jazzes})->singular, q{jazz}  => q{singular: 'jazzes' --> 'jazz'};
is noun(q{jazz})->singular,   q{jazz}  => q{singular: 'jazz' --> 'jazz'};
is noun(q{ellipses})->singular, q{ellipse}  => q{singular: 'ellipses' --> 'ellipse'};
is noun(q{ellipse})->singular,   q{ellipse}  => q{singular: 'ellipse' --> 'ellipse'};
is noun(q{octohedra})->singular, q{octohedron}  => q{singular: 'octohedra' --> 'octohedron'};
is noun(q{octohedron})->singular,   q{octohedron}  => q{singular: 'octohedron' --> 'octohedron'};
is noun(q{caules})->singular, q{caulis}  => q{singular: 'caules' --> 'caulis'};
is noun(q{caulis})->singular,   q{caulis}  => q{singular: 'caulis' --> 'caulis'};
is noun(q{aecidia})->singular, q{aecidium}  => q{singular: 'aecidia' --> 'aecidium'};
is noun(q{aecidium})->singular,   q{aecidium}  => q{singular: 'aecidium' --> 'aecidium'};
is noun(q{optima})->singular, q{optimum}  => q{singular: 'optima' --> 'optimum'};
is noun(q{optimum})->singular,   q{optimum}  => q{singular: 'optimum' --> 'optimum'};
is noun(q{schismata})->singular, q{schisma}  => q{singular: 'schismata' --> 'schisma'};
is noun(q{schisma})->singular,   q{schisma}  => q{singular: 'schisma' --> 'schisma'};
is noun(q{tropaeolums})->singular, q{tropaeolum}  => q{singular: 'tropaeolums' --> 'tropaeolum'};
is noun(q{tropaeolum})->singular,   q{tropaeolum}  => q{singular: 'tropaeolum' --> 'tropaeolum'};
is noun(q{herrings})->singular, q{herring}  => q{singular: 'herrings' --> 'herring'};
is noun(q{four-star generals})->singular, q{four-star general}  => q{singular: 'four-star generals' --> 'four-star general'};
is noun(q{four-star general})->singular,   q{four-star general}  => q{singular: 'four-star general' --> 'four-star general'};
is noun(q{frizzes})->singular, q{frizz}  => q{singular: 'frizzes' --> 'frizz'};
is noun(q{frizz})->singular,   q{frizz}  => q{singular: 'frizz' --> 'frizz'};
is noun(q{sinuses})->singular, q{sinus}  => q{singular: 'sinuses' --> 'sinus'};
is noun(q{Tocharese})->singular, q{Tocharese}  => q{singular: 'Tocharese' --> 'Tocharese'};
is noun(q{anlages})->singular, q{anlage}  => q{singular: 'anlages' --> 'anlage'};
is noun(q{anlage})->singular,   q{anlage}  => q{singular: 'anlage' --> 'anlage'};
is noun(q{holothurias})->singular, q{holothuria}  => q{singular: 'holothurias' --> 'holothuria'};
is noun(q{holothuria})->singular,   q{holothuria}  => q{singular: 'holothuria' --> 'holothuria'};
is noun(q{photos})->singular, q{photo}  => q{singular: 'photos' --> 'photo'};
is noun(q{photo})->singular,   q{photo}  => q{singular: 'photo' --> 'photo'};
is noun(q{octopi})->singular, q{octopus}  => q{singular: 'octopi' --> 'octopus'};
is noun(q{octopus})->singular,   q{octopus}  => q{singular: 'octopus' --> 'octopus'};
is noun(q{vesiculae})->singular, q{vesicula}  => q{singular: 'vesiculae' --> 'vesicula'};
is noun(q{vesicula})->singular,   q{vesicula}  => q{singular: 'vesicula' --> 'vesicula'};
is noun(q{Javanese})->singular, q{Javanese}  => q{singular: 'Javanese' --> 'Javanese'};
is noun(q{terremare})->singular, q{terramara}  => q{singular: 'terremare' --> 'terramara'};
is noun(q{terramara})->singular,   q{terramara}  => q{singular: 'terramara' --> 'terramara'};
is noun(q{Bahamans})->singular, q{Bahaman}  => q{singular: 'Bahamans' --> 'Bahaman'};
is noun(q{Bahaman})->singular,   q{Bahaman}  => q{singular: 'Bahaman' --> 'Bahaman'};
is noun(q{tuberculomata})->singular, q{tuberculoma}  => q{singular: 'tuberculomata' --> 'tuberculoma'};
is noun(q{tuberculoma})->singular,   q{tuberculoma}  => q{singular: 'tuberculoma' --> 'tuberculoma'};
is noun(q{aurei})->singular, q{aureus}  => q{singular: 'aurei' --> 'aureus'};
is noun(q{aureus})->singular,   q{aureus}  => q{singular: 'aureus' --> 'aureus'};
is noun(q{furfures})->singular, q{furfur}  => q{singular: 'furfures' --> 'furfur'};
is noun(q{furfur})->singular,   q{furfur}  => q{singular: 'furfur' --> 'furfur'};
is noun(q{syntagmas})->singular, q{syntagma}  => q{singular: 'syntagmas' --> 'syntagma'};
is noun(q{syntagma})->singular,   q{syntagma}  => q{singular: 'syntagma' --> 'syntagma'};
is noun(q{alluvia})->singular, q{alluvium}  => q{singular: 'alluvia' --> 'alluvium'};
is noun(q{alluvium})->singular,   q{alluvium}  => q{singular: 'alluvium' --> 'alluvium'};
is noun(q{sistrums})->singular, q{sistrum}  => q{singular: 'sistrums' --> 'sistrum'};
is noun(q{sistrum})->singular,   q{sistrum}  => q{singular: 'sistrum' --> 'sistrum'};
is noun(q{symposiums})->singular, q{symposium}  => q{singular: 'symposiums' --> 'symposium'};
is noun(q{symposium})->singular,   q{symposium}  => q{singular: 'symposium' --> 'symposium'};
is noun(q{lixivia})->singular, q{lixivium}  => q{singular: 'lixivia' --> 'lixivium'};
is noun(q{lixivium})->singular,   q{lixivium}  => q{singular: 'lixivium' --> 'lixivium'};
is noun(q{menservants})->singular, q{manservant}  => q{singular: 'menservants' --> 'manservant'};
is noun(q{manservant})->singular,   q{manservant}  => q{singular: 'manservant' --> 'manservant'};
is noun(q{provisoes})->singular, q{proviso}  => q{singular: 'provisoes' --> 'proviso'};
is noun(q{proviso})->singular,   q{proviso}  => q{singular: 'proviso' --> 'proviso'};
is noun(q{Yunnanese})->singular, q{Yunnanese}  => q{singular: 'Yunnanese' --> 'Yunnanese'};
is noun(q{clepsydras})->singular, q{clepsydra}  => q{singular: 'clepsydras' --> 'clepsydra'};
is noun(q{clepsydra})->singular,   q{clepsydra}  => q{singular: 'clepsydra' --> 'clepsydra'};
is noun(q{tarantate})->singular, q{tarantata}  => q{singular: 'tarantate' --> 'tarantata'};
is noun(q{tarantata})->singular,   q{tarantata}  => q{singular: 'tarantata' --> 'tarantata'};
is noun(q{paha})->singular, q{paha}  => q{singular: 'paha' --> 'paha'};
is noun(q{men-servants})->singular, q{man-servant}  => q{singular: 'men-servants' --> 'man-servant'};
is noun(q{man-servant})->singular,   q{man-servant}  => q{singular: 'man-servant' --> 'man-servant'};
is noun(q{pteromata})->singular, q{pteroma}  => q{singular: 'pteromata' --> 'pteroma'};
is noun(q{pteroma})->singular,   q{pteroma}  => q{singular: 'pteroma' --> 'pteroma'};
is noun(q{ricordi})->singular, q{ricordo}  => q{singular: 'ricordi' --> 'ricordo'};
is noun(q{ricordo})->singular,   q{ricordo}  => q{singular: 'ricordo' --> 'ricordo'};
is noun(q{proceedings})->singular, q{proceedings}  => q{singular: 'proceedings' --> 'proceedings'};
is noun(q{tracheae})->singular, q{trachea}  => q{singular: 'tracheae' --> 'trachea'};
is noun(q{trachea})->singular,   q{trachea}  => q{singular: 'trachea' --> 'trachea'};
is noun(q{monos})->singular, q{mono}  => q{singular: 'monos' --> 'mono'};
is noun(q{mono})->singular,   q{mono}  => q{singular: 'mono' --> 'mono'};
is noun(q{sets-off})->singular, q{set-off}  => q{singular: 'sets-off' --> 'set-off'};
is noun(q{set-off})->singular,   q{set-off}  => q{singular: 'set-off' --> 'set-off'};
is noun(q{arrhae})->singular, q{arrha}  => q{singular: 'arrhae' --> 'arrha'};
is noun(q{arrha})->singular,   q{arrha}  => q{singular: 'arrha' --> 'arrha'};
is noun(q{Guaiaberos})->singular, q{Guaiabero}  => q{singular: 'Guaiaberos' --> 'Guaiabero'};
is noun(q{Guaiabero})->singular,   q{Guaiabero}  => q{singular: 'Guaiabero' --> 'Guaiabero'};
is noun(q{Auslesen})->singular, q{Auslese}  => q{singular: 'Auslesen' --> 'Auslese'};
is noun(q{Auslese})->singular,   q{Auslese}  => q{singular: 'Auslese' --> 'Auslese'};
is noun(q{poes})->singular, q{po}  => q{singular: 'poes' --> 'po'};
is noun(q{po})->singular,   q{po}  => q{singular: 'po' --> 'po'};
is noun(q{Sonamans})->singular, q{Sonaman}  => q{singular: 'Sonamans' --> 'Sonaman'};
is noun(q{Sonaman})->singular,   q{Sonaman}  => q{singular: 'Sonaman' --> 'Sonaman'};
is noun(q{occiputs})->singular, q{occiput}  => q{singular: 'occiputs' --> 'occiput'};
is noun(q{occiput})->singular,   q{occiput}  => q{singular: 'occiput' --> 'occiput'};
is noun(q{motoscafi})->singular, q{motoscafo}  => q{singular: 'motoscafi' --> 'motoscafo'};
is noun(q{motoscafo})->singular,   q{motoscafo}  => q{singular: 'motoscafo' --> 'motoscafo'};
is noun(q{genera})->singular, q{genus}  => q{singular: 'genera' --> 'genus'};
is noun(q{genus})->singular,   q{genus}  => q{singular: 'genus' --> 'genus'};
is noun(q{kernoi})->singular, q{kernos}  => q{singular: 'kernoi' --> 'kernos'};
is noun(q{kernos})->singular,   q{kernos}  => q{singular: 'kernos' --> 'kernos'};
is noun(q{vincula})->singular, q{vinculum}  => q{singular: 'vincula' --> 'vinculum'};
is noun(q{vinculum})->singular,   q{vinculum}  => q{singular: 'vinculum' --> 'vinculum'};
is noun(q{Aragonese})->singular, q{Aragonese}  => q{singular: 'Aragonese' --> 'Aragonese'};
is noun(q{five star generals})->singular, q{five star general}  => q{singular: 'five star generals' --> 'five star general'};
is noun(q{five star general})->singular,   q{five star general}  => q{singular: 'five star general' --> 'five star general'};
is noun(q{axopodia})->singular, q{axopodium}  => q{singular: 'axopodia' --> 'axopodium'};
is noun(q{axopodium})->singular,   q{axopodium}  => q{singular: 'axopodium' --> 'axopodium'};
is noun(q{loggias})->singular, q{loggia}  => q{singular: 'loggias' --> 'loggia'};
is noun(q{loggia})->singular,   q{loggia}  => q{singular: 'loggia' --> 'loggia'};
is noun(q{sezessionen})->singular, q{sezession}  => q{singular: 'sezessionen' --> 'sezession'};
is noun(q{sezession})->singular,   q{sezession}  => q{singular: 'sezession' --> 'sezession'};
is noun(q{leptomonas})->singular, q{leptomonas}  => q{singular: 'leptomonas' --> 'leptomonas'};
is noun(q{scandala magnatum})->singular, q{scandalum magnatum}  => q{singular: 'scandala magnatum' --> 'scandalum magnatum'};
is noun(q{scandalum magnatum})->singular,   q{scandalum magnatum}  => q{singular: 'scandalum magnatum' --> 'scandalum magnatum'};
is noun(q{karrenfelds})->singular, q{karrenfeld}  => q{singular: 'karrenfelds' --> 'karrenfeld'};
is noun(q{karrenfeld})->singular,   q{karrenfeld}  => q{singular: 'karrenfeld' --> 'karrenfeld'};
is noun(q{interambulacra})->singular, q{interambulacrum}  => q{singular: 'interambulacra' --> 'interambulacrum'};
is noun(q{interambulacrum})->singular,   q{interambulacrum}  => q{singular: 'interambulacrum' --> 'interambulacrum'};
is noun(q{internodia})->singular, q{internodium}  => q{singular: 'internodia' --> 'internodium'};
is noun(q{internodium})->singular,   q{internodium}  => q{singular: 'internodium' --> 'internodium'};
is noun(q{parapleura})->singular, q{parapleura}  => q{singular: 'parapleura' --> 'parapleura'};
is noun(q{themata})->singular, q{thema}  => q{singular: 'themata' --> 'thema'};
is noun(q{thema})->singular,   q{thema}  => q{singular: 'thema' --> 'thema'};
is noun(q{contadine})->singular, q{contadina}  => q{singular: 'contadine' --> 'contadina'};
is noun(q{contadina})->singular,   q{contadina}  => q{singular: 'contadina' --> 'contadina'};
is noun(q{abortoria})->singular, q{abortorium}  => q{singular: 'abortoria' --> 'abortorium'};
is noun(q{abortorium})->singular,   q{abortorium}  => q{singular: 'abortorium' --> 'abortorium'};
is noun(q{karakias})->singular, q{karakia}  => q{singular: 'karakias' --> 'karakia'};
is noun(q{semata})->singular, q{sema}  => q{singular: 'semata' --> 'sema'};
is noun(q{sema})->singular,   q{sema}  => q{singular: 'sema' --> 'sema'};
is noun(q{crustae})->singular, q{crusta}  => q{singular: 'crustae' --> 'crusta'};
is noun(q{crusta})->singular,   q{crusta}  => q{singular: 'crusta' --> 'crusta'};
is noun(q{whosoever})->singular, q{whosoever}  => q{singular: 'whosoever' --> 'whosoever'};
is noun(q{cocos})->singular, q{coco}  => q{singular: 'cocos' --> 'coco'};
is noun(q{coco})->singular,   q{coco}  => q{singular: 'coco' --> 'coco'};
is noun(q{gyros})->singular, q{gyro}  => q{singular: 'gyros' --> 'gyro'};
is noun(q{gyro})->singular,   q{gyro}  => q{singular: 'gyro' --> 'gyro'};
is noun(q{mausoleums})->singular, q{mausoleum}  => q{singular: 'mausoleums' --> 'mausoleum'};
is noun(q{mausoleum})->singular,   q{mausoleum}  => q{singular: 'mausoleum' --> 'mausoleum'};
is noun(q{rad})->singular, q{rad}  => q{singular: 'rad' --> 'rad'};
is noun(q{placebos})->singular, q{placebo}  => q{singular: 'placebos' --> 'placebo'};
is noun(q{placebo})->singular,   q{placebo}  => q{singular: 'placebo' --> 'placebo'};
is noun(q{arcosolia})->singular, q{arcosolium}  => q{singular: 'arcosolia' --> 'arcosolium'};
is noun(q{arcosolium})->singular,   q{arcosolium}  => q{singular: 'arcosolium' --> 'arcosolium'};
is noun(q{bronchi})->singular, q{bronchus}  => q{singular: 'bronchi' --> 'bronchus'};
is noun(q{bronchus})->singular,   q{bronchus}  => q{singular: 'bronchus' --> 'bronchus'};
is noun(q{ronds de jambes})->singular, q{rond de jambe}  => q{singular: 'ronds de jambes' --> 'rond de jambe'};
is noun(q{rond de jambe})->singular,   q{rond de jambe}  => q{singular: 'rond de jambe' --> 'rond de jambe'};
is noun(q{grabens})->singular, q{graben}  => q{singular: 'grabens' --> 'graben'};
is noun(q{felones-de-se})->singular, q{felo-de-se}  => q{singular: 'felones-de-se' --> 'felo-de-se'};
is noun(q{felo-de-se})->singular,   q{felo-de-se}  => q{singular: 'felo-de-se' --> 'felo-de-se'};
is noun(q{Whitmanese})->singular, q{Whitmanese}  => q{singular: 'Whitmanese' --> 'Whitmanese'};
is noun(q{meningiomata})->singular, q{meningioma}  => q{singular: 'meningiomata' --> 'meningioma'};
is noun(q{meningioma})->singular,   q{meningioma}  => q{singular: 'meningioma' --> 'meningioma'};
is noun(q{tongs})->singular, q{tongs}  => q{singular: 'tongs' --> 'tongs'};
is noun(q{vivaria})->singular, q{vivarium}  => q{singular: 'vivaria' --> 'vivarium'};
is noun(q{vivarium})->singular,   q{vivarium}  => q{singular: 'vivarium' --> 'vivarium'};
is noun(q{amici curiae})->singular, q{amicus curiae}  => q{singular: 'amici curiae' --> 'amicus curiae'};
is noun(q{amicus curiae})->singular,   q{amicus curiae}  => q{singular: 'amicus curiae' --> 'amicus curiae'};
is noun(q{one-star generals})->singular, q{one-star general}  => q{singular: 'one-star generals' --> 'one-star general'};
is noun(q{one-star general})->singular,   q{one-star general}  => q{singular: 'one-star general' --> 'one-star general'};
is noun(q{theirs})->singular, q{its}  => q{singular: 'theirs' --> 'its'};
is noun(q{its})->singular,   q{its}  => q{singular: 'its' --> 'its'};
is noun(q{Antananarivos})->singular, q{Antananarivo}  => q{singular: 'Antananarivos' --> 'Antananarivo'};
is noun(q{Antananarivo})->singular,   q{Antananarivo}  => q{singular: 'Antananarivo' --> 'Antananarivo'};
is noun(q{men-midwives})->singular, q{man-midwife}  => q{singular: 'men-midwives' --> 'man-midwife'};
is noun(q{man-midwife})->singular,   q{man-midwife}  => q{singular: 'man-midwife' --> 'man-midwife'};
is noun(q{loci})->singular, q{locus}  => q{singular: 'loci' --> 'locus'};
is noun(q{locus})->singular,   q{locus}  => q{singular: 'locus' --> 'locus'};
is noun(q{crania})->singular, q{cranium}  => q{singular: 'crania' --> 'cranium'};
is noun(q{cranium})->singular,   q{cranium}  => q{singular: 'cranium' --> 'cranium'};
is noun(q{postulata})->singular, q{postulatum}  => q{singular: 'postulata' --> 'postulatum'};
is noun(q{postulatum})->singular,   q{postulatum}  => q{singular: 'postulatum' --> 'postulatum'};
is noun(q{suggestiones falsi})->singular, q{suggestio falsi}  => q{singular: 'suggestiones falsi' --> 'suggestio falsi'};
is noun(q{suggestio falsi})->singular,   q{suggestio falsi}  => q{singular: 'suggestio falsi' --> 'suggestio falsi'};
is noun(q{clostridia})->singular, q{clostridium}  => q{singular: 'clostridia' --> 'clostridium'};
is noun(q{clostridium})->singular,   q{clostridium}  => q{singular: 'clostridium' --> 'clostridium'};
is noun(q{caryatids})->singular, q{caryatid}  => q{singular: 'caryatids' --> 'caryatid'};
is noun(q{caryatid})->singular,   q{caryatid}  => q{singular: 'caryatid' --> 'caryatid'};
is noun(q{prolabia})->singular, q{prolabium}  => q{singular: 'prolabia' --> 'prolabium'};
is noun(q{prolabium})->singular,   q{prolabium}  => q{singular: 'prolabium' --> 'prolabium'};
is noun(q{octopodes})->singular, q{octopus}  => q{singular: 'octopodes' --> 'octopus'};
is noun(q{octopus})->singular,   q{octopus}  => q{singular: 'octopus' --> 'octopus'};
is noun(q{zoaria})->singular, q{zoarium}  => q{singular: 'zoaria' --> 'zoarium'};
is noun(q{zoarium})->singular,   q{zoarium}  => q{singular: 'zoarium' --> 'zoarium'};
is noun(q{interregnums})->singular, q{interregnum}  => q{singular: 'interregnums' --> 'interregnum'};
is noun(q{interregnum})->singular,   q{interregnum}  => q{singular: 'interregnum' --> 'interregnum'};
is noun(q{diplomas})->singular, q{diploma}  => q{singular: 'diplomas' --> 'diploma'};
is noun(q{diploma})->singular,   q{diploma}  => q{singular: 'diploma' --> 'diploma'};
is noun(q{chapeaux})->singular, q{chapeau}  => q{singular: 'chapeaux' --> 'chapeau'};
is noun(q{chapeau})->singular,   q{chapeau}  => q{singular: 'chapeau' --> 'chapeau'};
is noun(q{whatsoever})->singular, q{whatsoever}  => q{singular: 'whatsoever' --> 'whatsoever'};
is noun(q{wandervogel})->singular, q{wandervogel}  => q{singular: 'wandervogel' --> 'wandervogel'};
is noun(q{capataces})->singular, q{capataz}  => q{singular: 'capataces' --> 'capataz'};
is noun(q{capataz})->singular,   q{capataz}  => q{singular: 'capataz' --> 'capataz'};
is noun(q{volcanos})->singular, q{volcano}  => q{singular: 'volcanos' --> 'volcano'};
is noun(q{volcano})->singular,   q{volcano}  => q{singular: 'volcano' --> 'volcano'};
is noun(q{Romanies})->singular, q{Romany}  => q{singular: 'Romanies' --> 'Romany'};
is noun(q{Romany})->singular,   q{Romany}  => q{singular: 'Romany' --> 'Romany'};
is noun(q{pizzas})->singular, q{pizza}  => q{singular: 'pizzas' --> 'pizza'};
is noun(q{pizza})->singular,   q{pizza}  => q{singular: 'pizza' --> 'pizza'};
is noun(q{Congolese})->singular, q{Congolese}  => q{singular: 'Congolese' --> 'Congolese'};
is noun(q{Nepalese})->singular, q{Nepalese}  => q{singular: 'Nepalese' --> 'Nepalese'};
is noun(q{diastemata})->singular, q{diastema}  => q{singular: 'diastemata' --> 'diastema'};
is noun(q{diastema})->singular,   q{diastema}  => q{singular: 'diastema' --> 'diastema'};
is noun(q{prytan})->singular, q{prytanis}  => q{singular: 'prytan' --> 'prytanis'};
is noun(q{prytanis})->singular,   q{prytanis}  => q{singular: 'prytanis' --> 'prytanis'};
is noun(q{umbilicuses})->singular, q{umbilicus}  => q{singular: 'umbilicuses' --> 'umbilicus'};
is noun(q{umbilicus})->singular,   q{umbilicus}  => q{singular: 'umbilicus' --> 'umbilicus'};
is noun(q{braccia})->singular, q{braccio}  => q{singular: 'braccia' --> 'braccio'};
is noun(q{braccio})->singular,   q{braccio}  => q{singular: 'braccio' --> 'braccio'};
is noun(q{chordae})->singular, q{chorda}  => q{singular: 'chordae' --> 'chorda'};
is noun(q{chorda})->singular,   q{chorda}  => q{singular: 'chorda' --> 'chorda'};
is noun(q{hydraulica})->singular, q{hydraulicon}  => q{singular: 'hydraulica' --> 'hydraulicon'};
is noun(q{hydraulicon})->singular,   q{hydraulicon}  => q{singular: 'hydraulicon' --> 'hydraulicon'};
is noun(q{wildebeest})->singular, q{wildebeest}  => q{singular: 'wildebeest' --> 'wildebeest'};
is noun(q{viscera})->singular, q{viscus}  => q{singular: 'viscera' --> 'viscus'};
is noun(q{viscus})->singular,   q{viscus}  => q{singular: 'viscus' --> 'viscus'};
is noun(q{bass})->singular, q{bass}  => q{singular: 'bass' --> 'bass'};
is noun(q{feiseanna})->singular, q{feis}  => q{singular: 'feiseanna' --> 'feis'};
is noun(q{feis})->singular,   q{feis}  => q{singular: 'feis' --> 'feis'};
is noun(q{yours})->singular, q{yours}  => q{singular: 'yours' --> 'yours'};
is noun(q{belle epoques})->singular, q{belle epoque}  => q{singular: 'belle epoques' --> 'belle epoque'};
is noun(q{belle epoque})->singular,   q{belle epoque}  => q{singular: 'belle epoque' --> 'belle epoque'};
is noun(q{stephania})->singular, q{stephanion}  => q{singular: 'stephania' --> 'stephanion'};
is noun(q{stephanion})->singular,   q{stephanion}  => q{singular: 'stephanion' --> 'stephanion'};
is noun(q{thymi})->singular, q{thymus}  => q{singular: 'thymi' --> 'thymus'};
is noun(q{thymus})->singular,   q{thymus}  => q{singular: 'thymus' --> 'thymus'};
is noun(q{phalloi})->singular, q{phallos}  => q{singular: 'phalloi' --> 'phallos'};
is noun(q{phallos})->singular,   q{phallos}  => q{singular: 'phallos' --> 'phallos'};
is noun(q{intermedia})->singular, q{intermedium}  => q{singular: 'intermedia' --> 'intermedium'};
is noun(q{intermedium})->singular,   q{intermedium}  => q{singular: 'intermedium' --> 'intermedium'};
is noun(q{phenomena})->singular, q{phenomenon}  => q{singular: 'phenomena' --> 'phenomenon'};
is noun(q{phenomenon})->singular,   q{phenomenon}  => q{singular: 'phenomenon' --> 'phenomenon'};
is noun(q{profluvia})->singular, q{profluvium}  => q{singular: 'profluvia' --> 'profluvium'};
is noun(q{profluvium})->singular,   q{profluvium}  => q{singular: 'profluvium' --> 'profluvium'};
is noun(q{pensieri})->singular, q{pensiero}  => q{singular: 'pensieri' --> 'pensiero'};
is noun(q{pensiero})->singular,   q{pensiero}  => q{singular: 'pensiero' --> 'pensiero'};
is noun(q{antefixa})->singular, q{antefix}  => q{singular: 'antefixa' --> 'antefix'};
is noun(q{antefix})->singular,   q{antefix}  => q{singular: 'antefix' --> 'antefix'};
is noun(q{phyllobranchiae})->singular, q{phyllobranchia}  => q{singular: 'phyllobranchiae' --> 'phyllobranchia'};
is noun(q{phyllobranchia})->singular,   q{phyllobranchia}  => q{singular: 'phyllobranchia' --> 'phyllobranchia'};
is noun(q{deliriums})->singular, q{delirium}  => q{singular: 'deliriums' --> 'delirium'};
is noun(q{delirium})->singular,   q{delirium}  => q{singular: 'delirium' --> 'delirium'};
is noun(q{quartzes})->singular, q{quartz}  => q{singular: 'quartzes' --> 'quartz'};
is noun(q{quartz})->singular,   q{quartz}  => q{singular: 'quartz' --> 'quartz'};
is noun(q{isidia})->singular, q{isidium}  => q{singular: 'isidia' --> 'isidium'};
is noun(q{isidium})->singular,   q{isidium}  => q{singular: 'isidium' --> 'isidium'};
is noun(q{cistophorori})->singular, q{cistophorus}  => q{singular: 'cistophorori' --> 'cistophorus'};
is noun(q{cistophorus})->singular,   q{cistophorus}  => q{singular: 'cistophorus' --> 'cistophorus'};
is noun(q{synechiae})->singular, q{synechia}  => q{singular: 'synechiae' --> 'synechia'};
is noun(q{synechia})->singular,   q{synechia}  => q{singular: 'synechia' --> 'synechia'};
is noun(q{terga})->singular, q{tergum}  => q{singular: 'terga' --> 'tergum'};
is noun(q{tergum})->singular,   q{tergum}  => q{singular: 'tergum' --> 'tergum'};
is noun(q{chlamydias})->singular, q{chlamydia}  => q{singular: 'chlamydias' --> 'chlamydia'};
is noun(q{chlamydia})->singular,   q{chlamydia}  => q{singular: 'chlamydia' --> 'chlamydia'};
is noun(q{septenarii})->singular, q{septenarius}  => q{singular: 'septenarii' --> 'septenarius'};
is noun(q{septenarius})->singular,   q{septenarius}  => q{singular: 'septenarius' --> 'septenarius'};
is noun(q{nouvelle pauvre})->singular, q{nouveau pauvre}  => q{singular: 'nouvelle pauvre' --> 'nouveau pauvre'};
is noun(q{nouveau pauvre})->singular,   q{nouveau pauvre}  => q{singular: 'nouveau pauvre' --> 'nouveau pauvre'};
is noun(q{enigmata})->singular, q{enigma}  => q{singular: 'enigmata' --> 'enigma'};
is noun(q{enigma})->singular,   q{enigma}  => q{singular: 'enigma' --> 'enigma'};
is noun(q{otos})->singular, q{oto}  => q{singular: 'otos' --> 'oto'};
is noun(q{oto})->singular,   q{oto}  => q{singular: 'oto' --> 'oto'};
is noun(q{pedalos})->singular, q{pedalo}  => q{singular: 'pedalos' --> 'pedalo'};
is noun(q{pedalo})->singular,   q{pedalo}  => q{singular: 'pedalo' --> 'pedalo'};
is noun(q{blastemata})->singular, q{blastema}  => q{singular: 'blastemata' --> 'blastema'};
is noun(q{blastema})->singular,   q{blastema}  => q{singular: 'blastema' --> 'blastema'};
is noun(q{bechuana})->singular, q{bechuana}  => q{singular: 'bechuana' --> 'bechuana'};
is noun(q{papillae})->singular, q{papilla}  => q{singular: 'papillae' --> 'papilla'};
is noun(q{papilla})->singular,   q{papilla}  => q{singular: 'papilla' --> 'papilla'};
is noun(q{stabilimenta})->singular, q{stabilimentum}  => q{singular: 'stabilimenta' --> 'stabilimentum'};
is noun(q{stabilimentum})->singular,   q{stabilimentum}  => q{singular: 'stabilimentum' --> 'stabilimentum'};
is noun(q{plether})->singular, q{plethron}  => q{singular: 'plether' --> 'plethron'};
is noun(q{plethron})->singular,   q{plethron}  => q{singular: 'plethron' --> 'plethron'};
is noun(q{granite})->singular, q{granita}  => q{singular: 'granite' --> 'granita'};
is noun(q{granita})->singular,   q{granita}  => q{singular: 'granita' --> 'granita'};
is noun(q{uredia})->singular, q{uredium}  => q{singular: 'uredia' --> 'uredium'};
is noun(q{uredium})->singular,   q{uredium}  => q{singular: 'uredium' --> 'uredium'};
is noun(q{lives})->singular, q{life}  => q{singular: 'lives' --> 'life'};
is noun(q{life})->singular,   q{life}  => q{singular: 'life' --> 'life'};
is noun(q{kouroi})->singular, q{kouros}  => q{singular: 'kouroi' --> 'kouros'};
is noun(q{kouros})->singular,   q{kouros}  => q{singular: 'kouros' --> 'kouros'};
is noun(q{fasciculi})->singular, q{fasciculus}  => q{singular: 'fasciculi' --> 'fasciculus'};
is noun(q{fasciculus})->singular,   q{fasciculus}  => q{singular: 'fasciculus' --> 'fasciculus'};
is noun(q{beeves})->singular, q{beef}  => q{singular: 'beeves' --> 'beef'};
is noun(q{beef})->singular,   q{beef}  => q{singular: 'beef' --> 'beef'};
is noun(q{solfeggios})->singular, q{solfeggio}  => q{singular: 'solfeggios' --> 'solfeggio'};
is noun(q{solfeggio})->singular,   q{solfeggio}  => q{singular: 'solfeggio' --> 'solfeggio'};
is noun(q{yo yos})->singular, q{yo yo}  => q{singular: 'yo yos' --> 'yo yo'};
is noun(q{yo yo})->singular,   q{yo yo}  => q{singular: 'yo yo' --> 'yo yo'};
is noun(q{erotes})->singular, q{eros}  => q{singular: 'erotes' --> 'eros'};
is noun(q{eros})->singular,   q{eros}  => q{singular: 'eros' --> 'eros'};
is noun(q{florae})->singular, q{flora}  => q{singular: 'florae' --> 'flora'};
is noun(q{flora})->singular,   q{flora}  => q{singular: 'flora' --> 'flora'};
is noun(q{Kongolese})->singular, q{Kongolese}  => q{singular: 'Kongolese' --> 'Kongolese'};
is noun(q{dilettanti})->singular, q{dilettante}  => q{singular: 'dilettanti' --> 'dilettante'};
is noun(q{dilettante})->singular,   q{dilettante}  => q{singular: 'dilettante' --> 'dilettante'};
is noun(q{verticilli})->singular, q{verticillus}  => q{singular: 'verticilli' --> 'verticillus'};
is noun(q{verticillus})->singular,   q{verticillus}  => q{singular: 'verticillus' --> 'verticillus'};
is noun(q{amoebae})->singular, q{amoeba}  => q{singular: 'amoebae' --> 'amoeba'};
is noun(q{amoeba})->singular,   q{amoeba}  => q{singular: 'amoeba' --> 'amoeba'};
is noun(q{intercalaria})->singular, q{intercalarium}  => q{singular: 'intercalaria' --> 'intercalarium'};
is noun(q{intercalarium})->singular,   q{intercalarium}  => q{singular: 'intercalarium' --> 'intercalarium'};
is noun(q{fiascos})->singular, q{fiasco}  => q{singular: 'fiascos' --> 'fiasco'};
is noun(q{fiasco})->singular,   q{fiasco}  => q{singular: 'fiasco' --> 'fiasco'};
is noun(q{aciculae})->singular, q{acicula}  => q{singular: 'aciculae' --> 'acicula'};
is noun(q{acicula})->singular,   q{acicula}  => q{singular: 'acicula' --> 'acicula'};
is noun(q{yeses})->singular, q{yes}  => q{singular: 'yeses' --> 'yes'};
is noun(q{yes})->singular,   q{yes}  => q{singular: 'yes' --> 'yes'};
is noun(q{pedia})->singular, q{pedion}  => q{singular: 'pedia' --> 'pedion'};
is noun(q{pedion})->singular,   q{pedion}  => q{singular: 'pedion' --> 'pedion'};
is noun(q{enemata})->singular, q{enema}  => q{singular: 'enemata' --> 'enema'};
is noun(q{enema})->singular,   q{enema}  => q{singular: 'enema' --> 'enema'};
is noun(q{line outs})->singular, q{line out}  => q{singular: 'line outs' --> 'line out'};
is noun(q{line out})->singular,   q{line out}  => q{singular: 'line out' --> 'line out'};
is noun(q{stromodea})->singular, q{stromodeum}  => q{singular: 'stromodea' --> 'stromodeum'};
is noun(q{stromodeum})->singular,   q{stromodeum}  => q{singular: 'stromodeum' --> 'stromodeum'};
is noun(q{neurinomata})->singular, q{neurinoma}  => q{singular: 'neurinomata' --> 'neurinoma'};
is noun(q{neurinoma})->singular,   q{neurinoma}  => q{singular: 'neurinoma' --> 'neurinoma'};
is noun(q{Sudanese})->singular, q{Sudanese}  => q{singular: 'Sudanese' --> 'Sudanese'};
is noun(q{anti serums})->singular, q{anti serum}  => q{singular: 'anti serums' --> 'anti serum'};
is noun(q{anti serum})->singular,   q{anti serum}  => q{singular: 'anti serum' --> 'anti serum'};
is noun(q{gemmae})->singular, q{gemma}  => q{singular: 'gemmae' --> 'gemma'};
is noun(q{gemma})->singular,   q{gemma}  => q{singular: 'gemma' --> 'gemma'};
is noun(q{radiuses})->singular, q{radius}  => q{singular: 'radiuses' --> 'radius'};
is noun(q{radius})->singular,   q{radius}  => q{singular: 'radius' --> 'radius'};
is noun(q{secundiparas})->singular, q{secundipara}  => q{singular: 'secundiparas' --> 'secundipara'};
is noun(q{secundipara})->singular,   q{secundipara}  => q{singular: 'secundipara' --> 'secundipara'};
is noun(q{zemiroth})->singular, q{zemirah}  => q{singular: 'zemiroth' --> 'zemirah'};
is noun(q{zemirah})->singular,   q{zemirah}  => q{singular: 'zemirah' --> 'zemirah'};
is noun(q{pipkrakes})->singular, q{pipkrake}  => q{singular: 'pipkrakes' --> 'pipkrake'};
is noun(q{pipkrake})->singular,   q{pipkrake}  => q{singular: 'pipkrake' --> 'pipkrake'};
is noun(q{Roma})->singular, q{Rom}  => q{singular: 'Roma' --> 'Rom'};
is noun(q{Rom})->singular,   q{Rom}  => q{singular: 'Rom' --> 'Rom'};
is noun(q{umbrae})->singular, q{umbra}  => q{singular: 'umbrae' --> 'umbra'};
is noun(q{umbra})->singular,   q{umbra}  => q{singular: 'umbra' --> 'umbra'};
is noun(q{miliolae})->singular, q{miliola}  => q{singular: 'miliolae' --> 'miliola'};
is noun(q{miliola})->singular,   q{miliola}  => q{singular: 'miliola' --> 'miliola'};
is noun(q{stipulas})->singular, q{stipula}  => q{singular: 'stipulas' --> 'stipula'};
is noun(q{stipula})->singular,   q{stipula}  => q{singular: 'stipula' --> 'stipula'};
is noun(q{maculae})->singular, q{macula}  => q{singular: 'maculae' --> 'macula'};
is noun(q{macula})->singular,   q{macula}  => q{singular: 'macula' --> 'macula'};
is noun(q{decennia})->singular, q{decennium}  => q{singular: 'decennia' --> 'decennium'};
is noun(q{decennium})->singular,   q{decennium}  => q{singular: 'decennium' --> 'decennium'};
is noun(q{prokarya})->singular, q{prokaryon}  => q{singular: 'prokarya' --> 'prokaryon'};
is noun(q{prokaryon})->singular,   q{prokaryon}  => q{singular: 'prokaryon' --> 'prokaryon'};
is noun(q{uredinia})->singular, q{uredinium}  => q{singular: 'uredinia' --> 'uredinium'};
is noun(q{uredinium})->singular,   q{uredinium}  => q{singular: 'uredinium' --> 'uredinium'};
is noun(q{sambos})->singular, q{sambo}  => q{singular: 'sambos' --> 'sambo'};
is noun(q{sambo})->singular,   q{sambo}  => q{singular: 'sambo' --> 'sambo'};
is noun(q{set-outs})->singular, q{set-out}  => q{singular: 'set-outs' --> 'set-out'};
is noun(q{set-out})->singular,   q{set-out}  => q{singular: 'set-out' --> 'set-out'};
is noun(q{aculei})->singular, q{aculeus}  => q{singular: 'aculei' --> 'aculeus'};
is noun(q{aculeus})->singular,   q{aculeus}  => q{singular: 'aculeus' --> 'aculeus'};
is noun(q{two star generals})->singular, q{two star general}  => q{singular: 'two star generals' --> 'two star general'};
is noun(q{two star general})->singular,   q{two star general}  => q{singular: 'two star general' --> 'two star general'};
is noun(q{falsettos})->singular, q{falsetto}  => q{singular: 'falsettos' --> 'falsetto'};
is noun(q{falsetto})->singular,   q{falsetto}  => q{singular: 'falsetto' --> 'falsetto'};
is noun(q{bruschette})->singular, q{bruschetta}  => q{singular: 'bruschette' --> 'bruschetta'};
is noun(q{bruschetta})->singular,   q{bruschetta}  => q{singular: 'bruschetta' --> 'bruschetta'};
is noun(q{casinos})->singular, q{casino}  => q{singular: 'casinos' --> 'casino'};
is noun(q{casino})->singular,   q{casino}  => q{singular: 'casino' --> 'casino'};
is noun(q{indicia})->singular, q{indicium}  => q{singular: 'indicia' --> 'indicium'};
is noun(q{indicium})->singular,   q{indicium}  => q{singular: 'indicium' --> 'indicium'};
is noun(q{gminy})->singular, q{gmina}  => q{singular: 'gminy' --> 'gmina'};
is noun(q{gmina})->singular,   q{gmina}  => q{singular: 'gmina' --> 'gmina'};
is noun(q{rioni})->singular, q{rione}  => q{singular: 'rioni' --> 'rione'};
is noun(q{rione})->singular,   q{rione}  => q{singular: 'rione' --> 'rione'};
is noun(q{sputa})->singular, q{sputum}  => q{singular: 'sputa' --> 'sputum'};
is noun(q{sputum})->singular,   q{sputum}  => q{singular: 'sputum' --> 'sputum'};
is noun(q{neumas})->singular, q{neuma}  => q{singular: 'neumas' --> 'neuma'};
is noun(q{neuma})->singular,   q{neuma}  => q{singular: 'neuma' --> 'neuma'};
is noun(q{corps generals})->singular, q{corps general}  => q{singular: 'corps generals' --> 'corps general'};
is noun(q{corps general})->singular,   q{corps general}  => q{singular: 'corps general' --> 'corps general'};
is noun(q{bream})->singular, q{bream}  => q{singular: 'bream' --> 'bream'};
is noun(q{basilicae})->singular, q{basilica}  => q{singular: 'basilicae' --> 'basilica'};
is noun(q{basilica})->singular,   q{basilica}  => q{singular: 'basilica' --> 'basilica'};
is noun(q{indusia})->singular, q{indusium}  => q{singular: 'indusia' --> 'indusium'};
is noun(q{indusium})->singular,   q{indusium}  => q{singular: 'indusium' --> 'indusium'};
is noun(q{simulacra})->singular, q{simulacrum}  => q{singular: 'simulacra' --> 'simulacrum'};
is noun(q{simulacrum})->singular,   q{simulacrum}  => q{singular: 'simulacrum' --> 'simulacrum'};
is noun(q{bureaux})->singular, q{bureau}  => q{singular: 'bureaux' --> 'bureau'};
is noun(q{bureau})->singular,   q{bureau}  => q{singular: 'bureau' --> 'bureau'};
is noun(q{epitheliomata})->singular, q{epithelioma}  => q{singular: 'epitheliomata' --> 'epithelioma'};
is noun(q{epithelioma})->singular,   q{epithelioma}  => q{singular: 'epithelioma' --> 'epithelioma'};
is noun(q{tolkachi})->singular, q{tolkach}  => q{singular: 'tolkachi' --> 'tolkach'};
is noun(q{tolkach})->singular,   q{tolkach}  => q{singular: 'tolkach' --> 'tolkach'};
is noun(q{nebenkerne})->singular, q{nebenkern}  => q{singular: 'nebenkerne' --> 'nebenkern'};
is noun(q{nebenkern})->singular,   q{nebenkern}  => q{singular: 'nebenkern' --> 'nebenkern'};
is noun(q{shifta})->singular, q{shifta}  => q{singular: 'shifta' --> 'shifta'};
is noun(q{heroa})->singular, q{heroon}  => q{singular: 'heroa' --> 'heroon'};
is noun(q{heroon})->singular,   q{heroon}  => q{singular: 'heroon' --> 'heroon'};
is noun(q{trattorie})->singular, q{trattoria}  => q{singular: 'trattorie' --> 'trattoria'};
is noun(q{trattoria})->singular,   q{trattoria}  => q{singular: 'trattoria' --> 'trattoria'};
is noun(q{scioli})->singular, q{sciolus}  => q{singular: 'scioli' --> 'sciolus'};
is noun(q{sciolus})->singular,   q{sciolus}  => q{singular: 'sciolus' --> 'sciolus'};
is noun(q{star-fish})->singular, q{star-fish}  => q{singular: 'star-fish' --> 'star-fish'};
is noun(q{goes})->singular, q{go}  => q{singular: 'goes' --> 'go'};
is noun(q{go})->singular,   q{go}  => q{singular: 'go' --> 'go'};
is noun(q{testes})->singular, q{testes}  => q{singular: 'testes' --> 'testes'};
is noun(q{razzes})->singular, q{razz}  => q{singular: 'razzes' --> 'razz'};
is noun(q{razz})->singular,   q{razz}  => q{singular: 'razz' --> 'razz'};
is noun(q{demos})->singular, q{demo}  => q{singular: 'demos' --> 'demo'};
is noun(q{demo})->singular,   q{demo}  => q{singular: 'demo' --> 'demo'};
is noun(q{grouse})->singular, q{grouse}  => q{singular: 'grouse' --> 'grouse'};
is noun(q{fibrillae})->singular, q{fibrilla}  => q{singular: 'fibrillae' --> 'fibrilla'};
is noun(q{fibrilla})->singular,   q{fibrilla}  => q{singular: 'fibrilla' --> 'fibrilla'};
is noun(q{franc-archers})->singular, q{franc-archer}  => q{singular: 'franc-archers' --> 'franc-archer'};
is noun(q{franc-archer})->singular,   q{franc-archer}  => q{singular: 'franc-archer' --> 'franc-archer'};
is noun(q{didymes})->singular, q{didymis}  => q{singular: 'didymes' --> 'didymis'};
is noun(q{didymis})->singular,   q{didymis}  => q{singular: 'didymis' --> 'didymis'};
is noun(q{ephemerae})->singular, q{ephemera}  => q{singular: 'ephemerae' --> 'ephemera'};
is noun(q{ephemera})->singular,   q{ephemera}  => q{singular: 'ephemera' --> 'ephemera'};
is noun(q{tetracola})->singular, q{tetracolon}  => q{singular: 'tetracola' --> 'tetracolon'};
is noun(q{tetracolon})->singular,   q{tetracolon}  => q{singular: 'tetracolon' --> 'tetracolon'};
is noun(q{conversaziones})->singular, q{conversazione}  => q{singular: 'conversaziones' --> 'conversazione'};
is noun(q{conversazione})->singular,   q{conversazione}  => q{singular: 'conversazione' --> 'conversazione'};
is noun(q{tractatrices})->singular, q{tractatrix}  => q{singular: 'tractatrices' --> 'tractatrix'};
is noun(q{tractatrix})->singular,   q{tractatrix}  => q{singular: 'tractatrix' --> 'tractatrix'};
is noun(q{Orlandos})->singular, q{Orlando}  => q{singular: 'Orlandos' --> 'Orlando'};
is noun(q{Orlando})->singular,   q{Orlando}  => q{singular: 'Orlando' --> 'Orlando'};
is noun(q{errata})->singular, q{erratum}  => q{singular: 'errata' --> 'erratum'};
is noun(q{erratum})->singular,   q{erratum}  => q{singular: 'erratum' --> 'erratum'};
is noun(q{hippocampi})->singular, q{hippocampus}  => q{singular: 'hippocampi' --> 'hippocampus'};
is noun(q{hippocampus})->singular,   q{hippocampus}  => q{singular: 'hippocampus' --> 'hippocampus'};
is noun(q{tetrahedrons})->singular, q{tetrahedron}  => q{singular: 'tetrahedrons' --> 'tetrahedron'};
is noun(q{tetrahedron})->singular,   q{tetrahedron}  => q{singular: 'tetrahedron' --> 'tetrahedron'};
is noun(q{vertexes})->singular, q{vertex}  => q{singular: 'vertexes' --> 'vertex'};
is noun(q{vertex})->singular,   q{vertex}  => q{singular: 'vertex' --> 'vertex'};
is noun(q{pogos})->singular, q{pogo}  => q{singular: 'pogos' --> 'pogo'};
is noun(q{pogo})->singular,   q{pogo}  => q{singular: 'pogo' --> 'pogo'};
is noun(q{Wenchowese})->singular, q{Wenchowese}  => q{singular: 'Wenchowese' --> 'Wenchowese'};
is noun(q{Torinese})->singular, q{Torinese}  => q{singular: 'Torinese' --> 'Torinese'};
is noun(q{prosecutrices})->singular, q{prosecutrix}  => q{singular: 'prosecutrices' --> 'prosecutrix'};
is noun(q{prosecutrix})->singular,   q{prosecutrix}  => q{singular: 'prosecutrix' --> 'prosecutrix'};
is noun(q{neuromata})->singular, q{neuroma}  => q{singular: 'neuromata' --> 'neuroma'};
is noun(q{neuroma})->singular,   q{neuroma}  => q{singular: 'neuroma' --> 'neuroma'};
is noun(q{mumps})->singular, q{mumps}  => q{singular: 'mumps' --> 'mumps'};
is noun(q{cassones})->singular, q{cassone}  => q{singular: 'cassones' --> 'cassone'};
is noun(q{cassone})->singular,   q{cassone}  => q{singular: 'cassone' --> 'cassone'};
is noun(q{kiokos})->singular, q{kioko}  => q{singular: 'kiokos' --> 'kioko'};
is noun(q{minyanim})->singular, q{minyan}  => q{singular: 'minyanim' --> 'minyan'};
is noun(q{minyan})->singular,   q{minyan}  => q{singular: 'minyan' --> 'minyan'};
is noun(q{-oxen})->singular, q{-ox}  => q{singular: '-oxen' --> '-ox'};
is noun(q{-ox})->singular,   q{-ox}  => q{singular: '-ox' --> '-ox'};
is noun(q{sumos})->singular, q{sumo}  => q{singular: 'sumos' --> 'sumo'};
is noun(q{sumo})->singular,   q{sumo}  => q{singular: 'sumo' --> 'sumo'};
is noun(q{trout})->singular, q{trout}  => q{singular: 'trout' --> 'trout'};
is noun(q{scazontes})->singular, q{scazon}  => q{singular: 'scazontes' --> 'scazon'};
is noun(q{scazon})->singular,   q{scazon}  => q{singular: 'scazon' --> 'scazon'};
is noun(q{substrata})->singular, q{substratum}  => q{singular: 'substrata' --> 'substratum'};
is noun(q{substratum})->singular,   q{substratum}  => q{singular: 'substratum' --> 'substratum'};
is noun(q{startsy})->singular, q{starets}  => q{singular: 'startsy' --> 'starets'};
is noun(q{starets})->singular,   q{starets}  => q{singular: 'starets' --> 'starets'};
is noun(q{vorspiele})->singular, q{vorspiel}  => q{singular: 'vorspiele' --> 'vorspiel'};
is noun(q{vorspiel})->singular,   q{vorspiel}  => q{singular: 'vorspiel' --> 'vorspiel'};
is noun(q{medusas})->singular, q{medusa}  => q{singular: 'medusas' --> 'medusa'};
is noun(q{medusa})->singular,   q{medusa}  => q{singular: 'medusa' --> 'medusa'};
is noun(q{sustentacula})->singular, q{sustentaculum}  => q{singular: 'sustentacula' --> 'sustentaculum'};
is noun(q{sustentaculum})->singular,   q{sustentaculum}  => q{singular: 'sustentaculum' --> 'sustentaculum'};
is noun(q{spectrums})->singular, q{spectrum}  => q{singular: 'spectrums' --> 'spectrum'};
is noun(q{spectrum})->singular,   q{spectrum}  => q{singular: 'spectrum' --> 'spectrum'};
is noun(q{fungi})->singular, q{fungus}  => q{singular: 'fungi' --> 'fungus'};
is noun(q{fungus})->singular,   q{fungus}  => q{singular: 'fungus' --> 'fungus'};
is noun(q{stomatia})->singular, q{stomatium}  => q{singular: 'stomatia' --> 'stomatium'};
is noun(q{stomatium})->singular,   q{stomatium}  => q{singular: 'stomatium' --> 'stomatium'};
is noun(q{precognita})->singular, q{precognitum}  => q{singular: 'precognita' --> 'precognitum'};
is noun(q{precognitum})->singular,   q{precognitum}  => q{singular: 'precognitum' --> 'precognitum'};
is noun(q{sforzatos})->singular, q{sforzato}  => q{singular: 'sforzatos' --> 'sforzato'};
is noun(q{sforzato})->singular,   q{sforzato}  => q{singular: 'sforzato' --> 'sforzato'};
is noun(q{feculae})->singular, q{fecula}  => q{singular: 'feculae' --> 'fecula'};
is noun(q{fecula})->singular,   q{fecula}  => q{singular: 'fecula' --> 'fecula'};
is noun(q{enconiums})->singular, q{enconium}  => q{singular: 'enconiums' --> 'enconium'};
is noun(q{enconium})->singular,   q{enconium}  => q{singular: 'enconium' --> 'enconium'};
is noun(q{cyclopses})->singular, q{cyclops}  => q{singular: 'cyclopses' --> 'cyclops'};
is noun(q{cyclops})->singular,   q{cyclops}  => q{singular: 'cyclops' --> 'cyclops'};
is noun(q{nauplii})->singular, q{nauplius}  => q{singular: 'nauplii' --> 'nauplius'};
is noun(q{nauplius})->singular,   q{nauplius}  => q{singular: 'nauplius' --> 'nauplius'};
is noun(q{macaronies})->singular, q{macaroni}  => q{singular: 'macaronies' --> 'macaroni'};
is noun(q{macaroni})->singular,   q{macaroni}  => q{singular: 'macaroni' --> 'macaroni'};
is noun(q{scuta})->singular, q{scutum}  => q{singular: 'scuta' --> 'scutum'};
is noun(q{scutum})->singular,   q{scutum}  => q{singular: 'scutum' --> 'scutum'};
is noun(q{lyssae})->singular, q{lyssa}  => q{singular: 'lyssae' --> 'lyssa'};
is noun(q{lyssa})->singular,   q{lyssa}  => q{singular: 'lyssa' --> 'lyssa'};
is noun(q{innings})->singular, q{innings}  => q{singular: 'innings' --> 'innings'};
is noun(q{addendums})->singular, q{addendum}  => q{singular: 'addendums' --> 'addendum'};
is noun(q{addendum})->singular,   q{addendum}  => q{singular: 'addendum' --> 'addendum'};
is noun(q{pinaces})->singular, q{pinax}  => q{singular: 'pinaces' --> 'pinax'};
is noun(q{pinax})->singular,   q{pinax}  => q{singular: 'pinax' --> 'pinax'};
is noun(q{stilettoes})->singular, q{stiletto}  => q{singular: 'stilettoes' --> 'stiletto'};
is noun(q{stiletto})->singular,   q{stiletto}  => q{singular: 'stiletto' --> 'stiletto'};
is noun(q{secundigravidas})->singular, q{secundigravida}  => q{singular: 'secundigravidas' --> 'secundigravida'};
is noun(q{secundigravida})->singular,   q{secundigravida}  => q{singular: 'secundigravida' --> 'secundigravida'};
is noun(q{condos})->singular, q{condo}  => q{singular: 'condos' --> 'condo'};
is noun(q{condo})->singular,   q{condo}  => q{singular: 'condo' --> 'condo'};
is noun(q{Veronese})->singular, q{Veronese}  => q{singular: 'Veronese' --> 'Veronese'};
is noun(q{imagines})->singular, q{imago}  => q{singular: 'imagines' --> 'imago'};
is noun(q{imago})->singular,   q{imago}  => q{singular: 'imago' --> 'imago'};
is noun(q{zoosporangia})->singular, q{zoosporangium}  => q{singular: 'zoosporangia' --> 'zoosporangium'};
is noun(q{zoosporangium})->singular,   q{zoosporangium}  => q{singular: 'zoosporangium' --> 'zoosporangium'};
is noun(q{tori})->singular, q{torus}  => q{singular: 'tori' --> 'torus'};
is noun(q{torus})->singular,   q{torus}  => q{singular: 'torus' --> 'torus'};
is noun(q{jeux})->singular, q{jeu}  => q{singular: 'jeux' --> 'jeu'};
is noun(q{jeu})->singular,   q{jeu}  => q{singular: 'jeu' --> 'jeu'};
is noun(q{turves})->singular, q{turf}  => q{singular: 'turves' --> 'turf'};
is noun(q{turf})->singular,   q{turf}  => q{singular: 'turf' --> 'turf'};
is noun(q{supernovae})->singular, q{supernova}  => q{singular: 'supernovae' --> 'supernova'};
is noun(q{supernova})->singular,   q{supernova}  => q{singular: 'supernova' --> 'supernova'};
is noun(q{Sarawakese})->singular, q{Sarawakese}  => q{singular: 'Sarawakese' --> 'Sarawakese'};
is noun(q{ramuli})->singular, q{ramulus}  => q{singular: 'ramuli' --> 'ramulus'};
is noun(q{ramulus})->singular,   q{ramulus}  => q{singular: 'ramulus' --> 'ramulus'};
is noun(q{ispravniki})->singular, q{ispravnik}  => q{singular: 'ispravniki' --> 'ispravnik'};
is noun(q{ispravnik})->singular,   q{ispravnik}  => q{singular: 'ispravnik' --> 'ispravnik'};
is noun(q{antennas})->singular, q{antenna}  => q{singular: 'antennas' --> 'antenna'};
is noun(q{antenna})->singular,   q{antenna}  => q{singular: 'antenna' --> 'antenna'};
is noun(q{canzonette})->singular, q{canzonetta}  => q{singular: 'canzonette' --> 'canzonetta'};
is noun(q{canzonetta})->singular,   q{canzonetta}  => q{singular: 'canzonetta' --> 'canzonetta'};
is noun(q{bijoux})->singular, q{bijou}  => q{singular: 'bijoux' --> 'bijou'};
is noun(q{bijou})->singular,   q{bijou}  => q{singular: 'bijou' --> 'bijou'};
is noun(q{ranunculi})->singular, q{ranunculus}  => q{singular: 'ranunculi' --> 'ranunculus'};
is noun(q{ranunculus})->singular,   q{ranunculus}  => q{singular: 'ranunculus' --> 'ranunculus'};
is noun(q{gliosarcomata})->singular, q{gliosarcoma}  => q{singular: 'gliosarcomata' --> 'gliosarcoma'};
is noun(q{gliosarcoma})->singular,   q{gliosarcoma}  => q{singular: 'gliosarcoma' --> 'gliosarcoma'};
is noun(q{hyperbolas})->singular, q{hyperbola}  => q{singular: 'hyperbolas' --> 'hyperbola'};
is noun(q{hyperbola})->singular,   q{hyperbola}  => q{singular: 'hyperbola' --> 'hyperbola'};
is noun(q{sertularias})->singular, q{sertularia}  => q{singular: 'sertularias' --> 'sertularia'};
is noun(q{sertularia})->singular,   q{sertularia}  => q{singular: 'sertularia' --> 'sertularia'};
is noun(q{pineta})->singular, q{pinetum}  => q{singular: 'pineta' --> 'pinetum'};
is noun(q{pinetum})->singular,   q{pinetum}  => q{singular: 'pinetum' --> 'pinetum'};
is noun(q{wadis})->singular, q{wadi}  => q{singular: 'wadis' --> 'wadi'};
is noun(q{wadi})->singular,   q{wadi}  => q{singular: 'wadi' --> 'wadi'};
is noun(q{nimbuses})->singular, q{nimbus}  => q{singular: 'nimbuses' --> 'nimbus'};
is noun(q{nimbus})->singular,   q{nimbus}  => q{singular: 'nimbus' --> 'nimbus'};
is noun(q{antisera})->singular, q{antiserum}  => q{singular: 'antisera' --> 'antiserum'};
is noun(q{antiserum})->singular,   q{antiserum}  => q{singular: 'antiserum' --> 'antiserum'};
is noun(q{waldos})->singular, q{waldo}  => q{singular: 'waldos' --> 'waldo'};
is noun(q{waldo})->singular,   q{waldo}  => q{singular: 'waldo' --> 'waldo'};
is noun(q{Carlylese})->singular, q{Carlylese}  => q{singular: 'Carlylese' --> 'Carlylese'};
is noun(q{bons vivants})->singular, q{bon vivant}  => q{singular: 'bons vivants' --> 'bon vivant'};
is noun(q{bon vivant})->singular,   q{bon vivant}  => q{singular: 'bon vivant' --> 'bon vivant'};
is noun(q{calathi})->singular, q{calathus}  => q{singular: 'calathi' --> 'calathus'};
is noun(q{calathus})->singular,   q{calathus}  => q{singular: 'calathus' --> 'calathus'};
is noun(q{prospectus})->singular, q{prospectus}  => q{singular: 'prospectus' --> 'prospectus'};
is noun(q{lacunaria})->singular, q{lacunar}  => q{singular: 'lacunaria' --> 'lacunar'};
is noun(q{lacunar})->singular,   q{lacunar}  => q{singular: 'lacunar' --> 'lacunar'};
is noun(q{manubria})->singular, q{manubrium}  => q{singular: 'manubria' --> 'manubrium'};
is noun(q{manubrium})->singular,   q{manubrium}  => q{singular: 'manubrium' --> 'manubrium'};
is noun(q{sileni})->singular, q{silenus}  => q{singular: 'sileni' --> 'silenus'};
is noun(q{silenus})->singular,   q{silenus}  => q{singular: 'silenus' --> 'silenus'};
is noun(q{exes})->singular, q{ex}  => q{singular: 'exes' --> 'ex'};
is noun(q{ex})->singular,   q{ex}  => q{singular: 'ex' --> 'ex'};
is noun(q{Sapporos})->singular, q{Sapporo}  => q{singular: 'Sapporos' --> 'Sapporo'};
is noun(q{Sapporo})->singular,   q{Sapporo}  => q{singular: 'Sapporo' --> 'Sapporo'};
is noun(q{men})->singular, q{man}  => q{singular: 'men' --> 'man'};
is noun(q{man})->singular,   q{man}  => q{singular: 'man' --> 'man'};
is noun(q{meningiomas})->singular, q{meningioma}  => q{singular: 'meningiomas' --> 'meningioma'};
is noun(q{meningioma})->singular,   q{meningioma}  => q{singular: 'meningioma' --> 'meningioma'};
is noun(q{deer})->singular, q{deer}  => q{singular: 'deer' --> 'deer'};
is noun(q{Bhutanese})->singular, q{Bhutanese}  => q{singular: 'Bhutanese' --> 'Bhutanese'};
is noun(q{Guianese})->singular, q{Guianese}  => q{singular: 'Guianese' --> 'Guianese'};
is noun(q{tractrices})->singular, q{tractrix}  => q{singular: 'tractrices' --> 'tractrix'};
is noun(q{tractrix})->singular,   q{tractrix}  => q{singular: 'tractrix' --> 'tractrix'};
is noun(q{mukim})->singular, q{mukim}  => q{singular: 'mukim' --> 'mukim'};
is noun(q{strata})->singular, q{stratum}  => q{singular: 'strata' --> 'stratum'};
is noun(q{stratum})->singular,   q{stratum}  => q{singular: 'stratum' --> 'stratum'};
is noun(q{lemures})->singular, q{lemur}  => q{singular: 'lemures' --> 'lemur'};
is noun(q{lemur})->singular,   q{lemur}  => q{singular: 'lemur' --> 'lemur'};
is noun(q{magnetos})->singular, q{magneto}  => q{singular: 'magnetos' --> 'magneto'};
is noun(q{magneto})->singular,   q{magneto}  => q{singular: 'magneto' --> 'magneto'};
is noun(q{autos de fes})->singular, q{auto de fe}  => q{singular: 'autos de fes' --> 'auto de fe'};
is noun(q{auto de fe})->singular,   q{auto de fe}  => q{singular: 'auto de fe' --> 'auto de fe'};
is noun(q{coeliae})->singular, q{coelia}  => q{singular: 'coeliae' --> 'coelia'};
is noun(q{coelia})->singular,   q{coelia}  => q{singular: 'coelia' --> 'coelia'};
is noun(q{zite})->singular, q{zita}  => q{singular: 'zite' --> 'zita'};
is noun(q{zita})->singular,   q{zita}  => q{singular: 'zita' --> 'zita'};
is noun(q{stalactitae})->singular, q{stalactite}  => q{singular: 'stalactitae' --> 'stalactite'};
is noun(q{stalactite})->singular,   q{stalactite}  => q{singular: 'stalactite' --> 'stalactite'};
is noun(q{adyta})->singular, q{adytum}  => q{singular: 'adyta' --> 'adytum'};
is noun(q{adytum})->singular,   q{adytum}  => q{singular: 'adytum' --> 'adytum'};
is noun(q{scyphi})->singular, q{scyphus}  => q{singular: 'scyphi' --> 'scyphus'};
is noun(q{scyphus})->singular,   q{scyphus}  => q{singular: 'scyphus' --> 'scyphus'};
is noun(q{trapezohedra})->singular, q{trapezohedron}  => q{singular: 'trapezohedra' --> 'trapezohedron'};
is noun(q{trapezohedron})->singular,   q{trapezohedron}  => q{singular: 'trapezohedron' --> 'trapezohedron'};
is noun(q{roe})->singular, q{roe}  => q{singular: 'roe' --> 'roe'};
is noun(q{studia generali})->singular, q{studium generale}  => q{singular: 'studia generali' --> 'studium generale'};
is noun(q{studium generale})->singular,   q{studium generale}  => q{singular: 'studium generale' --> 'studium generale'};
is noun(q{sarcomas})->singular, q{sarcoma}  => q{singular: 'sarcomas' --> 'sarcoma'};
is noun(q{sarcoma})->singular,   q{sarcoma}  => q{singular: 'sarcoma' --> 'sarcoma'};
is noun(q{microcephali})->singular, q{microcephalus}  => q{singular: 'microcephali' --> 'microcephalus'};
is noun(q{microcephalus})->singular,   q{microcephalus}  => q{singular: 'microcephalus' --> 'microcephalus'};
is noun(q{burros})->singular, q{burro}  => q{singular: 'burros' --> 'burro'};
is noun(q{burro})->singular,   q{burro}  => q{singular: 'burro' --> 'burro'};
is noun(q{taxa})->singular, q{taxon}  => q{singular: 'taxa' --> 'taxon'};
is noun(q{taxon})->singular,   q{taxon}  => q{singular: 'taxon' --> 'taxon'};
is noun(q{shochetim})->singular, q{shochet}  => q{singular: 'shochetim' --> 'shochet'};
is noun(q{shochet})->singular,   q{shochet}  => q{singular: 'shochet' --> 'shochet'};
is noun(q{globigerinae})->singular, q{globigerina}  => q{singular: 'globigerinae' --> 'globigerina'};
is noun(q{globigerina})->singular,   q{globigerina}  => q{singular: 'globigerina' --> 'globigerina'};
is noun(q{torsos})->singular, q{torso}  => q{singular: 'torsos' --> 'torso'};
is noun(q{torso})->singular,   q{torso}  => q{singular: 'torso' --> 'torso'};
is noun(q{ignoramus})->singular, q{ignoramus}  => q{singular: 'ignoramus' --> 'ignoramus'};
is noun(q{pollinaria})->singular, q{pollinarium}  => q{singular: 'pollinaria' --> 'pollinarium'};
is noun(q{pollinarium})->singular,   q{pollinarium}  => q{singular: 'pollinarium' --> 'pollinarium'};
is noun(q{sertulariae})->singular, q{sertularia}  => q{singular: 'sertulariae' --> 'sertularia'};
is noun(q{sertularia})->singular,   q{sertularia}  => q{singular: 'sertularia' --> 'sertularia'};
is noun(q{pulsella})->singular, q{pulsellum}  => q{singular: 'pulsella' --> 'pulsellum'};
is noun(q{pulsellum})->singular,   q{pulsellum}  => q{singular: 'pulsellum' --> 'pulsellum'};
is noun(q{deliria})->singular, q{delirium}  => q{singular: 'deliria' --> 'delirium'};
is noun(q{delirium})->singular,   q{delirium}  => q{singular: 'delirium' --> 'delirium'};
is noun(q{ganglia})->singular, q{ganglion}  => q{singular: 'ganglia' --> 'ganglion'};
is noun(q{ganglion})->singular,   q{ganglion}  => q{singular: 'ganglion' --> 'ganglion'};
is noun(q{mortadelle})->singular, q{mortadella}  => q{singular: 'mortadelle' --> 'mortadella'};
is noun(q{mortadella})->singular,   q{mortadella}  => q{singular: 'mortadella' --> 'mortadella'};
is noun(q{frena})->singular, q{frenum}  => q{singular: 'frena' --> 'frenum'};
is noun(q{frenum})->singular,   q{frenum}  => q{singular: 'frenum' --> 'frenum'};
is noun(q{vestigia})->singular, q{vestigium}  => q{singular: 'vestigia' --> 'vestigium'};
is noun(q{vestigium})->singular,   q{vestigium}  => q{singular: 'vestigium' --> 'vestigium'};
is noun(q{paraglossae})->singular, q{paraglossa}  => q{singular: 'paraglossae' --> 'paraglossa'};
is noun(q{paraglossa})->singular,   q{paraglossa}  => q{singular: 'paraglossa' --> 'paraglossa'};
is noun(q{scari})->singular, q{scarus}  => q{singular: 'scari' --> 'scarus'};
is noun(q{scarus})->singular,   q{scarus}  => q{singular: 'scarus' --> 'scarus'};
is noun(q{psychos})->singular, q{psycho}  => q{singular: 'psychos' --> 'psycho'};
is noun(q{psycho})->singular,   q{psycho}  => q{singular: 'psycho' --> 'psycho'};
is noun(q{syncytia})->singular, q{syncytium}  => q{singular: 'syncytia' --> 'syncytium'};
is noun(q{syncytium})->singular,   q{syncytium}  => q{singular: 'syncytium' --> 'syncytium'};
is noun(q{daises})->singular, q{dais}  => q{singular: 'daises' --> 'dais'};
is noun(q{dais})->singular,   q{dais}  => q{singular: 'dais' --> 'dais'};
is noun(q{ethoses})->singular, q{ethos}  => q{singular: 'ethoses' --> 'ethos'};
is noun(q{ethos})->singular,   q{ethos}  => q{singular: 'ethos' --> 'ethos'};
is noun(q{lacunae})->singular, q{lacuna}  => q{singular: 'lacunae' --> 'lacuna'};
is noun(q{lacuna})->singular,   q{lacuna}  => q{singular: 'lacuna' --> 'lacuna'};
is noun(q{styli})->singular, q{stylus}  => q{singular: 'styli' --> 'stylus'};
is noun(q{stylus})->singular,   q{stylus}  => q{singular: 'stylus' --> 'stylus'};
is noun(q{indigenae})->singular, q{indigena}  => q{singular: 'indigenae' --> 'indigena'};
is noun(q{indigena})->singular,   q{indigena}  => q{singular: 'indigena' --> 'indigena'};
is noun(q{white staves})->singular, q{white staff}  => q{singular: 'white staves' --> 'white staff'};
is noun(q{white staff})->singular,   q{white staff}  => q{singular: 'white staff' --> 'white staff'};
is noun(q{lice})->singular, q{louse}  => q{singular: 'lice' --> 'louse'};
is noun(q{louse})->singular,   q{louse}  => q{singular: 'louse' --> 'louse'};
is noun(q{ispravniks})->singular, q{ispravnik}  => q{singular: 'ispravniks' --> 'ispravnik'};
is noun(q{ispravnik})->singular,   q{ispravnik}  => q{singular: 'ispravnik' --> 'ispravnik'};
is noun(q{prototypa})->singular, q{prototypon}  => q{singular: 'prototypa' --> 'prototypon'};
is noun(q{prototypon})->singular,   q{prototypon}  => q{singular: 'prototypon' --> 'prototypon'};
is noun(q{genae})->singular, q{gena}  => q{singular: 'genae' --> 'gena'};
is noun(q{gena})->singular,   q{gena}  => q{singular: 'gena' --> 'gena'};
is noun(q{Modenese})->singular, q{Modenese}  => q{singular: 'Modenese' --> 'Modenese'};
is noun(q{thrasones})->singular, q{thraso}  => q{singular: 'thrasones' --> 'thraso'};
is noun(q{thraso})->singular,   q{thraso}  => q{singular: 'thraso' --> 'thraso'};
is noun(q{gametangia})->singular, q{gametangium}  => q{singular: 'gametangia' --> 'gametangium'};
is noun(q{gametangium})->singular,   q{gametangium}  => q{singular: 'gametangium' --> 'gametangium'};
is noun(q{violoncellos})->singular, q{violoncello}  => q{singular: 'violoncellos' --> 'violoncello'};
is noun(q{violoncello})->singular,   q{violoncello}  => q{singular: 'violoncello' --> 'violoncello'};
is noun(q{autobahns})->singular, q{autobahn}  => q{singular: 'autobahns' --> 'autobahn'};
is noun(q{autobahn})->singular,   q{autobahn}  => q{singular: 'autobahn' --> 'autobahn'};
is noun(q{Timorese})->singular, q{Timorese}  => q{singular: 'Timorese' --> 'Timorese'};
is noun(q{oxymora})->singular, q{oxymoron}  => q{singular: 'oxymora' --> 'oxymoron'};
is noun(q{oxymoron})->singular,   q{oxymoron}  => q{singular: 'oxymoron' --> 'oxymoron'};
is noun(q{premiers danseurs})->singular, q{premier danseur}  => q{singular: 'premiers danseurs' --> 'premier danseur'};
is noun(q{premier danseur})->singular,   q{premier danseur}  => q{singular: 'premier danseur' --> 'premier danseur'};
is noun(q{serirs})->singular, q{serir}  => q{singular: 'serirs' --> 'serir'};
is noun(q{stasima})->singular, q{stasimon}  => q{singular: 'stasima' --> 'stasimon'};
is noun(q{stasimon})->singular,   q{stasimon}  => q{singular: 'stasimon' --> 'stasimon'};
is noun(q{ocelli})->singular, q{ocellus}  => q{singular: 'ocelli' --> 'ocellus'};
is noun(q{ocellus})->singular,   q{ocellus}  => q{singular: 'ocellus' --> 'ocellus'};
is noun(q{wreaths})->singular, q{wreath}  => q{singular: 'wreaths' --> 'wreath'};
is noun(q{wreath})->singular,   q{wreath}  => q{singular: 'wreath' --> 'wreath'};
is noun(q{syphilomata})->singular, q{syphiloma}  => q{singular: 'syphilomata' --> 'syphiloma'};
is noun(q{syphiloma})->singular,   q{syphiloma}  => q{singular: 'syphiloma' --> 'syphiloma'};
is noun(q{nachtlokale})->singular, q{nachtlokal}  => q{singular: 'nachtlokale' --> 'nachtlokal'};
is noun(q{nachtlokal})->singular,   q{nachtlokal}  => q{singular: 'nachtlokal' --> 'nachtlokal'};
is noun(q{hertz})->singular, q{hertz}  => q{singular: 'hertz' --> 'hertz'};
is noun(q{timpanos})->singular, q{timpano}  => q{singular: 'timpanos' --> 'timpano'};
is noun(q{timpano})->singular,   q{timpano}  => q{singular: 'timpano' --> 'timpano'};
is noun(q{vivariums})->singular, q{vivarium}  => q{singular: 'vivariums' --> 'vivarium'};
is noun(q{vivarium})->singular,   q{vivarium}  => q{singular: 'vivarium' --> 'vivarium'};
is noun(q{penicilli})->singular, q{penicillus}  => q{singular: 'penicilli' --> 'penicillus'};
is noun(q{penicillus})->singular,   q{penicillus}  => q{singular: 'penicillus' --> 'penicillus'};
is noun(q{funghi porchini})->singular, q{fungo porcino}  => q{singular: 'funghi porchini' --> 'fungo porcino'};
is noun(q{fungo porcino})->singular,   q{fungo porcino}  => q{singular: 'fungo porcino' --> 'fungo porcino'};
is noun(q{pharmakoi})->singular, q{pharmakos}  => q{singular: 'pharmakoi' --> 'pharmakos'};
is noun(q{pharmakos})->singular,   q{pharmakos}  => q{singular: 'pharmakos' --> 'pharmakos'};
is noun(q{sensilla})->singular, q{sensillum}  => q{singular: 'sensilla' --> 'sensillum'};
is noun(q{sensillum})->singular,   q{sensillum}  => q{singular: 'sensillum' --> 'sensillum'};
is noun(q{unci})->singular, q{uncus}  => q{singular: 'unci' --> 'uncus'};
is noun(q{uncus})->singular,   q{uncus}  => q{singular: 'uncus' --> 'uncus'};
is noun(q{poria})->singular, q{porion}  => q{singular: 'poria' --> 'porion'};
is noun(q{porion})->singular,   q{porion}  => q{singular: 'porion' --> 'porion'};
is noun(q{fermatas})->singular, q{fermata}  => q{singular: 'fermatas' --> 'fermata'};
is noun(q{fermata})->singular,   q{fermata}  => q{singular: 'fermata' --> 'fermata'};
is noun(q{cornua})->singular, q{cornu}  => q{singular: 'cornua' --> 'cornu'};
is noun(q{cornu})->singular,   q{cornu}  => q{singular: 'cornu' --> 'cornu'};
is noun(q{scaleni})->singular, q{scalenus}  => q{singular: 'scaleni' --> 'scalenus'};
is noun(q{scalenus})->singular,   q{scalenus}  => q{singular: 'scalenus' --> 'scalenus'};
is noun(q{buffalo})->singular, q{buffalo}  => q{singular: 'buffalo' --> 'buffalo'};
is noun(q{Oslos})->singular, q{Oslo}  => q{singular: 'Oslos' --> 'Oslo'};
is noun(q{Oslo})->singular,   q{Oslo}  => q{singular: 'Oslo' --> 'Oslo'};
is noun(q{Maputos})->singular, q{Maputo}  => q{singular: 'Maputos' --> 'Maputo'};
is noun(q{Maputo})->singular,   q{Maputo}  => q{singular: 'Maputo' --> 'Maputo'};
is noun(q{Hararese})->singular, q{Hararese}  => q{singular: 'Hararese' --> 'Hararese'};
is noun(q{usneae})->singular, q{usnea}  => q{singular: 'usneae' --> 'usnea'};
is noun(q{usnea})->singular,   q{usnea}  => q{singular: 'usnea' --> 'usnea'};
is noun(q{primordia})->singular, q{primordium}  => q{singular: 'primordia' --> 'primordium'};
is noun(q{primordium})->singular,   q{primordium}  => q{singular: 'primordium' --> 'primordium'};
is noun(q{septa})->singular, q{septum}  => q{singular: 'septa' --> 'septum'};
is noun(q{septum})->singular,   q{septum}  => q{singular: 'septum' --> 'septum'};
is noun(q{termini})->singular, q{terminus}  => q{singular: 'termini' --> 'terminus'};
is noun(q{terminus})->singular,   q{terminus}  => q{singular: 'terminus' --> 'terminus'};
is noun(q{francs-archers})->singular, q{franc-archer}  => q{singular: 'francs-archers' --> 'franc-archer'};
is noun(q{franc-archer})->singular,   q{franc-archer}  => q{singular: 'franc-archer' --> 'franc-archer'};
is noun(q{lowlifes})->singular, q{lowlife}  => q{singular: 'lowlifes' --> 'lowlife'};
is noun(q{lowlife})->singular,   q{lowlife}  => q{singular: 'lowlife' --> 'lowlife'};
is noun(q{cysticerci})->singular, q{cysticercus}  => q{singular: 'cysticerci' --> 'cysticercus'};
is noun(q{cysticercus})->singular,   q{cysticercus}  => q{singular: 'cysticercus' --> 'cysticercus'};
is noun(q{mimosas})->singular, q{mimosa}  => q{singular: 'mimosas' --> 'mimosa'};
is noun(q{mimosa})->singular,   q{mimosa}  => q{singular: 'mimosa' --> 'mimosa'};
is noun(q{vermicellos})->singular, q{vermicello}  => q{singular: 'vermicellos' --> 'vermicello'};
is noun(q{vermicello})->singular,   q{vermicello}  => q{singular: 'vermicello' --> 'vermicello'};
is noun(q{scutella})->singular, q{scutellum}  => q{singular: 'scutella' --> 'scutellum'};
is noun(q{scutellum})->singular,   q{scutellum}  => q{singular: 'scutellum' --> 'scutellum'};
is noun(q{Lesothos})->singular, q{Lesotho}  => q{singular: 'Lesothos' --> 'Lesotho'};
is noun(q{Lesotho})->singular,   q{Lesotho}  => q{singular: 'Lesotho' --> 'Lesotho'};
is noun(q{caudices})->singular, q{caudex}  => q{singular: 'caudices' --> 'caudex'};
is noun(q{caudex})->singular,   q{caudex}  => q{singular: 'caudex' --> 'caudex'};
is noun(q{albinos})->singular, q{albino}  => q{singular: 'albinos' --> 'albino'};
is noun(q{albino})->singular,   q{albino}  => q{singular: 'albino' --> 'albino'};
is noun(q{valuten})->singular, q{valuta}  => q{singular: 'valuten' --> 'valuta'};
is noun(q{valuta})->singular,   q{valuta}  => q{singular: 'valuta' --> 'valuta'};
is noun(q{ligamenta})->singular, q{ligamentum}  => q{singular: 'ligamenta' --> 'ligamentum'};
is noun(q{ligamentum})->singular,   q{ligamentum}  => q{singular: 'ligamentum' --> 'ligamentum'};
is noun(q{udarniki})->singular, q{udarnik}  => q{singular: 'udarniki' --> 'udarnik'};
is noun(q{udarnik})->singular,   q{udarnik}  => q{singular: 'udarnik' --> 'udarnik'};
is noun(q{porrones})->singular, q{porron}  => q{singular: 'porrones' --> 'porron'};
is noun(q{porron})->singular,   q{porron}  => q{singular: 'porron' --> 'porron'};
is noun(q{kimonos})->singular, q{kimono}  => q{singular: 'kimonos' --> 'kimono'};
is noun(q{kimono})->singular,   q{kimono}  => q{singular: 'kimono' --> 'kimono'};
is noun(q{pos})->singular, q{po}  => q{singular: 'pos' --> 'po'};
is noun(q{po})->singular,   q{po}  => q{singular: 'po' --> 'po'};
is noun(q{porrons})->singular, q{porron}  => q{singular: 'porrons' --> 'porron'};
is noun(q{porron})->singular,   q{porron}  => q{singular: 'porron' --> 'porron'};
is noun(q{formulae})->singular, q{formula}  => q{singular: 'formulae' --> 'formula'};
is noun(q{formula})->singular,   q{formula}  => q{singular: 'formula' --> 'formula'};
is noun(q{gringos})->singular, q{gringo}  => q{singular: 'gringos' --> 'gringo'};
is noun(q{gringo})->singular,   q{gringo}  => q{singular: 'gringo' --> 'gringo'};
is noun(q{Japanese})->singular, q{Japanese}  => q{singular: 'Japanese' --> 'Japanese'};
is noun(q{ephelides})->singular, q{ephelis}  => q{singular: 'ephelides' --> 'ephelis'};
is noun(q{ephelis})->singular,   q{ephelis}  => q{singular: 'ephelis' --> 'ephelis'};
is noun(q{melastomas})->singular, q{melastoma}  => q{singular: 'melastomas' --> 'melastoma'};
is noun(q{melastoma})->singular,   q{melastoma}  => q{singular: 'melastoma' --> 'melastoma'};
is noun(q{Gallas})->singular, q{Galla}  => q{singular: 'Gallas' --> 'Galla'};
is noun(q{mews})->singular, q{mew}  => q{singular: 'mews' --> 'mew'};
is noun(q{mew})->singular,   q{mew}  => q{singular: 'mew' --> 'mew'};
is noun(q{municipia})->singular, q{municipium}  => q{singular: 'municipia' --> 'municipium'};
is noun(q{municipium})->singular,   q{municipium}  => q{singular: 'municipium' --> 'municipium'};
is noun(q{moscardini})->singular, q{moscardino}  => q{singular: 'moscardini' --> 'moscardino'};
is noun(q{moscardino})->singular,   q{moscardino}  => q{singular: 'moscardino' --> 'moscardino'};
is noun(q{portiforia})->singular, q{portiforium}  => q{singular: 'portiforia' --> 'portiforium'};
is noun(q{portiforium})->singular,   q{portiforium}  => q{singular: 'portiforium' --> 'portiforium'};
is noun(q{starfish})->singular, q{starfish}  => q{singular: 'starfish' --> 'starfish'};
is noun(q{Esperantos})->singular, q{Esperanto}  => q{singular: 'Esperantos' --> 'Esperanto'};
is noun(q{Esperanto})->singular,   q{Esperanto}  => q{singular: 'Esperanto' --> 'Esperanto'};
is noun(q{zyga})->singular, q{zygon}  => q{singular: 'zyga' --> 'zygon'};
is noun(q{zygon})->singular,   q{zygon}  => q{singular: 'zygon' --> 'zygon'};
is noun(q{capi})->singular, q{capo}  => q{singular: 'capi' --> 'capo'};
is noun(q{capo})->singular,   q{capo}  => q{singular: 'capo' --> 'capo'};
is noun(q{cumuli})->singular, q{cumulus}  => q{singular: 'cumuli' --> 'cumulus'};
is noun(q{cumulus})->singular,   q{cumulus}  => q{singular: 'cumulus' --> 'cumulus'};
is noun(q{maestri})->singular, q{maestro}  => q{singular: 'maestri' --> 'maestro'};
is noun(q{maestro})->singular,   q{maestro}  => q{singular: 'maestro' --> 'maestro'};
is noun(q{propositi})->singular, q{propositus}  => q{singular: 'propositi' --> 'propositus'};
is noun(q{propositus})->singular,   q{propositus}  => q{singular: 'propositus' --> 'propositus'};
is noun(q{shad})->singular, q{shad}  => q{singular: 'shad' --> 'shad'};
is noun(q{adieux})->singular, q{adieu}  => q{singular: 'adieux' --> 'adieu'};
is noun(q{adieu})->singular,   q{adieu}  => q{singular: 'adieu' --> 'adieu'};
is noun(q{pennies})->singular, q{penny}  => q{singular: 'pennies' --> 'penny'};
is noun(q{penny})->singular,   q{penny}  => q{singular: 'penny' --> 'penny'};
is noun(q{blouses})->singular, q{blouse}  => q{singular: 'blouses' --> 'blouse'};
is noun(q{blouse})->singular,   q{blouse}  => q{singular: 'blouse' --> 'blouse'};
is noun(q{sporodochia})->singular, q{sporodochium}  => q{singular: 'sporodochia' --> 'sporodochium'};
is noun(q{sporodochium})->singular,   q{sporodochium}  => q{singular: 'sporodochium' --> 'sporodochium'};
is noun(q{algae})->singular, q{alga}  => q{singular: 'algae' --> 'alga'};
is noun(q{alga})->singular,   q{alga}  => q{singular: 'alga' --> 'alga'};
is noun(q{toxoplasmata})->singular, q{toxoplasma}  => q{singular: 'toxoplasmata' --> 'toxoplasma'};
is noun(q{toxoplasma})->singular,   q{toxoplasma}  => q{singular: 'toxoplasma' --> 'toxoplasma'};
is noun(q{pneumothoraxes})->singular, q{pneumothorax}  => q{singular: 'pneumothoraxes' --> 'pneumothorax'};
is noun(q{pneumothorax})->singular,   q{pneumothorax}  => q{singular: 'pneumothorax' --> 'pneumothorax'};
is noun(q{maestros})->singular, q{maestro}  => q{singular: 'maestros' --> 'maestro'};
is noun(q{maestro})->singular,   q{maestro}  => q{singular: 'maestro' --> 'maestro'};
is noun(q{villi})->singular, q{villus}  => q{singular: 'villi' --> 'villus'};
is noun(q{villus})->singular,   q{villus}  => q{singular: 'villus' --> 'villus'};
is noun(q{pina coladas})->singular, q{pina colada}  => q{singular: 'pina coladas' --> 'pina colada'};
is noun(q{pina colada})->singular,   q{pina colada}  => q{singular: 'pina colada' --> 'pina colada'};
is noun(q{synthroni})->singular, q{synthronus}  => q{singular: 'synthroni' --> 'synthronus'};
is noun(q{synthronus})->singular,   q{synthronus}  => q{singular: 'synthronus' --> 'synthronus'};
is noun(q{Nipponese})->singular, q{Nipponese}  => q{singular: 'Nipponese' --> 'Nipponese'};
is noun(q{oboli})->singular, q{obolus}  => q{singular: 'oboli' --> 'obolus'};
is noun(q{obolus})->singular,   q{obolus}  => q{singular: 'obolus' --> 'obolus'};
is noun(q{milieux interieurs})->singular, q{milieu interieur}  => q{singular: 'milieux interieurs' --> 'milieu interieur'};
is noun(q{milieu interieur})->singular,   q{milieu interieur}  => q{singular: 'milieu interieur' --> 'milieu interieur'};
is noun(q{apsides})->singular, q{apsis}  => q{singular: 'apsides' --> 'apsis'};
is noun(q{apsis})->singular,   q{apsis}  => q{singular: 'apsis' --> 'apsis'};
is noun(q{alluviums})->singular, q{alluvium}  => q{singular: 'alluviums' --> 'alluvium'};
is noun(q{alluvium})->singular,   q{alluvium}  => q{singular: 'alluvium' --> 'alluvium'};
is noun(q{Santiagos})->singular, q{Santiago}  => q{singular: 'Santiagos' --> 'Santiago'};
is noun(q{Santiago})->singular,   q{Santiago}  => q{singular: 'Santiago' --> 'Santiago'};
is noun(q{propodia})->singular, q{propodium}  => q{singular: 'propodia' --> 'propodium'};
is noun(q{propodium})->singular,   q{propodium}  => q{singular: 'propodium' --> 'propodium'};
is noun(q{individuums})->singular, q{individuum}  => q{singular: 'individuums' --> 'individuum'};
is noun(q{individuum})->singular,   q{individuum}  => q{singular: 'individuum' --> 'individuum'};
is noun(q{femurs})->singular, q{femur}  => q{singular: 'femurs' --> 'femur'};
is noun(q{femur})->singular,   q{femur}  => q{singular: 'femur' --> 'femur'};
is noun(q{fabliaux})->singular, q{fabliau}  => q{singular: 'fabliaux' --> 'fabliau'};
is noun(q{fabliau})->singular,   q{fabliau}  => q{singular: 'fabliau' --> 'fabliau'};
is noun(q{pecias})->singular, q{pecia}  => q{singular: 'pecias' --> 'pecia'};
is noun(q{pecia})->singular,   q{pecia}  => q{singular: 'pecia' --> 'pecia'};
is noun(q{impetuses})->singular, q{impetus}  => q{singular: 'impetuses' --> 'impetus'};
is noun(q{embryos})->singular, q{embryo}  => q{singular: 'embryos' --> 'embryo'};
is noun(q{embryo})->singular,   q{embryo}  => q{singular: 'embryo' --> 'embryo'};
is noun(q{streptothrices})->singular, q{streptothrix}  => q{singular: 'streptothrices' --> 'streptothrix'};
is noun(q{streptothrix})->singular,   q{streptothrix}  => q{singular: 'streptothrix' --> 'streptothrix'};
is noun(q{corgwn})->singular, q{corgi}  => q{singular: 'corgwn' --> 'corgi'};
is noun(q{corgi})->singular,   q{corgi}  => q{singular: 'corgi' --> 'corgi'};
is noun(q{pirrites})->singular, q{pyrites}  => q{singular: 'pirrites' --> 'pyrites'};
is noun(q{pyrites})->singular,   q{pyrites}  => q{singular: 'pyrites' --> 'pyrites'};
is noun(q{pinas coladas})->singular, q{pina colada}  => q{singular: 'pinas coladas' --> 'pina colada'};
is noun(q{pina colada})->singular,   q{pina colada}  => q{singular: 'pina colada' --> 'pina colada'};
is noun(q{bateaux})->singular, q{bateau}  => q{singular: 'bateaux' --> 'bateau'};
is noun(q{bateau})->singular,   q{bateau}  => q{singular: 'bateau' --> 'bateau'};
is noun(q{dreikanter})->singular, q{dreikanter}  => q{singular: 'dreikanter' --> 'dreikanter'};
is noun(q{sedes})->singular, q{sedes}  => q{singular: 'sedes' --> 'sedes'};
is noun(q{Paramaribos})->singular, q{Paramaribo}  => q{singular: 'Paramaribos' --> 'Paramaribo'};
is noun(q{Paramaribo})->singular,   q{Paramaribo}  => q{singular: 'Paramaribo' --> 'Paramaribo'};
is noun(q{osmateria})->singular, q{osmaterium}  => q{singular: 'osmateria' --> 'osmaterium'};
is noun(q{osmaterium})->singular,   q{osmaterium}  => q{singular: 'osmaterium' --> 'osmaterium'};
is noun(q{tessellas})->singular, q{tessella}  => q{singular: 'tessellas' --> 'tessella'};
is noun(q{tessella})->singular,   q{tessella}  => q{singular: 'tessella' --> 'tessella'};
is noun(q{Chicagos})->singular, q{Chicago}  => q{singular: 'Chicagos' --> 'Chicago'};
is noun(q{Chicago})->singular,   q{Chicago}  => q{singular: 'Chicago' --> 'Chicago'};
is noun(q{flys})->singular, q{fly}  => q{singular: 'flys' --> 'fly'};
is noun(q{fly})->singular,   q{fly}  => q{singular: 'fly' --> 'fly'};
is noun(q{virii})->singular, q{virus}  => q{singular: 'virii' --> 'virus'};
is noun(q{virus})->singular,   q{virus}  => q{singular: 'virus' --> 'virus'};
is noun(q{tenderfoots})->singular, q{tenderfoot}  => q{singular: 'tenderfoots' --> 'tenderfoot'};
is noun(q{tenderfoot})->singular,   q{tenderfoot}  => q{singular: 'tenderfoot' --> 'tenderfoot'};
is noun(q{protonemata})->singular, q{protonema}  => q{singular: 'protonemata' --> 'protonema'};
is noun(q{protonema})->singular,   q{protonema}  => q{singular: 'protonema' --> 'protonema'};
is noun(q{pycnides})->singular, q{pycnis}  => q{singular: 'pycnides' --> 'pycnis'};
is noun(q{pycnis})->singular,   q{pycnis}  => q{singular: 'pycnis' --> 'pycnis'};
is noun(q{novae})->singular, q{nova}  => q{singular: 'novae' --> 'nova'};
is noun(q{nova})->singular,   q{nova}  => q{singular: 'nova' --> 'nova'};
is noun(q{pithoi})->singular, q{pithos}  => q{singular: 'pithoi' --> 'pithos'};
is noun(q{pithos})->singular,   q{pithos}  => q{singular: 'pithos' --> 'pithos'};
is noun(q{eucalypti})->singular, q{eucalyptus}  => q{singular: 'eucalypti' --> 'eucalyptus'};
is noun(q{eucalyptus})->singular,   q{eucalyptus}  => q{singular: 'eucalyptus' --> 'eucalyptus'};
is noun(q{focuses})->singular, q{focus}  => q{singular: 'focuses' --> 'focus'};
is noun(q{focus})->singular,   q{focus}  => q{singular: 'focus' --> 'focus'};
is noun(q{vilas})->singular, q{vila}  => q{singular: 'vilas' --> 'vila'};
is noun(q{vila})->singular,   q{vila}  => q{singular: 'vila' --> 'vila'};
is noun(q{gutti})->singular, q{guttus}  => q{singular: 'gutti' --> 'guttus'};
is noun(q{guttus})->singular,   q{guttus}  => q{singular: 'guttus' --> 'guttus'};
is noun(q{uomini})->singular, q{uomo}  => q{singular: 'uomini' --> 'uomo'};
is noun(q{uomo})->singular,   q{uomo}  => q{singular: 'uomo' --> 'uomo'};
is noun(q{euporista})->singular, q{euporiston}  => q{singular: 'euporista' --> 'euporiston'};
is noun(q{euporiston})->singular,   q{euporiston}  => q{singular: 'euporiston' --> 'euporiston'};
is noun(q{avisos})->singular, q{aviso}  => q{singular: 'avisos' --> 'aviso'};
is noun(q{aviso})->singular,   q{aviso}  => q{singular: 'aviso' --> 'aviso'};
is noun(q{stemmata})->singular, q{stemma}  => q{singular: 'stemmata' --> 'stemma'};
is noun(q{stemma})->singular,   q{stemma}  => q{singular: 'stemma' --> 'stemma'};
is noun(q{breaks away})->singular, q{break away}  => q{singular: 'breaks away' --> 'break away'};
is noun(q{break away})->singular,   q{break away}  => q{singular: 'break away' --> 'break away'};
is noun(q{cathismata})->singular, q{cathisma}  => q{singular: 'cathismata' --> 'cathisma'};
is noun(q{cathisma})->singular,   q{cathisma}  => q{singular: 'cathisma' --> 'cathisma'};
is noun(q{scapulae})->singular, q{scapula}  => q{singular: 'scapulae' --> 'scapula'};
is noun(q{scapula})->singular,   q{scapula}  => q{singular: 'scapula' --> 'scapula'};
is noun(q{hetaerae})->singular, q{hetaera}  => q{singular: 'hetaerae' --> 'hetaera'};
is noun(q{hetaera})->singular,   q{hetaera}  => q{singular: 'hetaera' --> 'hetaera'};
is noun(q{sori})->singular, q{sorus}  => q{singular: 'sori' --> 'sorus'};
is noun(q{sorus})->singular,   q{sorus}  => q{singular: 'sorus' --> 'sorus'};
is noun(q{radices})->singular, q{radix}  => q{singular: 'radices' --> 'radix'};
is noun(q{radix})->singular,   q{radix}  => q{singular: 'radix' --> 'radix'};
is noun(q{wanderjahre})->singular, q{wanderjahr}  => q{singular: 'wanderjahre' --> 'wanderjahr'};
is noun(q{wanderjahr})->singular,   q{wanderjahr}  => q{singular: 'wanderjahr' --> 'wanderjahr'};
is noun(q{arves})->singular, q{arf}  => q{singular: 'arves' --> 'arf'};
is noun(q{arf})->singular,   q{arf}  => q{singular: 'arf' --> 'arf'};
is noun(q{chateaux})->singular, q{chateau}  => q{singular: 'chateaux' --> 'chateau'};
is noun(q{chateau})->singular,   q{chateau}  => q{singular: 'chateau' --> 'chateau'};
is noun(q{tepidaria})->singular, q{tepidarium}  => q{singular: 'tepidaria' --> 'tepidarium'};
is noun(q{tepidarium})->singular,   q{tepidarium}  => q{singular: 'tepidarium' --> 'tepidarium'};
is noun(q{cystomata})->singular, q{cystoma}  => q{singular: 'cystomata' --> 'cystoma'};
is noun(q{cystoma})->singular,   q{cystoma}  => q{singular: 'cystoma' --> 'cystoma'};
is noun(q{moduli})->singular, q{modulus}  => q{singular: 'moduli' --> 'modulus'};
is noun(q{modulus})->singular,   q{modulus}  => q{singular: 'modulus' --> 'modulus'};
is noun(q{jalapenos})->singular, q{jalapeno}  => q{singular: 'jalapenos' --> 'jalapeno'};
is noun(q{jalapeno})->singular,   q{jalapeno}  => q{singular: 'jalapeno' --> 'jalapeno'};
is noun(q{Otomi})->singular, q{Otomi}  => q{singular: 'Otomi' --> 'Otomi'};
is noun(q{inukshuit})->singular, q{inukshuk}  => q{singular: 'inukshuit' --> 'inukshuk'};
is noun(q{inukshuk})->singular,   q{inukshuk}  => q{singular: 'inukshuk' --> 'inukshuk'};
is noun(q{orthocerata})->singular, q{orthoceras}  => q{singular: 'orthocerata' --> 'orthoceras'};
is noun(q{orthoceras})->singular,   q{orthoceras}  => q{singular: 'orthoceras' --> 'orthoceras'};
is noun(q{Tenggerese})->singular, q{Tenggerese}  => q{singular: 'Tenggerese' --> 'Tenggerese'};
is noun(q{procoeliae})->singular, q{procoelia}  => q{singular: 'procoeliae' --> 'procoelia'};
is noun(q{procoelia})->singular,   q{procoelia}  => q{singular: 'procoelia' --> 'procoelia'};
is noun(q{subsellia})->singular, q{subsellium}  => q{singular: 'subsellia' --> 'subsellium'};
is noun(q{subsellium})->singular,   q{subsellium}  => q{singular: 'subsellium' --> 'subsellium'};
is noun(q{granulae})->singular, q{granula}  => q{singular: 'granulae' --> 'granula'};
is noun(q{granula})->singular,   q{granula}  => q{singular: 'granula' --> 'granula'};
is noun(q{memos})->singular, q{memo}  => q{singular: 'memos' --> 'memo'};
is noun(q{memo})->singular,   q{memo}  => q{singular: 'memo' --> 'memo'};
is noun(q{pycnidia})->singular, q{pycnidium}  => q{singular: 'pycnidia' --> 'pycnidium'};
is noun(q{pycnidium})->singular,   q{pycnidium}  => q{singular: 'pycnidium' --> 'pycnidium'};
is noun(q{boluses})->singular, q{bolus}  => q{singular: 'boluses' --> 'bolus'};
is noun(q{bolus})->singular,   q{bolus}  => q{singular: 'bolus' --> 'bolus'};
is noun(q{mycoplasmas})->singular, q{mycoplasma}  => q{singular: 'mycoplasmas' --> 'mycoplasma'};
is noun(q{mycoplasma})->singular,   q{mycoplasma}  => q{singular: 'mycoplasma' --> 'mycoplasma'};
is noun(q{alto-relievos})->singular, q{alto-relievo}  => q{singular: 'alto-relievos' --> 'alto-relievo'};
is noun(q{alto-relievo})->singular,   q{alto-relievo}  => q{singular: 'alto-relievo' --> 'alto-relievo'};
is noun(q{rostrums})->singular, q{rostrum}  => q{singular: 'rostrums' --> 'rostrum'};
is noun(q{rostrum})->singular,   q{rostrum}  => q{singular: 'rostrum' --> 'rostrum'};
is noun(q{pali})->singular, q{palus}  => q{singular: 'pali' --> 'palus'};
is noun(q{palus})->singular,   q{palus}  => q{singular: 'palus' --> 'palus'};
is noun(q{Tokyos})->singular, q{Tokyo}  => q{singular: 'Tokyos' --> 'Tokyo'};
is noun(q{Tokyo})->singular,   q{Tokyo}  => q{singular: 'Tokyo' --> 'Tokyo'};
is noun(q{chaetae})->singular, q{chaeta}  => q{singular: 'chaetae' --> 'chaeta'};
is noun(q{chaeta})->singular,   q{chaeta}  => q{singular: 'chaeta' --> 'chaeta'};
is noun(q{plasmolytica})->singular, q{plasmolyticum}  => q{singular: 'plasmolytica' --> 'plasmolyticum'};
is noun(q{plasmolyticum})->singular,   q{plasmolyticum}  => q{singular: 'plasmolyticum' --> 'plasmolyticum'};
is noun(q{cochitos})->singular, q{cochito}  => q{singular: 'cochitos' --> 'cochito'};
is noun(q{cochito})->singular,   q{cochito}  => q{singular: 'cochito' --> 'cochito'};
is noun(q{efreeti})->singular, q{efreet}  => q{singular: 'efreeti' --> 'efreet'};
is noun(q{efreet})->singular,   q{efreet}  => q{singular: 'efreet' --> 'efreet'};
is noun(q{spari})->singular, q{sparus}  => q{singular: 'spari' --> 'sparus'};
is noun(q{sparus})->singular,   q{sparus}  => q{singular: 'sparus' --> 'sparus'};
is noun(q{rhododendra})->singular, q{rhododendron}  => q{singular: 'rhododendra' --> 'rhododendron'};
is noun(q{rhododendron})->singular,   q{rhododendron}  => q{singular: 'rhododendron' --> 'rhododendron'};
is noun(q{rem})->singular, q{rem}  => q{singular: 'rem' --> 'rem'};
is noun(q{6-star generals})->singular, q{6-star general}  => q{singular: '6-star generals' --> '6-star general'};
is noun(q{6-star general})->singular,   q{6-star general}  => q{singular: '6-star general' --> '6-star general'};
is noun(q{Singhalese})->singular, q{Singhalese}  => q{singular: 'Singhalese' --> 'Singhalese'};
is noun(q{caffe ristretti})->singular, q{caffe ristretto}  => q{singular: 'caffe ristretti' --> 'caffe ristretto'};
is noun(q{caffe ristretto})->singular,   q{caffe ristretto}  => q{singular: 'caffe ristretto' --> 'caffe ristretto'};
is noun(q{hoofs})->singular, q{hoof}  => q{singular: 'hoofs' --> 'hoof'};
is noun(q{hoof})->singular,   q{hoof}  => q{singular: 'hoof' --> 'hoof'};
is noun(q{afriti})->singular, q{afrit}  => q{singular: 'afriti' --> 'afrit'};
is noun(q{afrit})->singular,   q{afrit}  => q{singular: 'afrit' --> 'afrit'};
is noun(q{reductiones})->singular, q{reductio}  => q{singular: 'reductiones' --> 'reductio'};
is noun(q{reductio})->singular,   q{reductio}  => q{singular: 'reductio' --> 'reductio'};
is noun(q{parietes})->singular, q{paries}  => q{singular: 'parietes' --> 'paries'};
is noun(q{paries})->singular,   q{paries}  => q{singular: 'paries' --> 'paries'};
is noun(q{bases})->singular, q{base}  => q{singular: 'bases' --> 'base'};
is noun(q{base})->singular,   q{base}  => q{singular: 'base' --> 'base'};
is noun(q{falces})->singular, q{falx}  => q{singular: 'falces' --> 'falx'};
is noun(q{falx})->singular,   q{falx}  => q{singular: 'falx' --> 'falx'};
is noun(q{Andamanese})->singular, q{Andamanese}  => q{singular: 'Andamanese' --> 'Andamanese'};
is noun(q{maquereaux})->singular, q{maquereau}  => q{singular: 'maquereaux' --> 'maquereau'};
is noun(q{maquereau})->singular,   q{maquereau}  => q{singular: 'maquereau' --> 'maquereau'};
is noun(q{incubuses})->singular, q{incubus}  => q{singular: 'incubuses' --> 'incubus'};
is noun(q{incubus})->singular,   q{incubus}  => q{singular: 'incubus' --> 'incubus'};
is noun(q{vomicas})->singular, q{vomica}  => q{singular: 'vomicas' --> 'vomica'};
is noun(q{vomica})->singular,   q{vomica}  => q{singular: 'vomica' --> 'vomica'};
is noun(q{Avignonese})->singular, q{Avignonese}  => q{singular: 'Avignonese' --> 'Avignonese'};
is noun(q{xiphopagi})->singular, q{xiphopagus}  => q{singular: 'xiphopagi' --> 'xiphopagus'};
is noun(q{xiphopagus})->singular,   q{xiphopagus}  => q{singular: 'xiphopagus' --> 'xiphopagus'};
is noun(q{perikarya})->singular, q{perikaryon}  => q{singular: 'perikarya' --> 'perikaryon'};
is noun(q{perikaryon})->singular,   q{perikaryon}  => q{singular: 'perikaryon' --> 'perikaryon'};
is noun(q{propylons})->singular, q{propylon}  => q{singular: 'propylons' --> 'propylon'};
is noun(q{propylon})->singular,   q{propylon}  => q{singular: 'propylon' --> 'propylon'};
is noun(q{Macanese})->singular, q{Macanese}  => q{singular: 'Macanese' --> 'Macanese'};
is noun(q{unciae})->singular, q{uncia}  => q{singular: 'unciae' --> 'uncia'};
is noun(q{uncia})->singular,   q{uncia}  => q{singular: 'uncia' --> 'uncia'};
is noun(q{tete a tetes})->singular, q{tete a tete}  => q{singular: 'tete a tetes' --> 'tete a tete'};
is noun(q{tete a tete})->singular,   q{tete a tete}  => q{singular: 'tete a tete' --> 'tete a tete'};
is noun(q{aides-de-camp})->singular, q{aide-de-camp}  => q{singular: 'aides-de-camp' --> 'aide-de-camp'};
is noun(q{aide-de-camp})->singular,   q{aide-de-camp}  => q{singular: 'aide-de-camp' --> 'aide-de-camp'};
is noun(q{Burmans})->singular, q{Burman}  => q{singular: 'Burmans' --> 'Burman'};
is noun(q{Burman})->singular,   q{Burman}  => q{singular: 'Burman' --> 'Burman'};
is noun(q{idola})->singular, q{idolum}  => q{singular: 'idola' --> 'idolum'};
is noun(q{idolum})->singular,   q{idolum}  => q{singular: 'idolum' --> 'idolum'};
is noun(q{tarantati})->singular, q{tarantato}  => q{singular: 'tarantati' --> 'tarantato'};
is noun(q{tarantato})->singular,   q{tarantato}  => q{singular: 'tarantato' --> 'tarantato'};
is noun(q{retia})->singular, q{rete}  => q{singular: 'retia' --> 'rete'};
is noun(q{rete})->singular,   q{rete}  => q{singular: 'rete' --> 'rete'};
is noun(q{angustiae})->singular, q{angustia}  => q{singular: 'angustiae' --> 'angustia'};
is noun(q{angustia})->singular,   q{angustia}  => q{singular: 'angustia' --> 'angustia'};
is noun(q{enigmas})->singular, q{enigma}  => q{singular: 'enigmas' --> 'enigma'};
is noun(q{enigma})->singular,   q{enigma}  => q{singular: 'enigma' --> 'enigma'};
is noun(q{lobuli})->singular, q{lobulus}  => q{singular: 'lobuli' --> 'lobulus'};
is noun(q{lobulus})->singular,   q{lobulus}  => q{singular: 'lobulus' --> 'lobulus'};
is noun(q{sforzati})->singular, q{sforzato}  => q{singular: 'sforzati' --> 'sforzato'};
is noun(q{sforzato})->singular,   q{sforzato}  => q{singular: 'sforzato' --> 'sforzato'};
is noun(q{kylixes})->singular, q{kylix}  => q{singular: 'kylixes' --> 'kylix'};
is noun(q{kylix})->singular,   q{kylix}  => q{singular: 'kylix' --> 'kylix'};
is noun(q{archegonia})->singular, q{archegonium}  => q{singular: 'archegonia' --> 'archegonium'};
is noun(q{archegonium})->singular,   q{archegonium}  => q{singular: 'archegonium' --> 'archegonium'};
is noun(q{consortia})->singular, q{consortium}  => q{singular: 'consortia' --> 'consortium'};
is noun(q{consortium})->singular,   q{consortium}  => q{singular: 'consortium' --> 'consortium'};
is noun(q{humans})->singular, q{human}  => q{singular: 'humans' --> 'human'};
is noun(q{human})->singular,   q{human}  => q{singular: 'human' --> 'human'};
is noun(q{tete-a-tetes})->singular, q{tete-a-tete}  => q{singular: 'tete-a-tetes' --> 'tete-a-tete'};
is noun(q{tete-a-tete})->singular,   q{tete-a-tete}  => q{singular: 'tete-a-tete' --> 'tete-a-tete'};
is noun(q{stolones})->singular, q{stolo}  => q{singular: 'stolones' --> 'stolo'};
is noun(q{stolo})->singular,   q{stolo}  => q{singular: 'stolo' --> 'stolo'};
is noun(q{naumachiae})->singular, q{naumachia}  => q{singular: 'naumachiae' --> 'naumachia'};
is noun(q{naumachia})->singular,   q{naumachia}  => q{singular: 'naumachia' --> 'naumachia'};
is noun(q{noumena})->singular, q{noumenon}  => q{singular: 'noumena' --> 'noumenon'};
is noun(q{noumenon})->singular,   q{noumenon}  => q{singular: 'noumenon' --> 'noumenon'};
is noun(q{oxen})->singular, q{ox}  => q{singular: 'oxen' --> 'ox'};
is noun(q{ox})->singular,   q{ox}  => q{singular: 'ox' --> 'ox'};
is noun(q{spermaria})->singular, q{spermarium}  => q{singular: 'spermaria' --> 'spermarium'};
is noun(q{spermarium})->singular,   q{spermarium}  => q{singular: 'spermarium' --> 'spermarium'};
is noun(q{addenda})->singular, q{addendum}  => q{singular: 'addenda' --> 'addendum'};
is noun(q{addendum})->singular,   q{addendum}  => q{singular: 'addendum' --> 'addendum'};
is noun(q{clitorises})->singular, q{clitoris}  => q{singular: 'clitorises' --> 'clitoris'};
is noun(q{clitoris})->singular,   q{clitoris}  => q{singular: 'clitoris' --> 'clitoris'};
is noun(q{afreets})->singular, q{afreet}  => q{singular: 'afreets' --> 'afreet'};
is noun(q{afreet})->singular,   q{afreet}  => q{singular: 'afreet' --> 'afreet'};
is noun(q{plesiosauri})->singular, q{plesiosaurus}  => q{singular: 'plesiosauri' --> 'plesiosaurus'};
is noun(q{plesiosaurus})->singular,   q{plesiosaurus}  => q{singular: 'plesiosaurus' --> 'plesiosaurus'};
is noun(q{terzetti})->singular, q{terzetto}  => q{singular: 'terzetti' --> 'terzetto'};
is noun(q{terzetto})->singular,   q{terzetto}  => q{singular: 'terzetto' --> 'terzetto'};
is noun(q{scorias})->singular, q{scoria}  => q{singular: 'scorias' --> 'scoria'};
is noun(q{scoria})->singular,   q{scoria}  => q{singular: 'scoria' --> 'scoria'};
is noun(q{vaginas})->singular, q{vagina}  => q{singular: 'vaginas' --> 'vagina'};
is noun(q{vagina})->singular,   q{vagina}  => q{singular: 'vagina' --> 'vagina'};
is noun(q{metros})->singular, q{metro}  => q{singular: 'metros' --> 'metro'};
is noun(q{metro})->singular,   q{metro}  => q{singular: 'metro' --> 'metro'};
is noun(q{putti})->singular, q{putto}  => q{singular: 'putti' --> 'putto'};
is noun(q{putto})->singular,   q{putto}  => q{singular: 'putto' --> 'putto'};
is noun(q{enconia})->singular, q{enconium}  => q{singular: 'enconia' --> 'enconium'};
is noun(q{enconium})->singular,   q{enconium}  => q{singular: 'enconium' --> 'enconium'};
is noun(q{amphipneusta})->singular, q{amphipneust}  => q{singular: 'amphipneusta' --> 'amphipneust'};
is noun(q{amphipneust})->singular,   q{amphipneust}  => q{singular: 'amphipneust' --> 'amphipneust'};
is noun(q{angiomata})->singular, q{angioma}  => q{singular: 'angiomata' --> 'angioma'};
is noun(q{angioma})->singular,   q{angioma}  => q{singular: 'angioma' --> 'angioma'};
is noun(q{moratoria})->singular, q{moratorium}  => q{singular: 'moratoria' --> 'moratorium'};
is noun(q{moratorium})->singular,   q{moratorium}  => q{singular: 'moratorium' --> 'moratorium'};
is noun(q{Parduscos})->singular, q{Pardusco}  => q{singular: 'Parduscos' --> 'Pardusco'};
is noun(q{Pardusco})->singular,   q{Pardusco}  => q{singular: 'Pardusco' --> 'Pardusco'};
is noun(q{jacobuses})->singular, q{jacobus}  => q{singular: 'jacobuses' --> 'jacobus'};
is noun(q{spadixes})->singular, q{spadix}  => q{singular: 'spadixes' --> 'spadix'};
is noun(q{spadix})->singular,   q{spadix}  => q{singular: 'spadix' --> 'spadix'};
is noun(q{pastorales})->singular, q{pastorale}  => q{singular: 'pastorales' --> 'pastorale'};
is noun(q{pastorale})->singular,   q{pastorale}  => q{singular: 'pastorale' --> 'pastorale'};
is noun(q{paradors})->singular, q{parador}  => q{singular: 'paradors' --> 'parador'};
is noun(q{parador})->singular,   q{parador}  => q{singular: 'parador' --> 'parador'};
is noun(q{tablina})->singular, q{tablinum}  => q{singular: 'tablina' --> 'tablinum'};
is noun(q{tablinum})->singular,   q{tablinum}  => q{singular: 'tablinum' --> 'tablinum'};
is noun(q{Annamese})->singular, q{Annamese}  => q{singular: 'Annamese' --> 'Annamese'};
is noun(q{minutias})->singular, q{minutia}  => q{singular: 'minutias' --> 'minutia'};
is noun(q{minutia})->singular,   q{minutia}  => q{singular: 'minutia' --> 'minutia'};
is noun(q{pycnia})->singular, q{pycnium}  => q{singular: 'pycnia' --> 'pycnium'};
is noun(q{pycnium})->singular,   q{pycnium}  => q{singular: 'pycnium' --> 'pycnium'};
is noun(q{zooecia})->singular, q{zooecium}  => q{singular: 'zooecia' --> 'zooecium'};
is noun(q{zooecium})->singular,   q{zooecium}  => q{singular: 'zooecium' --> 'zooecium'};
is noun(q{salvos})->singular, q{salvo}  => q{singular: 'salvos' --> 'salvo'};
is noun(q{salvo})->singular,   q{salvo}  => q{singular: 'salvo' --> 'salvo'};
is noun(q{oaths})->singular, q{oath}  => q{singular: 'oaths' --> 'oath'};
is noun(q{oath})->singular,   q{oath}  => q{singular: 'oath' --> 'oath'};
is noun(q{spectra})->singular, q{spectrum}  => q{singular: 'spectra' --> 'spectrum'};
is noun(q{spectrum})->singular,   q{spectrum}  => q{singular: 'spectrum' --> 'spectrum'};
is noun(q{legomena})->singular, q{legomenon}  => q{singular: 'legomena' --> 'legomenon'};
is noun(q{legomenon})->singular,   q{legomenon}  => q{singular: 'legomenon' --> 'legomenon'};
is noun(q{cabalette})->singular, q{cabaletta}  => q{singular: 'cabalette' --> 'cabaletta'};
is noun(q{cabaletta})->singular,   q{cabaletta}  => q{singular: 'cabaletta' --> 'cabaletta'};
is noun(q{loa})->singular, q{loa}  => q{singular: 'loa' --> 'loa'};
is noun(q{intertrigos})->singular, q{intertrigo}  => q{singular: 'intertrigos' --> 'intertrigo'};
is noun(q{intertrigo})->singular,   q{intertrigo}  => q{singular: 'intertrigo' --> 'intertrigo'};
is noun(q{phocae})->singular, q{phoca}  => q{singular: 'phocae' --> 'phoca'};
is noun(q{phoca})->singular,   q{phoca}  => q{singular: 'phoca' --> 'phoca'};
is noun(q{ascidia})->singular, q{ascidium}  => q{singular: 'ascidia' --> 'ascidium'};
is noun(q{ascidium})->singular,   q{ascidium}  => q{singular: 'ascidium' --> 'ascidium'};
is noun(q{sanatoriums})->singular, q{sanatorium}  => q{singular: 'sanatoriums' --> 'sanatorium'};
is noun(q{sanatorium})->singular,   q{sanatorium}  => q{singular: 'sanatorium' --> 'sanatorium'};
is noun(q{recti})->singular, q{rectus}  => q{singular: 'recti' --> 'rectus'};
is noun(q{rectus})->singular,   q{rectus}  => q{singular: 'rectus' --> 'rectus'};
is noun(q{puirt a beul})->singular, q{port a beul}  => q{singular: 'puirt a beul' --> 'port a beul'};
is noun(q{port a beul})->singular,   q{port a beul}  => q{singular: 'port a beul' --> 'port a beul'};
is noun(q{malagmata})->singular, q{malagma}  => q{singular: 'malagmata' --> 'malagma'};
is noun(q{malagma})->singular,   q{malagma}  => q{singular: 'malagma' --> 'malagma'};
is noun(q{separatrices})->singular, q{separatrix}  => q{singular: 'separatrices' --> 'separatrix'};
is noun(q{separatrix})->singular,   q{separatrix}  => q{singular: 'separatrix' --> 'separatrix'};
is noun(q{serpulae})->singular, q{serpula}  => q{singular: 'serpulae' --> 'serpula'};
is noun(q{serpula})->singular,   q{serpula}  => q{singular: 'serpula' --> 'serpula'};
is noun(q{2-star generals})->singular, q{2-star general}  => q{singular: '2-star generals' --> '2-star general'};
is noun(q{2-star general})->singular,   q{2-star general}  => q{singular: '2-star general' --> '2-star general'};
is noun(q{Malabarese})->singular, q{Malabarese}  => q{singular: 'Malabarese' --> 'Malabarese'};
is noun(q{toxica})->singular, q{toxicum}  => q{singular: 'toxica' --> 'toxicum'};
is noun(q{toxicum})->singular,   q{toxicum}  => q{singular: 'toxicum' --> 'toxicum'};
is noun(q{anti-sera})->singular, q{anti-serum}  => q{singular: 'anti-sera' --> 'anti-serum'};
is noun(q{anti-serum})->singular,   q{anti-serum}  => q{singular: 'anti-serum' --> 'anti-serum'};
is noun(q{tropides})->singular, q{tropis}  => q{singular: 'tropides' --> 'tropis'};
is noun(q{tropis})->singular,   q{tropis}  => q{singular: 'tropis' --> 'tropis'};
is noun(q{autostrade})->singular, q{autostrada}  => q{singular: 'autostrade' --> 'autostrada'};
is noun(q{autostrada})->singular,   q{autostrada}  => q{singular: 'autostrada' --> 'autostrada'};
is noun(q{secantes})->singular, q{secans}  => q{singular: 'secantes' --> 'secans'};
is noun(q{secans})->singular,   q{secans}  => q{singular: 'secans' --> 'secans'};
is noun(q{promeropes})->singular, q{promerops}  => q{singular: 'promeropes' --> 'promerops'};
is noun(q{promerops})->singular,   q{promerops}  => q{singular: 'promerops' --> 'promerops'};
is noun(q{gladioluses})->singular, q{gladiolus}  => q{singular: 'gladioluses' --> 'gladiolus'};
is noun(q{gladiolus})->singular,   q{gladiolus}  => q{singular: 'gladiolus' --> 'gladiolus'};
is noun(q{casus belli})->singular, q{casus belli}  => q{singular: 'casus belli' --> 'casus belli'};
is noun(q{ports de bras})->singular, q{port de bras}  => q{singular: 'ports de bras' --> 'port de bras'};
is noun(q{port de bras})->singular,   q{port de bras}  => q{singular: 'port de bras' --> 'port de bras'};
is noun(q{tubuli})->singular, q{tubulus}  => q{singular: 'tubuli' --> 'tubulus'};
is noun(q{tubulus})->singular,   q{tubulus}  => q{singular: 'tubulus' --> 'tubulus'};
is noun(q{maries})->singular, q{mary}  => q{singular: 'maries' --> 'mary'};
is noun(q{mary})->singular,   q{mary}  => q{singular: 'mary' --> 'mary'};
is noun(q{brachiopoda})->singular, q{brachiopod}  => q{singular: 'brachiopoda' --> 'brachiopod'};
is noun(q{brachiopod})->singular,   q{brachiopod}  => q{singular: 'brachiopod' --> 'brachiopod'};
is noun(q{syntagmata})->singular, q{syntagma}  => q{singular: 'syntagmata' --> 'syntagma'};
is noun(q{syntagma})->singular,   q{syntagma}  => q{singular: 'syntagma' --> 'syntagma'};
is noun(q{hyphae})->singular, q{hypha}  => q{singular: 'hyphae' --> 'hypha'};
is noun(q{hypha})->singular,   q{hypha}  => q{singular: 'hypha' --> 'hypha'};
is noun(q{holothuriae})->singular, q{holothuria}  => q{singular: 'holothuriae' --> 'holothuria'};
is noun(q{holothuria})->singular,   q{holothuria}  => q{singular: 'holothuria' --> 'holothuria'};
is noun(q{mukims})->singular, q{mukim}  => q{singular: 'mukims' --> 'mukim'};
is noun(q{halluces})->singular, q{hallux}  => q{singular: 'halluces' --> 'hallux'};
is noun(q{hallux})->singular,   q{hallux}  => q{singular: 'hallux' --> 'hallux'};
is noun(q{furiosos})->singular, q{furioso}  => q{singular: 'furiosos' --> 'furioso'};
is noun(q{furioso})->singular,   q{furioso}  => q{singular: 'furioso' --> 'furioso'};
is noun(q{maximums})->singular, q{maximum}  => q{singular: 'maximums' --> 'maximum'};
is noun(q{maximum})->singular,   q{maximum}  => q{singular: 'maximum' --> 'maximum'};
is noun(q{grissini})->singular, q{grissino}  => q{singular: 'grissini' --> 'grissino'};
is noun(q{grissino})->singular,   q{grissino}  => q{singular: 'grissino' --> 'grissino'};
is noun(q{grani})->singular, q{grano}  => q{singular: 'grani' --> 'grano'};
is noun(q{grano})->singular,   q{grano}  => q{singular: 'grano' --> 'grano'};
is noun(q{millennia})->singular, q{millennium}  => q{singular: 'millennia' --> 'millennium'};
is noun(q{millennium})->singular,   q{millennium}  => q{singular: 'millennium' --> 'millennium'};
is noun(q{bravos})->singular, q{bravo}  => q{singular: 'bravos' --> 'bravo'};
is noun(q{bravo})->singular,   q{bravo}  => q{singular: 'bravo' --> 'bravo'};
is noun(q{star fishes})->singular, q{star fish}  => q{singular: 'star fishes' --> 'star fish'};
is noun(q{gonangia})->singular, q{gonangium}  => q{singular: 'gonangia' --> 'gonangium'};
is noun(q{gonangium})->singular,   q{gonangium}  => q{singular: 'gonangium' --> 'gonangium'};
is noun(q{pommes de terre})->singular, q{pomme de terre}  => q{singular: 'pommes de terre' --> 'pomme de terre'};
is noun(q{pomme de terre})->singular,   q{pomme de terre}  => q{singular: 'pomme de terre' --> 'pomme de terre'};
is noun(q{magnificos})->singular, q{magnifico}  => q{singular: 'magnificos' --> 'magnifico'};
is noun(q{magnifico})->singular,   q{magnifico}  => q{singular: 'magnifico' --> 'magnifico'};
is noun(q{avocados})->singular, q{avocado}  => q{singular: 'avocados' --> 'avocado'};
is noun(q{avocado})->singular,   q{avocado}  => q{singular: 'avocado' --> 'avocado'};
is noun(q{bratwurste})->singular, q{bratwurst}  => q{singular: 'bratwurste' --> 'bratwurst'};
is noun(q{bratwurst})->singular,   q{bratwurst}  => q{singular: 'bratwurst' --> 'bratwurst'};
is noun(q{scapi})->singular, q{scapus}  => q{singular: 'scapi' --> 'scapus'};
is noun(q{scapus})->singular,   q{scapus}  => q{singular: 'scapus' --> 'scapus'};
is noun(q{intaglios})->singular, q{intaglio}  => q{singular: 'intaglios' --> 'intaglio'};
is noun(q{intaglio})->singular,   q{intaglio}  => q{singular: 'intaglio' --> 'intaglio'};
is noun(q{pantos})->singular, q{panto}  => q{singular: 'pantos' --> 'panto'};
is noun(q{panto})->singular,   q{panto}  => q{singular: 'panto' --> 'panto'};
is noun(q{sacrums})->singular, q{sacrum}  => q{singular: 'sacrums' --> 'sacrum'};
is noun(q{sacrum})->singular,   q{sacrum}  => q{singular: 'sacrum' --> 'sacrum'};
is noun(q{porticos})->singular, q{portico}  => q{singular: 'porticos' --> 'portico'};
is noun(q{portico})->singular,   q{portico}  => q{singular: 'portico' --> 'portico'};
is noun(q{ritardandos})->singular, q{ritardando}  => q{singular: 'ritardandos' --> 'ritardando'};
is noun(q{ritardando})->singular,   q{ritardando}  => q{singular: 'ritardando' --> 'ritardando'};
is noun(q{statuses})->singular, q{status}  => q{singular: 'statuses' --> 'status'};
is noun(q{sequelae})->singular, q{sequela}  => q{singular: 'sequelae' --> 'sequela'};
is noun(q{sequela})->singular,   q{sequela}  => q{singular: 'sequela' --> 'sequela'};
is noun(q{Yokohamans})->singular, q{Yokohaman}  => q{singular: 'Yokohamans' --> 'Yokohaman'};
is noun(q{Yokohaman})->singular,   q{Yokohaman}  => q{singular: 'Yokohaman' --> 'Yokohaman'};
is noun(q{kylikes})->singular, q{kylix}  => q{singular: 'kylikes' --> 'kylix'};
is noun(q{kylix})->singular,   q{kylix}  => q{singular: 'kylix' --> 'kylix'};
is noun(q{polythecia})->singular, q{polythecium}  => q{singular: 'polythecia' --> 'polythecium'};
is noun(q{polythecium})->singular,   q{polythecium}  => q{singular: 'polythecium' --> 'polythecium'};
is noun(q{nouvelle riche})->singular, q{nouveau riche}  => q{singular: 'nouvelle riche' --> 'nouveau riche'};
is noun(q{nouveau riche})->singular,   q{nouveau riche}  => q{singular: 'nouveau riche' --> 'nouveau riche'};
is noun(q{prepennae})->singular, q{prepenna}  => q{singular: 'prepennae' --> 'prepenna'};
is noun(q{prepenna})->singular,   q{prepenna}  => q{singular: 'prepenna' --> 'prepenna'};
is noun(q{allegros})->singular, q{allegro}  => q{singular: 'allegros' --> 'allegro'};
is noun(q{allegro})->singular,   q{allegro}  => q{singular: 'allegro' --> 'allegro'};
is noun(q{phylums})->singular, q{phylum}  => q{singular: 'phylums' --> 'phylum'};
is noun(q{phylum})->singular,   q{phylum}  => q{singular: 'phylum' --> 'phylum'};
is noun(q{cementomata})->singular, q{cementoma}  => q{singular: 'cementomata' --> 'cementoma'};
is noun(q{cementoma})->singular,   q{cementoma}  => q{singular: 'cementoma' --> 'cementoma'};
is noun(q{melismata})->singular, q{melisma}  => q{singular: 'melismata' --> 'melisma'};
is noun(q{melisma})->singular,   q{melisma}  => q{singular: 'melisma' --> 'melisma'};
is noun(q{nonentia})->singular, q{non-ens}  => q{singular: 'nonentia' --> 'non-ens'};
is noun(q{non-ens})->singular,   q{non-ens}  => q{singular: 'non-ens' --> 'non-ens'};
is noun(q{emblememata})->singular, q{emblema}  => q{singular: 'emblememata' --> 'emblema'};
is noun(q{emblema})->singular,   q{emblema}  => q{singular: 'emblema' --> 'emblema'};
is noun(q{ovaria})->singular, q{ovarium}  => q{singular: 'ovaria' --> 'ovarium'};
is noun(q{ovarium})->singular,   q{ovarium}  => q{singular: 'ovarium' --> 'ovarium'};
is noun(q{sedilia})->singular, q{sedile}  => q{singular: 'sedilia' --> 'sedile'};
is noun(q{sedile})->singular,   q{sedile}  => q{singular: 'sedile' --> 'sedile'};
is noun(q{volcanelli})->singular, q{volcanello}  => q{singular: 'volcanelli' --> 'volcanello'};
is noun(q{volcanello})->singular,   q{volcanello}  => q{singular: 'volcanello' --> 'volcanello'};
is noun(q{tempietti})->singular, q{tempietto}  => q{singular: 'tempietti' --> 'tempietto'};
is noun(q{tempietto})->singular,   q{tempietto}  => q{singular: 'tempietto' --> 'tempietto'};
is noun(q{ale wives})->singular, q{ale wife}  => q{singular: 'ale wives' --> 'ale wife'};
is noun(q{ale wife})->singular,   q{ale wife}  => q{singular: 'ale wife' --> 'ale wife'};
is noun(q{prothalli})->singular, q{prothallus}  => q{singular: 'prothalli' --> 'prothallus'};
is noun(q{prothallus})->singular,   q{prothallus}  => q{singular: 'prothallus' --> 'prothallus'};
is noun(q{mycoplasmata})->singular, q{mycoplasma}  => q{singular: 'mycoplasmata' --> 'mycoplasma'};
is noun(q{mycoplasma})->singular,   q{mycoplasma}  => q{singular: 'mycoplasma' --> 'mycoplasma'};
is noun(q{porcini})->singular, q{porcino}  => q{singular: 'porcini' --> 'porcino'};
is noun(q{porcino})->singular,   q{porcino}  => q{singular: 'porcino' --> 'porcino'};
is noun(q{ambuscadoes})->singular, q{ambuscado}  => q{singular: 'ambuscadoes' --> 'ambuscado'};
is noun(q{ambuscado})->singular,   q{ambuscado}  => q{singular: 'ambuscado' --> 'ambuscado'};
is noun(q{cacti})->singular, q{cactus}  => q{singular: 'cacti' --> 'cactus'};
is noun(q{cactus})->singular,   q{cactus}  => q{singular: 'cactus' --> 'cactus'};
is noun(q{propylaea})->singular, q{propylaeum}  => q{singular: 'propylaea' --> 'propylaeum'};
is noun(q{propylaeum})->singular,   q{propylaeum}  => q{singular: 'propylaeum' --> 'propylaeum'};
is noun(q{bongoes})->singular, q{bongo}  => q{singular: 'bongoes' --> 'bongo'};
is noun(q{bongo})->singular,   q{bongo}  => q{singular: 'bongo' --> 'bongo'};
is noun(q{Cassinese})->singular, q{Cassinese}  => q{singular: 'Cassinese' --> 'Cassinese'};
is noun(q{bassos})->singular, q{basso}  => q{singular: 'bassos' --> 'basso'};
is noun(q{basso})->singular,   q{basso}  => q{singular: 'basso' --> 'basso'};
is noun(q{cynocephali})->singular, q{cynocephalus}  => q{singular: 'cynocephali' --> 'cynocephalus'};
is noun(q{cynocephalus})->singular,   q{cynocephalus}  => q{singular: 'cynocephalus' --> 'cynocephalus'};
is noun(q{monades})->singular, q{monas}  => q{singular: 'monades' --> 'monas'};
is noun(q{monas})->singular,   q{monas}  => q{singular: 'monas' --> 'monas'};
is noun(q{Togos})->singular, q{Togo}  => q{singular: 'Togos' --> 'Togo'};
is noun(q{Togo})->singular,   q{Togo}  => q{singular: 'Togo' --> 'Togo'};
is noun(q{haemangiomas})->singular, q{haemangioma}  => q{singular: 'haemangiomas' --> 'haemangioma'};
is noun(q{haemangioma})->singular,   q{haemangioma}  => q{singular: 'haemangioma' --> 'haemangioma'};
is noun(q{contretemps})->singular, q{contretemps}  => q{singular: 'contretemps' --> 'contretemps'};
is noun(q{zadrugas})->singular, q{zadruga}  => q{singular: 'zadrugas' --> 'zadruga'};
is noun(q{zadruga})->singular,   q{zadruga}  => q{singular: 'zadruga' --> 'zadruga'};
is noun(q{loxes})->singular, q{lox}  => q{singular: 'loxes' --> 'lox'};
is noun(q{hydras})->singular, q{hydra}  => q{singular: 'hydras' --> 'hydra'};
is noun(q{hydra})->singular,   q{hydra}  => q{singular: 'hydra' --> 'hydra'};
is noun(q{franc archers})->singular, q{franc archer}  => q{singular: 'franc archers' --> 'franc archer'};
is noun(q{franc archer})->singular,   q{franc archer}  => q{singular: 'franc archer' --> 'franc archer'};
is noun(q{entera})->singular, q{enteron}  => q{singular: 'entera' --> 'enteron'};
is noun(q{enteron})->singular,   q{enteron}  => q{singular: 'enteron' --> 'enteron'};
is noun(q{gumbos})->singular, q{gumbo}  => q{singular: 'gumbos' --> 'gumbo'};
is noun(q{gumbo})->singular,   q{gumbo}  => q{singular: 'gumbo' --> 'gumbo'};
is noun(q{latexes})->singular, q{latex}  => q{singular: 'latexes' --> 'latex'};
is noun(q{latex})->singular,   q{latex}  => q{singular: 'latex' --> 'latex'};
is noun(q{spasmi})->singular, q{spasmus}  => q{singular: 'spasmi' --> 'spasmus'};
is noun(q{spasmus})->singular,   q{spasmus}  => q{singular: 'spasmus' --> 'spasmus'};
is noun(q{avicularia})->singular, q{avicularium}  => q{singular: 'avicularia' --> 'avicularium'};
is noun(q{avicularium})->singular,   q{avicularium}  => q{singular: 'avicularium' --> 'avicularium'};
is noun(q{zucchini})->singular, q{zucchini}  => q{singular: 'zucchini' --> 'zucchini'};
is noun(q{quinquennia})->singular, q{quinquennium}  => q{singular: 'quinquennia' --> 'quinquennium'};
is noun(q{quinquennium})->singular,   q{quinquennium}  => q{singular: 'quinquennium' --> 'quinquennium'};
is noun(q{nautiluses})->singular, q{nautilus}  => q{singular: 'nautiluses' --> 'nautilus'};
is noun(q{nautilus})->singular,   q{nautilus}  => q{singular: 'nautilus' --> 'nautilus'};
is noun(q{atmas})->singular, q{atman}  => q{singular: 'atmas' --> 'atman'};
is noun(q{atman})->singular,   q{atman}  => q{singular: 'atman' --> 'atman'};
is noun(q{plasmodia})->singular, q{plasmodium}  => q{singular: 'plasmodia' --> 'plasmodium'};
is noun(q{plasmodium})->singular,   q{plasmodium}  => q{singular: 'plasmodium' --> 'plasmodium'};
is noun(q{linos})->singular, q{lino}  => q{singular: 'linos' --> 'lino'};
is noun(q{lino})->singular,   q{lino}  => q{singular: 'lino' --> 'lino'};
is noun(q{xiphoplastra})->singular, q{xiphoplastron}  => q{singular: 'xiphoplastra' --> 'xiphoplastron'};
is noun(q{xiphoplastron})->singular,   q{xiphoplastron}  => q{singular: 'xiphoplastron' --> 'xiphoplastron'};
is noun(q{kioko})->singular, q{kioko}  => q{singular: 'kioko' --> 'kioko'};
is noun(q{foramina})->singular, q{foramen}  => q{singular: 'foramina' --> 'foramen'};
is noun(q{foramen})->singular,   q{foramen}  => q{singular: 'foramen' --> 'foramen'};
is noun(q{Limans})->singular, q{Liman}  => q{singular: 'Limans' --> 'Liman'};
is noun(q{Liman})->singular,   q{Liman}  => q{singular: 'Liman' --> 'Liman'};
is noun(q{hemerae})->singular, q{hemera}  => q{singular: 'hemerae' --> 'hemera'};
is noun(q{hemera})->singular,   q{hemera}  => q{singular: 'hemera' --> 'hemera'};
is noun(q{rhombohedrons})->singular, q{rhombohedron}  => q{singular: 'rhombohedrons' --> 'rhombohedron'};
is noun(q{rhombohedron})->singular,   q{rhombohedron}  => q{singular: 'rhombohedron' --> 'rhombohedron'};
is noun(q{obeli})->singular, q{obelus}  => q{singular: 'obeli' --> 'obelus'};
is noun(q{obelus})->singular,   q{obelus}  => q{singular: 'obelus' --> 'obelus'};
is noun(q{contadini})->singular, q{contadino}  => q{singular: 'contadini' --> 'contadino'};
is noun(q{contadino})->singular,   q{contadino}  => q{singular: 'contadino' --> 'contadino'};
is noun(q{haddock})->singular, q{haddock}  => q{singular: 'haddock' --> 'haddock'};
is noun(q{Lorrainese})->singular, q{Lorrainese}  => q{singular: 'Lorrainese' --> 'Lorrainese'};
is noun(q{Plutos})->singular, q{Pluto}  => q{singular: 'Plutos' --> 'Pluto'};
is noun(q{Pluto})->singular,   q{Pluto}  => q{singular: 'Pluto' --> 'Pluto'};
is noun(q{synaxaria})->singular, q{synaxarium}  => q{singular: 'synaxaria' --> 'synaxarium'};
is noun(q{synaxarium})->singular,   q{synaxarium}  => q{singular: 'synaxarium' --> 'synaxarium'};
is noun(q{comatulae})->singular, q{comatula}  => q{singular: 'comatulae' --> 'comatula'};
is noun(q{comatula})->singular,   q{comatula}  => q{singular: 'comatula' --> 'comatula'};
is noun(q{variae lectiones})->singular, q{varia lectio}  => q{singular: 'variae lectiones' --> 'varia lectio'};
is noun(q{varia lectio})->singular,   q{varia lectio}  => q{singular: 'varia lectio' --> 'varia lectio'};
is noun(q{5-star generals})->singular, q{5-star general}  => q{singular: '5-star generals' --> '5-star general'};
is noun(q{5-star general})->singular,   q{5-star general}  => q{singular: '5-star general' --> '5-star general'};
is noun(q{Romans})->singular, q{Roman}  => q{singular: 'Romans' --> 'Roman'};
is noun(q{Roman})->singular,   q{Roman}  => q{singular: 'Roman' --> 'Roman'};
is noun(q{stoai})->singular, q{stoa}  => q{singular: 'stoai' --> 'stoa'};
is noun(q{stoa})->singular,   q{stoa}  => q{singular: 'stoa' --> 'stoa'};
is noun(q{fora})->singular, q{forum}  => q{singular: 'fora' --> 'forum'};
is noun(q{forum})->singular,   q{forum}  => q{singular: 'forum' --> 'forum'};
is noun(q{megatheria})->singular, q{megatherium}  => q{singular: 'megatheria' --> 'megatherium'};
is noun(q{megatherium})->singular,   q{megatherium}  => q{singular: 'megatherium' --> 'megatherium'};
is noun(q{hetmans})->singular, q{hetman}  => q{singular: 'hetmans' --> 'hetman'};
is noun(q{hetman})->singular,   q{hetman}  => q{singular: 'hetman' --> 'hetman'};
is noun(q{haptera})->singular, q{hapteron}  => q{singular: 'haptera' --> 'hapteron'};
is noun(q{hapteron})->singular,   q{hapteron}  => q{singular: 'hapteron' --> 'hapteron'};
is noun(q{erfs})->singular, q{erf}  => q{singular: 'erfs' --> 'erf'};
is noun(q{erf})->singular,   q{erf}  => q{singular: 'erf' --> 'erf'};
is noun(q{maths})->singular, q{math}  => q{singular: 'maths' --> 'math'};
is noun(q{math})->singular,   q{math}  => q{singular: 'math' --> 'math'};
is noun(q{ballistas})->singular, q{ballista}  => q{singular: 'ballistas' --> 'ballista'};
is noun(q{ballista})->singular,   q{ballista}  => q{singular: 'ballista' --> 'ballista'};
is noun(q{coronas})->singular, q{corona}  => q{singular: 'coronas' --> 'corona'};
is noun(q{corona})->singular,   q{corona}  => q{singular: 'corona' --> 'corona'};
is noun(q{tetrasporangia})->singular, q{tetrasporangium}  => q{singular: 'tetrasporangia' --> 'tetrasporangium'};
is noun(q{tetrasporangium})->singular,   q{tetrasporangium}  => q{singular: 'tetrasporangium' --> 'tetrasporangium'};
is noun(q{spathae})->singular, q{spatha}  => q{singular: 'spathae' --> 'spatha'};
is noun(q{spatha})->singular,   q{spatha}  => q{singular: 'spatha' --> 'spatha'};
is noun(q{fundamenta divisionis})->singular, q{fundamentum divisionis}  => q{singular: 'fundamenta divisionis' --> 'fundamentum divisionis'};
is noun(q{fundamentum divisionis})->singular,   q{fundamentum divisionis}  => q{singular: 'fundamentum divisionis' --> 'fundamentum divisionis'};
is noun(q{pilleis})->singular, q{pillie}  => q{singular: 'pilleis' --> 'pillie'};
is noun(q{pillie})->singular,   q{pillie}  => q{singular: 'pillie' --> 'pillie'};
is noun(q{harmans})->singular, q{harman}  => q{singular: 'harmans' --> 'harman'};
is noun(q{harman})->singular,   q{harman}  => q{singular: 'harman' --> 'harman'};
is noun(q{Nentsi})->singular, q{Nenets}  => q{singular: 'Nentsi' --> 'Nenets'};
is noun(q{Kakapos})->singular, q{Kakapo}  => q{singular: 'Kakapos' --> 'Kakapo'};
is noun(q{Kakapo})->singular,   q{Kakapo}  => q{singular: 'Kakapo' --> 'Kakapo'};
is noun(q{fricandeaux})->singular, q{fricandeau}  => q{singular: 'fricandeaux' --> 'fricandeau'};
is noun(q{fricandeau})->singular,   q{fricandeau}  => q{singular: 'fricandeau' --> 'fricandeau'};
is noun(q{mixolimnia})->singular, q{mixolimnion}  => q{singular: 'mixolimnia' --> 'mixolimnion'};
is noun(q{mixolimnion})->singular,   q{mixolimnion}  => q{singular: 'mixolimnion' --> 'mixolimnion'};
is noun(q{rostra})->singular, q{rostrum}  => q{singular: 'rostra' --> 'rostrum'};
is noun(q{rostrum})->singular,   q{rostrum}  => q{singular: 'rostrum' --> 'rostrum'};
is noun(q{equinoctia})->singular, q{equinoctium}  => q{singular: 'equinoctia' --> 'equinoctium'};
is noun(q{equinoctium})->singular,   q{equinoctium}  => q{singular: 'equinoctium' --> 'equinoctium'};
is noun(q{galla})->singular, q{galla}  => q{singular: 'galla' --> 'galla'};
is noun(q{kantharoi})->singular, q{kantharos}  => q{singular: 'kantharoi' --> 'kantharos'};
is noun(q{kantharos})->singular,   q{kantharos}  => q{singular: 'kantharos' --> 'kantharos'};
is noun(q{psydracia})->singular, q{psydracium}  => q{singular: 'psydracia' --> 'psydracium'};
is noun(q{psydracium})->singular,   q{psydracium}  => q{singular: 'psydracium' --> 'psydracium'};
is noun(q{retinacula})->singular, q{retinaculum}  => q{singular: 'retinacula' --> 'retinaculum'};
is noun(q{retinaculum})->singular,   q{retinaculum}  => q{singular: 'retinaculum' --> 'retinaculum'};
is noun(q{crafts childer})->singular, q{crafts child}  => q{singular: 'crafts childer' --> 'crafts child'};
is noun(q{crafts child})->singular,   q{crafts child}  => q{singular: 'crafts child' --> 'crafts child'};
is noun(q{silices})->singular, q{silex}  => q{singular: 'silices' --> 'silex'};
is noun(q{silex})->singular,   q{silex}  => q{singular: 'silex' --> 'silex'};
is noun(q{monsignori})->singular, q{monsignore}  => q{singular: 'monsignori' --> 'monsignore'};
is noun(q{monsignore})->singular,   q{monsignore}  => q{singular: 'monsignore' --> 'monsignore'};
is noun(q{leishmaniae})->singular, q{leishmania}  => q{singular: 'leishmaniae' --> 'leishmania'};
is noun(q{leishmania})->singular,   q{leishmania}  => q{singular: 'leishmania' --> 'leishmania'};
is noun(q{caffe ristrettos})->singular, q{caffe ristretto}  => q{singular: 'caffe ristrettos' --> 'caffe ristretto'};
is noun(q{caffe ristretto})->singular,   q{caffe ristretto}  => q{singular: 'caffe ristretto' --> 'caffe ristretto'};
is noun(q{utriculariae})->singular, q{utricularia}  => q{singular: 'utriculariae' --> 'utricularia'};
is noun(q{utricularia})->singular,   q{utricularia}  => q{singular: 'utricularia' --> 'utricularia'};
is noun(q{salpas})->singular, q{salpa}  => q{singular: 'salpas' --> 'salpa'};
is noun(q{salpa})->singular,   q{salpa}  => q{singular: 'salpa' --> 'salpa'};
is noun(q{trichidia})->singular, q{trichidium}  => q{singular: 'trichidia' --> 'trichidium'};
is noun(q{trichidium})->singular,   q{trichidium}  => q{singular: 'trichidium' --> 'trichidium'};
is noun(q{brigadier generals})->singular, q{brigadier general}  => q{singular: 'brigadier generals' --> 'brigadier general'};
is noun(q{brigadier general})->singular,   q{brigadier general}  => q{singular: 'brigadier general' --> 'brigadier general'};
is noun(q{Nenets})->singular, q{Nenets}  => q{singular: 'Nenets' --> 'Nenets'};
is noun(q{remexes})->singular, q{remex}  => q{singular: 'remexes' --> 'remex'};
is noun(q{remex})->singular,   q{remex}  => q{singular: 'remex' --> 'remex'};
is noun(q{genii})->singular, q{genie}  => q{singular: 'genii' --> 'genie'};
is noun(q{genie})->singular,   q{genie}  => q{singular: 'genie' --> 'genie'};
is noun(q{glutaei})->singular, q{glutaeus}  => q{singular: 'glutaei' --> 'glutaeus'};
is noun(q{glutaeus})->singular,   q{glutaeus}  => q{singular: 'glutaeus' --> 'glutaeus'};
is noun(q{paragangliomata})->singular, q{paraganglioma}  => q{singular: 'paragangliomata' --> 'paraganglioma'};
is noun(q{paraganglioma})->singular,   q{paraganglioma}  => q{singular: 'paraganglioma' --> 'paraganglioma'};
is noun(q{interradii})->singular, q{interradius}  => q{singular: 'interradii' --> 'interradius'};
is noun(q{interradius})->singular,   q{interradius}  => q{singular: 'interradius' --> 'interradius'};
is noun(q{medulloblastomata})->singular, q{medulloblastoma}  => q{singular: 'medulloblastomata' --> 'medulloblastoma'};
is noun(q{medulloblastoma})->singular,   q{medulloblastoma}  => q{singular: 'medulloblastoma' --> 'medulloblastoma'};
is noun(q{squadristi})->singular, q{squadrist}  => q{singular: 'squadristi' --> 'squadrist'};
is noun(q{squadrist})->singular,   q{squadrist}  => q{singular: 'squadrist' --> 'squadrist'};
is noun(q{stomachs})->singular, q{stomach}  => q{singular: 'stomachs' --> 'stomach'};
is noun(q{stomach})->singular,   q{stomach}  => q{singular: 'stomach' --> 'stomach'};
is noun(q{cornetti})->singular, q{cornetto}  => q{singular: 'cornetti' --> 'cornetto'};
is noun(q{cornetto})->singular,   q{cornetto}  => q{singular: 'cornetto' --> 'cornetto'};
is noun(q{lipomata})->singular, q{lipoma}  => q{singular: 'lipomata' --> 'lipoma'};
is noun(q{lipoma})->singular,   q{lipoma}  => q{singular: 'lipoma' --> 'lipoma'};
is noun(q{sera})->singular, q{serum}  => q{singular: 'sera' --> 'serum'};
is noun(q{serum})->singular,   q{serum}  => q{singular: 'serum' --> 'serum'};
is noun(q{rond de jambes})->singular, q{rond de jambe}  => q{singular: 'rond de jambes' --> 'rond de jambe'};
is noun(q{rond de jambe})->singular,   q{rond de jambe}  => q{singular: 'rond de jambe' --> 'rond de jambe'};
is noun(q{unios})->singular, q{unio}  => q{singular: 'unios' --> 'unio'};
is noun(q{unio})->singular,   q{unio}  => q{singular: 'unio' --> 'unio'};
is noun(q{hemangiomata})->singular, q{hemangioma}  => q{singular: 'hemangiomata' --> 'hemangioma'};
is noun(q{hemangioma})->singular,   q{hemangioma}  => q{singular: 'hemangioma' --> 'hemangioma'};
is noun(q{secreta})->singular, q{secretum}  => q{singular: 'secreta' --> 'secretum'};
is noun(q{secretum})->singular,   q{secretum}  => q{singular: 'secretum' --> 'secretum'};
is noun(q{figuranti})->singular, q{figurante}  => q{singular: 'figuranti' --> 'figurante'};
is noun(q{figurante})->singular,   q{figurante}  => q{singular: 'figurante' --> 'figurante'};
is noun(q{zitelle})->singular, q{zitella}  => q{singular: 'zitelle' --> 'zitella'};
is noun(q{zitella})->singular,   q{zitella}  => q{singular: 'zitella' --> 'zitella'};
is noun(q{monimolimnia})->singular, q{monimolimnion}  => q{singular: 'monimolimnia' --> 'monimolimnion'};
is noun(q{monimolimnion})->singular,   q{monimolimnion}  => q{singular: 'monimolimnion' --> 'monimolimnion'};
is noun(q{epididymises})->singular, q{epididymis}  => q{singular: 'epididymises' --> 'epididymis'};
is noun(q{epididymis})->singular,   q{epididymis}  => q{singular: 'epididymis' --> 'epididymis'};
is noun(q{nautili})->singular, q{nautilus}  => q{singular: 'nautili' --> 'nautilus'};
is noun(q{nautilus})->singular,   q{nautilus}  => q{singular: 'nautilus' --> 'nautilus'};
is noun(q{euros})->singular, q{euro}  => q{singular: 'euros' --> 'euro'};
is noun(q{euro})->singular,   q{euro}  => q{singular: 'euro' --> 'euro'};
is noun(q{blini})->singular, q{blin}  => q{singular: 'blini' --> 'blin'};
is noun(q{blin})->singular,   q{blin}  => q{singular: 'blin' --> 'blin'};
is noun(q{ephemerides})->singular, q{ephemeris}  => q{singular: 'ephemerides' --> 'ephemeris'};
is noun(q{ephemeris})->singular,   q{ephemeris}  => q{singular: 'ephemeris' --> 'ephemeris'};
is noun(q{marquises})->singular, q{marquis}  => q{singular: 'marquises' --> 'marquis'};
is noun(q{marquis})->singular,   q{marquis}  => q{singular: 'marquis' --> 'marquis'};
is noun(q{teniae})->singular, q{tenia}  => q{singular: 'teniae' --> 'tenia'};
is noun(q{tenia})->singular,   q{tenia}  => q{singular: 'tenia' --> 'tenia'};
is noun(q{ambones})->singular, q{ambo}  => q{singular: 'ambones' --> 'ambo'};
is noun(q{ambo})->singular,   q{ambo}  => q{singular: 'ambo' --> 'ambo'};
is noun(q{yarramen})->singular, q{yarraman}  => q{singular: 'yarramen' --> 'yarraman'};
is noun(q{yarraman})->singular,   q{yarraman}  => q{singular: 'yarraman' --> 'yarraman'};
is noun(q{Marys})->singular, q{Mary}  => q{singular: 'Marys' --> 'Mary'};
is noun(q{Mary})->singular,   q{Mary}  => q{singular: 'Mary' --> 'Mary'};
is noun(q{hamadryades})->singular, q{hamadryad}  => q{singular: 'hamadryades' --> 'hamadryad'};
is noun(q{hamadryad})->singular,   q{hamadryad}  => q{singular: 'hamadryad' --> 'hamadryad'};
is noun(q{phalanxes})->singular, q{phalanx}  => q{singular: 'phalanxes' --> 'phalanx'};
is noun(q{phalanx})->singular,   q{phalanx}  => q{singular: 'phalanx' --> 'phalanx'};
is noun(q{viali})->singular, q{viale}  => q{singular: 'viali' --> 'viale'};
is noun(q{viale})->singular,   q{viale}  => q{singular: 'viale' --> 'viale'};
is noun(q{niellos})->singular, q{niello}  => q{singular: 'niellos' --> 'niello'};
is noun(q{niello})->singular,   q{niello}  => q{singular: 'niello' --> 'niello'};
is noun(q{calzoni})->singular, q{calzone}  => q{singular: 'calzoni' --> 'calzone'};
is noun(q{calzone})->singular,   q{calzone}  => q{singular: 'calzone' --> 'calzone'};
is noun(q{man-milliners})->singular, q{man-milliner}  => q{singular: 'man-milliners' --> 'man-milliner'};
is noun(q{man-milliner})->singular,   q{man-milliner}  => q{singular: 'man-milliner' --> 'man-milliner'};
is noun(q{muzzes})->singular, q{muzz}  => q{singular: 'muzzes' --> 'muzz'};
is noun(q{muzz})->singular,   q{muzz}  => q{singular: 'muzz' --> 'muzz'};
is noun(q{mezuzoth})->singular, q{mezuza}  => q{singular: 'mezuzoth' --> 'mezuza'};
is noun(q{mezuza})->singular,   q{mezuza}  => q{singular: 'mezuza' --> 'mezuza'};
is noun(q{fossae})->singular, q{fossa}  => q{singular: 'fossae' --> 'fossa'};
is noun(q{fossa})->singular,   q{fossa}  => q{singular: 'fossa' --> 'fossa'};
is noun(q{Amboinese})->singular, q{Amboinese}  => q{singular: 'Amboinese' --> 'Amboinese'};
is noun(q{minutiae})->singular, q{minutia}  => q{singular: 'minutiae' --> 'minutia'};
is noun(q{minutia})->singular,   q{minutia}  => q{singular: 'minutia' --> 'minutia'};
is noun(q{matinees musicales})->singular, q{matinee musicale}  => q{singular: 'matinees musicales' --> 'matinee musicale'};
is noun(q{matinee musicale})->singular,   q{matinee musicale}  => q{singular: 'matinee musicale' --> 'matinee musicale'};
is noun(q{1 star generals})->singular, q{1 star general}  => q{singular: '1 star generals' --> '1 star general'};
is noun(q{1 star general})->singular,   q{1 star general}  => q{singular: '1 star general' --> '1 star general'};
is noun(q{intervalla})->singular, q{intervallum}  => q{singular: 'intervalla' --> 'intervallum'};
is noun(q{intervallum})->singular,   q{intervallum}  => q{singular: 'intervallum' --> 'intervallum'};
is noun(q{sarcophagi})->singular, q{sarcophagus}  => q{singular: 'sarcophagi' --> 'sarcophagus'};
is noun(q{sarcophagus})->singular,   q{sarcophagus}  => q{singular: 'sarcophagus' --> 'sarcophagus'};
is noun(q{modelli})->singular, q{modello}  => q{singular: 'modelli' --> 'modello'};
is noun(q{modello})->singular,   q{modello}  => q{singular: 'modello' --> 'modello'};
is noun(q{lidos})->singular, q{lido}  => q{singular: 'lidos' --> 'lido'};
is noun(q{lido})->singular,   q{lido}  => q{singular: 'lido' --> 'lido'};
is noun(q{hernias})->singular, q{hernia}  => q{singular: 'hernias' --> 'hernia'};
is noun(q{hernia})->singular,   q{hernia}  => q{singular: 'hernia' --> 'hernia'};
is noun(q{solos})->singular, q{solo}  => q{singular: 'solos' --> 'solo'};
is noun(q{solo})->singular,   q{solo}  => q{singular: 'solo' --> 'solo'};
is noun(q{parabolas})->singular, q{parabola}  => q{singular: 'parabolas' --> 'parabola'};
is noun(q{parabola})->singular,   q{parabola}  => q{singular: 'parabola' --> 'parabola'};
is noun(q{corpora})->singular, q{corpus}  => q{singular: 'corpora' --> 'corpus'};
is noun(q{corpus})->singular,   q{corpus}  => q{singular: 'corpus' --> 'corpus'};
is noun(q{haustra})->singular, q{haustrum}  => q{singular: 'haustra' --> 'haustrum'};
is noun(q{haustrum})->singular,   q{haustrum}  => q{singular: 'haustrum' --> 'haustrum'};
is noun(q{modellos})->singular, q{modello}  => q{singular: 'modellos' --> 'modello'};
is noun(q{modello})->singular,   q{modello}  => q{singular: 'modello' --> 'modello'};
is noun(q{terebratulas})->singular, q{terebratula}  => q{singular: 'terebratulas' --> 'terebratula'};
is noun(q{terebratula})->singular,   q{terebratula}  => q{singular: 'terebratula' --> 'terebratula'};
is noun(q{sizzes})->singular, q{sizz}  => q{singular: 'sizzes' --> 'sizz'};
is noun(q{sizz})->singular,   q{sizz}  => q{singular: 'sizz' --> 'sizz'};
is noun(q{Normans})->singular, q{Norman}  => q{singular: 'Normans' --> 'Norman'};
is noun(q{Norman})->singular,   q{Norman}  => q{singular: 'Norman' --> 'Norman'};
is noun(q{valute})->singular, q{valuta}  => q{singular: 'valute' --> 'valuta'};
is noun(q{valuta})->singular,   q{valuta}  => q{singular: 'valuta' --> 'valuta'};
is noun(q{pediluvia})->singular, q{pediluvium}  => q{singular: 'pediluvia' --> 'pediluvium'};
is noun(q{pediluvium})->singular,   q{pediluvium}  => q{singular: 'pediluvium' --> 'pediluvium'};
is noun(q{quadratrices})->singular, q{quadratrix}  => q{singular: 'quadratrices' --> 'quadratrix'};
is noun(q{quadratrix})->singular,   q{quadratrix}  => q{singular: 'quadratrix' --> 'quadratrix'};
is noun(q{vlaktes})->singular, q{vlakte}  => q{singular: 'vlaktes' --> 'vlakte'};
is noun(q{vlakte})->singular,   q{vlakte}  => q{singular: 'vlakte' --> 'vlakte'};
is noun(q{vasa})->singular, q{vas}  => q{singular: 'vasa' --> 'vas'};
is noun(q{vas})->singular,   q{vas}  => q{singular: 'vas' --> 'vas'};
is noun(q{lora})->singular, q{lorum}  => q{singular: 'lora' --> 'lorum'};
is noun(q{lorum})->singular,   q{lorum}  => q{singular: 'lorum' --> 'lorum'};
is noun(q{axons})->singular, q{axon}  => q{singular: 'axons' --> 'axon'};
is noun(q{axon})->singular,   q{axon}  => q{singular: 'axon' --> 'axon'};
is noun(q{perithecia})->singular, q{perithecium}  => q{singular: 'perithecia' --> 'perithecium'};
is noun(q{perithecium})->singular,   q{perithecium}  => q{singular: 'perithecium' --> 'perithecium'};
is noun(q{fomites})->singular, q{fomes}  => q{singular: 'fomites' --> 'fomes'};
is noun(q{fomes})->singular,   q{fomes}  => q{singular: 'fomes' --> 'fomes'};
is noun(q{triforia})->singular, q{triforium}  => q{singular: 'triforia' --> 'triforium'};
is noun(q{triforium})->singular,   q{triforium}  => q{singular: 'triforium' --> 'triforium'};
is noun(q{Tonkinese})->singular, q{Tonkinese}  => q{singular: 'Tonkinese' --> 'Tonkinese'};
is noun(q{Hottentotese})->singular, q{Hottentotese}  => q{singular: 'Hottentotese' --> 'Hottentotese'};
is noun(q{baals})->singular, q{baal}  => q{singular: 'baals' --> 'baal'};
is noun(q{baal})->singular,   q{baal}  => q{singular: 'baal' --> 'baal'};
is noun(q{propyla})->singular, q{propylon}  => q{singular: 'propyla' --> 'propylon'};
is noun(q{propylon})->singular,   q{propylon}  => q{singular: 'propylon' --> 'propylon'};
is noun(q{appressoria})->singular, q{appressorium}  => q{singular: 'appressoria' --> 'appressorium'};
is noun(q{appressorium})->singular,   q{appressorium}  => q{singular: 'appressorium' --> 'appressorium'};
is noun(q{trattorias})->singular, q{trattoria}  => q{singular: 'trattorias' --> 'trattoria'};
is noun(q{trattoria})->singular,   q{trattoria}  => q{singular: 'trattoria' --> 'trattoria'};
is noun(q{germaria})->singular, q{germarium}  => q{singular: 'germaria' --> 'germarium'};
is noun(q{germarium})->singular,   q{germarium}  => q{singular: 'germarium' --> 'germarium'};
is noun(q{veneres})->singular, q{venus}  => q{singular: 'veneres' --> 'venus'};
is noun(q{venus})->singular,   q{venus}  => q{singular: 'venus' --> 'venus'};
is noun(q{cortices})->singular, q{cortex}  => q{singular: 'cortices' --> 'cortex'};
is noun(q{cortex})->singular,   q{cortex}  => q{singular: 'cortex' --> 'cortex'};
is noun(q{mediatrices})->singular, q{mediatrix}  => q{singular: 'mediatrices' --> 'mediatrix'};
is noun(q{mediatrix})->singular,   q{mediatrix}  => q{singular: 'mediatrix' --> 'mediatrix'};
is noun(q{caddises})->singular, q{caddis}  => q{singular: 'caddises' --> 'caddis'};
is noun(q{caddis})->singular,   q{caddis}  => q{singular: 'caddis' --> 'caddis'};
is noun(q{courts martial})->singular, q{court martial}  => q{singular: 'courts martial' --> 'court martial'};
is noun(q{court martial})->singular,   q{court martial}  => q{singular: 'court martial' --> 'court martial'};
is noun(q{4-star generals})->singular, q{4-star general}  => q{singular: '4-star generals' --> '4-star general'};
is noun(q{4-star general})->singular,   q{4-star general}  => q{singular: '4-star general' --> '4-star general'};
is noun(q{musees imaginaires})->singular, q{musee imaginaire}  => q{singular: 'musees imaginaires' --> 'musee imaginaire'};
is noun(q{musee imaginaire})->singular,   q{musee imaginaire}  => q{singular: 'musee imaginaire' --> 'musee imaginaire'};
is noun(q{autos})->singular, q{auto}  => q{singular: 'autos' --> 'auto'};
is noun(q{auto})->singular,   q{auto}  => q{singular: 'auto' --> 'auto'};
is noun(q{routes nationales})->singular, q{route nationale}  => q{singular: 'routes nationales' --> 'route nationale'};
is noun(q{route nationale})->singular,   q{route nationale}  => q{singular: 'route nationale' --> 'route nationale'};
is noun(q{raggare})->singular, q{raggare}  => q{singular: 'raggare' --> 'raggare'};
is noun(q{scombri})->singular, q{scomber}  => q{singular: 'scombri' --> 'scomber'};
is noun(q{scomber})->singular,   q{scomber}  => q{singular: 'scomber' --> 'scomber'};
is noun(q{pincers})->singular, q{pincer}  => q{singular: 'pincers' --> 'pincer'};
is noun(q{pincer})->singular,   q{pincer}  => q{singular: 'pincer' --> 'pincer'};
is noun(q{maars})->singular, q{maar}  => q{singular: 'maars' --> 'maar'};
is noun(q{maar})->singular,   q{maar}  => q{singular: 'maar' --> 'maar'};
is noun(q{honorariums})->singular, q{honorarium}  => q{singular: 'honorariums' --> 'honorarium'};
is noun(q{honorarium})->singular,   q{honorarium}  => q{singular: 'honorarium' --> 'honorarium'};
is noun(q{bulimi})->singular, q{bulimus}  => q{singular: 'bulimi' --> 'bulimus'};
is noun(q{bulimus})->singular,   q{bulimus}  => q{singular: 'bulimus' --> 'bulimus'};
is noun(q{streptococci})->singular, q{streptococcus}  => q{singular: 'streptococci' --> 'streptococcus'};
is noun(q{streptococcus})->singular,   q{streptococcus}  => q{singular: 'streptococcus' --> 'streptococcus'};
is noun(q{bandeaux})->singular, q{bandeau}  => q{singular: 'bandeaux' --> 'bandeau'};
is noun(q{bandeau})->singular,   q{bandeau}  => q{singular: 'bandeau' --> 'bandeau'};
is noun(q{jacobus})->singular, q{jacobus}  => q{singular: 'jacobus' --> 'jacobus'};
is noun(q{Otomies})->singular, q{Otomi}  => q{singular: 'Otomies' --> 'Otomi'};
is noun(q{pieds a terre})->singular, q{pied a terre}  => q{singular: 'pieds a terre' --> 'pied a terre'};
is noun(q{pied a terre})->singular,   q{pied a terre}  => q{singular: 'pied a terre' --> 'pied a terre'};
is noun(q{gousblomme})->singular, q{gousblom}  => q{singular: 'gousblomme' --> 'gousblom'};
is noun(q{gousblom})->singular,   q{gousblom}  => q{singular: 'gousblom' --> 'gousblom'};
is noun(q{stomia})->singular, q{stomion}  => q{singular: 'stomia' --> 'stomion'};
is noun(q{stomion})->singular,   q{stomion}  => q{singular: 'stomion' --> 'stomion'};
is noun(q{tiros})->singular, q{tiro}  => q{singular: 'tiros' --> 'tiro'};
is noun(q{tiro})->singular,   q{tiro}  => q{singular: 'tiro' --> 'tiro'};
is noun(q{xoana})->singular, q{xoanon}  => q{singular: 'xoana' --> 'xoanon'};
is noun(q{xoanon})->singular,   q{xoanon}  => q{singular: 'xoanon' --> 'xoanon'};
is noun(q{men-children})->singular, q{man-child}  => q{singular: 'men-children' --> 'man-child'};
is noun(q{man-child})->singular,   q{man-child}  => q{singular: 'man-child' --> 'man-child'};
is noun(q{amorini})->singular, q{amorino}  => q{singular: 'amorini' --> 'amorino'};
is noun(q{amorino})->singular,   q{amorino}  => q{singular: 'amorino' --> 'amorino'};
is noun(q{ragazze})->singular, q{ragazza}  => q{singular: 'ragazze' --> 'ragazza'};
is noun(q{ragazza})->singular,   q{ragazza}  => q{singular: 'ragazza' --> 'ragazza'};
is noun(q{xysti})->singular, q{xystus}  => q{singular: 'xysti' --> 'xystus'};
is noun(q{xystus})->singular,   q{xystus}  => q{singular: 'xystus' --> 'xystus'};
is noun(q{protypa})->singular, q{protypon}  => q{singular: 'protypa' --> 'protypon'};
is noun(q{protypon})->singular,   q{protypon}  => q{singular: 'protypon' --> 'protypon'};
is noun(q{pendulums})->singular, q{pendulum}  => q{singular: 'pendulums' --> 'pendulum'};
is noun(q{pendulum})->singular,   q{pendulum}  => q{singular: 'pendulum' --> 'pendulum'};
is noun(q{saxicavae})->singular, q{saxicava}  => q{singular: 'saxicavae' --> 'saxicava'};
is noun(q{saxicava})->singular,   q{saxicava}  => q{singular: 'saxicava' --> 'saxicava'};
is noun(q{moakses})->singular, q{moaks}  => q{singular: 'moakses' --> 'moaks'};
is noun(q{moaks})->singular,   q{moaks}  => q{singular: 'moaks' --> 'moaks'};
is noun(q{inuit})->singular, q{inuk}  => q{singular: 'inuit' --> 'inuk'};
is noun(q{inuk})->singular,   q{inuk}  => q{singular: 'inuk' --> 'inuk'};
is noun(q{Faroese})->singular, q{Faroese}  => q{singular: 'Faroese' --> 'Faroese'};
is noun(q{livedos})->singular, q{livedo}  => q{singular: 'livedos' --> 'livedo'};
is noun(q{livedo})->singular,   q{livedo}  => q{singular: 'livedo' --> 'livedo'};
is noun(q{conidia})->singular, q{conidium}  => q{singular: 'conidia' --> 'conidium'};
is noun(q{conidium})->singular,   q{conidium}  => q{singular: 'conidium' --> 'conidium'};
is noun(q{venuses})->singular, q{venus}  => q{singular: 'venuses' --> 'venus'};
is noun(q{venus})->singular,   q{venus}  => q{singular: 'venus' --> 'venus'};
is noun(q{sacella})->singular, q{sacellum}  => q{singular: 'sacella' --> 'sacellum'};
is noun(q{sacellum})->singular,   q{sacellum}  => q{singular: 'sacellum' --> 'sacellum'};
is noun(q{praecognita})->singular, q{praecognitum}  => q{singular: 'praecognita' --> 'praecognitum'};
is noun(q{praecognitum})->singular,   q{praecognitum}  => q{singular: 'praecognitum' --> 'praecognitum'};
is noun(q{wolves})->singular, q{wolf}  => q{singular: 'wolves' --> 'wolf'};
is noun(q{wolf})->singular,   q{wolf}  => q{singular: 'wolf' --> 'wolf'};
is noun(q{osteoclastomata})->singular, q{osteoclastoma}  => q{singular: 'osteoclastomata' --> 'osteoclastoma'};
is noun(q{osteoclastoma})->singular,   q{osteoclastoma}  => q{singular: 'osteoclastoma' --> 'osteoclastoma'};
is noun(q{toruses})->singular, q{torus}  => q{singular: 'toruses' --> 'torus'};
is noun(q{torus})->singular,   q{torus}  => q{singular: 'torus' --> 'torus'};
is noun(q{lymphangiomata})->singular, q{lymphangioma}  => q{singular: 'lymphangiomata' --> 'lymphangioma'};
is noun(q{lymphangioma})->singular,   q{lymphangioma}  => q{singular: 'lymphangioma' --> 'lymphangioma'};
is noun(q{ngwee})->singular, q{ngwee}  => q{singular: 'ngwee' --> 'ngwee'};
is noun(q{haruspices})->singular, q{haruspex}  => q{singular: 'haruspices' --> 'haruspex'};
is noun(q{haruspex})->singular,   q{haruspex}  => q{singular: 'haruspex' --> 'haruspex'};
is noun(q{mythoi})->singular, q{mythos}  => q{singular: 'mythoi' --> 'mythos'};
is noun(q{mythos})->singular,   q{mythos}  => q{singular: 'mythos' --> 'mythos'};
is noun(q{loas})->singular, q{loa}  => q{singular: 'loas' --> 'loa'};
is noun(q{stichidia})->singular, q{stichidium}  => q{singular: 'stichidia' --> 'stichidium'};
is noun(q{stichidium})->singular,   q{stichidium}  => q{singular: 'stichidium' --> 'stichidium'};
is noun(q{satellites})->singular, q{satelles}  => q{singular: 'satellites' --> 'satelles'};
is noun(q{satelles})->singular,   q{satelles}  => q{singular: 'satelles' --> 'satelles'};
is noun(q{yuon})->singular, q{yuo}  => q{singular: 'yuon' --> 'yuo'};
is noun(q{yuo})->singular,   q{yuo}  => q{singular: 'yuo' --> 'yuo'};
is noun(q{plexus})->singular, q{plexus}  => q{singular: 'plexus' --> 'plexus'};
is noun(q{punti blanchi})->singular, q{punto blanco}  => q{singular: 'punti blanchi' --> 'punto blanco'};
is noun(q{punto blanco})->singular,   q{punto blanco}  => q{singular: 'punto blanco' --> 'punto blanco'};
is noun(q{flag staves})->singular, q{flag staff}  => q{singular: 'flag staves' --> 'flag staff'};
is noun(q{flag staff})->singular,   q{flag staff}  => q{singular: 'flag staff' --> 'flag staff'};
is noun(q{meatuses})->singular, q{meatus}  => q{singular: 'meatuses' --> 'meatus'};
is noun(q{shorts})->singular, q{shorts}  => q{singular: 'shorts' --> 'shorts'};
is noun(q{tegmenta})->singular, q{tegmentum}  => q{singular: 'tegmenta' --> 'tegmentum'};
is noun(q{tegmentum})->singular,   q{tegmentum}  => q{singular: 'tegmentum' --> 'tegmentum'};
is noun(q{vaalpens})->singular, q{vaalpens}  => q{singular: 'vaalpens' --> 'vaalpens'};
is noun(q{bons mots})->singular, q{bon mot}  => q{singular: 'bons mots' --> 'bon mot'};
is noun(q{bon mot})->singular,   q{bon mot}  => q{singular: 'bon mot' --> 'bon mot'};
is noun(q{ipse dixits})->singular, q{ipse dixit}  => q{singular: 'ipse dixits' --> 'ipse dixit'};
is noun(q{ipse dixit})->singular,   q{ipse dixit}  => q{singular: 'ipse dixit' --> 'ipse dixit'};
is noun(q{vaalpensen})->singular, q{vaalpens}  => q{singular: 'vaalpensen' --> 'vaalpens'};
is noun(q{uri})->singular, q{urus}  => q{singular: 'uri' --> 'urus'};
is noun(q{urus})->singular,   q{urus}  => q{singular: 'urus' --> 'urus'};
is noun(q{buboes})->singular, q{bubo}  => q{singular: 'buboes' --> 'bubo'};
is noun(q{bubo})->singular,   q{bubo}  => q{singular: 'bubo' --> 'bubo'};
is noun(q{beaux esprits})->singular, q{bel-esprit}  => q{singular: 'beaux esprits' --> 'bel-esprit'};
is noun(q{bel-esprit})->singular,   q{bel-esprit}  => q{singular: 'bel-esprit' --> 'bel-esprit'};
is noun(q{dolphinariums})->singular, q{dolphinarium}  => q{singular: 'dolphinariums' --> 'dolphinarium'};
is noun(q{dolphinarium})->singular,   q{dolphinarium}  => q{singular: 'dolphinarium' --> 'dolphinarium'};
is noun(q{zlotys})->singular, q{zloty}  => q{singular: 'zlotys' --> 'zloty'};
is noun(q{mackerel})->singular, q{mackerel}  => q{singular: 'mackerel' --> 'mackerel'};
is noun(q{Ningbos})->singular, q{Ningbo}  => q{singular: 'Ningbos' --> 'Ningbo'};
is noun(q{Ningbo})->singular,   q{Ningbo}  => q{singular: 'Ningbo' --> 'Ningbo'};
is noun(q{six star generals})->singular, q{six star general}  => q{singular: 'six star generals' --> 'six star general'};
is noun(q{six star general})->singular,   q{six star general}  => q{singular: 'six star general' --> 'six star general'};
is noun(q{micros})->singular, q{micro}  => q{singular: 'micros' --> 'micro'};
is noun(q{micro})->singular,   q{micro}  => q{singular: 'micro' --> 'micro'};
is noun(q{piani})->singular, q{piano}  => q{singular: 'piani' --> 'piano'};
is noun(q{piano})->singular,   q{piano}  => q{singular: 'piano' --> 'piano'};
is noun(q{confluvia})->singular, q{confluvium}  => q{singular: 'confluvia' --> 'confluvium'};
is noun(q{confluvium})->singular,   q{confluvium}  => q{singular: 'confluvium' --> 'confluvium'};
is noun(q{musas})->singular, q{musa}  => q{singular: 'musas' --> 'musa'};
is noun(q{musa})->singular,   q{musa}  => q{singular: 'musa' --> 'musa'};
is noun(q{maxillae})->singular, q{maxilla}  => q{singular: 'maxillae' --> 'maxilla'};
is noun(q{maxilla})->singular,   q{maxilla}  => q{singular: 'maxilla' --> 'maxilla'};
is noun(q{sets-to})->singular, q{set-to}  => q{singular: 'sets-to' --> 'set-to'};
is noun(q{set-to})->singular,   q{set-to}  => q{singular: 'set-to' --> 'set-to'};
is noun(q{spicula})->singular, q{spiculum}  => q{singular: 'spicula' --> 'spiculum'};
is noun(q{spiculum})->singular,   q{spiculum}  => q{singular: 'spiculum' --> 'spiculum'};
is noun(q{spheges})->singular, q{sphex}  => q{singular: 'spheges' --> 'sphex'};
is noun(q{sphex})->singular,   q{sphex}  => q{singular: 'sphex' --> 'sphex'};
is noun(q{Macassarese})->singular, q{Macassarese}  => q{singular: 'Macassarese' --> 'Macassarese'};
is noun(q{solidos})->singular, q{solidus}  => q{singular: 'solidos' --> 'solidus'};
is noun(q{solidus})->singular,   q{solidus}  => q{singular: 'solidus' --> 'solidus'};
is noun(q{chassis})->singular, q{chassis}  => q{singular: 'chassis' --> 'chassis'};
is noun(q{nymphae})->singular, q{nympha}  => q{singular: 'nymphae' --> 'nympha'};
is noun(q{nympha})->singular,   q{nympha}  => q{singular: 'nympha' --> 'nympha'};
is noun(q{limbos})->singular, q{limbo}  => q{singular: 'limbos' --> 'limbo'};
is noun(q{limbo})->singular,   q{limbo}  => q{singular: 'limbo' --> 'limbo'};
is noun(q{multigravidas})->singular, q{multigravida}  => q{singular: 'multigravidas' --> 'multigravida'};
is noun(q{multigravida})->singular,   q{multigravida}  => q{singular: 'multigravida' --> 'multigravida'};
is noun(q{parcs fermes})->singular, q{parc ferme}  => q{singular: 'parcs fermes' --> 'parc ferme'};
is noun(q{parc ferme})->singular,   q{parc ferme}  => q{singular: 'parc ferme' --> 'parc ferme'};
is noun(q{pseudopodia})->singular, q{pseudopodium}  => q{singular: 'pseudopodia' --> 'pseudopodium'};
is noun(q{pseudopodium})->singular,   q{pseudopodium}  => q{singular: 'pseudopodium' --> 'pseudopodium'};
is noun(q{felos-de-se})->singular, q{felo-de-se}  => q{singular: 'felos-de-se' --> 'felo-de-se'};
is noun(q{felo-de-se})->singular,   q{felo-de-se}  => q{singular: 'felo-de-se' --> 'felo-de-se'};
is noun(q{spermatoa})->singular, q{spermatoon}  => q{singular: 'spermatoa' --> 'spermatoon'};
is noun(q{spermatoon})->singular,   q{spermatoon}  => q{singular: 'spermatoon' --> 'spermatoon'};
is noun(q{leges humanae})->singular, q{lex humana}  => q{singular: 'leges humanae' --> 'lex humana'};
is noun(q{lex humana})->singular,   q{lex humana}  => q{singular: 'lex humana' --> 'lex humana'};
is noun(q{plethra})->singular, q{plethron}  => q{singular: 'plethra' --> 'plethron'};
is noun(q{plethron})->singular,   q{plethron}  => q{singular: 'plethron' --> 'plethron'};
is noun(q{lepromas})->singular, q{leproma}  => q{singular: 'lepromas' --> 'leproma'};
is noun(q{leproma})->singular,   q{leproma}  => q{singular: 'leproma' --> 'leproma'};
is noun(q{ritardandi})->singular, q{ritardando}  => q{singular: 'ritardandi' --> 'ritardando'};
is noun(q{ritardando})->singular,   q{ritardando}  => q{singular: 'ritardando' --> 'ritardando'};
is noun(q{scherzandos})->singular, q{scherzando}  => q{singular: 'scherzandos' --> 'scherzando'};
is noun(q{scherzando})->singular,   q{scherzando}  => q{singular: 'scherzando' --> 'scherzando'};
is noun(q{endotheliomata})->singular, q{endothelioma}  => q{singular: 'endotheliomata' --> 'endothelioma'};
is noun(q{endothelioma})->singular,   q{endothelioma}  => q{singular: 'endothelioma' --> 'endothelioma'};
is noun(q{plateaus})->singular, q{plateau}  => q{singular: 'plateaus' --> 'plateau'};
is noun(q{plateau})->singular,   q{plateau}  => q{singular: 'plateau' --> 'plateau'};
is noun(q{sceattas})->singular, q{sceat}  => q{singular: 'sceattas' --> 'sceat'};
is noun(q{sceat})->singular,   q{sceat}  => q{singular: 'sceat' --> 'sceat'};
is noun(q{seminia})->singular, q{seminium}  => q{singular: 'seminia' --> 'seminium'};
is noun(q{seminium})->singular,   q{seminium}  => q{singular: 'seminium' --> 'seminium'};
is noun(q{vedutas})->singular, q{veduta}  => q{singular: 'vedutas' --> 'veduta'};
is noun(q{veduta})->singular,   q{veduta}  => q{singular: 'veduta' --> 'veduta'};
is noun(q{intermaxillae})->singular, q{intermaxilla}  => q{singular: 'intermaxillae' --> 'intermaxilla'};
is noun(q{intermaxilla})->singular,   q{intermaxilla}  => q{singular: 'intermaxilla' --> 'intermaxilla'};
is noun(q{repla})->singular, q{replum}  => q{singular: 'repla' --> 'replum'};
is noun(q{replum})->singular,   q{replum}  => q{singular: 'replum' --> 'replum'};
is noun(q{brethren german})->singular, q{brother german}  => q{singular: 'brethren german' --> 'brother german'};
is noun(q{brother german})->singular,   q{brother german}  => q{singular: 'brother german' --> 'brother german'};
is noun(q{Tacomans})->singular, q{Tacoman}  => q{singular: 'Tacomans' --> 'Tacoman'};
is noun(q{Tacoman})->singular,   q{Tacoman}  => q{singular: 'Tacoman' --> 'Tacoman'};
is noun(q{miasmas})->singular, q{miasma}  => q{singular: 'miasmas' --> 'miasma'};
is noun(q{miasma})->singular,   q{miasma}  => q{singular: 'miasma' --> 'miasma'};
is noun(q{principia})->singular, q{principium}  => q{singular: 'principia' --> 'principium'};
is noun(q{principium})->singular,   q{principium}  => q{singular: 'principium' --> 'principium'};
is noun(q{digitalises})->singular, q{digitalis}  => q{singular: 'digitalises' --> 'digitalis'};
is noun(q{digitalis})->singular,   q{digitalis}  => q{singular: 'digitalis' --> 'digitalis'};
is noun(q{aquaria})->singular, q{aquarium}  => q{singular: 'aquaria' --> 'aquarium'};
is noun(q{aquarium})->singular,   q{aquarium}  => q{singular: 'aquarium' --> 'aquarium'};
is noun(q{finger-ends})->singular, q{finger-end}  => q{singular: 'finger-ends' --> 'finger-end'};
is noun(q{finger-end})->singular,   q{finger-end}  => q{singular: 'finger-end' --> 'finger-end'};
is noun(q{knoppers})->singular, q{knopper}  => q{singular: 'knoppers' --> 'knopper'};
is noun(q{knopper})->singular,   q{knopper}  => q{singular: 'knopper' --> 'knopper'};
is noun(q{brothers})->singular, q{brother}  => q{singular: 'brothers' --> 'brother'};
is noun(q{brother})->singular,   q{brother}  => q{singular: 'brother' --> 'brother'};
is noun(q{Monacos})->singular, q{Monaco}  => q{singular: 'Monacos' --> 'Monaco'};
is noun(q{Monaco})->singular,   q{Monaco}  => q{singular: 'Monaco' --> 'Monaco'};
is noun(q{leprosaria})->singular, q{leprosarium}  => q{singular: 'leprosaria' --> 'leprosarium'};
is noun(q{leprosarium})->singular,   q{leprosarium}  => q{singular: 'leprosarium' --> 'leprosarium'};
is noun(q{criteria})->singular, q{criterion}  => q{singular: 'criteria' --> 'criterion'};
is noun(q{criterion})->singular,   q{criterion}  => q{singular: 'criterion' --> 'criterion'};
is noun(q{lineae})->singular, q{linea}  => q{singular: 'lineae' --> 'linea'};
is noun(q{linea})->singular,   q{linea}  => q{singular: 'linea' --> 'linea'};
is noun(q{cognoscenti})->singular, q{cognoscente}  => q{singular: 'cognoscenti' --> 'cognoscente'};
is noun(q{cognoscente})->singular,   q{cognoscente}  => q{singular: 'cognoscente' --> 'cognoscente'};
is noun(q{palpebrae})->singular, q{palpebra}  => q{singular: 'palpebrae' --> 'palpebra'};
is noun(q{palpebra})->singular,   q{palpebra}  => q{singular: 'palpebra' --> 'palpebra'};
is noun(q{plankton})->singular, q{plankter}  => q{singular: 'plankton' --> 'plankter'};
is noun(q{plankter})->singular,   q{plankter}  => q{singular: 'plankter' --> 'plankter'};
is noun(q{senes})->singular, q{senex}  => q{singular: 'senes' --> 'senex'};
is noun(q{senex})->singular,   q{senex}  => q{singular: 'senex' --> 'senex'};
is noun(q{sphagnums})->singular, q{sphagnum}  => q{singular: 'sphagnums' --> 'sphagnum'};
is noun(q{sphagnum})->singular,   q{sphagnum}  => q{singular: 'sphagnum' --> 'sphagnum'};
is noun(q{duumviri})->singular, q{duumvir}  => q{singular: 'duumviri' --> 'duumvir'};
is noun(q{duumvir})->singular,   q{duumvir}  => q{singular: 'duumvir' --> 'duumvir'};
is noun(q{nucleoluses})->singular, q{nucleolus}  => q{singular: 'nucleoluses' --> 'nucleolus'};
is noun(q{nucleolus})->singular,   q{nucleolus}  => q{singular: 'nucleolus' --> 'nucleolus'};
is noun(q{hymnaria})->singular, q{hymnarium}  => q{singular: 'hymnaria' --> 'hymnarium'};
is noun(q{hymnarium})->singular,   q{hymnarium}  => q{singular: 'hymnarium' --> 'hymnarium'};
is noun(q{bursae})->singular, q{bursa}  => q{singular: 'bursae' --> 'bursa'};
is noun(q{bursa})->singular,   q{bursa}  => q{singular: 'bursa' --> 'bursa'};
is noun(q{chromonemata})->singular, q{chromonema}  => q{singular: 'chromonemata' --> 'chromonema'};
is noun(q{chromonema})->singular,   q{chromonema}  => q{singular: 'chromonema' --> 'chromonema'};
is noun(q{3-star generals})->singular, q{3-star general}  => q{singular: '3-star generals' --> '3-star general'};
is noun(q{3-star general})->singular,   q{3-star general}  => q{singular: '3-star general' --> '3-star general'};
is noun(q{sheep})->singular, q{sheep}  => q{singular: 'sheep' --> 'sheep'};
is noun(q{fibulas})->singular, q{fibula}  => q{singular: 'fibulas' --> 'fibula'};
is noun(q{fibula})->singular,   q{fibula}  => q{singular: 'fibula' --> 'fibula'};
is noun(q{starosti})->singular, q{starosta}  => q{singular: 'starosti' --> 'starosta'};
is noun(q{starosta})->singular,   q{starosta}  => q{singular: 'starosta' --> 'starosta'};
is noun(q{chapplies})->singular, q{chapplis}  => q{singular: 'chapplies' --> 'chapplis'};
is noun(q{chapplis})->singular,   q{chapplis}  => q{singular: 'chapplis' --> 'chapplis'};
is noun(q{calluses})->singular, q{callus}  => q{singular: 'calluses' --> 'callus'};
is noun(q{callus})->singular,   q{callus}  => q{singular: 'callus' --> 'callus'};
is noun(q{oxyurides})->singular, q{oxyuris}  => q{singular: 'oxyurides' --> 'oxyuris'};
is noun(q{oxyuris})->singular,   q{oxyuris}  => q{singular: 'oxyuris' --> 'oxyuris'};
is noun(q{zoeas})->singular, q{zoea}  => q{singular: 'zoeas' --> 'zoea'};
is noun(q{zoea})->singular,   q{zoea}  => q{singular: 'zoea' --> 'zoea'};
is noun(q{alti})->singular, q{alto}  => q{singular: 'alti' --> 'alto'};
is noun(q{alto})->singular,   q{alto}  => q{singular: 'alto' --> 'alto'};
is noun(q{conoscenti})->singular, q{conoscente}  => q{singular: 'conoscenti' --> 'conoscente'};
is noun(q{conoscente})->singular,   q{conoscente}  => q{singular: 'conoscente' --> 'conoscente'};
is noun(q{osteomata})->singular, q{osteoma}  => q{singular: 'osteomata' --> 'osteoma'};
is noun(q{osteoma})->singular,   q{osteoma}  => q{singular: 'osteoma' --> 'osteoma'};
is noun(q{samboes})->singular, q{sambo}  => q{singular: 'samboes' --> 'sambo'};
is noun(q{sambo})->singular,   q{sambo}  => q{singular: 'sambo' --> 'sambo'};
is noun(q{Borghese})->singular, q{Borghese}  => q{singular: 'Borghese' --> 'Borghese'};
is noun(q{hake})->singular, q{hake}  => q{singular: 'hake' --> 'hake'};
is noun(q{dace})->singular, q{dace}  => q{singular: 'dace' --> 'dace'};
is noun(q{cuspides})->singular, q{cuspis}  => q{singular: 'cuspides' --> 'cuspis'};
is noun(q{cuspis})->singular,   q{cuspis}  => q{singular: 'cuspis' --> 'cuspis'};
is noun(q{septemviri})->singular, q{septemvir}  => q{singular: 'septemviri' --> 'septemvir'};
is noun(q{septemvir})->singular,   q{septemvir}  => q{singular: 'septemvir' --> 'septemvir'};
is noun(q{bierstubes})->singular, q{bierstube}  => q{singular: 'bierstubes' --> 'bierstube'};
is noun(q{bierstube})->singular,   q{bierstube}  => q{singular: 'bierstube' --> 'bierstube'};
is noun(q{magili})->singular, q{magilus}  => q{singular: 'magili' --> 'magilus'};
is noun(q{magilus})->singular,   q{magilus}  => q{singular: 'magilus' --> 'magilus'};
is noun(q{scotomata})->singular, q{scotoma}  => q{singular: 'scotomata' --> 'scotoma'};
is noun(q{scotoma})->singular,   q{scotoma}  => q{singular: 'scotoma' --> 'scotoma'};
is noun(q{papulae})->singular, q{papula}  => q{singular: 'papulae' --> 'papula'};
is noun(q{papula})->singular,   q{papula}  => q{singular: 'papula' --> 'papula'};
is noun(q{vibratos})->singular, q{vibrato}  => q{singular: 'vibratos' --> 'vibrato'};
is noun(q{vibrato})->singular,   q{vibrato}  => q{singular: 'vibrato' --> 'vibrato'};
is noun(q{cyathi})->singular, q{cyathus}  => q{singular: 'cyathi' --> 'cyathus'};
is noun(q{cyathus})->singular,   q{cyathus}  => q{singular: 'cyathus' --> 'cyathus'};
is noun(q{sarissae})->singular, q{sarissa}  => q{singular: 'sarissae' --> 'sarissa'};
is noun(q{sarissa})->singular,   q{sarissa}  => q{singular: 'sarissa' --> 'sarissa'};
is noun(q{prothallia})->singular, q{prothallium}  => q{singular: 'prothallia' --> 'prothallium'};
is noun(q{prothallium})->singular,   q{prothallium}  => q{singular: 'prothallium' --> 'prothallium'};
is noun(q{auslesen})->singular, q{auslese}  => q{singular: 'auslesen' --> 'auslese'};
is noun(q{auslese})->singular,   q{auslese}  => q{singular: 'auslese' --> 'auslese'};
is noun(q{tetrapleura})->singular, q{tetrapleuron}  => q{singular: 'tetrapleura' --> 'tetrapleuron'};
is noun(q{tetrapleuron})->singular,   q{tetrapleuron}  => q{singular: 'tetrapleuron' --> 'tetrapleuron'};
is noun(q{trabeculae})->singular, q{trabecula}  => q{singular: 'trabeculae' --> 'trabecula'};
is noun(q{trabecula})->singular,   q{trabecula}  => q{singular: 'trabecula' --> 'trabecula'};
is noun(q{lacunars})->singular, q{lacunar}  => q{singular: 'lacunars' --> 'lacunar'};
is noun(q{lacunar})->singular,   q{lacunar}  => q{singular: 'lacunar' --> 'lacunar'};
is noun(q{giunchi})->singular, q{giuncus}  => q{singular: 'giunchi' --> 'giuncus'};
is noun(q{giuncus})->singular,   q{giuncus}  => q{singular: 'giuncus' --> 'giuncus'};
is noun(q{Bamakos})->singular, q{Bamako}  => q{singular: 'Bamakos' --> 'Bamako'};
is noun(q{Bamako})->singular,   q{Bamako}  => q{singular: 'Bamako' --> 'Bamako'};
is noun(q{ses})->singular, q{sis}  => q{singular: 'ses' --> 'sis'};
is noun(q{sis})->singular,   q{sis}  => q{singular: 'sis' --> 'sis'};
is noun(q{microfiche})->singular, q{microfiche}  => q{singular: 'microfiche' --> 'microfiche'};
is noun(q{impetus})->singular, q{impetus}  => q{singular: 'impetus' --> 'impetus'};
is noun(q{hemangiomas})->singular, q{hemangioma}  => q{singular: 'hemangiomas' --> 'hemangioma'};
is noun(q{hemangioma})->singular,   q{hemangioma}  => q{singular: 'hemangioma' --> 'hemangioma'};
is noun(q{maxima})->singular, q{maximum}  => q{singular: 'maxima' --> 'maximum'};
is noun(q{maximum})->singular,   q{maximum}  => q{singular: 'maximum' --> 'maximum'};
is noun(q{hooves})->singular, q{hoof}  => q{singular: 'hooves' --> 'hoof'};
is noun(q{hoof})->singular,   q{hoof}  => q{singular: 'hoof' --> 'hoof'};
is noun(q{tegulae})->singular, q{tegula}  => q{singular: 'tegulae' --> 'tegula'};
is noun(q{tegula})->singular,   q{tegula}  => q{singular: 'tegula' --> 'tegula'};
is noun(q{formulas})->singular, q{formula}  => q{singular: 'formulas' --> 'formula'};
is noun(q{formula})->singular,   q{formula}  => q{singular: 'formula' --> 'formula'};
is noun(q{tsubos})->singular, q{tsubo}  => q{singular: 'tsubos' --> 'tsubo'};
is noun(q{descripta})->singular, q{descriptum}  => q{singular: 'descripta' --> 'descriptum'};
is noun(q{descriptum})->singular,   q{descriptum}  => q{singular: 'descriptum' --> 'descriptum'};
is noun(q{bodegones})->singular, q{bodegon}  => q{singular: 'bodegones' --> 'bodegon'};
is noun(q{bodegon})->singular,   q{bodegon}  => q{singular: 'bodegon' --> 'bodegon'};
is noun(q{gymnasiums})->singular, q{gymnasium}  => q{singular: 'gymnasiums' --> 'gymnasium'};
is noun(q{gymnasium})->singular,   q{gymnasium}  => q{singular: 'gymnasium' --> 'gymnasium'};
is noun(q{matzot})->singular, q{matzah}  => q{singular: 'matzot' --> 'matzah'};
is noun(q{matzah})->singular,   q{matzah}  => q{singular: 'matzah' --> 'matzah'};
is noun(q{Harlemese})->singular, q{Harlemese}  => q{singular: 'Harlemese' --> 'Harlemese'};
is noun(q{dumkas})->singular, q{dumka}  => q{singular: 'dumkas' --> 'dumka'};
is noun(q{dumka})->singular,   q{dumka}  => q{singular: 'dumka' --> 'dumka'};
is noun(q{Torinos})->singular, q{Torino}  => q{singular: 'Torinos' --> 'Torino'};
is noun(q{Torino})->singular,   q{Torino}  => q{singular: 'Torino' --> 'Torino'};
is noun(q{lord-lieutenants})->singular, q{lord-lieutenant}  => q{singular: 'lord-lieutenants' --> 'lord-lieutenant'};
is noun(q{lord-lieutenant})->singular,   q{lord-lieutenant}  => q{singular: 'lord-lieutenant' --> 'lord-lieutenant'};
is noun(q{sphaerideum})->singular, q{sphaeridium}  => q{singular: 'sphaerideum' --> 'sphaeridium'};
is noun(q{sphaeridium})->singular,   q{sphaeridium}  => q{singular: 'sphaeridium' --> 'sphaeridium'};
is noun(q{blues})->singular, q{blue}  => q{singular: 'blues' --> 'blue'};
is noun(q{blue})->singular,   q{blue}  => q{singular: 'blue' --> 'blue'};
is noun(q{imagos})->singular, q{imago}  => q{singular: 'imagos' --> 'imago'};
is noun(q{imago})->singular,   q{imago}  => q{singular: 'imago' --> 'imago'};
is noun(q{labra})->singular, q{labrum}  => q{singular: 'labra' --> 'labrum'};
is noun(q{labrum})->singular,   q{labrum}  => q{singular: 'labrum' --> 'labrum'};
is noun(q{solstitia})->singular, q{solstitium}  => q{singular: 'solstitia' --> 'solstitium'};
is noun(q{solstitium})->singular,   q{solstitium}  => q{singular: 'solstitium' --> 'solstitium'};
is noun(q{rems})->singular, q{rem}  => q{singular: 'rems' --> 'rem'};
is noun(q{statuae})->singular, q{statua}  => q{singular: 'statuae' --> 'statua'};
is noun(q{statua})->singular,   q{statua}  => q{singular: 'statua' --> 'statua'};
is noun(q{apparatchiks})->singular, q{apparatchik}  => q{singular: 'apparatchiks' --> 'apparatchik'};
is noun(q{apparatchik})->singular,   q{apparatchik}  => q{singular: 'apparatchik' --> 'apparatchik'};
is noun(q{deposita})->singular, q{depositum}  => q{singular: 'deposita' --> 'depositum'};
is noun(q{depositum})->singular,   q{depositum}  => q{singular: 'depositum' --> 'depositum'};
is noun(q{scriptoriums})->singular, q{scriptorium}  => q{singular: 'scriptoriums' --> 'scriptorium'};
is noun(q{scriptorium})->singular,   q{scriptorium}  => q{singular: 'scriptorium' --> 'scriptorium'};
is noun(q{Mexicos})->singular, q{Mexico}  => q{singular: 'Mexicos' --> 'Mexico'};
is noun(q{Mexico})->singular,   q{Mexico}  => q{singular: 'Mexico' --> 'Mexico'};
is noun(q{paisas})->singular, q{paisa}  => q{singular: 'paisas' --> 'paisa'};
is noun(q{paisa})->singular,   q{paisa}  => q{singular: 'paisa' --> 'paisa'};
is noun(q{species})->singular, q{species}  => q{singular: 'species' --> 'species'};
is noun(q{caryatides})->singular, q{caryatid}  => q{singular: 'caryatides' --> 'caryatid'};
is noun(q{caryatid})->singular,   q{caryatid}  => q{singular: 'caryatid' --> 'caryatid'};
is noun(q{branchiopoda})->singular, q{branchiopod}  => q{singular: 'branchiopoda' --> 'branchiopod'};
is noun(q{branchiopod})->singular,   q{branchiopod}  => q{singular: 'branchiopod' --> 'branchiopod'};
is noun(q{trellises})->singular, q{trellis}  => q{singular: 'trellises' --> 'trellis'};
is noun(q{trellis})->singular,   q{trellis}  => q{singular: 'trellis' --> 'trellis'};
is noun(q{teals})->singular, q{teal}  => q{singular: 'teals' --> 'teal'};
is noun(q{theologoumena})->singular, q{theologoumenon}  => q{singular: 'theologoumena' --> 'theologoumenon'};
is noun(q{theologoumenon})->singular,   q{theologoumenon}  => q{singular: 'theologoumenon' --> 'theologoumenon'};
is noun(q{morosi})->singular, q{moroso}  => q{singular: 'morosi' --> 'moroso'};
is noun(q{moroso})->singular,   q{moroso}  => q{singular: 'moroso' --> 'moroso'};
is noun(q{gorgoniae})->singular, q{gorgonia}  => q{singular: 'gorgoniae' --> 'gorgonia'};
is noun(q{gorgonia})->singular,   q{gorgonia}  => q{singular: 'gorgonia' --> 'gorgonia'};
is noun(q{brothers-german})->singular, q{brother-german}  => q{singular: 'brothers-german' --> 'brother-german'};
is noun(q{brother-german})->singular,   q{brother-german}  => q{singular: 'brother-german' --> 'brother-german'};
is noun(q{convolvuli})->singular, q{convolvulus}  => q{singular: 'convolvuli' --> 'convolvulus'};
is noun(q{convolvulus})->singular,   q{convolvulus}  => q{singular: 'convolvulus' --> 'convolvulus'};
is noun(q{turrones})->singular, q{turron}  => q{singular: 'turrones' --> 'turron'};
is noun(q{turron})->singular,   q{turron}  => q{singular: 'turron' --> 'turron'};
is noun(q{octopuses})->singular, q{octopus}  => q{singular: 'octopuses' --> 'octopus'};
is noun(q{octopus})->singular,   q{octopus}  => q{singular: 'octopus' --> 'octopus'};
is noun(q{oxymorons})->singular, q{oxymoron}  => q{singular: 'oxymorons' --> 'oxymoron'};
is noun(q{oxymoron})->singular,   q{oxymoron}  => q{singular: 'oxymoron' --> 'oxymoron'};
is noun(q{mucros})->singular, q{mucro}  => q{singular: 'mucros' --> 'mucro'};
is noun(q{mucro})->singular,   q{mucro}  => q{singular: 'mucro' --> 'mucro'};
is noun(q{parhelions})->singular, q{parhelion}  => q{singular: 'parhelions' --> 'parhelion'};
is noun(q{parhelion})->singular,   q{parhelion}  => q{singular: 'parhelion' --> 'parhelion'};
is noun(q{breakaways})->singular, q{breakaway}  => q{singular: 'breakaways' --> 'breakaway'};
is noun(q{breakaway})->singular,   q{breakaway}  => q{singular: 'breakaway' --> 'breakaway'};
is noun(q{frati})->singular, q{frate}  => q{singular: 'frati' --> 'frate'};
is noun(q{frate})->singular,   q{frate}  => q{singular: 'frate' --> 'frate'};
is noun(q{stasimons})->singular, q{stasimon}  => q{singular: 'stasimons' --> 'stasimon'};
is noun(q{stasimon})->singular,   q{stasimon}  => q{singular: 'stasimon' --> 'stasimon'};
is noun(q{aristae})->singular, q{arista}  => q{singular: 'aristae' --> 'arista'};
is noun(q{arista})->singular,   q{arista}  => q{singular: 'arista' --> 'arista'};
is noun(q{headquarters})->singular, q{headquarters}  => q{singular: 'headquarters' --> 'headquarters'};
is noun(q{turrons})->singular, q{turron}  => q{singular: 'turrons' --> 'turron'};
is noun(q{turron})->singular,   q{turron}  => q{singular: 'turron' --> 'turron'};
is noun(q{librettos})->singular, q{libretto}  => q{singular: 'librettos' --> 'libretto'};
is noun(q{libretto})->singular,   q{libretto}  => q{singular: 'libretto' --> 'libretto'};
is noun(q{conversazioni})->singular, q{conversazione}  => q{singular: 'conversazioni' --> 'conversazione'};
is noun(q{conversazione})->singular,   q{conversazione}  => q{singular: 'conversazione' --> 'conversazione'};
is noun(q{precis})->singular, q{precis}  => q{singular: 'precis' --> 'precis'};
is noun(q{signa})->singular, q{signum}  => q{singular: 'signa' --> 'signum'};
is noun(q{signum})->singular,   q{signum}  => q{singular: 'signum' --> 'signum'};
is noun(q{pyramidions})->singular, q{pyramidion}  => q{singular: 'pyramidions' --> 'pyramidion'};
is noun(q{pyramidion})->singular,   q{pyramidion}  => q{singular: 'pyramidion' --> 'pyramidion'};
is noun(q{vortices})->singular, q{vortex}  => q{singular: 'vortices' --> 'vortex'};
is noun(q{vortex})->singular,   q{vortex}  => q{singular: 'vortex' --> 'vortex'};
is noun(q{elves})->singular, q{elf}  => q{singular: 'elves' --> 'elf'};
is noun(q{elf})->singular,   q{elf}  => q{singular: 'elf' --> 'elf'};
is noun(q{Iquicos})->singular, q{Iquico}  => q{singular: 'Iquicos' --> 'Iquico'};
is noun(q{Iquico})->singular,   q{Iquico}  => q{singular: 'Iquico' --> 'Iquico'};
is noun(q{stryddae})->singular, q{stryddag}  => q{singular: 'stryddae' --> 'stryddag'};
is noun(q{stryddag})->singular,   q{stryddag}  => q{singular: 'stryddag' --> 'stryddag'};
is noun(q{scirrhi})->singular, q{scirrhus}  => q{singular: 'scirrhi' --> 'scirrhus'};
is noun(q{scirrhus})->singular,   q{scirrhus}  => q{singular: 'scirrhus' --> 'scirrhus'};
is noun(q{charismas})->singular, q{charisma}  => q{singular: 'charismas' --> 'charisma'};
is noun(q{charisma})->singular,   q{charisma}  => q{singular: 'charisma' --> 'charisma'};
is noun(q{vers libres})->singular, q{vers libre}  => q{singular: 'vers libres' --> 'vers libre'};
is noun(q{vers libre})->singular,   q{vers libre}  => q{singular: 'vers libre' --> 'vers libre'};
is noun(q{strategoi})->singular, q{strategos}  => q{singular: 'strategoi' --> 'strategos'};
is noun(q{strategos})->singular,   q{strategos}  => q{singular: 'strategos' --> 'strategos'};
is noun(q{stoas})->singular, q{stoa}  => q{singular: 'stoas' --> 'stoa'};
is noun(q{stoa})->singular,   q{stoa}  => q{singular: 'stoa' --> 'stoa'};
is noun(q{concertinos})->singular, q{concertino}  => q{singular: 'concertinos' --> 'concertino'};
is noun(q{concertino})->singular,   q{concertino}  => q{singular: 'concertino' --> 'concertino'};
is noun(q{cosmoses})->singular, q{cosmos}  => q{singular: 'cosmoses' --> 'cosmos'};
is noun(q{cosmos})->singular,   q{cosmos}  => q{singular: 'cosmos' --> 'cosmos'};
is noun(q{whoever})->singular, q{whoever}  => q{singular: 'whoever' --> 'whoever'};
is noun(q{ganglions})->singular, q{ganglion}  => q{singular: 'ganglions' --> 'ganglion'};
is noun(q{ganglion})->singular,   q{ganglion}  => q{singular: 'ganglion' --> 'ganglion'};
is noun(q{bemas})->singular, q{bema}  => q{singular: 'bemas' --> 'bema'};
is noun(q{bema})->singular,   q{bema}  => q{singular: 'bema' --> 'bema'};
is noun(q{gastrocnemii})->singular, q{gastrocnemius}  => q{singular: 'gastrocnemii' --> 'gastrocnemius'};
is noun(q{gastrocnemius})->singular,   q{gastrocnemius}  => q{singular: 'gastrocnemius' --> 'gastrocnemius'};
is noun(q{terminuses})->singular, q{terminus}  => q{singular: 'terminuses' --> 'terminus'};
is noun(q{terminus})->singular,   q{terminus}  => q{singular: 'terminus' --> 'terminus'};
is noun(q{triradii})->singular, q{triradius}  => q{singular: 'triradii' --> 'triradius'};
is noun(q{triradius})->singular,   q{triradius}  => q{singular: 'triradius' --> 'triradius'};
is noun(q{snipe})->singular, q{snipe}  => q{singular: 'snipe' --> 'snipe'};
is noun(q{zoa})->singular, q{zoon}  => q{singular: 'zoa' --> 'zoon'};
is noun(q{zoon})->singular,   q{zoon}  => q{singular: 'zoon' --> 'zoon'};
is noun(q{tipulae})->singular, q{tipula}  => q{singular: 'tipulae' --> 'tipula'};
is noun(q{tipula})->singular,   q{tipula}  => q{singular: 'tipula' --> 'tipula'};
is noun(q{foramens})->singular, q{foramen}  => q{singular: 'foramens' --> 'foramen'};
is noun(q{foramen})->singular,   q{foramen}  => q{singular: 'foramen' --> 'foramen'};
is noun(q{abscissae})->singular, q{abscissa}  => q{singular: 'abscissae' --> 'abscissa'};
is noun(q{abscissa})->singular,   q{abscissa}  => q{singular: 'abscissa' --> 'abscissa'};
is noun(q{neurinomas})->singular, q{neurinoma}  => q{singular: 'neurinomas' --> 'neurinoma'};
is noun(q{neurinoma})->singular,   q{neurinoma}  => q{singular: 'neurinoma' --> 'neurinoma'};
is noun(q{ricercars})->singular, q{ricercar}  => q{singular: 'ricercars' --> 'ricercar'};
is noun(q{ricercar})->singular,   q{ricercar}  => q{singular: 'ricercar' --> 'ricercar'};
is noun(q{scapulas})->singular, q{scapula}  => q{singular: 'scapulas' --> 'scapula'};
is noun(q{scapula})->singular,   q{scapula}  => q{singular: 'scapula' --> 'scapula'};
is noun(q{mongooses})->singular, q{mongoose}  => q{singular: 'mongooses' --> 'mongoose'};
is noun(q{mongoose})->singular,   q{mongoose}  => q{singular: 'mongoose' --> 'mongoose'};
is noun(q{humeri})->singular, q{humerus}  => q{singular: 'humeri' --> 'humerus'};
is noun(q{humerus})->singular,   q{humerus}  => q{singular: 'humerus' --> 'humerus'};
is noun(q{rhizomas})->singular, q{rhizoma}  => q{singular: 'rhizomas' --> 'rhizoma'};
is noun(q{rhizoma})->singular,   q{rhizoma}  => q{singular: 'rhizoma' --> 'rhizoma'};
is noun(q{fasciae})->singular, q{fascia}  => q{singular: 'fasciae' --> 'fascia'};
is noun(q{fascia})->singular,   q{fascia}  => q{singular: 'fascia' --> 'fascia'};
is noun(q{ottomans})->singular, q{ottoman}  => q{singular: 'ottomans' --> 'ottoman'};
is noun(q{ottoman})->singular,   q{ottoman}  => q{singular: 'ottoman' --> 'ottoman'};
is noun(q{we})->singular, q{I}  => q{singular: 'we' --> 'I'};
is noun(q{I})->singular,   q{I}  => q{singular: 'I' --> 'I'};
is noun(q{facienda})->singular, q{faciendum}  => q{singular: 'facienda' --> 'faciendum'};
is noun(q{faciendum})->singular,   q{faciendum}  => q{singular: 'faciendum' --> 'faciendum'};
is noun(q{sarcinae})->singular, q{sarcina}  => q{singular: 'sarcinae' --> 'sarcina'};
is noun(q{sarcina})->singular,   q{sarcina}  => q{singular: 'sarcina' --> 'sarcina'};
is noun(q{corgys})->singular, q{corgy}  => q{singular: 'corgys' --> 'corgy'};
is noun(q{corgy})->singular,   q{corgy}  => q{singular: 'corgy' --> 'corgy'};
is noun(q{ragazzi})->singular, q{ragazzo}  => q{singular: 'ragazzi' --> 'ragazzo'};
is noun(q{ragazzo})->singular,   q{ragazzo}  => q{singular: 'ragazzo' --> 'ragazzo'};
is noun(q{Romagnese})->singular, q{Romagnese}  => q{singular: 'Romagnese' --> 'Romagnese'};
is noun(q{soshi})->singular, q{soshi}  => q{singular: 'soshi' --> 'soshi'};
is noun(q{conys})->singular, q{cony}  => q{singular: 'conys' --> 'cony'};
is noun(q{cony})->singular,   q{cony}  => q{singular: 'cony' --> 'cony'};
is noun(q{Orinocos})->singular, q{Orinoco}  => q{singular: 'Orinocos' --> 'Orinoco'};
is noun(q{Orinoco})->singular,   q{Orinoco}  => q{singular: 'Orinoco' --> 'Orinoco'};
is noun(q{celiae})->singular, q{celia}  => q{singular: 'celiae' --> 'celia'};
is noun(q{celia})->singular,   q{celia}  => q{singular: 'celia' --> 'celia'};
is noun(q{epididymides})->singular, q{epididymis}  => q{singular: 'epididymides' --> 'epididymis'};
is noun(q{epididymis})->singular,   q{epididymis}  => q{singular: 'epididymis' --> 'epididymis'};
is noun(q{rara avises})->singular, q{rara avis}  => q{singular: 'rara avises' --> 'rara avis'};
is noun(q{rara avis})->singular,   q{rara avis}  => q{singular: 'rara avis' --> 'rara avis'};
is noun(q{hapax legomenons})->singular, q{hapax legomenon}  => q{singular: 'hapax legomenons' --> 'hapax legomenon'};
is noun(q{hapax legomenon})->singular,   q{hapax legomenon}  => q{singular: 'hapax legomenon' --> 'hapax legomenon'};
is noun(q{taenias})->singular, q{taenia}  => q{singular: 'taenias' --> 'taenia'};
is noun(q{taenia})->singular,   q{taenia}  => q{singular: 'taenia' --> 'taenia'};
is noun(q{phyla})->singular, q{phylum}  => q{singular: 'phyla' --> 'phylum'};
is noun(q{phylum})->singular,   q{phylum}  => q{singular: 'phylum' --> 'phylum'};
is noun(q{stelas})->singular, q{stela}  => q{singular: 'stelas' --> 'stela'};
is noun(q{stela})->singular,   q{stela}  => q{singular: 'stela' --> 'stela'};
is noun(q{divertimentos})->singular, q{divertimento}  => q{singular: 'divertimentos' --> 'divertimento'};
is noun(q{divertimento})->singular,   q{divertimento}  => q{singular: 'divertimento' --> 'divertimento'};
is noun(q{penises})->singular, q{penis}  => q{singular: 'penises' --> 'penis'};
is noun(q{penis})->singular,   q{penis}  => q{singular: 'penis' --> 'penis'};
is noun(q{bullae})->singular, q{bulla}  => q{singular: 'bullae' --> 'bulla'};
is noun(q{bulla})->singular,   q{bulla}  => q{singular: 'bulla' --> 'bulla'};
is noun(q{waldoes})->singular, q{waldo}  => q{singular: 'waldoes' --> 'waldo'};
is noun(q{waldo})->singular,   q{waldo}  => q{singular: 'waldo' --> 'waldo'};
is noun(q{bozzetti})->singular, q{bozzetto}  => q{singular: 'bozzetti' --> 'bozzetto'};
is noun(q{bozzetto})->singular,   q{bozzetto}  => q{singular: 'bozzetto' --> 'bozzetto'};
is noun(q{Muranese})->singular, q{Muranese}  => q{singular: 'Muranese' --> 'Muranese'};
is noun(q{thesauruses})->singular, q{thesaurus}  => q{singular: 'thesauruses' --> 'thesaurus'};
is noun(q{thesaurus})->singular,   q{thesaurus}  => q{singular: 'thesaurus' --> 'thesaurus'};
is noun(q{modii})->singular, q{modius}  => q{singular: 'modii' --> 'modius'};
is noun(q{modius})->singular,   q{modius}  => q{singular: 'modius' --> 'modius'};
is noun(q{sacra})->singular, q{sacrum}  => q{singular: 'sacra' --> 'sacrum'};
is noun(q{sacrum})->singular,   q{sacrum}  => q{singular: 'sacrum' --> 'sacrum'};
is noun(q{jumbos})->singular, q{jumbo}  => q{singular: 'jumbos' --> 'jumbo'};
is noun(q{jumbo})->singular,   q{jumbo}  => q{singular: 'jumbo' --> 'jumbo'};
is noun(q{nephridia})->singular, q{nephridium}  => q{singular: 'nephridia' --> 'nephridium'};
is noun(q{nephridium})->singular,   q{nephridium}  => q{singular: 'nephridium' --> 'nephridium'};
is noun(q{osmeteria})->singular, q{osmeterium}  => q{singular: 'osmeteria' --> 'osmeterium'};
is noun(q{osmeterium})->singular,   q{osmeterium}  => q{singular: 'osmeterium' --> 'osmeterium'};
is noun(q{menus})->singular, q{menu}  => q{singular: 'menus' --> 'menu'};
is noun(q{menu})->singular,   q{menu}  => q{singular: 'menu' --> 'menu'};
is noun(q{ballate})->singular, q{ballata}  => q{singular: 'ballate' --> 'ballata'};
is noun(q{ballata})->singular,   q{ballata}  => q{singular: 'ballata' --> 'ballata'};
is noun(q{cilantros})->singular, q{cilantro}  => q{singular: 'cilantros' --> 'cilantro'};
is noun(q{cilantro})->singular,   q{cilantro}  => q{singular: 'cilantro' --> 'cilantro'};
is noun(q{ovula})->singular, q{ovulum}  => q{singular: 'ovula' --> 'ovulum'};
is noun(q{ovulum})->singular,   q{ovulum}  => q{singular: 'ovulum' --> 'ovulum'};
is noun(q{culs de sac})->singular, q{cul de sac}  => q{singular: 'culs de sac' --> 'cul de sac'};
is noun(q{cul de sac})->singular,   q{cul de sac}  => q{singular: 'cul de sac' --> 'cul de sac'};
is noun(q{valleculae})->singular, q{vallecula}  => q{singular: 'valleculae' --> 'vallecula'};
is noun(q{vallecula})->singular,   q{vallecula}  => q{singular: 'vallecula' --> 'vallecula'};
is noun(q{lemurs})->singular, q{lemur}  => q{singular: 'lemurs' --> 'lemur'};
is noun(q{lemur})->singular,   q{lemur}  => q{singular: 'lemur' --> 'lemur'};
is noun(q{stigmariae})->singular, q{stigmaria}  => q{singular: 'stigmariae' --> 'stigmaria'};
is noun(q{stigmaria})->singular,   q{stigmaria}  => q{singular: 'stigmaria' --> 'stigmaria'};
is noun(q{chitarroni})->singular, q{chitarrone}  => q{singular: 'chitarroni' --> 'chitarrone'};
is noun(q{chitarrone})->singular,   q{chitarrone}  => q{singular: 'chitarrone' --> 'chitarrone'};
is noun(q{referendums})->singular, q{referendum}  => q{singular: 'referendums' --> 'referendum'};
is noun(q{referendum})->singular,   q{referendum}  => q{singular: 'referendum' --> 'referendum'};
is noun(q{Tirolese})->singular, q{Tirolese}  => q{singular: 'Tirolese' --> 'Tirolese'};
is noun(q{ungues})->singular, q{unguis}  => q{singular: 'ungues' --> 'unguis'};
is noun(q{unguis})->singular,   q{unguis}  => q{singular: 'unguis' --> 'unguis'};
is noun(q{plasmalemmae})->singular, q{plasmalemma}  => q{singular: 'plasmalemmae' --> 'plasmalemma'};
is noun(q{plasmalemma})->singular,   q{plasmalemma}  => q{singular: 'plasmalemma' --> 'plasmalemma'};
is noun(q{manteaux})->singular, q{manteau}  => q{singular: 'manteaux' --> 'manteau'};
is noun(q{manteau})->singular,   q{manteau}  => q{singular: 'manteau' --> 'manteau'};
is noun(q{parabolani})->singular, q{parabolanus}  => q{singular: 'parabolani' --> 'parabolanus'};
is noun(q{parabolanus})->singular,   q{parabolanus}  => q{singular: 'parabolanus' --> 'parabolanus'};
is noun(q{rites de passage})->singular, q{rite de passage}  => q{singular: 'rites de passage' --> 'rite de passage'};
is noun(q{rite de passage})->singular,   q{rite de passage}  => q{singular: 'rite de passage' --> 'rite de passage'};
is noun(q{crowfoots})->singular, q{crowfoot}  => q{singular: 'crowfoots' --> 'crowfoot'};
is noun(q{crowfoot})->singular,   q{crowfoot}  => q{singular: 'crowfoot' --> 'crowfoot'};
is noun(q{dichasia})->singular, q{dichasium}  => q{singular: 'dichasia' --> 'dichasium'};
is noun(q{dichasium})->singular,   q{dichasium}  => q{singular: 'dichasium' --> 'dichasium'};
is noun(q{pectens})->singular, q{pecten}  => q{singular: 'pectens' --> 'pecten'};
is noun(q{pecten})->singular,   q{pecten}  => q{singular: 'pecten' --> 'pecten'};
is noun(q{mortaria})->singular, q{mortarium}  => q{singular: 'mortaria' --> 'mortarium'};
is noun(q{mortarium})->singular,   q{mortarium}  => q{singular: 'mortarium' --> 'mortarium'};
is noun(q{hetairai})->singular, q{hetaera}  => q{singular: 'hetairai' --> 'hetaera'};
is noun(q{hetaera})->singular,   q{hetaera}  => q{singular: 'hetaera' --> 'hetaera'};
is noun(q{lapiths})->singular, q{lapith}  => q{singular: 'lapiths' --> 'lapith'};
is noun(q{lapith})->singular,   q{lapith}  => q{singular: 'lapith' --> 'lapith'};
is noun(q{Germans})->singular, q{German}  => q{singular: 'Germans' --> 'German'};
is noun(q{German})->singular,   q{German}  => q{singular: 'German' --> 'German'};
is noun(q{omenta})->singular, q{omentum}  => q{singular: 'omenta' --> 'omentum'};
is noun(q{omentum})->singular,   q{omentum}  => q{singular: 'omentum' --> 'omentum'};
is noun(q{Bolognese})->singular, q{Bolognese}  => q{singular: 'Bolognese' --> 'Bolognese'};
is noun(q{zucche})->singular, q{zucca}  => q{singular: 'zucche' --> 'zucca'};
is noun(q{zucca})->singular,   q{zucca}  => q{singular: 'zucca' --> 'zucca'};
is noun(q{acini})->singular, q{acinus}  => q{singular: 'acini' --> 'acinus'};
is noun(q{acinus})->singular,   q{acinus}  => q{singular: 'acinus' --> 'acinus'};
is noun(q{zuzim})->singular, q{zuz}  => q{singular: 'zuzim' --> 'zuz'};
is noun(q{zuz})->singular,   q{zuz}  => q{singular: 'zuz' --> 'zuz'};
is noun(q{ploshchadki})->singular, q{ploshchadka}  => q{singular: 'ploshchadki' --> 'ploshchadka'};
is noun(q{ploshchadka})->singular,   q{ploshchadka}  => q{singular: 'ploshchadka' --> 'ploshchadka'};
is noun(q{listeria})->singular, q{listeria}  => q{singular: 'listeria' --> 'listeria'};
is noun(q{pteropi})->singular, q{pteropus}  => q{singular: 'pteropi' --> 'pteropus'};
is noun(q{pteropus})->singular,   q{pteropus}  => q{singular: 'pteropus' --> 'pteropus'};
is noun(q{bylinas})->singular, q{bylina}  => q{singular: 'bylinas' --> 'bylina'};
is noun(q{bylina})->singular,   q{bylina}  => q{singular: 'bylina' --> 'bylina'};
is noun(q{goyim})->singular, q{goy}  => q{singular: 'goyim' --> 'goy'};
is noun(q{goy})->singular,   q{goy}  => q{singular: 'goy' --> 'goy'};
is noun(q{blinis})->singular, q{blin}  => q{singular: 'blinis' --> 'blin'};
is noun(q{blin})->singular,   q{blin}  => q{singular: 'blin' --> 'blin'};
is noun(q{myelomas})->singular, q{myeloma}  => q{singular: 'myelomas' --> 'myeloma'};
is noun(q{myeloma})->singular,   q{myeloma}  => q{singular: 'myeloma' --> 'myeloma'};
is noun(q{curricula})->singular, q{curriculum}  => q{singular: 'curricula' --> 'curriculum'};
is noun(q{curriculum})->singular,   q{curriculum}  => q{singular: 'curriculum' --> 'curriculum'};
is noun(q{triumviri})->singular, q{triumvir}  => q{singular: 'triumviri' --> 'triumvir'};
is noun(q{triumvir})->singular,   q{triumvir}  => q{singular: 'triumvir' --> 'triumvir'};
is noun(q{adieus})->singular, q{adieu}  => q{singular: 'adieus' --> 'adieu'};
is noun(q{adieu})->singular,   q{adieu}  => q{singular: 'adieu' --> 'adieu'};
is noun(q{hijinks})->singular, q{hijinks}  => q{singular: 'hijinks' --> 'hijinks'};
is noun(q{topazes})->singular, q{topaz}  => q{singular: 'topazes' --> 'topaz'};
is noun(q{topaz})->singular,   q{topaz}  => q{singular: 'topaz' --> 'topaz'};
is noun(q{pike})->singular, q{pike}  => q{singular: 'pike' --> 'pike'};
is noun(q{agenda})->singular, q{agendum}  => q{singular: 'agenda' --> 'agendum'};
is noun(q{agendum})->singular,   q{agendum}  => q{singular: 'agendum' --> 'agendum'};
is noun(q{prime donne})->singular, q{prima donna}  => q{singular: 'prime donne' --> 'prima donna'};
is noun(q{prima donna})->singular,   q{prima donna}  => q{singular: 'prima donna' --> 'prima donna'};
is noun(q{sinus})->singular, q{sinus}  => q{singular: 'sinus' --> 'sinus'};
is noun(q{neritae})->singular, q{nerita}  => q{singular: 'neritae' --> 'nerita'};
is noun(q{nerita})->singular,   q{nerita}  => q{singular: 'nerita' --> 'nerita'};
is noun(q{spirilla})->singular, q{spirillum}  => q{singular: 'spirilla' --> 'spirillum'};
is noun(q{spirillum})->singular,   q{spirillum}  => q{singular: 'spirillum' --> 'spirillum'};
is noun(q{nouveaux pauvres})->singular, q{nouveau pauvre}  => q{singular: 'nouveaux pauvres' --> 'nouveau pauvre'};
is noun(q{nouveau pauvre})->singular,   q{nouveau pauvre}  => q{singular: 'nouveau pauvre' --> 'nouveau pauvre'};
is noun(q{Asherahs})->singular, q{Asherah}  => q{singular: 'Asherahs' --> 'Asherah'};
is noun(q{Asherah})->singular,   q{Asherah}  => q{singular: 'Asherah' --> 'Asherah'};
is noun(q{improperia})->singular, q{improperium}  => q{singular: 'improperia' --> 'improperium'};
is noun(q{improperium})->singular,   q{improperium}  => q{singular: 'improperium' --> 'improperium'};
is noun(q{uomini universali})->singular, q{uomo universale}  => q{singular: 'uomini universali' --> 'uomo universale'};
is noun(q{uomo universale})->singular,   q{uomo universale}  => q{singular: 'uomo universale' --> 'uomo universale'};
is noun(q{taleae})->singular, q{talea}  => q{singular: 'taleae' --> 'talea'};
is noun(q{talea})->singular,   q{talea}  => q{singular: 'talea' --> 'talea'};
is noun(q{pendula})->singular, q{pendulum}  => q{singular: 'pendula' --> 'pendulum'};
is noun(q{pendulum})->singular,   q{pendulum}  => q{singular: 'pendulum' --> 'pendulum'};
is noun(q{coituses})->singular, q{coitus}  => q{singular: 'coituses' --> 'coitus'};
is noun(q{craniums})->singular, q{cranium}  => q{singular: 'craniums' --> 'cranium'};
is noun(q{cranium})->singular,   q{cranium}  => q{singular: 'cranium' --> 'cranium'};
is noun(q{solidi})->singular, q{solidus}  => q{singular: 'solidi' --> 'solidus'};
is noun(q{solidus})->singular,   q{solidus}  => q{singular: 'solidus' --> 'solidus'};
is noun(q{stipulae})->singular, q{stipula}  => q{singular: 'stipulae' --> 'stipula'};
is noun(q{stipula})->singular,   q{stipula}  => q{singular: 'stipula' --> 'stipula'};
is noun(q{lapithae})->singular, q{lapith}  => q{singular: 'lapithae' --> 'lapith'};
is noun(q{lapith})->singular,   q{lapith}  => q{singular: 'lapith' --> 'lapith'};
is noun(q{charismata})->singular, q{charisma}  => q{singular: 'charismata' --> 'charisma'};
is noun(q{charisma})->singular,   q{charisma}  => q{singular: 'charisma' --> 'charisma'};
is noun(q{vibriones})->singular, q{vibrio}  => q{singular: 'vibriones' --> 'vibrio'};
is noun(q{vibrio})->singular,   q{vibrio}  => q{singular: 'vibrio' --> 'vibrio'};
is noun(q{sets-out})->singular, q{set-out}  => q{singular: 'sets-out' --> 'set-out'};
is noun(q{set-out})->singular,   q{set-out}  => q{singular: 'set-out' --> 'set-out'};
is noun(q{cyclopes})->singular, q{cyclops}  => q{singular: 'cyclopes' --> 'cyclops'};
is noun(q{cyclops})->singular,   q{cyclops}  => q{singular: 'cyclops' --> 'cyclops'};
is noun(q{tetanothra})->singular, q{tetanothrum}  => q{singular: 'tetanothra' --> 'tetanothrum'};
is noun(q{tetanothrum})->singular,   q{tetanothrum}  => q{singular: 'tetanothrum' --> 'tetanothrum'};
is noun(q{zygantra})->singular, q{zygantrum}  => q{singular: 'zygantra' --> 'zygantrum'};
is noun(q{zygantrum})->singular,   q{zygantrum}  => q{singular: 'zygantrum' --> 'zygantrum'};
is noun(q{vaginulae})->singular, q{vaginula}  => q{singular: 'vaginulae' --> 'vaginula'};
is noun(q{vaginula})->singular,   q{vaginula}  => q{singular: 'vaginula' --> 'vaginula'};
is noun(q{beerenauslesen})->singular, q{beerenauslese}  => q{singular: 'beerenauslesen' --> 'beerenauslese'};
is noun(q{beerenauslese})->singular,   q{beerenauslese}  => q{singular: 'beerenauslese' --> 'beerenauslese'};
is noun(q{zuppe})->singular, q{zuppa}  => q{singular: 'zuppe' --> 'zuppa'};
is noun(q{zuppa})->singular,   q{zuppa}  => q{singular: 'zuppa' --> 'zuppa'};
is noun(q{hamadrayads})->singular, q{hamadryad}  => q{singular: 'hamadrayads' --> 'hamadryad'};
is noun(q{hamadryad})->singular,   q{hamadryad}  => q{singular: 'hamadryad' --> 'hamadryad'};
is noun(q{propleura})->singular, q{propleuron}  => q{singular: 'propleura' --> 'propleuron'};
is noun(q{propleuron})->singular,   q{propleuron}  => q{singular: 'propleuron' --> 'propleuron'};
is noun(q{ultimata})->singular, q{ultimatum}  => q{singular: 'ultimata' --> 'ultimatum'};
is noun(q{ultimatum})->singular,   q{ultimatum}  => q{singular: 'ultimatum' --> 'ultimatum'};
is noun(q{hyperbata})->singular, q{hyperbaton}  => q{singular: 'hyperbata' --> 'hyperbaton'};
is noun(q{hyperbaton})->singular,   q{hyperbaton}  => q{singular: 'hyperbaton' --> 'hyperbaton'};
is noun(q{zingani})->singular, q{zingano}  => q{singular: 'zingani' --> 'zingano'};
is noun(q{zingano})->singular,   q{zingano}  => q{singular: 'zingano' --> 'zingano'};
is noun(q{hippopotami})->singular, q{hippopotamus}  => q{singular: 'hippopotami' --> 'hippopotamus'};
is noun(q{hippopotamus})->singular,   q{hippopotamus}  => q{singular: 'hippopotamus' --> 'hippopotamus'};
is noun(q{mementos})->singular, q{memento}  => q{singular: 'mementos' --> 'memento'};
is noun(q{memento})->singular,   q{memento}  => q{singular: 'memento' --> 'memento'};
is noun(q{Goanese})->singular, q{Goanese}  => q{singular: 'Goanese' --> 'Goanese'};
is noun(q{wadys})->singular, q{wady}  => q{singular: 'wadys' --> 'wady'};
is noun(q{wady})->singular,   q{wady}  => q{singular: 'wady' --> 'wady'};
is noun(q{chaoses})->singular, q{chaos}  => q{singular: 'chaoses' --> 'chaos'};
is noun(q{chaos})->singular,   q{chaos}  => q{singular: 'chaos' --> 'chaos'};
is noun(q{neurulae})->singular, q{neurula}  => q{singular: 'neurulae' --> 'neurula'};
is noun(q{neurula})->singular,   q{neurula}  => q{singular: 'neurula' --> 'neurula'};
is noun(q{stamen})->singular, q{stamen}  => q{singular: 'stamen' --> 'stamen'};
is noun(q{diporpae})->singular, q{diporpa}  => q{singular: 'diporpae' --> 'diporpa'};
is noun(q{diporpa})->singular,   q{diporpa}  => q{singular: 'diporpa' --> 'diporpa'};
is noun(q{centumviri})->singular, q{centumvir}  => q{singular: 'centumviri' --> 'centumvir'};
is noun(q{centumvir})->singular,   q{centumvir}  => q{singular: 'centumvir' --> 'centumvir'};
is noun(q{hypolimnia})->singular, q{hypolimnion}  => q{singular: 'hypolimnia' --> 'hypolimnion'};
is noun(q{hypolimnion})->singular,   q{hypolimnion}  => q{singular: 'hypolimnion' --> 'hypolimnion'};
is noun(q{bhikshook})->singular, q{bhikshu}  => q{singular: 'bhikshook' --> 'bhikshu'};
is noun(q{bhikshu})->singular,   q{bhikshu}  => q{singular: 'bhikshu' --> 'bhikshu'};
is noun(q{uteri})->singular, q{uterus}  => q{singular: 'uteri' --> 'uterus'};
is noun(q{uterus})->singular,   q{uterus}  => q{singular: 'uterus' --> 'uterus'};
is noun(q{gallas})->singular, q{galla}  => q{singular: 'gallas' --> 'galla'};
is noun(q{milieux})->singular, q{milieu}  => q{singular: 'milieux' --> 'milieu'};
is noun(q{milieu})->singular,   q{milieu}  => q{singular: 'milieu' --> 'milieu'};
is noun(q{trapezia})->singular, q{trapezium}  => q{singular: 'trapezia' --> 'trapezium'};
is noun(q{trapezium})->singular,   q{trapezium}  => q{singular: 'trapezium' --> 'trapezium'};
is noun(q{aphelia})->singular, q{aphelion}  => q{singular: 'aphelia' --> 'aphelion'};
is noun(q{aphelion})->singular,   q{aphelion}  => q{singular: 'aphelion' --> 'aphelion'};
is noun(q{ambuscados})->singular, q{ambuscado}  => q{singular: 'ambuscados' --> 'ambuscado'};
is noun(q{ambuscado})->singular,   q{ambuscado}  => q{singular: 'ambuscado' --> 'ambuscado'};
is noun(q{insulae})->singular, q{insula}  => q{singular: 'insulae' --> 'insula'};
is noun(q{insula})->singular,   q{insula}  => q{singular: 'insula' --> 'insula'};
is noun(q{sensedata})->singular, q{sensedatum}  => q{singular: 'sensedata' --> 'sensedatum'};
is noun(q{sensedatum})->singular,   q{sensedatum}  => q{singular: 'sensedatum' --> 'sensedatum'};
is noun(q{anthemia})->singular, q{anthemion}  => q{singular: 'anthemia' --> 'anthemion'};
is noun(q{anthemion})->singular,   q{anthemion}  => q{singular: 'anthemion' --> 'anthemion'};
is noun(q{Kinkimavos})->singular, q{Kinkimavo}  => q{singular: 'Kinkimavos' --> 'Kinkimavo'};
is noun(q{Kinkimavo})->singular,   q{Kinkimavo}  => q{singular: 'Kinkimavo' --> 'Kinkimavo'};
is noun(q{felones de se})->singular, q{felo de se}  => q{singular: 'felones de se' --> 'felo de se'};
is noun(q{felo de se})->singular,   q{felo de se}  => q{singular: 'felo de se' --> 'felo de se'};
is noun(q{fingers ends})->singular, q{finger end}  => q{singular: 'fingers ends' --> 'finger end'};
is noun(q{finger end})->singular,   q{finger end}  => q{singular: 'finger end' --> 'finger end'};
is noun(q{haustella})->singular, q{haustellum}  => q{singular: 'haustella' --> 'haustellum'};
is noun(q{haustellum})->singular,   q{haustellum}  => q{singular: 'haustellum' --> 'haustellum'};
is noun(q{prolegomena})->singular, q{prolegomenon}  => q{singular: 'prolegomena' --> 'prolegomenon'};
is noun(q{prolegomenon})->singular,   q{prolegomenon}  => q{singular: 'prolegomenon' --> 'prolegomenon'};
is noun(q{Colombos})->singular, q{Colombo}  => q{singular: 'Colombos' --> 'Colombo'};
is noun(q{Colombo})->singular,   q{Colombo}  => q{singular: 'Colombo' --> 'Colombo'};
is noun(q{roes})->singular, q{roe}  => q{singular: 'roes' --> 'roe'};
is noun(q{regidors})->singular, q{regidor}  => q{singular: 'regidors' --> 'regidor'};
is noun(q{regidor})->singular,   q{regidor}  => q{singular: 'regidor' --> 'regidor'};
is noun(q{vasculitises})->singular, q{vasculitis}  => q{singular: 'vasculitises' --> 'vasculitis'};
is noun(q{vasculitis})->singular,   q{vasculitis}  => q{singular: 'vasculitis' --> 'vasculitis'};
is noun(q{vibracula})->singular, q{vibraculum}  => q{singular: 'vibracula' --> 'vibraculum'};
is noun(q{vibraculum})->singular,   q{vibraculum}  => q{singular: 'vibraculum' --> 'vibraculum'};
is noun(q{ruses de guerre})->singular, q{ruse de guerre}  => q{singular: 'ruses de guerre' --> 'ruse de guerre'};
is noun(q{ruse de guerre})->singular,   q{ruse de guerre}  => q{singular: 'ruse de guerre' --> 'ruse de guerre'};
is noun(q{proboscises})->singular, q{proboscis}  => q{singular: 'proboscises' --> 'proboscis'};
is noun(q{proboscis})->singular,   q{proboscis}  => q{singular: 'proboscis' --> 'proboscis'};
is noun(q{kars})->singular, q{kar}  => q{singular: 'kars' --> 'kar'};
is noun(q{kar})->singular,   q{kar}  => q{singular: 'kar' --> 'kar'};
is noun(q{pinnas})->singular, q{pinna}  => q{singular: 'pinnas' --> 'pinna'};
is noun(q{pinna})->singular,   q{pinna}  => q{singular: 'pinna' --> 'pinna'};
is noun(q{Niasese})->singular, q{Niasese}  => q{singular: 'Niasese' --> 'Niasese'};
is noun(q{Dongolese})->singular, q{Dongolese}  => q{singular: 'Dongolese' --> 'Dongolese'};
is noun(q{basses})->singular, q{bass}  => q{singular: 'basses' --> 'bass'};
is noun(q{nagaiki})->singular, q{nagaika}  => q{singular: 'nagaiki' --> 'nagaika'};
is noun(q{nagaika})->singular,   q{nagaika}  => q{singular: 'nagaika' --> 'nagaika'};
is noun(q{urodaea})->singular, q{urodaeum}  => q{singular: 'urodaea' --> 'urodaeum'};
is noun(q{urodaeum})->singular,   q{urodaeum}  => q{singular: 'urodaeum' --> 'urodaeum'};
is noun(q{hymenia})->singular, q{hymenium}  => q{singular: 'hymenia' --> 'hymenium'};
is noun(q{hymenium})->singular,   q{hymenium}  => q{singular: 'hymenium' --> 'hymenium'};
is noun(q{ricercate})->singular, q{ricercata}  => q{singular: 'ricercate' --> 'ricercata'};
is noun(q{ricercata})->singular,   q{ricercata}  => q{singular: 'ricercata' --> 'ricercata'};
is noun(q{gizmos})->singular, q{gizmo}  => q{singular: 'gizmos' --> 'gizmo'};
is noun(q{gizmo})->singular,   q{gizmo}  => q{singular: 'gizmo' --> 'gizmo'};
is noun(q{condottieri})->singular, q{condottiere}  => q{singular: 'condottieri' --> 'condottiere'};
is noun(q{condottiere})->singular,   q{condottiere}  => q{singular: 'condottiere' --> 'condottiere'};
is noun(q{zloty})->singular, q{zloty}  => q{singular: 'zloty' --> 'zloty'};
is noun(q{carices})->singular, q{carex}  => q{singular: 'carices' --> 'carex'};
is noun(q{carex})->singular,   q{carex}  => q{singular: 'carex' --> 'carex'};
is noun(q{enemas})->singular, q{enema}  => q{singular: 'enemas' --> 'enema'};
is noun(q{enema})->singular,   q{enema}  => q{singular: 'enema' --> 'enema'};
is noun(q{pelves})->singular, q{pelvis}  => q{singular: 'pelves' --> 'pelvis'};
is noun(q{pelvis})->singular,   q{pelvis}  => q{singular: 'pelvis' --> 'pelvis'};
is noun(q{argumenta})->singular, q{argumentum}  => q{singular: 'argumenta' --> 'argumentum'};
is noun(q{argumentum})->singular,   q{argumentum}  => q{singular: 'argumentum' --> 'argumentum'};
is noun(q{cabalettas})->singular, q{cabaletta}  => q{singular: 'cabalettas' --> 'cabaletta'};
is noun(q{cabaletta})->singular,   q{cabaletta}  => q{singular: 'cabaletta' --> 'cabaletta'};
is noun(q{espressos})->singular, q{espresso}  => q{singular: 'espressos' --> 'espresso'};
is noun(q{espresso})->singular,   q{espresso}  => q{singular: 'espresso' --> 'espresso'};
is noun(q{sistra})->singular, q{sistrum}  => q{singular: 'sistra' --> 'sistrum'};
is noun(q{sistrum})->singular,   q{sistrum}  => q{singular: 'sistrum' --> 'sistrum'};
is noun(q{apparatus})->singular, q{apparatus}  => q{singular: 'apparatus' --> 'apparatus'};
is noun(q{succineae})->singular, q{succinea}  => q{singular: 'succineae' --> 'succinea'};
is noun(q{succinea})->singular,   q{succinea}  => q{singular: 'succinea' --> 'succinea'};
is noun(q{chrysalides})->singular, q{chrysalis}  => q{singular: 'chrysalides' --> 'chrysalis'};
is noun(q{chrysalis})->singular,   q{chrysalis}  => q{singular: 'chrysalis' --> 'chrysalis'};
is noun(q{refugia})->singular, q{refugium}  => q{singular: 'refugia' --> 'refugium'};
is noun(q{refugium})->singular,   q{refugium}  => q{singular: 'refugium' --> 'refugium'};
is noun(q{tegmina})->singular, q{tegmen}  => q{singular: 'tegmina' --> 'tegmen'};
is noun(q{tegmen})->singular,   q{tegmen}  => q{singular: 'tegmen' --> 'tegmen'};
is noun(q{flatfoots})->singular, q{flatfoot}  => q{singular: 'flatfoots' --> 'flatfoot'};
is noun(q{flatfoot})->singular,   q{flatfoot}  => q{singular: 'flatfoot' --> 'flatfoot'};
is noun(q{waltzes})->singular, q{waltz}  => q{singular: 'waltzes' --> 'waltz'};
is noun(q{waltz})->singular,   q{waltz}  => q{singular: 'waltz' --> 'waltz'};
is noun(q{bacilli})->singular, q{bacillus}  => q{singular: 'bacilli' --> 'bacillus'};
is noun(q{bacillus})->singular,   q{bacillus}  => q{singular: 'bacillus' --> 'bacillus'};
is noun(q{vittae})->singular, q{vitta}  => q{singular: 'vittae' --> 'vitta'};
is noun(q{vitta})->singular,   q{vitta}  => q{singular: 'vitta' --> 'vitta'};
is noun(q{whomsoever})->singular, q{whomsoever}  => q{singular: 'whomsoever' --> 'whomsoever'};
is noun(q{caribous})->singular, q{caribou}  => q{singular: 'caribous' --> 'caribou'};
is noun(q{symplasmata})->singular, q{symplasma}  => q{singular: 'symplasmata' --> 'symplasma'};
is noun(q{symplasma})->singular,   q{symplasma}  => q{singular: 'symplasma' --> 'symplasma'};
is noun(q{archipelagoes})->singular, q{archipelago}  => q{singular: 'archipelagoes' --> 'archipelago'};
is noun(q{archipelago})->singular,   q{archipelago}  => q{singular: 'archipelago' --> 'archipelago'};
is noun(q{compendia})->singular, q{compendium}  => q{singular: 'compendia' --> 'compendium'};
is noun(q{compendium})->singular,   q{compendium}  => q{singular: 'compendium' --> 'compendium'};
is noun(q{thelyca})->singular, q{thelycum}  => q{singular: 'thelyca' --> 'thelycum'};
is noun(q{thelycum})->singular,   q{thelycum}  => q{singular: 'thelycum' --> 'thelycum'};
is noun(q{tableaux})->singular, q{tableau}  => q{singular: 'tableaux' --> 'tableau'};
is noun(q{tableau})->singular,   q{tableau}  => q{singular: 'tableau' --> 'tableau'};
is noun(q{proscollae})->singular, q{proscolla}  => q{singular: 'proscollae' --> 'proscolla'};
is noun(q{proscolla})->singular,   q{proscolla}  => q{singular: 'proscolla' --> 'proscolla'};
is noun(q{siliquae})->singular, q{siliqua}  => q{singular: 'siliquae' --> 'siliqua'};
is noun(q{siliqua})->singular,   q{siliqua}  => q{singular: 'siliqua' --> 'siliqua'};
is noun(q{optimums})->singular, q{optimum}  => q{singular: 'optimums' --> 'optimum'};
is noun(q{optimum})->singular,   q{optimum}  => q{singular: 'optimum' --> 'optimum'};
is noun(q{whosesoever})->singular, q{whosesoever}  => q{singular: 'whosesoever' --> 'whosesoever'};
is noun(q{logos})->singular, q{logo}  => q{singular: 'logos' --> 'logo'};
is noun(q{logo})->singular,   q{logo}  => q{singular: 'logo' --> 'logo'};
is noun(q{programmata})->singular, q{programma}  => q{singular: 'programmata' --> 'programma'};
is noun(q{programma})->singular,   q{programma}  => q{singular: 'programma' --> 'programma'};
is noun(q{armadillos})->singular, q{armadillo}  => q{singular: 'armadillos' --> 'armadillo'};
is noun(q{armadillo})->singular,   q{armadillo}  => q{singular: 'armadillo' --> 'armadillo'};
is noun(q{bersaglieri})->singular, q{bersagliere}  => q{singular: 'bersaglieri' --> 'bersagliere'};
is noun(q{bersagliere})->singular,   q{bersagliere}  => q{singular: 'bersagliere' --> 'bersagliere'};
is noun(q{laciniae})->singular, q{lacinia}  => q{singular: 'laciniae' --> 'lacinia'};
is noun(q{lacinia})->singular,   q{lacinia}  => q{singular: 'lacinia' --> 'lacinia'};
is noun(q{lemnisci})->singular, q{lemniscus}  => q{singular: 'lemnisci' --> 'lemniscus'};
is noun(q{lemniscus})->singular,   q{lemniscus}  => q{singular: 'lemniscus' --> 'lemniscus'};
is noun(q{hemi-elytra})->singular, q{hemi-elytrum}  => q{singular: 'hemi-elytra' --> 'hemi-elytrum'};
is noun(q{hemi-elytrum})->singular,   q{hemi-elytrum}  => q{singular: 'hemi-elytrum' --> 'hemi-elytrum'};
is noun(q{suprascapulae})->singular, q{suprascapula}  => q{singular: 'suprascapulae' --> 'suprascapula'};
is noun(q{suprascapula})->singular,   q{suprascapula}  => q{singular: 'suprascapula' --> 'suprascapula'};
is noun(q{heen})->singular, q{hsien}  => q{singular: 'heen' --> 'hsien'};
is noun(q{hsien})->singular,   q{hsien}  => q{singular: 'hsien' --> 'hsien'};
is noun(q{columbaria})->singular, q{columbarium}  => q{singular: 'columbaria' --> 'columbarium'};
is noun(q{columbarium})->singular,   q{columbarium}  => q{singular: 'columbarium' --> 'columbarium'};
is noun(q{Leonese})->singular, q{Leonese}  => q{singular: 'Leonese' --> 'Leonese'};
is noun(q{ova})->singular, q{ovum}  => q{singular: 'ova' --> 'ovum'};
is noun(q{ovum})->singular,   q{ovum}  => q{singular: 'ovum' --> 'ovum'};
is noun(q{mycorhizae})->singular, q{mycorhiza}  => q{singular: 'mycorhizae' --> 'mycorhiza'};
is noun(q{mycorhiza})->singular,   q{mycorhiza}  => q{singular: 'mycorhiza' --> 'mycorhiza'};
is noun(q{washers-up})->singular, q{washer-up}  => q{singular: 'washers-up' --> 'washer-up'};
is noun(q{washer-up})->singular,   q{washer-up}  => q{singular: 'washer-up' --> 'washer-up'};
is noun(q{antennae})->singular, q{antenna}  => q{singular: 'antennae' --> 'antenna'};
is noun(q{antenna})->singular,   q{antenna}  => q{singular: 'antenna' --> 'antenna'};
is noun(q{voorbokke})->singular, q{voorbok}  => q{singular: 'voorbokke' --> 'voorbok'};
is noun(q{voorbok})->singular,   q{voorbok}  => q{singular: 'voorbok' --> 'voorbok'};
is noun(q{meretrices})->singular, q{meretrix}  => q{singular: 'meretrices' --> 'meretrix'};
is noun(q{meretrix})->singular,   q{meretrix}  => q{singular: 'meretrix' --> 'meretrix'};
is noun(q{tonneaux})->singular, q{tonneau}  => q{singular: 'tonneaux' --> 'tonneau'};
is noun(q{tonneau})->singular,   q{tonneau}  => q{singular: 'tonneau' --> 'tonneau'};
is noun(q{megalosauri})->singular, q{megalosaurus}  => q{singular: 'megalosauri' --> 'megalosaurus'};
is noun(q{megalosaurus})->singular,   q{megalosaurus}  => q{singular: 'megalosaurus' --> 'megalosaurus'};
is noun(q{commandos})->singular, q{commando}  => q{singular: 'commandos' --> 'commando'};
is noun(q{commando})->singular,   q{commando}  => q{singular: 'commando' --> 'commando'};
is noun(q{risottos})->singular, q{risotto}  => q{singular: 'risottos' --> 'risotto'};
is noun(q{risotto})->singular,   q{risotto}  => q{singular: 'risotto' --> 'risotto'};
is noun(q{mares})->singular, q{mare}  => q{singular: 'mares' --> 'mare'};
is noun(q{mare})->singular,   q{mare}  => q{singular: 'mare' --> 'mare'};
is noun(q{pelvises})->singular, q{pelvis}  => q{singular: 'pelvises' --> 'pelvis'};
is noun(q{pelvis})->singular,   q{pelvis}  => q{singular: 'pelvis' --> 'pelvis'};
is noun(q{hefte})->singular, q{heft}  => q{singular: 'hefte' --> 'heft'};
is noun(q{heft})->singular,   q{heft}  => q{singular: 'heft' --> 'heft'};
is noun(q{Burmese})->singular, q{Burmese}  => q{singular: 'Burmese' --> 'Burmese'};
is noun(q{Achinese})->singular, q{Achinese}  => q{singular: 'Achinese' --> 'Achinese'};
is noun(q{Maltese})->singular, q{Maltese}  => q{singular: 'Maltese' --> 'Maltese'};
is noun(q{halibut})->singular, q{halibut}  => q{singular: 'halibut' --> 'halibut'};
is noun(q{dragomans})->singular, q{dragoman}  => q{singular: 'dragomans' --> 'dragoman'};
is noun(q{dragoman})->singular,   q{dragoman}  => q{singular: 'dragoman' --> 'dragoman'};
is noun(q{incubi})->singular, q{incubus}  => q{singular: 'incubi' --> 'incubus'};
is noun(q{incubus})->singular,   q{incubus}  => q{singular: 'incubus' --> 'incubus'};
is noun(q{Bernese})->singular, q{Bernese}  => q{singular: 'Bernese' --> 'Bernese'};
is noun(q{phrenes})->singular, q{phren}  => q{singular: 'phrenes' --> 'phren'};
is noun(q{phren})->singular,   q{phren}  => q{singular: 'phren' --> 'phren'};
is noun(q{culs-de-sac})->singular, q{cul-de-sac}  => q{singular: 'culs-de-sac' --> 'cul-de-sac'};
is noun(q{cul-de-sac})->singular,   q{cul-de-sac}  => q{singular: 'cul-de-sac' --> 'cul-de-sac'};
is noun(q{corpuses})->singular, q{corpus}  => q{singular: 'corpuses' --> 'corpus'};
is noun(q{corpus})->singular,   q{corpus}  => q{singular: 'corpus' --> 'corpus'};
is noun(q{caeca})->singular, q{caecum}  => q{singular: 'caeca' --> 'caecum'};
is noun(q{caecum})->singular,   q{caecum}  => q{singular: 'caecum' --> 'caecum'};
is noun(q{neumata})->singular, q{neuma}  => q{singular: 'neumata' --> 'neuma'};
is noun(q{neuma})->singular,   q{neuma}  => q{singular: 'neuma' --> 'neuma'};
is noun(q{rideaus})->singular, q{rideau}  => q{singular: 'rideaus' --> 'rideau'};
is noun(q{rideau})->singular,   q{rideau}  => q{singular: 'rideau' --> 'rideau'};
is noun(q{abstracta})->singular, q{abstractum}  => q{singular: 'abstracta' --> 'abstractum'};
is noun(q{abstractum})->singular,   q{abstractum}  => q{singular: 'abstractum' --> 'abstractum'};
is noun(q{femora})->singular, q{femur}  => q{singular: 'femora' --> 'femur'};
is noun(q{femur})->singular,   q{femur}  => q{singular: 'femur' --> 'femur'};
is noun(q{protococci})->singular, q{protococcus}  => q{singular: 'protococci' --> 'protococcus'};
is noun(q{protococcus})->singular,   q{protococcus}  => q{singular: 'protococcus' --> 'protococcus'};
is noun(q{familiae})->singular, q{familia}  => q{singular: 'familiae' --> 'familia'};
is noun(q{familia})->singular,   q{familia}  => q{singular: 'familia' --> 'familia'};
is noun(q{miasmata})->singular, q{miasma}  => q{singular: 'miasmata' --> 'miasma'};
is noun(q{miasma})->singular,   q{miasma}  => q{singular: 'miasma' --> 'miasma'};
is noun(q{stratums})->singular, q{stratum}  => q{singular: 'stratums' --> 'stratum'};
is noun(q{stratum})->singular,   q{stratum}  => q{singular: 'stratum' --> 'stratum'};
is noun(q{actiniae})->singular, q{actinia}  => q{singular: 'actiniae' --> 'actinia'};
is noun(q{actinia})->singular,   q{actinia}  => q{singular: 'actinia' --> 'actinia'};
is noun(q{triclinia})->singular, q{triclinium}  => q{singular: 'triclinia' --> 'triclinium'};
is noun(q{triclinium})->singular,   q{triclinium}  => q{singular: 'triclinium' --> 'triclinium'};
is noun(q{cantus})->singular, q{cantus}  => q{singular: 'cantus' --> 'cantus'};
is noun(q{libretti})->singular, q{libretto}  => q{singular: 'libretti' --> 'libretto'};
is noun(q{libretto})->singular,   q{libretto}  => q{singular: 'libretto' --> 'libretto'};
is noun(q{lingulae})->singular, q{lingula}  => q{singular: 'lingulae' --> 'lingula'};
is noun(q{lingula})->singular,   q{lingula}  => q{singular: 'lingula' --> 'lingula'};
is noun(q{aboiteaux})->singular, q{aboiteau}  => q{singular: 'aboiteaux' --> 'aboiteau'};
is noun(q{aboiteau})->singular,   q{aboiteau}  => q{singular: 'aboiteau' --> 'aboiteau'};
is noun(q{ichthyosauri})->singular, q{ichthyosaurus}  => q{singular: 'ichthyosauri' --> 'ichthyosaurus'};
is noun(q{ichthyosaurus})->singular,   q{ichthyosaurus}  => q{singular: 'ichthyosaurus' --> 'ichthyosaurus'};
is noun(q{percepta})->singular, q{perceptum}  => q{singular: 'percepta' --> 'perceptum'};
is noun(q{perceptum})->singular,   q{perceptum}  => q{singular: 'perceptum' --> 'perceptum'};
is noun(q{kibbutzim})->singular, q{kibbutz}  => q{singular: 'kibbutzim' --> 'kibbutz'};
is noun(q{kibbutz})->singular,   q{kibbutz}  => q{singular: 'kibbutz' --> 'kibbutz'};
is noun(q{stalactites})->singular, q{stalactite}  => q{singular: 'stalactites' --> 'stalactite'};
is noun(q{stalactite})->singular,   q{stalactite}  => q{singular: 'stalactite' --> 'stalactite'};
is noun(q{talismans})->singular, q{talisman}  => q{singular: 'talismans' --> 'talisman'};
is noun(q{talisman})->singular,   q{talisman}  => q{singular: 'talisman' --> 'talisman'};
is noun(q{glomera})->singular, q{glomus}  => q{singular: 'glomera' --> 'glomus'};
is noun(q{glomus})->singular,   q{glomus}  => q{singular: 'glomus' --> 'glomus'};
is noun(q{captain generals})->singular, q{captain general}  => q{singular: 'captain generals' --> 'captain general'};
is noun(q{captain general})->singular,   q{captain general}  => q{singular: 'captain general' --> 'captain general'};
is noun(q{yourselves})->singular, q{yourself}  => q{singular: 'yourselves' --> 'yourself'};
is noun(q{yourself})->singular,   q{yourself}  => q{singular: 'yourself' --> 'yourself'};
is noun(q{glacises})->singular, q{glacis}  => q{singular: 'glacises' --> 'glacis'};
is noun(q{stillicidia})->singular, q{stillicidium}  => q{singular: 'stillicidia' --> 'stillicidium'};
is noun(q{stillicidium})->singular,   q{stillicidium}  => q{singular: 'stillicidium' --> 'stillicidium'};
is noun(q{tsubo})->singular, q{tsubo}  => q{singular: 'tsubo' --> 'tsubo'};
is noun(q{nielli})->singular, q{niello}  => q{singular: 'nielli' --> 'niello'};
is noun(q{niello})->singular,   q{niello}  => q{singular: 'niello' --> 'niello'};
is noun(q{snoozes})->singular, q{snooze}  => q{singular: 'snoozes' --> 'snooze'};
is noun(q{snooze})->singular,   q{snooze}  => q{singular: 'snooze' --> 'snooze'};
is noun(q{tabellae})->singular, q{tabella}  => q{singular: 'tabellae' --> 'tabella'};
is noun(q{tabella})->singular,   q{tabella}  => q{singular: 'tabella' --> 'tabella'};
is noun(q{sums-total})->singular, q{sum-total}  => q{singular: 'sums-total' --> 'sum-total'};
is noun(q{sum-total})->singular,   q{sum-total}  => q{singular: 'sum-total' --> 'sum-total'};
is noun(q{plenaria})->singular, q{plenarium}  => q{singular: 'plenaria' --> 'plenarium'};
is noun(q{plenarium})->singular,   q{plenarium}  => q{singular: 'plenarium' --> 'plenarium'};
is noun(q{makuta})->singular, q{likuta}  => q{singular: 'makuta' --> 'likuta'};
is noun(q{likuta})->singular,   q{likuta}  => q{singular: 'likuta' --> 'likuta'};
is noun(q{myae})->singular, q{mya}  => q{singular: 'myae' --> 'mya'};
is noun(q{mya})->singular,   q{mya}  => q{singular: 'mya' --> 'mya'};
is noun(q{micetraps})->singular, q{mousetrap}  => q{singular: 'micetraps' --> 'mousetrap'};
is noun(q{mousetrap})->singular,   q{mousetrap}  => q{singular: 'mousetrap' --> 'mousetrap'};
is noun(q{acropolises})->singular, q{acropolis}  => q{singular: 'acropolises' --> 'acropolis'};
is noun(q{acropolis})->singular,   q{acropolis}  => q{singular: 'acropolis' --> 'acropolis'};
is noun(q{gubernacula})->singular, q{gubernaculum}  => q{singular: 'gubernacula' --> 'gubernaculum'};
is noun(q{gubernaculum})->singular,   q{gubernaculum}  => q{singular: 'gubernaculum' --> 'gubernaculum'};
is noun(q{bajocchi})->singular, q{bajocco}  => q{singular: 'bajocchi' --> 'bajocco'};
is noun(q{bajocco})->singular,   q{bajocco}  => q{singular: 'bajocco' --> 'bajocco'};
is noun(q{kobo})->singular, q{kobo}  => q{singular: 'kobo' --> 'kobo'};
is noun(q{strambotti})->singular, q{strambotto}  => q{singular: 'strambotti' --> 'strambotto'};
is noun(q{strambotto})->singular,   q{strambotto}  => q{singular: 'strambotto' --> 'strambotto'};
is noun(q{violette})->singular, q{violetta}  => q{singular: 'violette' --> 'violetta'};
is noun(q{violetta})->singular,   q{violetta}  => q{singular: 'violetta' --> 'violetta'};
is noun(q{moduluses})->singular, q{modulus}  => q{singular: 'moduluses' --> 'modulus'};
is noun(q{modulus})->singular,   q{modulus}  => q{singular: 'modulus' --> 'modulus'};
is noun(q{solfeggi})->singular, q{solfeggio}  => q{singular: 'solfeggi' --> 'solfeggio'};
is noun(q{solfeggio})->singular,   q{solfeggio}  => q{singular: 'solfeggio' --> 'solfeggio'};
is noun(q{data})->singular, q{datum}  => q{singular: 'data' --> 'datum'};
is noun(q{datum})->singular,   q{datum}  => q{singular: 'datum' --> 'datum'};
is noun(q{rads})->singular, q{rad}  => q{singular: 'rads' --> 'rad'};
is noun(q{sinfonias})->singular, q{sinfonia}  => q{singular: 'sinfonias' --> 'sinfonia'};
is noun(q{sinfonia})->singular,   q{sinfonia}  => q{singular: 'sinfonia' --> 'sinfonia'};
is noun(q{pinetums})->singular, q{pinetum}  => q{singular: 'pinetums' --> 'pinetum'};
is noun(q{pinetum})->singular,   q{pinetum}  => q{singular: 'pinetum' --> 'pinetum'};
is noun(q{villini})->singular, q{villino}  => q{singular: 'villini' --> 'villino'};
is noun(q{villino})->singular,   q{villino}  => q{singular: 'villino' --> 'villino'};
is noun(q{desmans})->singular, q{desman}  => q{singular: 'desmans' --> 'desman'};
is noun(q{desman})->singular,   q{desman}  => q{singular: 'desman' --> 'desman'};
is noun(q{aurorae})->singular, q{aurora}  => q{singular: 'aurorae' --> 'aurora'};
is noun(q{aurora})->singular,   q{aurora}  => q{singular: 'aurora' --> 'aurora'};
is noun(q{seraphim})->singular, q{seraph}  => q{singular: 'seraphim' --> 'seraph'};
is noun(q{seraph})->singular,   q{seraph}  => q{singular: 'seraph' --> 'seraph'};
is noun(q{squamae})->singular, q{squama}  => q{singular: 'squamae' --> 'squama'};
is noun(q{squama})->singular,   q{squama}  => q{singular: 'squama' --> 'squama'};
is noun(q{Muqdishos})->singular, q{Muqdisho}  => q{singular: 'Muqdishos' --> 'Muqdisho'};
is noun(q{Muqdisho})->singular,   q{Muqdisho}  => q{singular: 'Muqdisho' --> 'Muqdisho'};
is noun(q{maremme})->singular, q{maremma}  => q{singular: 'maremme' --> 'maremma'};
is noun(q{maremma})->singular,   q{maremma}  => q{singular: 'maremma' --> 'maremma'};
is noun(q{stomodaea})->singular, q{stomodaeum}  => q{singular: 'stomodaea' --> 'stomodaeum'};
is noun(q{stomodaeum})->singular,   q{stomodaeum}  => q{singular: 'stomodaeum' --> 'stomodaeum'};
is noun(q{cozes})->singular, q{coz}  => q{singular: 'cozes' --> 'coz'};
is noun(q{coz})->singular,   q{coz}  => q{singular: 'coz' --> 'coz'};
is noun(q{nucleolonemata})->singular, q{nucleolonema}  => q{singular: 'nucleolonemata' --> 'nucleolonema'};
is noun(q{nucleolonema})->singular,   q{nucleolonema}  => q{singular: 'nucleolonema' --> 'nucleolonema'};
is noun(q{phalangia})->singular, q{phalangium}  => q{singular: 'phalangia' --> 'phalangium'};
is noun(q{phalangium})->singular,   q{phalangium}  => q{singular: 'phalangium' --> 'phalangium'};
is noun(q{salitas})->singular, q{salita}  => q{singular: 'salitas' --> 'salita'};
is noun(q{salita})->singular,   q{salita}  => q{singular: 'salita' --> 'salita'};
is noun(q{dilettantes})->singular, q{dilettante}  => q{singular: 'dilettantes' --> 'dilettante'};
is noun(q{dilettante})->singular,   q{dilettante}  => q{singular: 'dilettante' --> 'dilettante'};
is noun(q{epyllia})->singular, q{epyllion}  => q{singular: 'epyllia' --> 'epyllion'};
is noun(q{epyllion})->singular,   q{epyllion}  => q{singular: 'epyllion' --> 'epyllion'};
is noun(q{rondeaux})->singular, q{rondeau}  => q{singular: 'rondeaux' --> 'rondeau'};
is noun(q{rondeau})->singular,   q{rondeau}  => q{singular: 'rondeau' --> 'rondeau'};
is noun(q{cultelli})->singular, q{cultellus}  => q{singular: 'cultelli' --> 'cultellus'};
is noun(q{cultellus})->singular,   q{cultellus}  => q{singular: 'cultellus' --> 'cultellus'};
is noun(q{skis})->singular, q{ski}  => q{singular: 'skis' --> 'ski'};
is noun(q{ski})->singular,   q{ski}  => q{singular: 'ski' --> 'ski'};
is noun(q{relata})->singular, q{relatum}  => q{singular: 'relata' --> 'relatum'};
is noun(q{relatum})->singular,   q{relatum}  => q{singular: 'relatum' --> 'relatum'};
is noun(q{ oxen})->singular, q{ ox}  => q{singular: ' oxen' --> ' ox'};
is noun(q{ ox})->singular,   q{ ox}  => q{singular: ' ox' --> ' ox'};
is noun(q{whiting})->singular, q{whiting}  => q{singular: 'whiting' --> 'whiting'};
is noun(q{menchildren})->singular, q{manchild}  => q{singular: 'menchildren' --> 'manchild'};
is noun(q{manchild})->singular,   q{manchild}  => q{singular: 'manchild' --> 'manchild'};
is noun(q{peninsulas})->singular, q{peninsula}  => q{singular: 'peninsulas' --> 'peninsula'};
is noun(q{peninsula})->singular,   q{peninsula}  => q{singular: 'peninsula' --> 'peninsula'};
is noun(q{soredia})->singular, q{soredium}  => q{singular: 'soredia' --> 'soredium'};
is noun(q{soredium})->singular,   q{soredium}  => q{singular: 'soredium' --> 'soredium'};
is noun(q{schizostylis})->singular, q{schizostylis}  => q{singular: 'schizostylis' --> 'schizostylis'};
is noun(q{terrariums})->singular, q{terrarium}  => q{singular: 'terrariums' --> 'terrarium'};
is noun(q{terrarium})->singular,   q{terrarium}  => q{singular: 'terrarium' --> 'terrarium'};
is noun(q{altorelievos})->singular, q{altorelievo}  => q{singular: 'altorelievos' --> 'altorelievo'};
is noun(q{altorelievo})->singular,   q{altorelievo}  => q{singular: 'altorelievo' --> 'altorelievo'};
is noun(q{plasmomata})->singular, q{plasmoma}  => q{singular: 'plasmomata' --> 'plasmoma'};
is noun(q{plasmoma})->singular,   q{plasmoma}  => q{singular: 'plasmoma' --> 'plasmoma'};
is noun(q{britches})->singular, q{britches}  => q{singular: 'britches' --> 'britches'};
is noun(q{logia})->singular, q{logion}  => q{singular: 'logia' --> 'logion'};
is noun(q{logion})->singular,   q{logion}  => q{singular: 'logion' --> 'logion'};
is noun(q{magi})->singular, q{magus}  => q{singular: 'magi' --> 'magus'};
is noun(q{magus})->singular,   q{magus}  => q{singular: 'magus' --> 'magus'};
is noun(q{Yumans})->singular, q{Yuman}  => q{singular: 'Yumans' --> 'Yuman'};
is noun(q{Yuman})->singular,   q{Yuman}  => q{singular: 'Yuman' --> 'Yuman'};
is noun(q{joes})->singular, q{joe}  => q{singular: 'joes' --> 'joe'};
is noun(q{joe})->singular,   q{joe}  => q{singular: 'joe' --> 'joe'};
is noun(q{tumuli})->singular, q{tumulus}  => q{singular: 'tumuli' --> 'tumulus'};
is noun(q{tumulus})->singular,   q{tumulus}  => q{singular: 'tumulus' --> 'tumulus'};
is noun(q{supercilia})->singular, q{supercilium}  => q{singular: 'supercilia' --> 'supercilium'};
is noun(q{supercilium})->singular,   q{supercilium}  => q{singular: 'supercilium' --> 'supercilium'};
is noun(q{fioriture})->singular, q{fioritura}  => q{singular: 'fioriture' --> 'fioritura'};
is noun(q{fioritura})->singular,   q{fioritura}  => q{singular: 'fioritura' --> 'fioritura'};
is noun(q{Americanese})->singular, q{Americanese}  => q{singular: 'Americanese' --> 'Americanese'};
is noun(q{ovoli})->singular, q{ovolo}  => q{singular: 'ovoli' --> 'ovolo'};
is noun(q{ovolo})->singular,   q{ovolo}  => q{singular: 'ovolo' --> 'ovolo'};
is noun(q{kibbutzes})->singular, q{kibbutz}  => q{singular: 'kibbutzes' --> 'kibbutz'};
is noun(q{kibbutz})->singular,   q{kibbutz}  => q{singular: 'kibbutz' --> 'kibbutz'};
is noun(q{set tos})->singular, q{set to}  => q{singular: 'set tos' --> 'set to'};
is noun(q{set to})->singular,   q{set to}  => q{singular: 'set to' --> 'set to'};
is noun(q{caimans})->singular, q{caiman}  => q{singular: 'caimans' --> 'caiman'};
is noun(q{caiman})->singular,   q{caiman}  => q{singular: 'caiman' --> 'caiman'};
is noun(q{troparia})->singular, q{troparion}  => q{singular: 'troparia' --> 'troparion'};
is noun(q{troparion})->singular,   q{troparion}  => q{singular: 'troparion' --> 'troparion'};
is noun(q{portraits parles})->singular, q{portrait parle}  => q{singular: 'portraits parles' --> 'portrait parle'};
is noun(q{portrait parle})->singular,   q{portrait parle}  => q{singular: 'portrait parle' --> 'portrait parle'};
is noun(q{nucleolonemas})->singular, q{nucleolonema}  => q{singular: 'nucleolonemas' --> 'nucleolonema'};
is noun(q{nucleolonema})->singular,   q{nucleolonema}  => q{singular: 'nucleolonema' --> 'nucleolonema'};
is noun(q{saddos})->singular, q{saddo}  => q{singular: 'saddos' --> 'saddo'};
is noun(q{saddo})->singular,   q{saddo}  => q{singular: 'saddo' --> 'saddo'};
is noun(q{spadices})->singular, q{spadix}  => q{singular: 'spadices' --> 'spadix'};
is noun(q{spadix})->singular,   q{spadix}  => q{singular: 'spadix' --> 'spadix'};
is noun(q{striata})->singular, q{striatum}  => q{singular: 'striata' --> 'striatum'};
is noun(q{striatum})->singular,   q{striatum}  => q{singular: 'striatum' --> 'striatum'};
is noun(q{terps})->singular, q{terp}  => q{singular: 'terps' --> 'terp'};
is noun(q{terp})->singular,   q{terp}  => q{singular: 'terp' --> 'terp'};
is noun(q{latices})->singular, q{latex}  => q{singular: 'latices' --> 'latex'};
is noun(q{latex})->singular,   q{latex}  => q{singular: 'latex' --> 'latex'};
is noun(q{sabertooths})->singular, q{sabertooth}  => q{singular: 'sabertooths' --> 'sabertooth'};
is noun(q{sabertooth})->singular,   q{sabertooth}  => q{singular: 'sabertooth' --> 'sabertooth'};
is noun(q{purlieus})->singular, q{purlieu}  => q{singular: 'purlieus' --> 'purlieu'};
is noun(q{purlieu})->singular,   q{purlieu}  => q{singular: 'purlieu' --> 'purlieu'};
is noun(q{larnakes})->singular, q{larnax}  => q{singular: 'larnakes' --> 'larnax'};
is noun(q{larnax})->singular,   q{larnax}  => q{singular: 'larnax' --> 'larnax'};
is noun(q{beefs})->singular, q{beef}  => q{singular: 'beefs' --> 'beef'};
is noun(q{beef})->singular,   q{beef}  => q{singular: 'beef' --> 'beef'};
is noun(q{breeches})->singular, q{breech}  => q{singular: 'breeches' --> 'breech'};
is noun(q{breech})->singular,   q{breech}  => q{singular: 'breech' --> 'breech'};
is noun(q{spermogonia})->singular, q{spermogonium}  => q{singular: 'spermogonia' --> 'spermogonium'};
is noun(q{spermogonium})->singular,   q{spermogonium}  => q{singular: 'spermogonium' --> 'spermogonium'};
is noun(q{tempi})->singular, q{tempo}  => q{singular: 'tempi' --> 'tempo'};
is noun(q{tempo})->singular,   q{tempo}  => q{singular: 'tempo' --> 'tempo'};
is noun(q{vorstellungen})->singular, q{vorstellung}  => q{singular: 'vorstellungen' --> 'vorstellung'};
is noun(q{vorstellung})->singular,   q{vorstellung}  => q{singular: 'vorstellung' --> 'vorstellung'};
is noun(q{flatuses})->singular, q{flatus}  => q{singular: 'flatuses' --> 'flatus'};
is noun(q{flatus})->singular,   q{flatus}  => q{singular: 'flatus' --> 'flatus'};
is noun(q{blitzes})->singular, q{blitz}  => q{singular: 'blitzes' --> 'blitz'};
is noun(q{blitz})->singular,   q{blitz}  => q{singular: 'blitz' --> 'blitz'};
is noun(q{carp})->singular, q{carp}  => q{singular: 'carp' --> 'carp'};
is noun(q{set-offs})->singular, q{set-off}  => q{singular: 'set-offs' --> 'set-off'};
is noun(q{set-off})->singular,   q{set-off}  => q{singular: 'set-off' --> 'set-off'};
is noun(q{scholia})->singular, q{scholium}  => q{singular: 'scholia' --> 'scholium'};
is noun(q{scholium})->singular,   q{scholium}  => q{singular: 'scholium' --> 'scholium'};
is noun(q{bravoes})->singular, q{bravo}  => q{singular: 'bravoes' --> 'bravo'};
is noun(q{bravo})->singular,   q{bravo}  => q{singular: 'bravo' --> 'bravo'};
is noun(q{bhikshus})->singular, q{bhikshu}  => q{singular: 'bhikshus' --> 'bhikshu'};
is noun(q{bhikshu})->singular,   q{bhikshu}  => q{singular: 'bhikshu' --> 'bhikshu'};
is noun(q{rhomboidei})->singular, q{rhomboideus}  => q{singular: 'rhomboidei' --> 'rhomboideus'};
is noun(q{rhomboideus})->singular,   q{rhomboideus}  => q{singular: 'rhomboideus' --> 'rhomboideus'};
is noun(q{Foochowese})->singular, q{Foochowese}  => q{singular: 'Foochowese' --> 'Foochowese'};
is noun(q{Sienese})->singular, q{Sienese}  => q{singular: 'Sienese' --> 'Sienese'};
is noun(q{pasteurellae})->singular, q{pasteurella}  => q{singular: 'pasteurellae' --> 'pasteurella'};
is noun(q{pasteurella})->singular,   q{pasteurella}  => q{singular: 'pasteurella' --> 'pasteurella'};
is noun(q{uvae})->singular, q{uva}  => q{singular: 'uvae' --> 'uva'};
is noun(q{uva})->singular,   q{uva}  => q{singular: 'uva' --> 'uva'};
is noun(q{agents provocateurs})->singular, q{agent provocateur}  => q{singular: 'agents provocateurs' --> 'agent provocateur'};
is noun(q{agent provocateur})->singular,   q{agent provocateur}  => q{singular: 'agent provocateur' --> 'agent provocateur'};
is noun(q{canvases})->singular, q{canvas}  => q{singular: 'canvases' --> 'canvas'};
is noun(q{canvas})->singular,   q{canvas}  => q{singular: 'canvas' --> 'canvas'};
is noun(q{vasculitides})->singular, q{vasculitis}  => q{singular: 'vasculitides' --> 'vasculitis'};
is noun(q{vasculitis})->singular,   q{vasculitis}  => q{singular: 'vasculitis' --> 'vasculitis'};
is noun(q{toxii})->singular, q{toxius}  => q{singular: 'toxii' --> 'toxius'};
is noun(q{toxius})->singular,   q{toxius}  => q{singular: 'toxius' --> 'toxius'};
is noun(q{goys})->singular, q{goy}  => q{singular: 'goys' --> 'goy'};
is noun(q{goy})->singular,   q{goy}  => q{singular: 'goy' --> 'goy'};
is noun(q{larynges})->singular, q{larynx}  => q{singular: 'larynges' --> 'larynx'};
is noun(q{larynx})->singular,   q{larynx}  => q{singular: 'larynx' --> 'larynx'};
is noun(q{geishas})->singular, q{geisha}  => q{singular: 'geishas' --> 'geisha'};
is noun(q{banditti})->singular, q{bandit}  => q{singular: 'banditti' --> 'bandit'};
is noun(q{bandit})->singular,   q{bandit}  => q{singular: 'bandit' --> 'bandit'};
is noun(q{cerci})->singular, q{cercus}  => q{singular: 'cerci' --> 'cercus'};
is noun(q{cercus})->singular,   q{cercus}  => q{singular: 'cercus' --> 'cercus'};
is noun(q{tetragrammata})->singular, q{tetragrammaton}  => q{singular: 'tetragrammata' --> 'tetragrammaton'};
is noun(q{tetragrammaton})->singular,   q{tetragrammaton}  => q{singular: 'tetragrammaton' --> 'tetragrammaton'};
is noun(q{Maracaibos})->singular, q{Maracaibo}  => q{singular: 'Maracaibos' --> 'Maracaibo'};
is noun(q{Maracaibo})->singular,   q{Maracaibo}  => q{singular: 'Maracaibo' --> 'Maracaibo'};
is noun(q{phragmata})->singular, q{phragma}  => q{singular: 'phragmata' --> 'phragma'};
is noun(q{phragma})->singular,   q{phragma}  => q{singular: 'phragma' --> 'phragma'};
is noun(q{turbots})->singular, q{turbot}  => q{singular: 'turbots' --> 'turbot'};
is noun(q{pickerel})->singular, q{pickerel}  => q{singular: 'pickerel' --> 'pickerel'};
is noun(q{foci})->singular, q{focus}  => q{singular: 'foci' --> 'focus'};
is noun(q{focus})->singular,   q{focus}  => q{singular: 'focus' --> 'focus'};
is noun(q{astrocytomas})->singular, q{astrocytoma}  => q{singular: 'astrocytomas' --> 'astrocytoma'};
is noun(q{astrocytoma})->singular,   q{astrocytoma}  => q{singular: 'astrocytoma' --> 'astrocytoma'};
is noun(q{Siamese})->singular, q{Siamese}  => q{singular: 'Siamese' --> 'Siamese'};
is noun(q{hiatuses})->singular, q{hiatus}  => q{singular: 'hiatuses' --> 'hiatus'};
is noun(q{army corps generals})->singular, q{army corps general}  => q{singular: 'army corps generals' --> 'army corps general'};
is noun(q{army corps general})->singular,   q{army corps general}  => q{singular: 'army corps general' --> 'army corps general'};
is noun(q{prima donnas})->singular, q{prima donna}  => q{singular: 'prima donnas' --> 'prima donna'};
is noun(q{prima donna})->singular,   q{prima donna}  => q{singular: 'prima donna' --> 'prima donna'};
is noun(q{themselves})->singular, q{themselves}  => q{singular: 'themselves' --> 'themselves'};
is noun(q{varices})->singular, q{varix}  => q{singular: 'varices' --> 'varix'};
is noun(q{varix})->singular,   q{varix}  => q{singular: 'varix' --> 'varix'};
is noun(q{seeds})->singular, q{seed}  => q{singular: 'seeds' --> 'seed'};
is noun(q{turfs})->singular, q{turf}  => q{singular: 'turfs' --> 'turf'};
is noun(q{turf})->singular,   q{turf}  => q{singular: 'turf' --> 'turf'};
is noun(q{vomitoriums})->singular, q{vomitorium}  => q{singular: 'vomitoriums' --> 'vomitorium'};
is noun(q{vomitorium})->singular,   q{vomitorium}  => q{singular: 'vomitorium' --> 'vomitorium'};
is noun(q{epimera})->singular, q{epimeron}  => q{singular: 'epimera' --> 'epimeron'};
is noun(q{epimeron})->singular,   q{epimeron}  => q{singular: 'epimeron' --> 'epimeron'};
is noun(q{proaves})->singular, q{proavis}  => q{singular: 'proaves' --> 'proavis'};
is noun(q{proavis})->singular,   q{proavis}  => q{singular: 'proavis' --> 'proavis'};
is noun(q{karrenfelder})->singular, q{karrenfeld}  => q{singular: 'karrenfelder' --> 'karrenfeld'};
is noun(q{karrenfeld})->singular,   q{karrenfeld}  => q{singular: 'karrenfeld' --> 'karrenfeld'};
is noun(q{weirdos})->singular, q{weirdo}  => q{singular: 'weirdos' --> 'weirdo'};
is noun(q{weirdo})->singular,   q{weirdo}  => q{singular: 'weirdo' --> 'weirdo'};
is noun(q{lox})->singular, q{lox}  => q{singular: 'lox' --> 'lox'};
is noun(q{ommatidia})->singular, q{ommatidium}  => q{singular: 'ommatidia' --> 'ommatidium'};
is noun(q{ommatidium})->singular,   q{ommatidium}  => q{singular: 'ommatidium' --> 'ommatidium'};
is noun(q{interreges})->singular, q{interrex}  => q{singular: 'interreges' --> 'interrex'};
is noun(q{interrex})->singular,   q{interrex}  => q{singular: 'interrex' --> 'interrex'};
is noun(q{Bengalese})->singular, q{Bengalese}  => q{singular: 'Bengalese' --> 'Bengalese'};
is noun(q{desiderata})->singular, q{desideratum}  => q{singular: 'desiderata' --> 'desideratum'};
is noun(q{desideratum})->singular,   q{desideratum}  => q{singular: 'desideratum' --> 'desideratum'};
is noun(q{Pekingese})->singular, q{Pekingese}  => q{singular: 'Pekingese' --> 'Pekingese'};
is noun(q{ophiophagi})->singular, q{ophiophagus}  => q{singular: 'ophiophagi' --> 'ophiophagus'};
is noun(q{ophiophagus})->singular,   q{ophiophagus}  => q{singular: 'ophiophagus' --> 'ophiophagus'};
is noun(q{simplices})->singular, q{simplex}  => q{singular: 'simplices' --> 'simplex'};
is noun(q{simplex})->singular,   q{simplex}  => q{singular: 'simplex' --> 'simplex'};
is noun(q{erven})->singular, q{erf}  => q{singular: 'erven' --> 'erf'};
is noun(q{erf})->singular,   q{erf}  => q{singular: 'erf' --> 'erf'};
is noun(q{storeys})->singular, q{storey}  => q{singular: 'storeys' --> 'storey'};
is noun(q{storey})->singular,   q{storey}  => q{singular: 'storey' --> 'storey'};
is noun(q{potestates})->singular, q{potestas}  => q{singular: 'potestates' --> 'potestas'};
is noun(q{potestas})->singular,   q{potestas}  => q{singular: 'potestas' --> 'potestas'};
is noun(q{haustoria})->singular, q{haustorium}  => q{singular: 'haustoria' --> 'haustorium'};
is noun(q{haustorium})->singular,   q{haustorium}  => q{singular: 'haustorium' --> 'haustorium'};
is noun(q{gaonim})->singular, q{gaon}  => q{singular: 'gaonim' --> 'gaon'};
is noun(q{gaon})->singular,   q{gaon}  => q{singular: 'gaon' --> 'gaon'};
is noun(q{nymphea})->singular, q{nymphaeum}  => q{singular: 'nymphea' --> 'nymphaeum'};
is noun(q{nymphaeum})->singular,   q{nymphaeum}  => q{singular: 'nymphaeum' --> 'nymphaeum'};
is noun(q{thalami})->singular, q{thalamus}  => q{singular: 'thalami' --> 'thalamus'};
is noun(q{thalamus})->singular,   q{thalamus}  => q{singular: 'thalamus' --> 'thalamus'};
is noun(q{monsignors})->singular, q{monsignor}  => q{singular: 'monsignors' --> 'monsignor'};
is noun(q{monsignor})->singular,   q{monsignor}  => q{singular: 'monsignor' --> 'monsignor'};
is noun(q{sphagna})->singular, q{sphagnum}  => q{singular: 'sphagna' --> 'sphagnum'};
is noun(q{sphagnum})->singular,   q{sphagnum}  => q{singular: 'sphagnum' --> 'sphagnum'};
is noun(q{candelabra})->singular, q{candelabrum}  => q{singular: 'candelabra' --> 'candelabrum'};
is noun(q{candelabrum})->singular,   q{candelabrum}  => q{singular: 'candelabrum' --> 'candelabrum'};
is noun(q{bongos})->singular, q{bongo}  => q{singular: 'bongos' --> 'bongo'};
is noun(q{bongo})->singular,   q{bongo}  => q{singular: 'bongo' --> 'bongo'};
is noun(q{fowls})->singular, q{fowl}  => q{singular: 'fowls' --> 'fowl'};
is noun(q{flag staffs})->singular, q{flag staff}  => q{singular: 'flag staffs' --> 'flag staff'};
is noun(q{flag staff})->singular,   q{flag staff}  => q{singular: 'flag staff' --> 'flag staff'};
is noun(q{laminae})->singular, q{lamina}  => q{singular: 'laminae' --> 'lamina'};
is noun(q{lamina})->singular,   q{lamina}  => q{singular: 'lamina' --> 'lamina'};
is noun(q{leishmanias})->singular, q{leishmania}  => q{singular: 'leishmanias' --> 'leishmania'};
is noun(q{leishmania})->singular,   q{leishmania}  => q{singular: 'leishmania' --> 'leishmania'};
is noun(q{beaux hommes})->singular, q{bel homme}  => q{singular: 'beaux hommes' --> 'bel homme'};
is noun(q{bel homme})->singular,   q{bel homme}  => q{singular: 'bel homme' --> 'bel homme'};
is noun(q{men milliners})->singular, q{man milliner}  => q{singular: 'men milliners' --> 'man milliner'};
is noun(q{man milliner})->singular,   q{man milliner}  => q{singular: 'man milliner' --> 'man milliner'};
is noun(q{Selmans})->singular, q{Selman}  => q{singular: 'Selmans' --> 'Selman'};
is noun(q{Selman})->singular,   q{Selman}  => q{singular: 'Selman' --> 'Selman'};
is noun(q{memoranda})->singular, q{memorandum}  => q{singular: 'memoranda' --> 'memorandum'};
is noun(q{memorandum})->singular,   q{memorandum}  => q{singular: 'memorandum' --> 'memorandum'};
is noun(q{irides})->singular, q{iris}  => q{singular: 'irides' --> 'iris'};
is noun(q{iris})->singular,   q{iris}  => q{singular: 'iris' --> 'iris'};
is noun(q{snipes})->singular, q{snipe}  => q{singular: 'snipes' --> 'snipe'};
is noun(q{editiones principes})->singular, q{editio princeps}  => q{singular: 'editiones principes' --> 'editio princeps'};
is noun(q{editio princeps})->singular,   q{editio princeps}  => q{singular: 'editio princeps' --> 'editio princeps'};
is noun(q{sum totals})->singular, q{sum total}  => q{singular: 'sum totals' --> 'sum total'};
is noun(q{sum total})->singular,   q{sum total}  => q{singular: 'sum total' --> 'sum total'};
is noun(q{coneys})->singular, q{coney}  => q{singular: 'coneys' --> 'coney'};
is noun(q{coney})->singular,   q{coney}  => q{singular: 'coney' --> 'coney'};
is noun(q{Senegalese})->singular, q{Senegalese}  => q{singular: 'Senegalese' --> 'Senegalese'};
is noun(q{representamina})->singular, q{representamen}  => q{singular: 'representamina' --> 'representamen'};
is noun(q{representamen})->singular,   q{representamen}  => q{singular: 'representamen' --> 'representamen'};
is noun(q{interphenomena})->singular, q{interphenomenon}  => q{singular: 'interphenomena' --> 'interphenomenon'};
is noun(q{interphenomenon})->singular,   q{interphenomenon}  => q{singular: 'interphenomenon' --> 'interphenomenon'};
is noun(q{lei})->singular, q{leu}  => q{singular: 'lei' --> 'leu'};
is noun(q{leu})->singular,   q{leu}  => q{singular: 'leu' --> 'leu'};
is noun(q{aquariums})->singular, q{aquarium}  => q{singular: 'aquariums' --> 'aquarium'};
is noun(q{aquarium})->singular,   q{aquarium}  => q{singular: 'aquarium' --> 'aquarium'};
is noun(q{strobili})->singular, q{strobilus}  => q{singular: 'strobili' --> 'strobilus'};
is noun(q{strobilus})->singular,   q{strobilus}  => q{singular: 'strobilus' --> 'strobilus'};
is noun(q{Shavese})->singular, q{Shavese}  => q{singular: 'Shavese' --> 'Shavese'};
is noun(q{laiki})->singular, q{laika}  => q{singular: 'laiki' --> 'laika'};
is noun(q{laika})->singular,   q{laika}  => q{singular: 'laika' --> 'laika'};
is noun(q{umbones})->singular, q{umbo}  => q{singular: 'umbones' --> 'umbo'};
is noun(q{umbo})->singular,   q{umbo}  => q{singular: 'umbo' --> 'umbo'};
is noun(q{squadrists})->singular, q{squadrist}  => q{singular: 'squadrists' --> 'squadrist'};
is noun(q{squadrist})->singular,   q{squadrist}  => q{singular: 'squadrist' --> 'squadrist'};
is noun(q{forums})->singular, q{forum}  => q{singular: 'forums' --> 'forum'};
is noun(q{forum})->singular,   q{forum}  => q{singular: 'forum' --> 'forum'};
is noun(q{lieder})->singular, q{lied}  => q{singular: 'lieder' --> 'lied'};
is noun(q{lied})->singular,   q{lied}  => q{singular: 'lied' --> 'lied'};
is noun(q{synapticulas})->singular, q{synapticula}  => q{singular: 'synapticulas' --> 'synapticula'};
is noun(q{synapticula})->singular,   q{synapticula}  => q{singular: 'synapticula' --> 'synapticula'};
is noun(q{leaves})->singular, q{leaf}  => q{singular: 'leaves' --> 'leaf'};
is noun(q{leaf})->singular,   q{leaf}  => q{singular: 'leaf' --> 'leaf'};
is noun(q{evirati})->singular, q{evirato}  => q{singular: 'evirati' --> 'evirato'};
is noun(q{evirato})->singular,   q{evirato}  => q{singular: 'evirato' --> 'evirato'};
is noun(q{dies})->singular, q{die}  => q{singular: 'dies' --> 'die'};
is noun(q{die})->singular,   q{die}  => q{singular: 'die' --> 'die'};
is noun(q{faunae})->singular, q{fauna}  => q{singular: 'faunae' --> 'fauna'};
is noun(q{fauna})->singular,   q{fauna}  => q{singular: 'fauna' --> 'fauna'};
is noun(q{legionellae})->singular, q{legionella}  => q{singular: 'legionellae' --> 'legionella'};
is noun(q{legionella})->singular,   q{legionella}  => q{singular: 'legionella' --> 'legionella'};
is noun(q{onagers})->singular, q{onager}  => q{singular: 'onagers' --> 'onager'};
is noun(q{onager})->singular,   q{onager}  => q{singular: 'onager' --> 'onager'};
is noun(q{eroses})->singular, q{eros}  => q{singular: 'eroses' --> 'eros'};
is noun(q{eros})->singular,   q{eros}  => q{singular: 'eros' --> 'eros'};
is noun(q{secundagravidas})->singular, q{secundagravida}  => q{singular: 'secundagravidas' --> 'secundagravida'};
is noun(q{secundagravida})->singular,   q{secundagravida}  => q{singular: 'secundagravida' --> 'secundagravida'};
is noun(q{frustula})->singular, q{frustulum}  => q{singular: 'frustula' --> 'frustulum'};
is noun(q{frustulum})->singular,   q{frustulum}  => q{singular: 'frustulum' --> 'frustulum'};
is noun(q{helices})->singular, q{helix}  => q{singular: 'helices' --> 'helix'};
is noun(q{helix})->singular,   q{helix}  => q{singular: 'helix' --> 'helix'};
is noun(q{famuli})->singular, q{famulus}  => q{singular: 'famuli' --> 'famulus'};
is noun(q{famulus})->singular,   q{famulus}  => q{singular: 'famulus' --> 'famulus'};
is noun(q{solaria})->singular, q{solarium}  => q{singular: 'solaria' --> 'solarium'};
is noun(q{solarium})->singular,   q{solarium}  => q{singular: 'solarium' --> 'solarium'};
is noun(q{situlas})->singular, q{situla}  => q{singular: 'situlas' --> 'situla'};
is noun(q{situla})->singular,   q{situla}  => q{singular: 'situla' --> 'situla'};
is noun(q{meshumadim})->singular, q{meshumad}  => q{singular: 'meshumadim' --> 'meshumad'};
is noun(q{meshumad})->singular,   q{meshumad}  => q{singular: 'meshumad' --> 'meshumad'};
is noun(q{shelves})->singular, q{shelf}  => q{singular: 'shelves' --> 'shelf'};
is noun(q{shelf})->singular,   q{shelf}  => q{singular: 'shelf' --> 'shelf'};
is noun(q{rhinoceroses})->singular, q{rhinoceros}  => q{singular: 'rhinoceroses' --> 'rhinoceros'};
is noun(q{Bolzanos})->singular, q{Bolzano}  => q{singular: 'Bolzanos' --> 'Bolzano'};
is noun(q{Bolzano})->singular,   q{Bolzano}  => q{singular: 'Bolzano' --> 'Bolzano'};
is noun(q{frottole})->singular, q{frottola}  => q{singular: 'frottole' --> 'frottola'};
is noun(q{frottola})->singular,   q{frottola}  => q{singular: 'frottola' --> 'frottola'};
is noun(q{hoes})->singular, q{hoe}  => q{singular: 'hoes' --> 'hoe'};
is noun(q{hoe})->singular,   q{hoe}  => q{singular: 'hoe' --> 'hoe'};
is noun(q{pipkraker})->singular, q{pipkrake}  => q{singular: 'pipkraker' --> 'pipkrake'};
is noun(q{pipkrake})->singular,   q{pipkrake}  => q{singular: 'pipkrake' --> 'pipkrake'};
is noun(q{Kanarese})->singular, q{Kanarese}  => q{singular: 'Kanarese' --> 'Kanarese'};
is noun(q{temblores})->singular, q{temblor}  => q{singular: 'temblores' --> 'temblor'};
is noun(q{temblor})->singular,   q{temblor}  => q{singular: 'temblor' --> 'temblor'};
is noun(q{metae})->singular, q{meta}  => q{singular: 'metae' --> 'meta'};
is noun(q{meta})->singular,   q{meta}  => q{singular: 'meta' --> 'meta'};
is noun(q{metapleura})->singular, q{metapleuron}  => q{singular: 'metapleura' --> 'metapleuron'};
is noun(q{metapleuron})->singular,   q{metapleuron}  => q{singular: 'metapleuron' --> 'metapleuron'};
is noun(q{sternos})->singular, q{sterno}  => q{singular: 'sternos' --> 'sterno'};
is noun(q{sterno})->singular,   q{sterno}  => q{singular: 'sterno' --> 'sterno'};
is noun(q{vibrios})->singular, q{vibrio}  => q{singular: 'vibrios' --> 'vibrio'};
is noun(q{vibrio})->singular,   q{vibrio}  => q{singular: 'vibrio' --> 'vibrio'};
is noun(q{bordereaux})->singular, q{bordereau}  => q{singular: 'bordereaux' --> 'bordereau'};
is noun(q{bordereau})->singular,   q{bordereau}  => q{singular: 'bordereau' --> 'bordereau'};
is noun(q{Dracos})->singular, q{Draco}  => q{singular: 'Dracos' --> 'Draco'};
is noun(q{Draco})->singular,   q{Draco}  => q{singular: 'Draco' --> 'Draco'};
is noun(q{Heavenese})->singular, q{Heavenese}  => q{singular: 'Heavenese' --> 'Heavenese'};
is noun(q{trapeziums})->singular, q{trapezium}  => q{singular: 'trapeziums' --> 'trapezium'};
is noun(q{trapezium})->singular,   q{trapezium}  => q{singular: 'trapezium' --> 'trapezium'};
is noun(q{thesauri})->singular, q{thesaurus}  => q{singular: 'thesauri' --> 'thesaurus'};
is noun(q{thesaurus})->singular,   q{thesaurus}  => q{singular: 'thesaurus' --> 'thesaurus'};
is noun(q{columnae})->singular, q{columna}  => q{singular: 'columnae' --> 'columna'};
is noun(q{columna})->singular,   q{columna}  => q{singular: 'columna' --> 'columna'};
is noun(q{agapae})->singular, q{agape}  => q{singular: 'agapae' --> 'agape'};
is noun(q{agape})->singular,   q{agape}  => q{singular: 'agape' --> 'agape'};
is noun(q{silos})->singular, q{silo}  => q{singular: 'silos' --> 'silo'};
is noun(q{silo})->singular,   q{silo}  => q{singular: 'silo' --> 'silo'};
is noun(q{plutei})->singular, q{pluteus}  => q{singular: 'plutei' --> 'pluteus'};
is noun(q{pluteus})->singular,   q{pluteus}  => q{singular: 'pluteus' --> 'pluteus'};
is noun(q{persons})->singular, q{person}  => q{singular: 'persons' --> 'person'};
is noun(q{person})->singular,   q{person}  => q{singular: 'person' --> 'person'};
is noun(q{interstitiums})->singular, q{interstitium}  => q{singular: 'interstitiums' --> 'interstitium'};
is noun(q{interstitium})->singular,   q{interstitium}  => q{singular: 'interstitium' --> 'interstitium'};
is noun(q{Sinhalese})->singular, q{Sinhalese}  => q{singular: 'Sinhalese' --> 'Sinhalese'};
is noun(q{teredos})->singular, q{teredo}  => q{singular: 'teredos' --> 'teredo'};
is noun(q{teredo})->singular,   q{teredo}  => q{singular: 'teredo' --> 'teredo'};
is noun(q{ados})->singular, q{ado}  => q{singular: 'ados' --> 'ado'};
is noun(q{ado})->singular,   q{ado}  => q{singular: 'ado' --> 'ado'};
is noun(q{lochi})->singular, q{lochus}  => q{singular: 'lochi' --> 'lochus'};
is noun(q{lochus})->singular,   q{lochus}  => q{singular: 'lochus' --> 'lochus'};
is noun(q{cellos})->singular, q{cello}  => q{singular: 'cellos' --> 'cello'};
is noun(q{cello})->singular,   q{cello}  => q{singular: 'cello' --> 'cello'};
is noun(q{Jerrys})->singular, q{Jerry}  => q{singular: 'Jerrys' --> 'Jerry'};
is noun(q{Jerry})->singular,   q{Jerry}  => q{singular: 'Jerry' --> 'Jerry'};
is noun(q{hordeola})->singular, q{hordeolum}  => q{singular: 'hordeola' --> 'hordeolum'};
is noun(q{hordeolum})->singular,   q{hordeolum}  => q{singular: 'hordeolum' --> 'hordeolum'};
is noun(q{hippos})->singular, q{hippo}  => q{singular: 'hippos' --> 'hippo'};
is noun(q{hippo})->singular,   q{hippo}  => q{singular: 'hippo' --> 'hippo'};
is noun(q{nagaikas})->singular, q{nagaika}  => q{singular: 'nagaikas' --> 'nagaika'};
is noun(q{nagaika})->singular,   q{nagaika}  => q{singular: 'nagaika' --> 'nagaika'};
is noun(q{autos-de-fes})->singular, q{auto-de-fe}  => q{singular: 'autos-de-fes' --> 'auto-de-fe'};
is noun(q{auto-de-fe})->singular,   q{auto-de-fe}  => q{singular: 'auto-de-fe' --> 'auto-de-fe'};
is noun(q{pengo})->singular, q{pengo}  => q{singular: 'pengo' --> 'pengo'};
is noun(q{moes})->singular, q{moe}  => q{singular: 'moes' --> 'moe'};
is noun(q{moe})->singular,   q{moe}  => q{singular: 'moe' --> 'moe'};
is noun(q{voeux})->singular, q{voeu}  => q{singular: 'voeux' --> 'voeu'};
is noun(q{voeu})->singular,   q{voeu}  => q{singular: 'voeu' --> 'voeu'};
is noun(q{mafiose})->singular, q{mafiosa}  => q{singular: 'mafiose' --> 'mafiosa'};
is noun(q{mafiosa})->singular,   q{mafiosa}  => q{singular: 'mafiosa' --> 'mafiosa'};
is noun(q{crura})->singular, q{crus}  => q{singular: 'crura' --> 'crus'};
is noun(q{crus})->singular,   q{crus}  => q{singular: 'crus' --> 'crus'};
is noun(q{Yengeese})->singular, q{Yengeese}  => q{singular: 'Yengeese' --> 'Yengeese'};
is noun(q{kine})->singular, q{cow}  => q{singular: 'kine' --> 'cow'};
is noun(q{cow})->singular,   q{cow}  => q{singular: 'cow' --> 'cow'};
is noun(q{agends})->singular, q{agend}  => q{singular: 'agends' --> 'agend'};
is noun(q{agend})->singular,   q{agend}  => q{singular: 'agend' --> 'agend'};
is noun(q{entia rationis})->singular, q{ens rationis}  => q{singular: 'entia rationis' --> 'ens rationis'};
is noun(q{ens rationis})->singular,   q{ens rationis}  => q{singular: 'ens rationis' --> 'ens rationis'};
is noun(q{scoleces})->singular, q{scolex}  => q{singular: 'scoleces' --> 'scolex'};
is noun(q{scolex})->singular,   q{scolex}  => q{singular: 'scolex' --> 'scolex'};
is noun(q{teratomata})->singular, q{teratoma}  => q{singular: 'teratomata' --> 'teratoma'};
is noun(q{teratoma})->singular,   q{teratoma}  => q{singular: 'teratoma' --> 'teratoma'};
is noun(q{anathemas})->singular, q{anathema}  => q{singular: 'anathemas' --> 'anathema'};
is noun(q{anathema})->singular,   q{anathema}  => q{singular: 'anathema' --> 'anathema'};
is noun(q{kare})->singular, q{kar}  => q{singular: 'kare' --> 'kar'};
is noun(q{kar})->singular,   q{kar}  => q{singular: 'kar' --> 'kar'};
is noun(q{Romanese})->singular, q{Romanese}  => q{singular: 'Romanese' --> 'Romanese'};
is noun(q{hiatus})->singular, q{hiatus}  => q{singular: 'hiatus' --> 'hiatus'};
is noun(q{plasmalemmas})->singular, q{plasmalemma}  => q{singular: 'plasmalemmas' --> 'plasmalemma'};
is noun(q{plasmalemma})->singular,   q{plasmalemma}  => q{singular: 'plasmalemma' --> 'plasmalemma'};
is noun(q{turbot})->singular, q{turbot}  => q{singular: 'turbot' --> 'turbot'};
is noun(q{crescendos})->singular, q{crescendo}  => q{singular: 'crescendos' --> 'crescendo'};
is noun(q{crescendo})->singular,   q{crescendo}  => q{singular: 'crescendo' --> 'crescendo'};
is noun(q{sphinxes})->singular, q{sphinx}  => q{singular: 'sphinxes' --> 'sphinx'};
is noun(q{sphinx})->singular,   q{sphinx}  => q{singular: 'sphinx' --> 'sphinx'};
is noun(q{Celanese})->singular, q{Celanese}  => q{singular: 'Celanese' --> 'Celanese'};
is noun(q{geisha})->singular, q{geisha}  => q{singular: 'geisha' --> 'geisha'};
is noun(q{silbadores})->singular, q{silbador}  => q{singular: 'silbadores' --> 'silbador'};
is noun(q{silbador})->singular,   q{silbador}  => q{singular: 'silbador' --> 'silbador'};
is noun(q{ultimatums})->singular, q{ultimatum}  => q{singular: 'ultimatums' --> 'ultimatum'};
is noun(q{ultimatum})->singular,   q{ultimatum}  => q{singular: 'ultimatum' --> 'ultimatum'};
is noun(q{intercalare})->singular, q{intercalarium}  => q{singular: 'intercalare' --> 'intercalarium'};
is noun(q{intercalarium})->singular,   q{intercalarium}  => q{singular: 'intercalarium' --> 'intercalarium'};
is noun(q{zoophori})->singular, q{zoophorus}  => q{singular: 'zoophori' --> 'zoophorus'};
is noun(q{zoophorus})->singular,   q{zoophorus}  => q{singular: 'zoophorus' --> 'zoophorus'};
is noun(q{calypsos})->singular, q{calypso}  => q{singular: 'calypsos' --> 'calypso'};
is noun(q{calypso})->singular,   q{calypso}  => q{singular: 'calypso' --> 'calypso'};
is noun(q{eland})->singular, q{eland}  => q{singular: 'eland' --> 'eland'};
is noun(q{alans})->singular, q{alan}  => q{singular: 'alans' --> 'alan'};
is noun(q{alan})->singular,   q{alan}  => q{singular: 'alan' --> 'alan'};
is noun(q{bierstuben})->singular, q{bierstube}  => q{singular: 'bierstuben' --> 'bierstube'};
is noun(q{bierstube})->singular,   q{bierstube}  => q{singular: 'bierstube' --> 'bierstube'};
is noun(q{teal})->singular, q{teal}  => q{singular: 'teal' --> 'teal'};
is noun(q{hydrae})->singular, q{hydra}  => q{singular: 'hydrae' --> 'hydra'};
is noun(q{hydra})->singular,   q{hydra}  => q{singular: 'hydra' --> 'hydra'};
is noun(q{synaesthesiae})->singular, q{synaesthesia}  => q{singular: 'synaesthesiae' --> 'synaesthesia'};
is noun(q{synaesthesia})->singular,   q{synaesthesia}  => q{singular: 'synaesthesia' --> 'synaesthesia'};
is noun(q{legumens})->singular, q{legumen}  => q{singular: 'legumens' --> 'legumen'};
is noun(q{legumen})->singular,   q{legumen}  => q{singular: 'legumen' --> 'legumen'};
is noun(q{melastomae})->singular, q{melastoma}  => q{singular: 'melastomae' --> 'melastoma'};
is noun(q{melastoma})->singular,   q{melastoma}  => q{singular: 'melastoma' --> 'melastoma'};
is noun(q{personae})->singular, q{persona}  => q{singular: 'personae' --> 'persona'};
is noun(q{persona})->singular,   q{persona}  => q{singular: 'persona' --> 'persona'};
is noun(q{sterigmata})->singular, q{sterigma}  => q{singular: 'sterigmata' --> 'sterigma'};
is noun(q{sterigma})->singular,   q{sterigma}  => q{singular: 'sterigma' --> 'sterigma'};
is noun(q{testudos})->singular, q{testudo}  => q{singular: 'testudos' --> 'testudo'};
is noun(q{testudo})->singular,   q{testudo}  => q{singular: 'testudo' --> 'testudo'};
is noun(q{collegia musica})->singular, q{collegium musicum}  => q{singular: 'collegia musica' --> 'collegium musicum'};
is noun(q{collegium musicum})->singular,   q{collegium musicum}  => q{singular: 'collegium musicum' --> 'collegium musicum'};
is noun(q{myelomata})->singular, q{myeloma}  => q{singular: 'myelomata' --> 'myeloma'};
is noun(q{myeloma})->singular,   q{myeloma}  => q{singular: 'myeloma' --> 'myeloma'};
is noun(q{konditorei})->singular, q{konditorei}  => q{singular: 'konditorei' --> 'konditorei'};
is noun(q{vile})->singular, q{vila}  => q{singular: 'vile' --> 'vila'};
is noun(q{vila})->singular,   q{vila}  => q{singular: 'vila' --> 'vila'};
is noun(q{machos})->singular, q{macho}  => q{singular: 'machos' --> 'macho'};
is noun(q{macho})->singular,   q{macho}  => q{singular: 'macho' --> 'macho'};
is noun(q{monotae})->singular, q{monota}  => q{singular: 'monotae' --> 'monota'};
is noun(q{monota})->singular,   q{monota}  => q{singular: 'monota' --> 'monota'};
is noun(q{nuntii})->singular, q{nuntius}  => q{singular: 'nuntii' --> 'nuntius'};
is noun(q{nuntius})->singular,   q{nuntius}  => q{singular: 'nuntius' --> 'nuntius'};
is noun(q{mezzo rilievos})->singular, q{mezzo rilievo}  => q{singular: 'mezzo rilievos' --> 'mezzo rilievo'};
is noun(q{mezzo rilievo})->singular,   q{mezzo rilievo}  => q{singular: 'mezzo rilievo' --> 'mezzo rilievo'};
is noun(q{designata})->singular, q{designatum}  => q{singular: 'designata' --> 'designatum'};
is noun(q{designatum})->singular,   q{designatum}  => q{singular: 'designatum' --> 'designatum'};
is noun(q{cassoni})->singular, q{cassone}  => q{singular: 'cassoni' --> 'cassone'};
is noun(q{cassone})->singular,   q{cassone}  => q{singular: 'cassone' --> 'cassone'};
is noun(q{honoraria})->singular, q{honorarium}  => q{singular: 'honoraria' --> 'honorarium'};
is noun(q{honorarium})->singular,   q{honorarium}  => q{singular: 'honorarium' --> 'honorarium'};
is noun(q{cristae})->singular, q{crista}  => q{singular: 'cristae' --> 'crista'};
is noun(q{crista})->singular,   q{crista}  => q{singular: 'crista' --> 'crista'};
is noun(q{plectra})->singular, q{plectrum}  => q{singular: 'plectra' --> 'plectrum'};
is noun(q{plectrum})->singular,   q{plectrum}  => q{singular: 'plectrum' --> 'plectrum'};
is noun(q{pterylae})->singular, q{pteryla}  => q{singular: 'pterylae' --> 'pteryla'};
is noun(q{pteryla})->singular,   q{pteryla}  => q{singular: 'pteryla' --> 'pteryla'};
is noun(q{lisses})->singular, q{lis}  => q{singular: 'lisses' --> 'lis'};
is noun(q{dolmans})->singular, q{dolman}  => q{singular: 'dolmans' --> 'dolman'};
is noun(q{dolman})->singular,   q{dolman}  => q{singular: 'dolman' --> 'dolman'};
is noun(q{potatoes})->singular, q{potato}  => q{singular: 'potatoes' --> 'potato'};
is noun(q{potato})->singular,   q{potato}  => q{singular: 'potato' --> 'potato'};
is noun(q{remous})->singular, q{remous}  => q{singular: 'remous' --> 'remous'};
is noun(q{prosopia})->singular, q{prosopium}  => q{singular: 'prosopia' --> 'prosopium'};
is noun(q{prosopium})->singular,   q{prosopium}  => q{singular: 'prosopium' --> 'prosopium'};
is noun(q{podiums})->singular, q{podium}  => q{singular: 'podiums' --> 'podium'};
is noun(q{podium})->singular,   q{podium}  => q{singular: 'podium' --> 'podium'};
is noun(q{Faros})->singular, q{Faro}  => q{singular: 'Faros' --> 'Faro'};
is noun(q{Faro})->singular,   q{Faro}  => q{singular: 'Faro' --> 'Faro'};
is noun(q{Atlantes})->singular, q{Atlas}  => q{singular: 'Atlantes' --> 'Atlas'};
is noun(q{Atlas})->singular,   q{Atlas}  => q{singular: 'Atlas' --> 'Atlas'};
is noun(q{anacolutha})->singular, q{anacoluthon}  => q{singular: 'anacolutha' --> 'anacoluthon'};
is noun(q{anacoluthon})->singular,   q{anacoluthon}  => q{singular: 'anacoluthon' --> 'anacoluthon'};
is noun(q{auspices})->singular, q{auspex}  => q{singular: 'auspices' --> 'auspex'};
is noun(q{auspex})->singular,   q{auspex}  => q{singular: 'auspex' --> 'auspex'};
is noun(q{swine})->singular, q{swine}  => q{singular: 'swine' --> 'swine'};
is noun(q{noctilucae})->singular, q{noctiluca}  => q{singular: 'noctilucae' --> 'noctiluca'};
is noun(q{noctiluca})->singular,   q{noctiluca}  => q{singular: 'noctiluca' --> 'noctiluca'};
is noun(q{allargandi})->singular, q{allargando}  => q{singular: 'allargandi' --> 'allargando'};
is noun(q{allargando})->singular,   q{allargando}  => q{singular: 'allargando' --> 'allargando'};
is noun(q{sgraffiati})->singular, q{sgraffiato}  => q{singular: 'sgraffiati' --> 'sgraffiato'};
is noun(q{sgraffiato})->singular,   q{sgraffiato}  => q{singular: 'sgraffiato' --> 'sgraffiato'};
is noun(q{karakia})->singular, q{karakia}  => q{singular: 'karakia' --> 'karakia'};
is noun(q{nuclei})->singular, q{nucleus}  => q{singular: 'nuclei' --> 'nucleus'};
is noun(q{nucleus})->singular,   q{nucleus}  => q{singular: 'nucleus' --> 'nucleus'};
is noun(q{pintos})->singular, q{pinto}  => q{singular: 'pintos' --> 'pinto'};
is noun(q{pinto})->singular,   q{pinto}  => q{singular: 'pinto' --> 'pinto'};
is noun(q{velums})->singular, q{velum}  => q{singular: 'velums' --> 'velum'};
is noun(q{velum})->singular,   q{velum}  => q{singular: 'velum' --> 'velum'};
is noun(q{hypna})->singular, q{hypnum}  => q{singular: 'hypna' --> 'hypnum'};
is noun(q{hypnum})->singular,   q{hypnum}  => q{singular: 'hypnum' --> 'hypnum'};
is noun(q{4 star generals})->singular, q{4 star general}  => q{singular: '4 star generals' --> '4 star general'};
is noun(q{4 star general})->singular,   q{4 star general}  => q{singular: '4 star general' --> '4 star general'};
is noun(q{chintzes})->singular, q{chintz}  => q{singular: 'chintzes' --> 'chintz'};
is noun(q{chintz})->singular,   q{chintz}  => q{singular: 'chintz' --> 'chintz'};
is noun(q{womenchildren})->singular, q{womanchild}  => q{singular: 'womenchildren' --> 'womanchild'};
is noun(q{womanchild})->singular,   q{womanchild}  => q{singular: 'womanchild' --> 'womanchild'};
is noun(q{hemi elytra})->singular, q{hemi elytrum}  => q{singular: 'hemi elytra' --> 'hemi elytrum'};
is noun(q{hemi elytrum})->singular,   q{hemi elytrum}  => q{singular: 'hemi elytrum' --> 'hemi elytrum'};
is noun(q{Oklahomans})->singular, q{Oklahoman}  => q{singular: 'Oklahomans' --> 'Oklahoman'};
is noun(q{Oklahoman})->singular,   q{Oklahoman}  => q{singular: 'Oklahoman' --> 'Oklahoman'};
is noun(q{perradii})->singular, q{perradius}  => q{singular: 'perradii' --> 'perradius'};
is noun(q{perradius})->singular,   q{perradius}  => q{singular: 'perradius' --> 'perradius'};
is noun(q{sigli})->singular, q{siglos}  => q{singular: 'sigli' --> 'siglos'};
is noun(q{siglos})->singular,   q{siglos}  => q{singular: 'siglos' --> 'siglos'};
is noun(q{Botos})->singular, q{Boto}  => q{singular: 'Botos' --> 'Boto'};
is noun(q{Boto})->singular,   q{Boto}  => q{singular: 'Boto' --> 'Boto'};
is noun(q{agones})->singular, q{agon}  => q{singular: 'agones' --> 'agon'};
is noun(q{agon})->singular,   q{agon}  => q{singular: 'agon' --> 'agon'};
is noun(q{shawabtis})->singular, q{shawabti}  => q{singular: 'shawabtis' --> 'shawabti'};
is noun(q{shawabti})->singular,   q{shawabti}  => q{singular: 'shawabti' --> 'shawabti'};
is noun(q{hippopotamuses})->singular, q{hippopotamus}  => q{singular: 'hippopotamuses' --> 'hippopotamus'};
is noun(q{hippopotamus})->singular,   q{hippopotamus}  => q{singular: 'hippopotamus' --> 'hippopotamus'};
is noun(q{cardophagi})->singular, q{cardophagus}  => q{singular: 'cardophagi' --> 'cardophagus'};
is noun(q{cardophagus})->singular,   q{cardophagus}  => q{singular: 'cardophagus' --> 'cardophagus'};
is noun(q{contraltos})->singular, q{contralto}  => q{singular: 'contraltos' --> 'contralto'};
is noun(q{contralto})->singular,   q{contralto}  => q{singular: 'contralto' --> 'contralto'};
is noun(q{glacis})->singular, q{glacis}  => q{singular: 'glacis' --> 'glacis'};
is noun(q{clippers})->singular, q{clippers}  => q{singular: 'clippers' --> 'clippers'};
is noun(q{espanoles})->singular, q{espanol}  => q{singular: 'espanoles' --> 'espanol'};
is noun(q{espanol})->singular,   q{espanol}  => q{singular: 'espanol' --> 'espanol'};
is noun(q{herring})->singular, q{herring}  => q{singular: 'herring' --> 'herring'};
is noun(q{pennia})->singular, q{penni}  => q{singular: 'pennia' --> 'penni'};
is noun(q{penni})->singular,   q{penni}  => q{singular: 'penni' --> 'penni'};
is noun(q{cantuses})->singular, q{cantus}  => q{singular: 'cantuses' --> 'cantus'};
is noun(q{equinoctiums})->singular, q{equinoctium}  => q{singular: 'equinoctiums' --> 'equinoctium'};
is noun(q{equinoctium})->singular,   q{equinoctium}  => q{singular: 'equinoctium' --> 'equinoctium'};
is noun(q{moderni})->singular, q{modernus}  => q{singular: 'moderni' --> 'modernus'};
is noun(q{modernus})->singular,   q{modernus}  => q{singular: 'modernus' --> 'modernus'};
is noun(q{rhinoceros})->singular, q{rhinoceros}  => q{singular: 'rhinoceros' --> 'rhinoceros'};
is noun(q{women-children})->singular, q{woman-child}  => q{singular: 'women-children' --> 'woman-child'};
is noun(q{woman-child})->singular,   q{woman-child}  => q{singular: 'woman-child' --> 'woman-child'};
is noun(q{soes})->singular, q{so}  => q{singular: 'soes' --> 'so'};
is noun(q{so})->singular,   q{so}  => q{singular: 'so' --> 'so'};
is noun(q{papyri})->singular, q{papyrus}  => q{singular: 'papyri' --> 'papyrus'};
is noun(q{papyrus})->singular,   q{papyrus}  => q{singular: 'papyrus' --> 'papyrus'};
is noun(q{lords-lieutenant})->singular, q{lord-lieutenant}  => q{singular: 'lords-lieutenant' --> 'lord-lieutenant'};
is noun(q{lord-lieutenant})->singular,   q{lord-lieutenant}  => q{singular: 'lord-lieutenant' --> 'lord-lieutenant'};
is noun(q{yoes})->singular, q{yo}  => q{singular: 'yoes' --> 'yo'};
is noun(q{yo})->singular,   q{yo}  => q{singular: 'yo' --> 'yo'};
is noun(q{eunuchs})->singular, q{eunuch}  => q{singular: 'eunuchs' --> 'eunuch'};
is noun(q{eunuch})->singular,   q{eunuch}  => q{singular: 'eunuch' --> 'eunuch'};
is noun(q{residuums})->singular, q{residuum}  => q{singular: 'residuums' --> 'residuum'};
is noun(q{residuum})->singular,   q{residuum}  => q{singular: 'residuum' --> 'residuum'};
is noun(q{adminicula})->singular, q{adminiculum}  => q{singular: 'adminicula' --> 'adminiculum'};
is noun(q{adminiculum})->singular,   q{adminiculum}  => q{singular: 'adminiculum' --> 'adminiculum'};
is noun(q{baalim})->singular, q{baal}  => q{singular: 'baalim' --> 'baal'};
is noun(q{baal})->singular,   q{baal}  => q{singular: 'baal' --> 'baal'};
is noun(q{melicerides})->singular, q{meliceris}  => q{singular: 'melicerides' --> 'meliceris'};
is noun(q{meliceris})->singular,   q{meliceris}  => q{singular: 'meliceris' --> 'meliceris'};
is noun(q{varely})->singular, q{varella}  => q{singular: 'varely' --> 'varella'};
is noun(q{varella})->singular,   q{varella}  => q{singular: 'varella' --> 'varella'};
is noun(q{mortadellas})->singular, q{mortadella}  => q{singular: 'mortadellas' --> 'mortadella'};
is noun(q{mortadella})->singular,   q{mortadella}  => q{singular: 'mortadella' --> 'mortadella'};
is noun(q{rhinos})->singular, q{rhino}  => q{singular: 'rhinos' --> 'rhino'};
is noun(q{rhino})->singular,   q{rhino}  => q{singular: 'rhino' --> 'rhino'};
is noun(q{nouveaux riches})->singular, q{nouveau riche}  => q{singular: 'nouveaux riches' --> 'nouveau riche'};
is noun(q{nouveau riche})->singular,   q{nouveau riche}  => q{singular: 'nouveau riche' --> 'nouveau riche'};
is noun(q{scissors})->singular, q{scissors}  => q{singular: 'scissors' --> 'scissors'};
is noun(q{1-star generals})->singular, q{1-star general}  => q{singular: '1-star generals' --> '1-star general'};
is noun(q{1-star general})->singular,   q{1-star general}  => q{singular: '1-star general' --> '1-star general'};
is noun(q{beaux gestes})->singular, q{beau geste}  => q{singular: 'beaux gestes' --> 'beau geste'};
is noun(q{beau geste})->singular,   q{beau geste}  => q{singular: 'beau geste' --> 'beau geste'};
is noun(q{ale-wives})->singular, q{ale-wife}  => q{singular: 'ale-wives' --> 'ale-wife'};
is noun(q{ale-wife})->singular,   q{ale-wife}  => q{singular: 'ale-wife' --> 'ale-wife'};
is noun(q{puncta})->singular, q{punctum}  => q{singular: 'puncta' --> 'punctum'};
is noun(q{punctum})->singular,   q{punctum}  => q{singular: 'punctum' --> 'punctum'};
is noun(q{setae})->singular, q{seta}  => q{singular: 'setae' --> 'seta'};
is noun(q{seta})->singular,   q{seta}  => q{singular: 'seta' --> 'seta'};
is noun(q{politicoes})->singular, q{politico}  => q{singular: 'politicoes' --> 'politico'};
is noun(q{politico})->singular,   q{politico}  => q{singular: 'politico' --> 'politico'};
is noun(q{septaria})->singular, q{septarium}  => q{singular: 'septaria' --> 'septarium'};
is noun(q{septarium})->singular,   q{septarium}  => q{singular: 'septarium' --> 'septarium'};
is noun(q{they})->singular, q{it}  => q{singular: 'they' --> 'it'};
is noun(q{it})->singular,   q{it}  => q{singular: 'it' --> 'it'};
is noun(q{podetia})->singular, q{podetium}  => q{singular: 'podetia' --> 'podetium'};
is noun(q{podetium})->singular,   q{podetium}  => q{singular: 'podetium' --> 'podetium'};
is noun(q{platypuses})->singular, q{platypus}  => q{singular: 'platypuses' --> 'platypus'};
is noun(q{platypus})->singular,   q{platypus}  => q{singular: 'platypus' --> 'platypus'};
is noun(q{isthmuses})->singular, q{isthmus}  => q{singular: 'isthmuses' --> 'isthmus'};
is noun(q{isthmus})->singular,   q{isthmus}  => q{singular: 'isthmus' --> 'isthmus'};
is noun(q{nebulae})->singular, q{nebula}  => q{singular: 'nebulae' --> 'nebula'};
is noun(q{nebula})->singular,   q{nebula}  => q{singular: 'nebula' --> 'nebula'};
is noun(q{Balinese})->singular, q{Balinese}  => q{singular: 'Balinese' --> 'Balinese'};
is noun(q{radixes})->singular, q{radix}  => q{singular: 'radixes' --> 'radix'};
is noun(q{radix})->singular,   q{radix}  => q{singular: 'radix' --> 'radix'};
is noun(q{trichinae})->singular, q{trichina}  => q{singular: 'trichinae' --> 'trichina'};
is noun(q{trichina})->singular,   q{trichina}  => q{singular: 'trichina' --> 'trichina'};
is noun(q{magnum opuses})->singular, q{magnum opus}  => q{singular: 'magnum opuses' --> 'magnum opus'};
is noun(q{magnum opus})->singular,   q{magnum opus}  => q{singular: 'magnum opus' --> 'magnum opus'};
is noun(q{Swahilese})->singular, q{Swahilese}  => q{singular: 'Swahilese' --> 'Swahilese'};
is noun(q{zeppoli})->singular, q{zeppole}  => q{singular: 'zeppoli' --> 'zeppole'};
is noun(q{zeppole})->singular,   q{zeppole}  => q{singular: 'zeppole' --> 'zeppole'};
is noun(q{stellae})->singular, q{stella}  => q{singular: 'stellae' --> 'stella'};
is noun(q{stella})->singular,   q{stella}  => q{singular: 'stella' --> 'stella'};
is noun(q{magmata})->singular, q{magma}  => q{singular: 'magmata' --> 'magma'};
is noun(q{magma})->singular,   q{magma}  => q{singular: 'magma' --> 'magma'};
is noun(q{lieus})->singular, q{lieu}  => q{singular: 'lieus' --> 'lieu'};
is noun(q{lieu})->singular,   q{lieu}  => q{singular: 'lieu' --> 'lieu'};
is noun(q{minima})->singular, q{minimum}  => q{singular: 'minima' --> 'minimum'};
is noun(q{minimum})->singular,   q{minimum}  => q{singular: 'minimum' --> 'minimum'};
is noun(q{felones})->singular, q{felo}  => q{singular: 'felones' --> 'felo'};
is noun(q{felo})->singular,   q{felo}  => q{singular: 'felo' --> 'felo'};
is noun(q{torulae})->singular, q{torula}  => q{singular: 'torulae' --> 'torula'};
is noun(q{torula})->singular,   q{torula}  => q{singular: 'torula' --> 'torula'};
is noun(q{divertimenti})->singular, q{divertimento}  => q{singular: 'divertimenti' --> 'divertimento'};
is noun(q{divertimento})->singular,   q{divertimento}  => q{singular: 'divertimento' --> 'divertimento'};
is noun(q{strategi})->singular, q{strategus}  => q{singular: 'strategi' --> 'strategus'};
is noun(q{strategus})->singular,   q{strategus}  => q{singular: 'strategus' --> 'strategus'};
is noun(q{morceaux})->singular, q{morceau}  => q{singular: 'morceaux' --> 'morceau'};
is noun(q{morceau})->singular,   q{morceau}  => q{singular: 'morceau' --> 'morceau'};
is noun(q{parabolae})->singular, q{parabola}  => q{singular: 'parabolae' --> 'parabola'};
is noun(q{parabola})->singular,   q{parabola}  => q{singular: 'parabola' --> 'parabola'};
is noun(q{starovers})->singular, q{starover}  => q{singular: 'starovers' --> 'starover'};
is noun(q{starover})->singular,   q{starover}  => q{singular: 'starover' --> 'starover'};
is noun(q{auto-de-fes})->singular, q{auto-de-fe}  => q{singular: 'auto-de-fes' --> 'auto-de-fe'};
is noun(q{auto-de-fe})->singular,   q{auto-de-fe}  => q{singular: 'auto-de-fe' --> 'auto-de-fe'};
is noun(q{menages a quatre})->singular, q{menage a quatre}  => q{singular: 'menages a quatre' --> 'menage a quatre'};
is noun(q{menage a quatre})->singular,   q{menage a quatre}  => q{singular: 'menage a quatre' --> 'menage a quatre'};
is noun(q{bathoses})->singular, q{bathos}  => q{singular: 'bathoses' --> 'bathos'};
is noun(q{bathos})->singular,   q{bathos}  => q{singular: 'bathos' --> 'bathos'};
is noun(q{Lilos})->singular, q{Lilo}  => q{singular: 'Lilos' --> 'Lilo'};
is noun(q{Lilo})->singular,   q{Lilo}  => q{singular: 'Lilo' --> 'Lilo'};
is noun(q{coccidia})->singular, q{coccidium}  => q{singular: 'coccidia' --> 'coccidium'};
is noun(q{coccidium})->singular,   q{coccidium}  => q{singular: 'coccidium' --> 'coccidium'};
is noun(q{nucleoli})->singular, q{nucleolus}  => q{singular: 'nucleoli' --> 'nucleolus'};
is noun(q{nucleolus})->singular,   q{nucleolus}  => q{singular: 'nucleolus' --> 'nucleolus'};
is noun(q{cerimans})->singular, q{ceriman}  => q{singular: 'cerimans' --> 'ceriman'};
is noun(q{ceriman})->singular,   q{ceriman}  => q{singular: 'ceriman' --> 'ceriman'};
is noun(q{otomi})->singular, q{otomi}  => q{singular: 'otomi' --> 'otomi'};
is noun(q{asylums})->singular, q{asylum}  => q{singular: 'asylums' --> 'asylum'};
is noun(q{asylum})->singular,   q{asylum}  => q{singular: 'asylum' --> 'asylum'};
is noun(q{extrema})->singular, q{extremum}  => q{singular: 'extrema' --> 'extremum'};
is noun(q{extremum})->singular,   q{extremum}  => q{singular: 'extremum' --> 'extremum'};
is noun(q{supracleithra})->singular, q{supracleithrum}  => q{singular: 'supracleithra' --> 'supracleithrum'};
is noun(q{supracleithrum})->singular,   q{supracleithrum}  => q{singular: 'supracleithrum' --> 'supracleithrum'};
is noun(q{syrphi})->singular, q{syrphus}  => q{singular: 'syrphi' --> 'syrphus'};
is noun(q{syrphus})->singular,   q{syrphus}  => q{singular: 'syrphus' --> 'syrphus'};
is noun(q{linctuses})->singular, q{linctus}  => q{singular: 'linctuses' --> 'linctus'};
is noun(q{linctus})->singular,   q{linctus}  => q{singular: 'linctus' --> 'linctus'};
is noun(q{alberghi})->singular, q{albergo}  => q{singular: 'alberghi' --> 'albergo'};
is noun(q{albergo})->singular,   q{albergo}  => q{singular: 'albergo' --> 'albergo'};
is noun(q{panini})->singular, q{panino}  => q{singular: 'panini' --> 'panino'};
is noun(q{panino})->singular,   q{panino}  => q{singular: 'panino' --> 'panino'};
is noun(q{supposita})->singular, q{suppositum}  => q{singular: 'supposita' --> 'suppositum'};
is noun(q{suppositum})->singular,   q{suppositum}  => q{singular: 'suppositum' --> 'suppositum'};
is noun(q{Madurese})->singular, q{Madurese}  => q{singular: 'Madurese' --> 'Madurese'};
is noun(q{Asherim})->singular, q{Asherah}  => q{singular: 'Asherim' --> 'Asherah'};
is noun(q{Asherah})->singular,   q{Asherah}  => q{singular: 'Asherah' --> 'Asherah'};
is noun(q{bandits})->singular, q{bandit}  => q{singular: 'bandits' --> 'bandit'};
is noun(q{bandit})->singular,   q{bandit}  => q{singular: 'bandit' --> 'bandit'};
is noun(q{emporiums})->singular, q{emporium}  => q{singular: 'emporiums' --> 'emporium'};
is noun(q{emporium})->singular,   q{emporium}  => q{singular: 'emporium' --> 'emporium'};
is noun(q{ballerinas})->singular, q{ballerina}  => q{singular: 'ballerinas' --> 'ballerina'};
is noun(q{ballerina})->singular,   q{ballerina}  => q{singular: 'ballerina' --> 'ballerina'};
is noun(q{dictums})->singular, q{dictum}  => q{singular: 'dictums' --> 'dictum'};
is noun(q{dictum})->singular,   q{dictum}  => q{singular: 'dictum' --> 'dictum'};
is noun(q{synangia})->singular, q{synangium}  => q{singular: 'synangia' --> 'synangium'};
is noun(q{synangium})->singular,   q{synangium}  => q{singular: 'synangium' --> 'synangium'};
is noun(q{sets out})->singular, q{set out}  => q{singular: 'sets out' --> 'set out'};
is noun(q{set out})->singular,   q{set out}  => q{singular: 'set out' --> 'set out'};
is noun(q{biscotti})->singular, q{biscotto}  => q{singular: 'biscotti' --> 'biscotto'};
is noun(q{biscotto})->singular,   q{biscotto}  => q{singular: 'biscotto' --> 'biscotto'};
is noun(q{phocas})->singular, q{phoca}  => q{singular: 'phocas' --> 'phoca'};
is noun(q{phoca})->singular,   q{phoca}  => q{singular: 'phoca' --> 'phoca'};
is noun(q{aptychi})->singular, q{aptychus}  => q{singular: 'aptychi' --> 'aptychus'};
is noun(q{aptychus})->singular,   q{aptychus}  => q{singular: 'aptychus' --> 'aptychus'};
is noun(q{crazie})->singular, q{crazia}  => q{singular: 'crazie' --> 'crazia'};
is noun(q{crazia})->singular,   q{crazia}  => q{singular: 'crazia' --> 'crazia'};
is noun(q{intervallums})->singular, q{intervallum}  => q{singular: 'intervallums' --> 'intervallum'};
is noun(q{intervallum})->singular,   q{intervallum}  => q{singular: 'intervallum' --> 'intervallum'};
is noun(q{thaumaturgi})->singular, q{thaumaturgus}  => q{singular: 'thaumaturgi' --> 'thaumaturgus'};
is noun(q{thaumaturgus})->singular,   q{thaumaturgus}  => q{singular: 'thaumaturgus' --> 'thaumaturgus'};
is noun(q{protomae})->singular, q{protoma}  => q{singular: 'protomae' --> 'protoma'};
is noun(q{protoma})->singular,   q{protoma}  => q{singular: 'protoma' --> 'protoma'};
is noun(q{choruses})->singular, q{chorus}  => q{singular: 'choruses' --> 'chorus'};
is noun(q{chorus})->singular,   q{chorus}  => q{singular: 'chorus' --> 'chorus'};
is noun(q{glochidia})->singular, q{glochidium}  => q{singular: 'glochidia' --> 'glochidium'};
is noun(q{glochidium})->singular,   q{glochidium}  => q{singular: 'glochidium' --> 'glochidium'};
is noun(q{daces})->singular, q{dace}  => q{singular: 'daces' --> 'dace'};
is noun(q{hakes})->singular, q{hake}  => q{singular: 'hakes' --> 'hake'};
is noun(q{Zibos})->singular, q{Zibo}  => q{singular: 'Zibos' --> 'Zibo'};
is noun(q{Zibo})->singular,   q{Zibo}  => q{singular: 'Zibo' --> 'Zibo'};
is noun(q{loaves})->singular, q{loaf}  => q{singular: 'loaves' --> 'loaf'};
is noun(q{loaf})->singular,   q{loaf}  => q{singular: 'loaf' --> 'loaf'};
is noun(q{taxes})->singular, q{taxis}  => q{singular: 'taxes' --> 'taxis'};
is noun(q{taxis})->singular,   q{taxis}  => q{singular: 'taxis' --> 'taxis'};
is noun(q{anacoluthons})->singular, q{anacoluthon}  => q{singular: 'anacoluthons' --> 'anacoluthon'};
is noun(q{anacoluthon})->singular,   q{anacoluthon}  => q{singular: 'anacoluthon' --> 'anacoluthon'};
is noun(q{fedais})->singular, q{fedai}  => q{singular: 'fedais' --> 'fedai'};
is noun(q{alulae})->singular, q{alula}  => q{singular: 'alulae' --> 'alula'};
is noun(q{alula})->singular,   q{alula}  => q{singular: 'alula' --> 'alula'};
is noun(q{carcinomata})->singular, q{carcinoma}  => q{singular: 'carcinomata' --> 'carcinoma'};
is noun(q{carcinoma})->singular,   q{carcinoma}  => q{singular: 'carcinoma' --> 'carcinoma'};
is noun(q{asyndeta})->singular, q{asyndeton}  => q{singular: 'asyndeta' --> 'asyndeton'};
is noun(q{asyndeton})->singular,   q{asyndeton}  => q{singular: 'asyndeton' --> 'asyndeton'};
is noun(q{stimuli})->singular, q{stimulus}  => q{singular: 'stimuli' --> 'stimulus'};
is noun(q{stimulus})->singular,   q{stimulus}  => q{singular: 'stimulus' --> 'stimulus'};
is noun(q{jambeaus})->singular, q{jambeau}  => q{singular: 'jambeaus' --> 'jambeau'};
is noun(q{jambeau})->singular,   q{jambeau}  => q{singular: 'jambeau' --> 'jambeau'};
is noun(q{acari})->singular, q{acarus}  => q{singular: 'acari' --> 'acarus'};
is noun(q{acarus})->singular,   q{acarus}  => q{singular: 'acarus' --> 'acarus'};
is noun(q{peciae})->singular, q{pecia}  => q{singular: 'peciae' --> 'pecia'};
is noun(q{pecia})->singular,   q{pecia}  => q{singular: 'pecia' --> 'pecia'};
is noun(q{thecae})->singular, q{theca}  => q{singular: 'thecae' --> 'theca'};
is noun(q{theca})->singular,   q{theca}  => q{singular: 'theca' --> 'theca'};
is noun(q{oreganos})->singular, q{oregano}  => q{singular: 'oreganos' --> 'oregano'};
is noun(q{oregano})->singular,   q{oregano}  => q{singular: 'oregano' --> 'oregano'};
is noun(q{referenda})->singular, q{referendum}  => q{singular: 'referenda' --> 'referendum'};
is noun(q{referendum})->singular,   q{referendum}  => q{singular: 'referendum' --> 'referendum'};
is noun(q{intermezzos})->singular, q{intermezzo}  => q{singular: 'intermezzos' --> 'intermezzo'};
is noun(q{intermezzo})->singular,   q{intermezzo}  => q{singular: 'intermezzo' --> 'intermezzo'};
is noun(q{alveoli})->singular, q{alveolus}  => q{singular: 'alveoli' --> 'alveolus'};
is noun(q{alveolus})->singular,   q{alveolus}  => q{singular: 'alveolus' --> 'alveolus'};
is noun(q{pulmonaria})->singular, q{pulmonarium}  => q{singular: 'pulmonaria' --> 'pulmonarium'};
is noun(q{pulmonarium})->singular,   q{pulmonarium}  => q{singular: 'pulmonarium' --> 'pulmonarium'};
is noun(q{sbirri})->singular, q{sbirro}  => q{singular: 'sbirri' --> 'sbirro'};
is noun(q{sbirro})->singular,   q{sbirro}  => q{singular: 'sbirro' --> 'sbirro'};
is noun(q{umwelten})->singular, q{umwelt}  => q{singular: 'umwelten' --> 'umwelt'};
is noun(q{umwelt})->singular,   q{umwelt}  => q{singular: 'umwelt' --> 'umwelt'};
is noun(q{scriptoria})->singular, q{scriptorium}  => q{singular: 'scriptoria' --> 'scriptorium'};
is noun(q{scriptorium})->singular,   q{scriptorium}  => q{singular: 'scriptorium' --> 'scriptorium'};
is noun(q{secundigravidae})->singular, q{secundigravida}  => q{singular: 'secundigravidae' --> 'secundigravida'};
is noun(q{secundigravida})->singular,   q{secundigravida}  => q{singular: 'secundigravida' --> 'secundigravida'};
is noun(q{duumvirs})->singular, q{duumvir}  => q{singular: 'duumvirs' --> 'duumvir'};
is noun(q{duumvir})->singular,   q{duumvir}  => q{singular: 'duumvir' --> 'duumvir'};
is noun(q{Piedmontese})->singular, q{Piedmontese}  => q{singular: 'Piedmontese' --> 'Piedmontese'};
is noun(q{nubeculae})->singular, q{nubecula}  => q{singular: 'nubeculae' --> 'nubecula'};
is noun(q{nubecula})->singular,   q{nubecula}  => q{singular: 'nubecula' --> 'nubecula'};
is noun(q{pili})->singular, q{pilus}  => q{singular: 'pili' --> 'pilus'};
is noun(q{pilus})->singular,   q{pilus}  => q{singular: 'pilus' --> 'pilus'};
is noun(q{army-corps generals})->singular, q{army-corps general}  => q{singular: 'army-corps generals' --> 'army-corps general'};
is noun(q{army-corps general})->singular,   q{army-corps general}  => q{singular: 'army-corps general' --> 'army-corps general'};
is noun(q{staminidia})->singular, q{staminidium}  => q{singular: 'staminidia' --> 'staminidium'};
is noun(q{staminidium})->singular,   q{staminidium}  => q{singular: 'staminidium' --> 'staminidium'};
is noun(q{Shawanese})->singular, q{Shawanese}  => q{singular: 'Shawanese' --> 'Shawanese'};
is noun(q{entia realia})->singular, q{ens reale}  => q{singular: 'entia realia' --> 'ens reale'};
is noun(q{ens reale})->singular,   q{ens reale}  => q{singular: 'ens reale' --> 'ens reale'};
is noun(q{antae})->singular, q{anta}  => q{singular: 'antae' --> 'anta'};
is noun(q{anta})->singular,   q{anta}  => q{singular: 'anta' --> 'anta'};
is noun(q{starovery})->singular, q{starover}  => q{singular: 'starovery' --> 'starover'};
is noun(q{starover})->singular,   q{starover}  => q{singular: 'starover' --> 'starover'};
is noun(q{tortillas espanolas})->singular, q{tortilla espanola}  => q{singular: 'tortillas espanolas' --> 'tortilla espanola'};
is noun(q{tortilla espanola})->singular,   q{tortilla espanola}  => q{singular: 'tortilla espanola' --> 'tortilla espanola'};
is noun(q{abscissas})->singular, q{abscissa}  => q{singular: 'abscissas' --> 'abscissa'};
is noun(q{abscissa})->singular,   q{abscissa}  => q{singular: 'abscissa' --> 'abscissa'};
is noun(q{terrae filii})->singular, q{terrae filius}  => q{singular: 'terrae filii' --> 'terrae filius'};
is noun(q{terrae filius})->singular,   q{terrae filius}  => q{singular: 'terrae filius' --> 'terrae filius'};
is noun(q{geniuses})->singular, q{genius}  => q{singular: 'geniuses' --> 'genius'};
is noun(q{genius})->singular,   q{genius}  => q{singular: 'genius' --> 'genius'};
is noun(q{Lapponese})->singular, q{Lapponese}  => q{singular: 'Lapponese' --> 'Lapponese'};
is noun(q{mafiosos})->singular, q{mafioso}  => q{singular: 'mafiosos' --> 'mafioso'};
is noun(q{mafioso})->singular,   q{mafioso}  => q{singular: 'mafioso' --> 'mafioso'};
is noun(q{desmas})->singular, q{desma}  => q{singular: 'desmas' --> 'desma'};
is noun(q{desma})->singular,   q{desma}  => q{singular: 'desma' --> 'desma'};
is noun(q{offspring})->singular, q{offspring}  => q{singular: 'offspring' --> 'offspring'};
is noun(q{soralia})->singular, q{soralium}  => q{singular: 'soralia' --> 'soralium'};
is noun(q{soralium})->singular,   q{soralium}  => q{singular: 'soralium' --> 'soralium'};
is noun(q{sotches})->singular, q{sotch}  => q{singular: 'sotches' --> 'sotch'};
is noun(q{sotch})->singular,   q{sotch}  => q{singular: 'sotch' --> 'sotch'};
is noun(q{melanomas})->singular, q{melanoma}  => q{singular: 'melanomas' --> 'melanoma'};
is noun(q{melanoma})->singular,   q{melanoma}  => q{singular: 'melanoma' --> 'melanoma'};
is noun(q{calices})->singular, q{calix}  => q{singular: 'calices' --> 'calix'};
is noun(q{calix})->singular,   q{calix}  => q{singular: 'calix' --> 'calix'};
is noun(q{pingos})->singular, q{pingo}  => q{singular: 'pingos' --> 'pingo'};
is noun(q{pingo})->singular,   q{pingo}  => q{singular: 'pingo' --> 'pingo'};
is noun(q{mafiosi})->singular, q{mafioso}  => q{singular: 'mafiosi' --> 'mafioso'};
is noun(q{mafioso})->singular,   q{mafioso}  => q{singular: 'mafioso' --> 'mafioso'};
is noun(q{bonis fidebus})->singular, q{bona fides}  => q{singular: 'bonis fidebus' --> 'bona fides'};
is noun(q{bona fides})->singular,   q{bona fides}  => q{singular: 'bona fides' --> 'bona fides'};
is noun(q{bechuanas})->singular, q{bechuana}  => q{singular: 'bechuanas' --> 'bechuana'};
is noun(q{cris de coeur})->singular, q{cri de coeur}  => q{singular: 'cris de coeur' --> 'cri de coeur'};
is noun(q{cri de coeur})->singular,   q{cri de coeur}  => q{singular: 'cri de coeur' --> 'cri de coeur'};
is noun(q{serrae})->singular, q{serra}  => q{singular: 'serrae' --> 'serra'};
is noun(q{serra})->singular,   q{serra}  => q{singular: 'serra' --> 'serra'};
is noun(q{proglottides})->singular, q{proglottis}  => q{singular: 'proglottides' --> 'proglottis'};
is noun(q{proglottis})->singular,   q{proglottis}  => q{singular: 'proglottis' --> 'proglottis'};
is noun(q{kletterschuhe})->singular, q{kletterschuh}  => q{singular: 'kletterschuhe' --> 'kletterschuh'};
is noun(q{kletterschuh})->singular,   q{kletterschuh}  => q{singular: 'kletterschuh' --> 'kletterschuh'};
is noun(q{gorgonias})->singular, q{gorgonia}  => q{singular: 'gorgonias' --> 'gorgonia'};
is noun(q{gorgonia})->singular,   q{gorgonia}  => q{singular: 'gorgonia' --> 'gorgonia'};
is noun(q{cicatrices})->singular, q{cicatrix}  => q{singular: 'cicatrices' --> 'cicatrix'};
is noun(q{cicatrix})->singular,   q{cicatrix}  => q{singular: 'cicatrix' --> 'cicatrix'};
is noun(q{cappuccinos})->singular, q{cappuccino}  => q{singular: 'cappuccinos' --> 'cappuccino'};
is noun(q{cappuccino})->singular,   q{cappuccino}  => q{singular: 'cappuccino' --> 'cappuccino'};
is noun(q{terraria})->singular, q{terrarium}  => q{singular: 'terraria' --> 'terrarium'};
is noun(q{terrarium})->singular,   q{terrarium}  => q{singular: 'terrarium' --> 'terrarium'};
is noun(q{explananda})->singular, q{explanandum}  => q{singular: 'explananda' --> 'explanandum'};
is noun(q{explanandum})->singular,   q{explanandum}  => q{singular: 'explanandum' --> 'explanandum'};
is noun(q{pocula})->singular, q{poculum}  => q{singular: 'pocula' --> 'poculum'};
is noun(q{poculum})->singular,   q{poculum}  => q{singular: 'poculum' --> 'poculum'};
is noun(q{Lapithae})->singular, q{Lapith}  => q{singular: 'Lapithae' --> 'Lapith'};
is noun(q{Lapith})->singular,   q{Lapith}  => q{singular: 'Lapith' --> 'Lapith'};
is noun(q{carmens})->singular, q{carmen}  => q{singular: 'carmens' --> 'carmen'};
is noun(q{carmen})->singular,   q{carmen}  => q{singular: 'carmen' --> 'carmen'};
is noun(q{quartos})->singular, q{quarto}  => q{singular: 'quartos' --> 'quarto'};
is noun(q{quarto})->singular,   q{quarto}  => q{singular: 'quarto' --> 'quarto'};
is noun(q{staccatos})->singular, q{staccato}  => q{singular: 'staccatos' --> 'staccato'};
is noun(q{staccato})->singular,   q{staccato}  => q{singular: 'staccato' --> 'staccato'};
is noun(q{regidores})->singular, q{regidor}  => q{singular: 'regidores' --> 'regidor'};
is noun(q{regidor})->singular,   q{regidor}  => q{singular: 'regidor' --> 'regidor'};
is noun(q{paranuclei})->singular, q{paranucleus}  => q{singular: 'paranuclei' --> 'paranucleus'};
is noun(q{paranucleus})->singular,   q{paranucleus}  => q{singular: 'paranucleus' --> 'paranucleus'};
is noun(q{xiphiplastra})->singular, q{xiphiplastron}  => q{singular: 'xiphiplastra' --> 'xiphiplastron'};
is noun(q{xiphiplastron})->singular,   q{xiphiplastron}  => q{singular: 'xiphiplastron' --> 'xiphiplastron'};
is noun(q{impetigos})->singular, q{impetigo}  => q{singular: 'impetigos' --> 'impetigo'};
is noun(q{impetigo})->singular,   q{impetigo}  => q{singular: 'impetigo' --> 'impetigo'};
is noun(q{Barquisimetos})->singular, q{Barquisimeto}  => q{singular: 'Barquisimetos' --> 'Barquisimeto'};
is noun(q{Barquisimeto})->singular,   q{Barquisimeto}  => q{singular: 'Barquisimeto' --> 'Barquisimeto'};
is noun(q{carmina})->singular, q{carmen}  => q{singular: 'carmina' --> 'carmen'};
is noun(q{carmen})->singular,   q{carmen}  => q{singular: 'carmen' --> 'carmen'};
is noun(q{appendixes})->singular, q{appendix}  => q{singular: 'appendixes' --> 'appendix'};
is noun(q{appendix})->singular,   q{appendix}  => q{singular: 'appendix' --> 'appendix'};
is noun(q{epicardia})->singular, q{epicardium}  => q{singular: 'epicardia' --> 'epicardium'};
is noun(q{epicardium})->singular,   q{epicardium}  => q{singular: 'epicardium' --> 'epicardium'};
is noun(q{medusae})->singular, q{medusa}  => q{singular: 'medusae' --> 'medusa'};
is noun(q{medusa})->singular,   q{medusa}  => q{singular: 'medusa' --> 'medusa'};
is noun(q{paparrazi})->singular, q{paparrazo}  => q{singular: 'paparrazi' --> 'paparrazo'};
is noun(q{paparrazo})->singular,   q{paparrazo}  => q{singular: 'paparrazo' --> 'paparrazo'};
is noun(q{opuses})->singular, q{opus}  => q{singular: 'opuses' --> 'opus'};
is noun(q{opus})->singular,   q{opus}  => q{singular: 'opus' --> 'opus'};
is noun(q{faveoli})->singular, q{faveolus}  => q{singular: 'faveoli' --> 'faveolus'};
is noun(q{faveolus})->singular,   q{faveolus}  => q{singular: 'faveolus' --> 'faveolus'};
is noun(q{dipsades})->singular, q{dipsas}  => q{singular: 'dipsades' --> 'dipsas'};
is noun(q{dipsas})->singular,   q{dipsas}  => q{singular: 'dipsas' --> 'dipsas'};
is noun(q{Indochinese})->singular, q{Indochinese}  => q{singular: 'Indochinese' --> 'Indochinese'};
is noun(q{axillae})->singular, q{axilla}  => q{singular: 'axillae' --> 'axilla'};
is noun(q{axilla})->singular,   q{axilla}  => q{singular: 'axilla' --> 'axilla'};
is noun(q{sinfonie})->singular, q{sinfonia}  => q{singular: 'sinfonie' --> 'sinfonia'};
is noun(q{sinfonia})->singular,   q{sinfonia}  => q{singular: 'sinfonia' --> 'sinfonia'};
is noun(q{clavulae})->singular, q{clavula}  => q{singular: 'clavulae' --> 'clavula'};
is noun(q{clavula})->singular,   q{clavula}  => q{singular: 'clavula' --> 'clavula'};
is noun(q{vacua})->singular, q{vacuum}  => q{singular: 'vacua' --> 'vacuum'};
is noun(q{vacuum})->singular,   q{vacuum}  => q{singular: 'vacuum' --> 'vacuum'};
is noun(q{milieus})->singular, q{milieu}  => q{singular: 'milieus' --> 'milieu'};
is noun(q{milieu})->singular,   q{milieu}  => q{singular: 'milieu' --> 'milieu'};
is noun(q{linenos})->singular, q{lineno}  => q{singular: 'linenos' --> 'lineno'};
is noun(q{lineno})->singular,   q{lineno}  => q{singular: 'lineno' --> 'lineno'};
is noun(q{viri})->singular, q{virus}  => q{singular: 'viri' --> 'virus'};
is noun(q{virus})->singular,   q{virus}  => q{singular: 'virus' --> 'virus'};
is noun(q{mycorrhizas})->singular, q{mycorrhiza}  => q{singular: 'mycorrhizas' --> 'mycorrhiza'};
is noun(q{mycorrhiza})->singular,   q{mycorrhiza}  => q{singular: 'mycorrhiza' --> 'mycorrhiza'};
is noun(q{inocula})->singular, q{inoculum}  => q{singular: 'inocula' --> 'inoculum'};
is noun(q{inoculum})->singular,   q{inoculum}  => q{singular: 'inoculum' --> 'inoculum'};
is noun(q{gummas})->singular, q{gumma}  => q{singular: 'gummas' --> 'gumma'};
is noun(q{gumma})->singular,   q{gumma}  => q{singular: 'gumma' --> 'gumma'};
is noun(q{niduses})->singular, q{nidus}  => q{singular: 'niduses' --> 'nidus'};
is noun(q{nidus})->singular,   q{nidus}  => q{singular: 'nidus' --> 'nidus'};
is noun(q{mementoes})->singular, q{memento}  => q{singular: 'mementoes' --> 'memento'};
is noun(q{memento})->singular,   q{memento}  => q{singular: 'memento' --> 'memento'};
is noun(q{noemata})->singular, q{noema}  => q{singular: 'noemata' --> 'noema'};
is noun(q{noema})->singular,   q{noema}  => q{singular: 'noema' --> 'noema'};
is noun(q{mala in se})->singular, q{malum in se}  => q{singular: 'mala in se' --> 'malum in se'};
is noun(q{malum in se})->singular,   q{malum in se}  => q{singular: 'malum in se' --> 'malum in se'};
is noun(q{break aways})->singular, q{break away}  => q{singular: 'break aways' --> 'break away'};
is noun(q{break away})->singular,   q{break away}  => q{singular: 'break away' --> 'break away'};
is noun(q{portmanteaux})->singular, q{portmanteau}  => q{singular: 'portmanteaux' --> 'portmanteau'};
is noun(q{portmanteau})->singular,   q{portmanteau}  => q{singular: 'portmanteau' --> 'portmanteau'};
is noun(q{simiae})->singular, q{simia}  => q{singular: 'simiae' --> 'simia'};
is noun(q{simia})->singular,   q{simia}  => q{singular: 'simia' --> 'simia'};
is noun(q{cystidia})->singular, q{cystidium}  => q{singular: 'cystidia' --> 'cystidium'};
is noun(q{cystidium})->singular,   q{cystidium}  => q{singular: 'cystidium' --> 'cystidium'};
is noun(q{myxomata})->singular, q{myxoma}  => q{singular: 'myxomata' --> 'myxoma'};
is noun(q{myxoma})->singular,   q{myxoma}  => q{singular: 'myxoma' --> 'myxoma'};
is noun(q{Tornesi})->singular, q{Tornese}  => q{singular: 'Tornesi' --> 'Tornese'};
is noun(q{Tornese})->singular,   q{Tornese}  => q{singular: 'Tornese' --> 'Tornese'};
is noun(q{Lapiths})->singular, q{Lapith}  => q{singular: 'Lapiths' --> 'Lapith'};
is noun(q{Lapith})->singular,   q{Lapith}  => q{singular: 'Lapith' --> 'Lapith'};
is noun(q{varellaes})->singular, q{varella}  => q{singular: 'varellaes' --> 'varella'};
is noun(q{varella})->singular,   q{varella}  => q{singular: 'varella' --> 'varella'};
is noun(q{naumachias})->singular, q{naumachia}  => q{singular: 'naumachias' --> 'naumachia'};
is noun(q{naumachia})->singular,   q{naumachia}  => q{singular: 'naumachia' --> 'naumachia'};
is noun(q{aphides})->singular, q{aphis}  => q{singular: 'aphides' --> 'aphis'};
is noun(q{aphis})->singular,   q{aphis}  => q{singular: 'aphis' --> 'aphis'};
is noun(q{boleros})->singular, q{bolero}  => q{singular: 'boleros' --> 'bolero'};
is noun(q{bolero})->singular,   q{bolero}  => q{singular: 'bolero' --> 'bolero'};
is noun(q{djinn})->singular, q{djinn}  => q{singular: 'djinn' --> 'djinn'};
is noun(q{myas})->singular, q{mya}  => q{singular: 'myas' --> 'mya'};
is noun(q{mya})->singular,   q{mya}  => q{singular: 'mya' --> 'mya'};
is noun(q{puls})->singular, q{pul}  => q{singular: 'puls' --> 'pul'};
is noun(q{pul})->singular,   q{pul}  => q{singular: 'pul' --> 'pul'};
is noun(q{summa bona})->singular, q{summum bonum}  => q{singular: 'summa bona' --> 'summum bonum'};
is noun(q{summum bonum})->singular,   q{summum bonum}  => q{singular: 'summum bonum' --> 'summum bonum'};
is noun(q{cardines})->singular, q{cardo}  => q{singular: 'cardines' --> 'cardo'};
is noun(q{cardo})->singular,   q{cardo}  => q{singular: 'cardo' --> 'cardo'};
is noun(q{contralti})->singular, q{contralto}  => q{singular: 'contralti' --> 'contralto'};
is noun(q{contralto})->singular,   q{contralto}  => q{singular: 'contralto' --> 'contralto'};
is noun(q{monstres sacres})->singular, q{monstre sacre}  => q{singular: 'monstres sacres' --> 'monstre sacre'};
is noun(q{monstre sacre})->singular,   q{monstre sacre}  => q{singular: 'monstre sacre' --> 'monstre sacre'};
is noun(q{flag-staffs})->singular, q{flag-staff}  => q{singular: 'flag-staffs' --> 'flag-staff'};
is noun(q{flag-staff})->singular,   q{flag-staff}  => q{singular: 'flag-staff' --> 'flag-staff'};
is noun(q{simpula})->singular, q{simpulum}  => q{singular: 'simpula' --> 'simpulum'};
is noun(q{simpulum})->singular,   q{simpulum}  => q{singular: 'simpulum' --> 'simpulum'};
is noun(q{Chimangos})->singular, q{Chimango}  => q{singular: 'Chimangos' --> 'Chimango'};
is noun(q{Chimango})->singular,   q{Chimango}  => q{singular: 'Chimango' --> 'Chimango'};
is noun(q{verrucae})->singular, q{verruca}  => q{singular: 'verrucae' --> 'verruca'};
is noun(q{verruca})->singular,   q{verruca}  => q{singular: 'verruca' --> 'verruca'};
is noun(q{cleithra})->singular, q{cleithrum}  => q{singular: 'cleithra' --> 'cleithrum'};
is noun(q{cleithrum})->singular,   q{cleithrum}  => q{singular: 'cleithrum' --> 'cleithrum'};
is noun(q{stamina})->singular, q{stamen}  => q{singular: 'stamina' --> 'stamen'};
is noun(q{beaux})->singular, q{beau}  => q{singular: 'beaux' --> 'beau'};
is noun(q{beau})->singular,   q{beau}  => q{singular: 'beau' --> 'beau'};
is noun(q{puli})->singular, q{pul}  => q{singular: 'puli' --> 'pul'};
is noun(q{pul})->singular,   q{pul}  => q{singular: 'pul' --> 'pul'};
is noun(q{dragomen})->singular, q{dragoman}  => q{singular: 'dragomen' --> 'dragoman'};
is noun(q{dragoman})->singular,   q{dragoman}  => q{singular: 'dragoman' --> 'dragoman'};
is noun(q{rondos})->singular, q{rondo}  => q{singular: 'rondos' --> 'rondo'};
is noun(q{rondo})->singular,   q{rondo}  => q{singular: 'rondo' --> 'rondo'};
is noun(q{bon vivants})->singular, q{bon vivant}  => q{singular: 'bon vivants' --> 'bon vivant'};
is noun(q{bon vivant})->singular,   q{bon vivant}  => q{singular: 'bon vivant' --> 'bon vivant'};
is noun(q{synesthesiae})->singular, q{synesthesia}  => q{singular: 'synesthesiae' --> 'synesthesia'};
is noun(q{synesthesia})->singular,   q{synesthesia}  => q{singular: 'synesthesia' --> 'synesthesia'};
is noun(q{stichoi})->singular, q{stichos}  => q{singular: 'stichoi' --> 'stichos'};
is noun(q{stichos})->singular,   q{stichos}  => q{singular: 'stichos' --> 'stichos'};
is noun(q{Porto-Novos})->singular, q{Porto-Novo}  => q{singular: 'Porto-Novos' --> 'Porto-Novo'};
is noun(q{Porto-Novo})->singular,   q{Porto-Novo}  => q{singular: 'Porto-Novo' --> 'Porto-Novo'};
is noun(q{maculas})->singular, q{macula}  => q{singular: 'maculas' --> 'macula'};
is noun(q{macula})->singular,   q{macula}  => q{singular: 'macula' --> 'macula'};
is noun(q{spermathecae})->singular, q{spermatheca}  => q{singular: 'spermathecae' --> 'spermatheca'};
is noun(q{spermatheca})->singular,   q{spermatheca}  => q{singular: 'spermatheca' --> 'spermatheca'};
is noun(q{quid})->singular, q{quid}  => q{singular: 'quid' --> 'quid'};
is noun(q{sums total})->singular, q{sum total}  => q{singular: 'sums total' --> 'sum total'};
is noun(q{sum total})->singular,   q{sum total}  => q{singular: 'sum total' --> 'sum total'};
is noun(q{ponchos})->singular, q{poncho}  => q{singular: 'ponchos' --> 'poncho'};
is noun(q{poncho})->singular,   q{poncho}  => q{singular: 'poncho' --> 'poncho'};
is noun(q{pontifices})->singular, q{pontifex}  => q{singular: 'pontifices' --> 'pontifex'};
is noun(q{pontifex})->singular,   q{pontifex}  => q{singular: 'pontifex' --> 'pontifex'};
is noun(q{stuccos})->singular, q{stucco}  => q{singular: 'stuccos' --> 'stucco'};
is noun(q{stucco})->singular,   q{stucco}  => q{singular: 'stucco' --> 'stucco'};
is noun(q{chapeaus})->singular, q{chapeau}  => q{singular: 'chapeaus' --> 'chapeau'};
is noun(q{chapeau})->singular,   q{chapeau}  => q{singular: 'chapeau' --> 'chapeau'};
is noun(q{hedrons})->singular, q{hedron}  => q{singular: 'hedrons' --> 'hedron'};
is noun(q{hedron})->singular,   q{hedron}  => q{singular: 'hedron' --> 'hedron'};
is noun(q{conies})->singular, q{coney}  => q{singular: 'conies' --> 'coney'};
is noun(q{coney})->singular,   q{coney}  => q{singular: 'coney' --> 'coney'};
is noun(q{media})->singular, q{medium}  => q{singular: 'media' --> 'medium'};
is noun(q{medium})->singular,   q{medium}  => q{singular: 'medium' --> 'medium'};
is noun(q{Bostonese})->singular, q{Bostonese}  => q{singular: 'Bostonese' --> 'Bostonese'};
is noun(q{primigravidae})->singular, q{primigravida}  => q{singular: 'primigravidae' --> 'primigravida'};
is noun(q{primigravida})->singular,   q{primigravida}  => q{singular: 'primigravida' --> 'primigravida'};
is noun(q{zemirot})->singular, q{zemirah}  => q{singular: 'zemirot' --> 'zemirah'};
is noun(q{zemirah})->singular,   q{zemirah}  => q{singular: 'zemirah' --> 'zemirah'};
is noun(q{sphaeridia})->singular, q{sphaeridium}  => q{singular: 'sphaeridia' --> 'sphaeridium'};
is noun(q{sphaeridium})->singular,   q{sphaeridium}  => q{singular: 'sphaeridium' --> 'sphaeridium'};
is noun(q{axes})->singular, q{axe}  => q{singular: 'axes' --> 'axe'};
is noun(q{axe})->singular,   q{axe}  => q{singular: 'axe' --> 'axe'};
is noun(q{bursitises})->singular, q{bursitis}  => q{singular: 'bursitises' --> 'bursitis'};
is noun(q{bursitis})->singular,   q{bursitis}  => q{singular: 'bursitis' --> 'bursitis'};
is noun(q{lustra})->singular, q{lustrum}  => q{singular: 'lustra' --> 'lustrum'};
is noun(q{lustrum})->singular,   q{lustrum}  => q{singular: 'lustrum' --> 'lustrum'};
is noun(q{coitus})->singular, q{coitus}  => q{singular: 'coitus' --> 'coitus'};
is noun(q{whomever})->singular, q{whomever}  => q{singular: 'whomever' --> 'whomever'};
is noun(q{syrinxes})->singular, q{syrinx}  => q{singular: 'syrinxes' --> 'syrinx'};
is noun(q{syrinx})->singular,   q{syrinx}  => q{singular: 'syrinx' --> 'syrinx'};
is noun(q{genies})->singular, q{genie}  => q{singular: 'genies' --> 'genie'};
is noun(q{genie})->singular,   q{genie}  => q{singular: 'genie' --> 'genie'};
is noun(q{haggis})->singular, q{haggis}  => q{singular: 'haggis' --> 'haggis'};
is noun(q{lis})->singular, q{lis}  => q{singular: 'lis' --> 'lis'};
is noun(q{concetti})->singular, q{concetto}  => q{singular: 'concetti' --> 'concetto'};
is noun(q{concetto})->singular,   q{concetto}  => q{singular: 'concetto' --> 'concetto'};
is noun(q{three-star generals})->singular, q{three-star general}  => q{singular: 'three-star generals' --> 'three-star general'};
is noun(q{three-star general})->singular,   q{three-star general}  => q{singular: 'three-star general' --> 'three-star general'};
is noun(q{lines out})->singular, q{line out}  => q{singular: 'lines out' --> 'line out'};
is noun(q{line out})->singular,   q{line out}  => q{singular: 'line out' --> 'line out'};
is noun(q{puttonys})->singular, q{puttony}  => q{singular: 'puttonys' --> 'puttony'};
is noun(q{puttony})->singular,   q{puttony}  => q{singular: 'puttony' --> 'puttony'};
is noun(q{gyri})->singular, q{gyrus}  => q{singular: 'gyri' --> 'gyrus'};
is noun(q{gyrus})->singular,   q{gyrus}  => q{singular: 'gyrus' --> 'gyrus'};
is noun(q{feet})->singular, q{foot}  => q{singular: 'feet' --> 'foot'};
is noun(q{foot})->singular,   q{foot}  => q{singular: 'foot' --> 'foot'};
is noun(q{scudi})->singular, q{scudo}  => q{singular: 'scudi' --> 'scudo'};
is noun(q{scudo})->singular,   q{scudo}  => q{singular: 'scudo' --> 'scudo'};
is noun(q{prosencephala})->singular, q{prosencephalon}  => q{singular: 'prosencephala' --> 'prosencephalon'};
is noun(q{prosencephalon})->singular,   q{prosencephalon}  => q{singular: 'prosencephalon' --> 'prosencephalon'};
is noun(q{terebratulae})->singular, q{terebratula}  => q{singular: 'terebratulae' --> 'terebratula'};
is noun(q{terebratula})->singular,   q{terebratula}  => q{singular: 'terebratula' --> 'terebratula'};
is noun(q{purum})->singular, q{purum}  => q{singular: 'purum' --> 'purum'};
is noun(q{pieds noirs})->singular, q{pied noir}  => q{singular: 'pieds noirs' --> 'pied noir'};
is noun(q{pied noir})->singular,   q{pied noir}  => q{singular: 'pied noir' --> 'pied noir'};
is noun(q{improvisatrici})->singular, q{improvisatrice}  => q{singular: 'improvisatrici' --> 'improvisatrice'};
is noun(q{improvisatrice})->singular,   q{improvisatrice}  => q{singular: 'improvisatrice' --> 'improvisatrice'};
is noun(q{epidermises})->singular, q{epidermis}  => q{singular: 'epidermises' --> 'epidermis'};
is noun(q{epidermis})->singular,   q{epidermis}  => q{singular: 'epidermis' --> 'epidermis'};
is noun(q{stadia})->singular, q{stadium}  => q{singular: 'stadia' --> 'stadium'};
is noun(q{stadium})->singular,   q{stadium}  => q{singular: 'stadium' --> 'stadium'};
is noun(q{bratwursts})->singular, q{bratwurst}  => q{singular: 'bratwursts' --> 'bratwurst'};
is noun(q{bratwurst})->singular,   q{bratwurst}  => q{singular: 'bratwurst' --> 'bratwurst'};
is noun(q{archipelagos})->singular, q{archipelago}  => q{singular: 'archipelagos' --> 'archipelago'};
is noun(q{archipelago})->singular,   q{archipelago}  => q{singular: 'archipelago' --> 'archipelago'};
is noun(q{tangos})->singular, q{tango}  => q{singular: 'tangos' --> 'tango'};
is noun(q{tango})->singular,   q{tango}  => q{singular: 'tango' --> 'tango'};
is noun(q{shamans})->singular, q{shaman}  => q{singular: 'shamans' --> 'shaman'};
is noun(q{shaman})->singular,   q{shaman}  => q{singular: 'shaman' --> 'shaman'};
is noun(q{usneas})->singular, q{usnea}  => q{singular: 'usneas' --> 'usnea'};
is noun(q{usnea})->singular,   q{usnea}  => q{singular: 'usnea' --> 'usnea'};
is noun(q{rideaux})->singular, q{rideau}  => q{singular: 'rideaux' --> 'rideau'};
is noun(q{rideau})->singular,   q{rideau}  => q{singular: 'rideau' --> 'rideau'};
is noun(q{triumvirs})->singular, q{triumvir}  => q{singular: 'triumvirs' --> 'triumvir'};
is noun(q{triumvir})->singular,   q{triumvir}  => q{singular: 'triumvir' --> 'triumvir'};
is noun(q{locos})->singular, q{loco}  => q{singular: 'locos' --> 'loco'};
is noun(q{loco})->singular,   q{loco}  => q{singular: 'loco' --> 'loco'};
is noun(q{ulpanim})->singular, q{ulpan}  => q{singular: 'ulpanim' --> 'ulpan'};
is noun(q{ulpan})->singular,   q{ulpan}  => q{singular: 'ulpan' --> 'ulpan'};
is noun(q{stomas})->singular, q{stoma}  => q{singular: 'stomas' --> 'stoma'};
is noun(q{stoma})->singular,   q{stoma}  => q{singular: 'stoma' --> 'stoma'};
is noun(q{baths})->singular, q{bath}  => q{singular: 'baths' --> 'bath'};
is noun(q{bath})->singular,   q{bath}  => q{singular: 'bath' --> 'bath'};
is noun(q{autostradas})->singular, q{autostrada}  => q{singular: 'autostradas' --> 'autostrada'};
is noun(q{autostrada})->singular,   q{autostrada}  => q{singular: 'autostrada' --> 'autostrada'};
is noun(q{edemas})->singular, q{edema}  => q{singular: 'edemas' --> 'edema'};
is noun(q{edema})->singular,   q{edema}  => q{singular: 'edema' --> 'edema'};
is noun(q{devoti})->singular, q{devoto}  => q{singular: 'devoti' --> 'devoto'};
is noun(q{devoto})->singular,   q{devoto}  => q{singular: 'devoto' --> 'devoto'};
is noun(q{noda})->singular, q{nodum}  => q{singular: 'noda' --> 'nodum'};
is noun(q{nodum})->singular,   q{nodum}  => q{singular: 'nodum' --> 'nodum'};
is noun(q{froes})->singular, q{fro}  => q{singular: 'froes' --> 'fro'};
is noun(q{fro})->singular,   q{fro}  => q{singular: 'fro' --> 'fro'};
is noun(q{indices})->singular, q{index}  => q{singular: 'indices' --> 'index'};
is noun(q{index})->singular,   q{index}  => q{singular: 'index' --> 'index'};
is noun(q{sterna})->singular, q{sternum}  => q{singular: 'sterna' --> 'sternum'};
is noun(q{sternum})->singular,   q{sternum}  => q{singular: 'sternum' --> 'sternum'};
is noun(q{intichiuma})->singular, q{intichiuma}  => q{singular: 'intichiuma' --> 'intichiuma'};
is noun(q{diplococci})->singular, q{diplococcus}  => q{singular: 'diplococci' --> 'diplococcus'};
is noun(q{diplococcus})->singular,   q{diplococcus}  => q{singular: 'diplococcus' --> 'diplococcus'};
is noun(q{gliomata})->singular, q{glioma}  => q{singular: 'gliomata' --> 'glioma'};
is noun(q{glioma})->singular,   q{glioma}  => q{singular: 'glioma' --> 'glioma'};
is noun(q{caymans})->singular, q{cayman}  => q{singular: 'caymans' --> 'cayman'};
is noun(q{cayman})->singular,   q{cayman}  => q{singular: 'cayman' --> 'cayman'};
is noun(q{choanae})->singular, q{choana}  => q{singular: 'choanae' --> 'choana'};
is noun(q{choana})->singular,   q{choana}  => q{singular: 'choana' --> 'choana'};
is noun(q{cherubs})->singular, q{cherub}  => q{singular: 'cherubs' --> 'cherub'};
is noun(q{cherub})->singular,   q{cherub}  => q{singular: 'cherub' --> 'cherub'};
is noun(q{amoebas})->singular, q{amoeba}  => q{singular: 'amoebas' --> 'amoeba'};
is noun(q{amoeba})->singular,   q{amoeba}  => q{singular: 'amoeba' --> 'amoeba'};
is noun(q{pectines})->singular, q{pecten}  => q{singular: 'pectines' --> 'pecten'};
is noun(q{pecten})->singular,   q{pecten}  => q{singular: 'pecten' --> 'pecten'};
is noun(q{frusta})->singular, q{frustum}  => q{singular: 'frusta' --> 'frustum'};
is noun(q{frustum})->singular,   q{frustum}  => q{singular: 'frustum' --> 'frustum'};
is noun(q{piscinae})->singular, q{piscina}  => q{singular: 'piscinae' --> 'piscina'};
is noun(q{piscina})->singular,   q{piscina}  => q{singular: 'piscina' --> 'piscina'};
is noun(q{anlagen})->singular, q{anlage}  => q{singular: 'anlagen' --> 'anlage'};
is noun(q{anlage})->singular,   q{anlage}  => q{singular: 'anlage' --> 'anlage'};
is noun(q{squillae})->singular, q{squilla}  => q{singular: 'squillae' --> 'squilla'};
is noun(q{squilla})->singular,   q{squilla}  => q{singular: 'squilla' --> 'squilla'};
is noun(q{pastorali})->singular, q{pastorale}  => q{singular: 'pastorali' --> 'pastorale'};
is noun(q{pastorale})->singular,   q{pastorale}  => q{singular: 'pastorale' --> 'pastorale'};
is noun(q{Pistoiese})->singular, q{Pistoiese}  => q{singular: 'Pistoiese' --> 'Pistoiese'};
is noun(q{3 star generals})->singular, q{3 star general}  => q{singular: '3 star generals' --> '3 star general'};
is noun(q{3 star general})->singular,   q{3 star general}  => q{singular: '3 star general' --> '3 star general'};
is noun(q{antra})->singular, q{antrum}  => q{singular: 'antra' --> 'antrum'};
is noun(q{antrum})->singular,   q{antrum}  => q{singular: 'antrum' --> 'antrum'};
is noun(q{imbrices})->singular, q{imbrex}  => q{singular: 'imbrices' --> 'imbrex'};
is noun(q{imbrex})->singular,   q{imbrex}  => q{singular: 'imbrex' --> 'imbrex'};
is noun(q{messeigneurs})->singular, q{monseigneur}  => q{singular: 'messeigneurs' --> 'monseigneur'};
is noun(q{monseigneur})->singular,   q{monseigneur}  => q{singular: 'monseigneur' --> 'monseigneur'};
is noun(q{ententes cordiales})->singular, q{entente cordiale}  => q{singular: 'ententes cordiales' --> 'entente cordiale'};
is noun(q{entente cordiale})->singular,   q{entente cordiale}  => q{singular: 'entente cordiale' --> 'entente cordiale'};
is noun(q{metatarsi})->singular, q{metatarsus}  => q{singular: 'metatarsi' --> 'metatarsus'};
is noun(q{metatarsus})->singular,   q{metatarsus}  => q{singular: 'metatarsus' --> 'metatarsus'};
is noun(q{pyramidia})->singular, q{pyramidion}  => q{singular: 'pyramidia' --> 'pyramidion'};
is noun(q{pyramidion})->singular,   q{pyramidion}  => q{singular: 'pyramidion' --> 'pyramidion'};
is noun(q{tali})->singular, q{talus}  => q{singular: 'tali' --> 'talus'};
is noun(q{talus})->singular,   q{talus}  => q{singular: 'talus' --> 'talus'};
is noun(q{synusiae})->singular, q{synusia}  => q{singular: 'synusiae' --> 'synusia'};
is noun(q{synusia})->singular,   q{synusia}  => q{singular: 'synusia' --> 'synusia'};
is noun(q{tormas})->singular, q{torma}  => q{singular: 'tormas' --> 'torma'};
is noun(q{lares})->singular, q{lar}  => q{singular: 'lares' --> 'lar'};
is noun(q{lar})->singular,   q{lar}  => q{singular: 'lar' --> 'lar'};
is noun(q{representamens})->singular, q{representamen}  => q{singular: 'representamens' --> 'representamen'};
is noun(q{representamen})->singular,   q{representamen}  => q{singular: 'representamen' --> 'representamen'};
is noun(q{denarii})->singular, q{denarius}  => q{singular: 'denarii' --> 'denarius'};
is noun(q{denarius})->singular,   q{denarius}  => q{singular: 'denarius' --> 'denarius'};
is noun(q{glutei})->singular, q{glutaeus}  => q{singular: 'glutei' --> 'glutaeus'};
is noun(q{glutaeus})->singular,   q{glutaeus}  => q{singular: 'glutaeus' --> 'glutaeus'};
is noun(q{startzy})->singular, q{staretz}  => q{singular: 'startzy' --> 'staretz'};
is noun(q{staretz})->singular,   q{staretz}  => q{singular: 'staretz' --> 'staretz'};
is noun(q{telia})->singular, q{telium}  => q{singular: 'telia' --> 'telium'};
is noun(q{telium})->singular,   q{telium}  => q{singular: 'telium' --> 'telium'};
is noun(q{nectocalyces})->singular, q{nectocalyx}  => q{singular: 'nectocalyces' --> 'nectocalyx'};
is noun(q{nectocalyx})->singular,   q{nectocalyx}  => q{singular: 'nectocalyx' --> 'nectocalyx'};
is noun(q{montes})->singular, q{mons}  => q{singular: 'montes' --> 'mons'};
is noun(q{mons})->singular,   q{mons}  => q{singular: 'mons' --> 'mons'};
is noun(q{hydriae})->singular, q{hydria}  => q{singular: 'hydriae' --> 'hydria'};
is noun(q{hydria})->singular,   q{hydria}  => q{singular: 'hydria' --> 'hydria'};
is noun(q{versos})->singular, q{verso}  => q{singular: 'versos' --> 'verso'};
is noun(q{verso})->singular,   q{verso}  => q{singular: 'verso' --> 'verso'};
is noun(q{Purums})->singular, q{Purum}  => q{singular: 'Purums' --> 'Purum'};
is noun(q{breaksaway})->singular, q{breakaway}  => q{singular: 'breaksaway' --> 'breakaway'};
is noun(q{breakaway})->singular,   q{breakaway}  => q{singular: 'breakaway' --> 'breakaway'};
is noun(q{corpuscula})->singular, q{corpusculum}  => q{singular: 'corpuscula' --> 'corpusculum'};
is noun(q{corpusculum})->singular,   q{corpusculum}  => q{singular: 'corpusculum' --> 'corpusculum'};
is noun(q{trichine})->singular, q{trichina}  => q{singular: 'trichine' --> 'trichina'};
is noun(q{trichina})->singular,   q{trichina}  => q{singular: 'trichina' --> 'trichina'};
is noun(q{lords lieutenant})->singular, q{lord lieutenant}  => q{singular: 'lords lieutenant' --> 'lord lieutenant'};
is noun(q{lord lieutenant})->singular,   q{lord lieutenant}  => q{singular: 'lord lieutenant' --> 'lord lieutenant'};
is noun(q{courts-martial})->singular, q{court-martial}  => q{singular: 'courts-martial' --> 'court-martial'};
is noun(q{court-martial})->singular,   q{court-martial}  => q{singular: 'court-martial' --> 'court-martial'};
is noun(q{souvlakia})->singular, q{souvlaki}  => q{singular: 'souvlakia' --> 'souvlaki'};
is noun(q{souvlaki})->singular,   q{souvlaki}  => q{singular: 'souvlaki' --> 'souvlaki'};
is noun(q{Arakanese})->singular, q{Arakanese}  => q{singular: 'Arakanese' --> 'Arakanese'};
is noun(q{swines})->singular, q{swine}  => q{singular: 'swines' --> 'swine'};
is noun(q{emporia})->singular, q{emporium}  => q{singular: 'emporia' --> 'emporium'};
is noun(q{emporium})->singular,   q{emporium}  => q{singular: 'emporium' --> 'emporium'};
is noun(q{fraena})->singular, q{fraenum}  => q{singular: 'fraena' --> 'fraenum'};
is noun(q{fraenum})->singular,   q{fraenum}  => q{singular: 'fraenum' --> 'fraenum'};
is noun(q{alae})->singular, q{ala}  => q{singular: 'alae' --> 'ala'};
is noun(q{ala})->singular,   q{ala}  => q{singular: 'ala' --> 'ala'};
is noun(q{thoraxes})->singular, q{thorax}  => q{singular: 'thoraxes' --> 'thorax'};
is noun(q{thorax})->singular,   q{thorax}  => q{singular: 'thorax' --> 'thorax'};
is noun(q{jerries})->singular, q{jerry}  => q{singular: 'jerries' --> 'jerry'};
is noun(q{jerry})->singular,   q{jerry}  => q{singular: 'jerry' --> 'jerry'};
is noun(q{wadies})->singular, q{wadi}  => q{singular: 'wadies' --> 'wadi'};
is noun(q{wadi})->singular,   q{wadi}  => q{singular: 'wadi' --> 'wadi'};
is noun(q{pylae})->singular, q{pyla}  => q{singular: 'pylae' --> 'pyla'};
is noun(q{pyla})->singular,   q{pyla}  => q{singular: 'pyla' --> 'pyla'};
is noun(q{pectora})->singular, q{pectus}  => q{singular: 'pectora' --> 'pectus'};
is noun(q{pectus})->singular,   q{pectus}  => q{singular: 'pectus' --> 'pectus'};
is noun(q{lars})->singular, q{lar}  => q{singular: 'lars' --> 'lar'};
is noun(q{lar})->singular,   q{lar}  => q{singular: 'lar' --> 'lar'};
is noun(q{rhynchodaea})->singular, q{rhynchodaeum}  => q{singular: 'rhynchodaea' --> 'rhynchodaeum'};
is noun(q{rhynchodaeum})->singular,   q{rhynchodaeum}  => q{singular: 'rhynchodaeum' --> 'rhynchodaeum'};
is noun(q{exempla})->singular, q{exemplum}  => q{singular: 'exempla' --> 'exemplum'};
is noun(q{exemplum})->singular,   q{exemplum}  => q{singular: 'exemplum' --> 'exemplum'};
is noun(q{Taikos})->singular, q{Taiko}  => q{singular: 'Taikos' --> 'Taiko'};
is noun(q{Taiko})->singular,   q{Taiko}  => q{singular: 'Taiko' --> 'Taiko'};
is noun(q{vetturini})->singular, q{vetturino}  => q{singular: 'vetturini' --> 'vetturino'};
is noun(q{vetturino})->singular,   q{vetturino}  => q{singular: 'vetturino' --> 'vetturino'};
is noun(q{autobahnen})->singular, q{autobahn}  => q{singular: 'autobahnen' --> 'autobahn'};
is noun(q{autobahn})->singular,   q{autobahn}  => q{singular: 'autobahn' --> 'autobahn'};
is noun(q{syllabaria})->singular, q{syllabarium}  => q{singular: 'syllabaria' --> 'syllabarium'};
is noun(q{syllabarium})->singular,   q{syllabarium}  => q{singular: 'syllabarium' --> 'syllabarium'};
is noun(q{seed})->singular, q{seed}  => q{singular: 'seed' --> 'seed'};
is noun(q{dentalia})->singular, q{dentalium}  => q{singular: 'dentalia' --> 'dentalium'};
is noun(q{dentalium})->singular,   q{dentalium}  => q{singular: 'dentalium' --> 'dentalium'};
is noun(q{nses})->singular, q{nse}  => q{singular: 'nses' --> 'nse'};
is noun(q{nse})->singular,   q{nse}  => q{singular: 'nse' --> 'nse'};
is noun(q{Kokakos})->singular, q{Kokako}  => q{singular: 'Kokakos' --> 'Kokako'};
is noun(q{Kokako})->singular,   q{Kokako}  => q{singular: 'Kokako' --> 'Kokako'};
is noun(q{extremums})->singular, q{extremum}  => q{singular: 'extremums' --> 'extremum'};
is noun(q{extremum})->singular,   q{extremum}  => q{singular: 'extremum' --> 'extremum'};
is noun(q{fess})->singular, q{feis}  => q{singular: 'fess' --> 'feis'};
is noun(q{feis})->singular,   q{feis}  => q{singular: 'feis' --> 'feis'};
is noun(q{tholi})->singular, q{tholus}  => q{singular: 'tholi' --> 'tholus'};
is noun(q{tholus})->singular,   q{tholus}  => q{singular: 'tholus' --> 'tholus'};
is noun(q{ilia})->singular, q{ilium}  => q{singular: 'ilia' --> 'ilium'};
is noun(q{ilium})->singular,   q{ilium}  => q{singular: 'ilium' --> 'ilium'};
is noun(q{shears})->singular, q{shears}  => q{singular: 'shears' --> 'shears'};
is noun(q{ballabili})->singular, q{ballabile}  => q{singular: 'ballabili' --> 'ballabile'};
is noun(q{ballabile})->singular,   q{ballabile}  => q{singular: 'ballabile' --> 'ballabile'};
is noun(q{onagri})->singular, q{onager}  => q{singular: 'onagri' --> 'onager'};
is noun(q{onager})->singular,   q{onager}  => q{singular: 'onager' --> 'onager'};
is noun(q{sestieri})->singular, q{sestiere}  => q{singular: 'sestieri' --> 'sestiere'};
is noun(q{sestiere})->singular,   q{sestiere}  => q{singular: 'sestiere' --> 'sestiere'};
is noun(q{barricoes})->singular, q{barrico}  => q{singular: 'barricoes' --> 'barrico'};
is noun(q{barrico})->singular,   q{barrico}  => q{singular: 'barrico' --> 'barrico'};
is noun(q{bemata})->singular, q{bema}  => q{singular: 'bemata' --> 'bema'};
is noun(q{bema})->singular,   q{bema}  => q{singular: 'bema' --> 'bema'};
is noun(q{synapticulae})->singular, q{synapticula}  => q{singular: 'synapticulae' --> 'synapticula'};
is noun(q{synapticula})->singular,   q{synapticula}  => q{singular: 'synapticula' --> 'synapticula'};
is noun(q{ricercari})->singular, q{ricercar}  => q{singular: 'ricercari' --> 'ricercar'};
is noun(q{ricercar})->singular,   q{ricercar}  => q{singular: 'ricercar' --> 'ricercar'};
is noun(q{indumenta})->singular, q{indumentum}  => q{singular: 'indumenta' --> 'indumentum'};
is noun(q{indumentum})->singular,   q{indumentum}  => q{singular: 'indumentum' --> 'indumentum'};
is noun(q{telamones})->singular, q{telamon}  => q{singular: 'telamones' --> 'telamon'};
is noun(q{telamon})->singular,   q{telamon}  => q{singular: 'telamon' --> 'telamon'};
is noun(q{proscenia})->singular, q{proscenium}  => q{singular: 'proscenia' --> 'proscenium'};
is noun(q{proscenium})->singular,   q{proscenium}  => q{singular: 'proscenium' --> 'proscenium'};
is noun(q{exencephali})->singular, q{exencephalus}  => q{singular: 'exencephali' --> 'exencephalus'};
is noun(q{exencephalus})->singular,   q{exencephalus}  => q{singular: 'exencephalus' --> 'exencephalus'};
is noun(q{remou})->singular, q{remous}  => q{singular: 'remou' --> 'remous'};
is noun(q{lieutenant generals})->singular, q{lieutenant general}  => q{singular: 'lieutenant generals' --> 'lieutenant general'};
is noun(q{lieutenant general})->singular,   q{lieutenant general}  => q{singular: 'lieutenant general' --> 'lieutenant general'};
is noun(q{collegia})->singular, q{collegium}  => q{singular: 'collegia' --> 'collegium'};
is noun(q{collegium})->singular,   q{collegium}  => q{singular: 'collegium' --> 'collegium'};
is noun(q{plicae})->singular, q{plica}  => q{singular: 'plicae' --> 'plica'};
is noun(q{plica})->singular,   q{plica}  => q{singular: 'plica' --> 'plica'};
is noun(q{monsiegneurs})->singular, q{monseigneur}  => q{singular: 'monsiegneurs' --> 'monseigneur'};
is noun(q{monseigneur})->singular,   q{monseigneur}  => q{singular: 'monseigneur' --> 'monseigneur'};
is noun(q{women children})->singular, q{woman child}  => q{singular: 'women children' --> 'woman child'};
is noun(q{woman child})->singular,   q{woman child}  => q{singular: 'woman child' --> 'woman child'};
is noun(q{lebensformen})->singular, q{lebensform}  => q{singular: 'lebensformen' --> 'lebensform'};
is noun(q{lebensform})->singular,   q{lebensform}  => q{singular: 'lebensform' --> 'lebensform'};
is noun(q{synedria})->singular, q{synedrium}  => q{singular: 'synedria' --> 'synedrium'};
is noun(q{synedrium})->singular,   q{synedrium}  => q{singular: 'synedrium' --> 'synedrium'};
is noun(q{succineas})->singular, q{succinea}  => q{singular: 'succineas' --> 'succinea'};
is noun(q{succinea})->singular,   q{succinea}  => q{singular: 'succinea' --> 'succinea'};
is noun(q{generalissimos})->singular, q{generalissimo}  => q{singular: 'generalissimos' --> 'generalissimo'};
is noun(q{generalissimo})->singular,   q{generalissimo}  => q{singular: 'generalissimo' --> 'generalissimo'};
is noun(q{rezidentsii})->singular, q{rezidentsia}  => q{singular: 'rezidentsii' --> 'rezidentsia'};
is noun(q{rezidentsia})->singular,   q{rezidentsia}  => q{singular: 'rezidentsia' --> 'rezidentsia'};
is noun(q{amphipneusts})->singular, q{amphipneust}  => q{singular: 'amphipneusts' --> 'amphipneust'};
is noun(q{amphipneust})->singular,   q{amphipneust}  => q{singular: 'amphipneust' --> 'amphipneust'};
is noun(q{tyros})->singular, q{tyro}  => q{singular: 'tyros' --> 'tyro'};
is noun(q{tyro})->singular,   q{tyro}  => q{singular: 'tyro' --> 'tyro'};
is noun(q{two-star generals})->singular, q{two-star general}  => q{singular: 'two-star generals' --> 'two-star general'};
is noun(q{two-star general})->singular,   q{two-star general}  => q{singular: 'two-star general' --> 'two-star general'};
is noun(q{vires})->singular, q{vis}  => q{singular: 'vires' --> 'vis'};
is noun(q{vis})->singular,   q{vis}  => q{singular: 'vis' --> 'vis'};
is noun(q{set outs})->singular, q{set out}  => q{singular: 'set outs' --> 'set out'};
is noun(q{set out})->singular,   q{set out}  => q{singular: 'set out' --> 'set out'};
is noun(q{surculi})->singular, q{surculus}  => q{singular: 'surculi' --> 'surculus'};
is noun(q{surculus})->singular,   q{surculus}  => q{singular: 'surculus' --> 'surculus'};
is noun(q{syndendria})->singular, q{syndendrium}  => q{singular: 'syndendria' --> 'syndendrium'};
is noun(q{syndendrium})->singular,   q{syndendrium}  => q{singular: 'syndendrium' --> 'syndendrium'};
is noun(q{arcana})->singular, q{arcanum}  => q{singular: 'arcana' --> 'arcanum'};
is noun(q{arcanum})->singular,   q{arcanum}  => q{singular: 'arcanum' --> 'arcanum'};
is noun(q{mustachios})->singular, q{mustachio}  => q{singular: 'mustachios' --> 'mustachio'};
is noun(q{mustachio})->singular,   q{mustachio}  => q{singular: 'mustachio' --> 'mustachio'};
is noun(q{compendiums})->singular, q{compendium}  => q{singular: 'compendiums' --> 'compendium'};
is noun(q{compendium})->singular,   q{compendium}  => q{singular: 'compendium' --> 'compendium'};
is noun(q{pathoses})->singular, q{pathos}  => q{singular: 'pathoses' --> 'pathos'};
is noun(q{pathos})->singular,   q{pathos}  => q{singular: 'pathos' --> 'pathos'};
is noun(q{rubashki})->singular, q{rubashka}  => q{singular: 'rubashki' --> 'rubashka'};
is noun(q{rubashka})->singular,   q{rubashka}  => q{singular: 'rubashka' --> 'rubashka'};
is noun(q{elands})->singular, q{eland}  => q{singular: 'elands' --> 'eland'};
is noun(q{residua})->singular, q{residuum}  => q{singular: 'residua' --> 'residuum'};
is noun(q{residuum})->singular,   q{residuum}  => q{singular: 'residuum' --> 'residuum'};
is noun(q{maecenases})->singular, q{maecenas}  => q{singular: 'maecenases' --> 'maecenas'};
is noun(q{maecenas})->singular,   q{maecenas}  => q{singular: 'maecenas' --> 'maecenas'};
is noun(q{clepsydrae})->singular, q{clepsydra}  => q{singular: 'clepsydrae' --> 'clepsydra'};
is noun(q{clepsydra})->singular,   q{clepsydra}  => q{singular: 'clepsydra' --> 'clepsydra'};
is noun(q{novi homines})->singular, q{novus homo}  => q{singular: 'novi homines' --> 'novus homo'};
is noun(q{novus homo})->singular,   q{novus homo}  => q{singular: 'novus homo' --> 'novus homo'};
is noun(q{irises})->singular, q{iris}  => q{singular: 'irises' --> 'iris'};
is noun(q{iris})->singular,   q{iris}  => q{singular: 'iris' --> 'iris'};
is noun(q{aelfe})->singular, q{aelf}  => q{singular: 'aelfe' --> 'aelf'};
is noun(q{aelf})->singular,   q{aelf}  => q{singular: 'aelf' --> 'aelf'};
is noun(q{Hiroshimans})->singular, q{Hiroshiman}  => q{singular: 'Hiroshimans' --> 'Hiroshiman'};
is noun(q{Hiroshiman})->singular,   q{Hiroshiman}  => q{singular: 'Hiroshiman' --> 'Hiroshiman'};
is noun(q{flag-staves})->singular, q{flag-staff}  => q{singular: 'flag-staves' --> 'flag-staff'};
is noun(q{flag-staff})->singular,   q{flag-staff}  => q{singular: 'flag-staff' --> 'flag-staff'};
is noun(q{spermata})->singular, q{sperma}  => q{singular: 'spermata' --> 'sperma'};
is noun(q{sperma})->singular,   q{sperma}  => q{singular: 'sperma' --> 'sperma'};
is noun(q{denkmaler})->singular, q{denkmal}  => q{singular: 'denkmaler' --> 'denkmal'};
is noun(q{denkmal})->singular,   q{denkmal}  => q{singular: 'denkmal' --> 'denkmal'};
is noun(q{pasteurellas})->singular, q{pasteurella}  => q{singular: 'pasteurellas' --> 'pasteurella'};
is noun(q{pasteurella})->singular,   q{pasteurella}  => q{singular: 'pasteurella' --> 'pasteurella'};
is noun(q{bustoes})->singular, q{busto}  => q{singular: 'bustoes' --> 'busto'};
is noun(q{busto})->singular,   q{busto}  => q{singular: 'busto' --> 'busto'};
is noun(q{phalli})->singular, q{phallus}  => q{singular: 'phalli' --> 'phallus'};
is noun(q{phallus})->singular,   q{phallus}  => q{singular: 'phallus' --> 'phallus'};
is noun(q{kuvaszok})->singular, q{kuvasz}  => q{singular: 'kuvaszok' --> 'kuvasz'};
is noun(q{kuvasz})->singular,   q{kuvasz}  => q{singular: 'kuvasz' --> 'kuvasz'};
is noun(q{phyogemmaria})->singular, q{phyogemmarium}  => q{singular: 'phyogemmaria' --> 'phyogemmarium'};
is noun(q{phyogemmarium})->singular,   q{phyogemmarium}  => q{singular: 'phyogemmarium' --> 'phyogemmarium'};
is noun(q{hapax legomena})->singular, q{hapax legomenon}  => q{singular: 'hapax legomena' --> 'hapax legomenon'};
is noun(q{hapax legomenon})->singular,   q{hapax legomenon}  => q{singular: 'hapax legomenon' --> 'hapax legomenon'};
is noun(q{roms})->singular, q{rom}  => q{singular: 'roms' --> 'rom'};
is noun(q{rom})->singular,   q{rom}  => q{singular: 'rom' --> 'rom'};
is noun(q{thyridia})->singular, q{thyridium}  => q{singular: 'thyridia' --> 'thyridium'};
is noun(q{thyridium})->singular,   q{thyridium}  => q{singular: 'thyridium' --> 'thyridium'};
is noun(q{flamencos})->singular, q{flamenco}  => q{singular: 'flamencos' --> 'flamenco'};
is noun(q{flamenco})->singular,   q{flamenco}  => q{singular: 'flamenco' --> 'flamenco'};
is noun(q{suffrutices})->singular, q{suffrutex}  => q{singular: 'suffrutices' --> 'suffrutex'};
is noun(q{suffrutex})->singular,   q{suffrutex}  => q{singular: 'suffrutex' --> 'suffrutex'};
is noun(q{helia})->singular, q{helion}  => q{singular: 'helia' --> 'helion'};
is noun(q{helion})->singular,   q{helion}  => q{singular: 'helion' --> 'helion'};
is noun(q{geese})->singular, q{goose}  => q{singular: 'geese' --> 'goose'};
is noun(q{goose})->singular,   q{goose}  => q{singular: 'goose' --> 'goose'};
is noun(q{fowl})->singular, q{fowl}  => q{singular: 'fowl' --> 'fowl'};
is noun(q{mangos})->singular, q{mango}  => q{singular: 'mangos' --> 'mango'};
is noun(q{mango})->singular,   q{mango}  => q{singular: 'mango' --> 'mango'};
is noun(q{subsidia})->singular, q{subsidium}  => q{singular: 'subsidia' --> 'subsidium'};
is noun(q{subsidium})->singular,   q{subsidium}  => q{singular: 'subsidium' --> 'subsidium'};
is noun(q{Vietnamese})->singular, q{Vietnamese}  => q{singular: 'Vietnamese' --> 'Vietnamese'};
is noun(q{nasuti})->singular, q{nasutus}  => q{singular: 'nasuti' --> 'nasutus'};
is noun(q{nasutus})->singular,   q{nasutus}  => q{singular: 'nasutus' --> 'nasutus'};
is noun(q{paragangliomas})->singular, q{paraganglioma}  => q{singular: 'paragangliomas' --> 'paraganglioma'};
is noun(q{paraganglioma})->singular,   q{paraganglioma}  => q{singular: 'paraganglioma' --> 'paraganglioma'};
is noun(q{rhinophymas})->singular, q{rhinophyma}  => q{singular: 'rhinophymas' --> 'rhinophyma'};
is noun(q{rhinophyma})->singular,   q{rhinophyma}  => q{singular: 'rhinophyma' --> 'rhinophyma'};
is noun(q{Azerbaijanese})->singular, q{Azerbaijanese}  => q{singular: 'Azerbaijanese' --> 'Azerbaijanese'};
is noun(q{mycorrhizae})->singular, q{mycorrhiza}  => q{singular: 'mycorrhizae' --> 'mycorrhiza'};
is noun(q{mycorrhiza})->singular,   q{mycorrhiza}  => q{singular: 'mycorrhiza' --> 'mycorrhiza'};
is noun(q{samurai})->singular, q{samurai}  => q{singular: 'samurai' --> 'samurai'};
is noun(q{devotos})->singular, q{devoto}  => q{singular: 'devotos' --> 'devoto'};
is noun(q{devoto})->singular,   q{devoto}  => q{singular: 'devoto' --> 'devoto'};
is noun(q{salmon})->singular, q{salmon}  => q{singular: 'salmon' --> 'salmon'};
is noun(q{loggie})->singular, q{loggia}  => q{singular: 'loggie' --> 'loggia'};
is noun(q{loggia})->singular,   q{loggia}  => q{singular: 'loggia' --> 'loggia'};
is noun(q{osteoclastomas})->singular, q{osteoclastoma}  => q{singular: 'osteoclastomas' --> 'osteoclastoma'};
is noun(q{osteoclastoma})->singular,   q{osteoclastoma}  => q{singular: 'osteoclastoma' --> 'osteoclastoma'};
is noun(q{lithophyta})->singular, q{lithophyton}  => q{singular: 'lithophyta' --> 'lithophyton'};
is noun(q{lithophyton})->singular,   q{lithophyton}  => q{singular: 'lithophyton' --> 'lithophyton'};
is noun(q{afreeti})->singular, q{afreet}  => q{singular: 'afreeti' --> 'afreet'};
is noun(q{afreet})->singular,   q{afreet}  => q{singular: 'afreet' --> 'afreet'};
is noun(q{oglys})->singular, q{ogle}  => q{singular: 'oglys' --> 'ogle'};
is noun(q{ogle})->singular,   q{ogle}  => q{singular: 'ogle' --> 'ogle'};
is noun(q{pajamas})->singular, q{pajamas}  => q{singular: 'pajamas' --> 'pajamas'};
is noun(q{spiracula})->singular, q{spiraculum}  => q{singular: 'spiracula' --> 'spiraculum'};
is noun(q{spiraculum})->singular,   q{spiraculum}  => q{singular: 'spiraculum' --> 'spiraculum'};
is noun(q{asbestoses})->singular, q{asbestos}  => q{singular: 'asbestoses' --> 'asbestos'};
is noun(q{asbestos})->singular,   q{asbestos}  => q{singular: 'asbestos' --> 'asbestos'};
is noun(q{buffalos})->singular, q{buffalo}  => q{singular: 'buffalos' --> 'buffalo'};
is noun(q{Moroccos})->singular, q{Morocco}  => q{singular: 'Moroccos' --> 'Morocco'};
is noun(q{Morocco})->singular,   q{Morocco}  => q{singular: 'Morocco' --> 'Morocco'};
is noun(q{knives})->singular, q{knife}  => q{singular: 'knives' --> 'knife'};
is noun(q{knife})->singular,   q{knife}  => q{singular: 'knife' --> 'knife'};
is noun(q{mimosae})->singular, q{mimosa}  => q{singular: 'mimosae' --> 'mimosa'};
is noun(q{mimosa})->singular,   q{mimosa}  => q{singular: 'mimosa' --> 'mimosa'};
is noun(q{fish})->singular, q{fish}  => q{singular: 'fish' --> 'fish'};
is noun(q{tympana})->singular, q{tympanum}  => q{singular: 'tympana' --> 'tympanum'};
is noun(q{tympanum})->singular,   q{tympanum}  => q{singular: 'tympanum' --> 'tympanum'};
is noun(q{Montenegros})->singular, q{Montenegro}  => q{singular: 'Montenegros' --> 'Montenegro'};
is noun(q{Montenegro})->singular,   q{Montenegro}  => q{singular: 'Montenegro' --> 'Montenegro'};
is noun(q{bacteria})->singular, q{bacterium}  => q{singular: 'bacteria' --> 'bacterium'};
is noun(q{bacterium})->singular,   q{bacterium}  => q{singular: 'bacterium' --> 'bacterium'};
is noun(q{summa genera})->singular, q{summum genus}  => q{singular: 'summa genera' --> 'summum genus'};
is noun(q{summum genus})->singular,   q{summum genus}  => q{singular: 'summum genus' --> 'summum genus'};
is noun(q{mithraea})->singular, q{mithraeum}  => q{singular: 'mithraea' --> 'mithraeum'};
is noun(q{mithraeum})->singular,   q{mithraeum}  => q{singular: 'mithraeum' --> 'mithraeum'};
is noun(q{teredines})->singular, q{teredo}  => q{singular: 'teredines' --> 'teredo'};
is noun(q{teredo})->singular,   q{teredo}  => q{singular: 'teredo' --> 'teredo'};
is noun(q{juga})->singular, q{jugum}  => q{singular: 'juga' --> 'jugum'};
is noun(q{jugum})->singular,   q{jugum}  => q{singular: 'jugum' --> 'jugum'};
is noun(q{souvlakis})->singular, q{souvlaki}  => q{singular: 'souvlakis' --> 'souvlaki'};
is noun(q{souvlaki})->singular,   q{souvlaki}  => q{singular: 'souvlaki' --> 'souvlaki'};
is noun(q{crafts-childer})->singular, q{crafts-child}  => q{singular: 'crafts-childer' --> 'crafts-child'};
is noun(q{crafts-child})->singular,   q{crafts-child}  => q{singular: 'crafts-child' --> 'crafts-child'};
is noun(q{those})->singular, q{that}  => q{singular: 'those' --> 'that'};
is noun(q{that})->singular,   q{that}  => q{singular: 'that' --> 'that'};
is noun(q{hormogonia})->singular, q{hormogonium}  => q{singular: 'hormogonia' --> 'hormogonium'};
is noun(q{hormogonium})->singular,   q{hormogonium}  => q{singular: 'hormogonium' --> 'hormogonium'};
is noun(q{magna opera})->singular, q{magnum opus}  => q{singular: 'magna opera' --> 'magnum opus'};
is noun(q{magnum opus})->singular,   q{magnum opus}  => q{singular: 'magnum opus' --> 'magnum opus'};
is noun(q{microbia})->singular, q{microbion}  => q{singular: 'microbia' --> 'microbion'};
is noun(q{microbion})->singular,   q{microbion}  => q{singular: 'microbion' --> 'microbion'};
is noun(q{funambuli})->singular, q{funambulus}  => q{singular: 'funambuli' --> 'funambulus'};
is noun(q{funambulus})->singular,   q{funambulus}  => q{singular: 'funambulus' --> 'funambulus'};
is noun(q{thebe})->singular, q{thebe}  => q{singular: 'thebe' --> 'thebe'};
is noun(q{menages a trois})->singular, q{menage a trois}  => q{singular: 'menages a trois' --> 'menage a trois'};
is noun(q{menage a trois})->singular,   q{menage a trois}  => q{singular: 'menage a trois' --> 'menage a trois'};
is noun(q{iueles})->singular, q{juelet}  => q{singular: 'iueles' --> 'juelet'};
is noun(q{juelet})->singular,   q{juelet}  => q{singular: 'juelet' --> 'juelet'};
is noun(q{pedes})->singular, q{pes}  => q{singular: 'pedes' --> 'pes'};
is noun(q{pes})->singular,   q{pes}  => q{singular: 'pes' --> 'pes'};
is noun(q{apothecia})->singular, q{apothecium}  => q{singular: 'apothecia' --> 'apothecium'};
is noun(q{apothecium})->singular,   q{apothecium}  => q{singular: 'apothecium' --> 'apothecium'};
is noun(q{floras})->singular, q{flora}  => q{singular: 'floras' --> 'flora'};
is noun(q{flora})->singular,   q{flora}  => q{singular: 'flora' --> 'flora'};
is noun(q{schistosomula})->singular, q{schistosomulum}  => q{singular: 'schistosomula' --> 'schistosomulum'};
is noun(q{schistosomulum})->singular,   q{schistosomulum}  => q{singular: 'schistosomulum' --> 'schistosomulum'};
is noun(q{syringes})->singular, q{syringe}  => q{singular: 'syringes' --> 'syringe'};
is noun(q{syringe})->singular,   q{syringe}  => q{singular: 'syringe' --> 'syringe'};
is noun(q{vertices})->singular, q{vertex}  => q{singular: 'vertices' --> 'vertex'};
is noun(q{vertex})->singular,   q{vertex}  => q{singular: 'vertex' --> 'vertex'};
is noun(q{quantums})->singular, q{quantum}  => q{singular: 'quantums' --> 'quantum'};
is noun(q{quantum})->singular,   q{quantum}  => q{singular: 'quantum' --> 'quantum'};
is noun(q{cinclides})->singular, q{cinclis}  => q{singular: 'cinclides' --> 'cinclis'};
is noun(q{cinclis})->singular,   q{cinclis}  => q{singular: 'cinclis' --> 'cinclis'};
is noun(q{melanomata})->singular, q{melanoma}  => q{singular: 'melanomata' --> 'melanoma'};
is noun(q{melanoma})->singular,   q{melanoma}  => q{singular: 'melanoma' --> 'melanoma'};
is noun(q{apparatuses})->singular, q{apparatus}  => q{singular: 'apparatuses' --> 'apparatus'};
is noun(q{Milanese})->singular, q{Milanese}  => q{singular: 'Milanese' --> 'Milanese'};
is noun(q{matzahs})->singular, q{matzah}  => q{singular: 'matzahs' --> 'matzah'};
is noun(q{matzah})->singular,   q{matzah}  => q{singular: 'matzah' --> 'matzah'};
is noun(q{Messinese})->singular, q{Messinese}  => q{singular: 'Messinese' --> 'Messinese'};
is noun(q{aides de camp})->singular, q{aide de camp}  => q{singular: 'aides de camp' --> 'aide de camp'};
is noun(q{aide de camp})->singular,   q{aide de camp}  => q{singular: 'aide de camp' --> 'aide de camp'};
is noun(q{apparatchiki})->singular, q{apparatchik}  => q{singular: 'apparatchiki' --> 'apparatchik'};
is noun(q{apparatchik})->singular,   q{apparatchik}  => q{singular: 'apparatchik' --> 'apparatchik'};
is noun(q{whom})->singular, q{whom}  => q{singular: 'whom' --> 'whom'};
is noun(q{tintinnabula})->singular, q{tintinnabulum}  => q{singular: 'tintinnabula' --> 'tintinnabulum'};
is noun(q{tintinnabulum})->singular,   q{tintinnabulum}  => q{singular: 'tintinnabulum' --> 'tintinnabulum'};
is noun(q{cartes-de-visite})->singular, q{carte-de-visite}  => q{singular: 'cartes-de-visite' --> 'carte-de-visite'};
is noun(q{carte-de-visite})->singular,   q{carte-de-visite}  => q{singular: 'carte-de-visite' --> 'carte-de-visite'};
is noun(q{craspeda})->singular, q{craspedum}  => q{singular: 'craspeda' --> 'craspedum'};
is noun(q{craspedum})->singular,   q{craspedum}  => q{singular: 'craspedum' --> 'craspedum'};
is noun(q{numina})->singular, q{numen}  => q{singular: 'numina' --> 'numen'};
is noun(q{numen})->singular,   q{numen}  => q{singular: 'numen' --> 'numen'};
is noun(q{treponemata})->singular, q{treponema}  => q{singular: 'treponemata' --> 'treponema'};
is noun(q{treponema})->singular,   q{treponema}  => q{singular: 'treponema' --> 'treponema'};
is noun(q{rhododendrons})->singular, q{rhododendron}  => q{singular: 'rhododendrons' --> 'rhododendron'};
is noun(q{rhododendron})->singular,   q{rhododendron}  => q{singular: 'rhododendron' --> 'rhododendron'};
is noun(q{corgis})->singular, q{corgi}  => q{singular: 'corgis' --> 'corgi'};
is noun(q{corgi})->singular,   q{corgi}  => q{singular: 'corgi' --> 'corgi'};
is noun(q{curriculums})->singular, q{curriculum}  => q{singular: 'curriculums' --> 'curriculum'};
is noun(q{curriculum})->singular,   q{curriculum}  => q{singular: 'curriculum' --> 'curriculum'};
is noun(q{glissandi})->singular, q{glissando}  => q{singular: 'glissandi' --> 'glissando'};
is noun(q{glissando})->singular,   q{glissando}  => q{singular: 'glissando' --> 'glissando'};
is noun(q{astrocytomata})->singular, q{astrocytoma}  => q{singular: 'astrocytomata' --> 'astrocytoma'};
is noun(q{astrocytoma})->singular,   q{astrocytoma}  => q{singular: 'astrocytoma' --> 'astrocytoma'};
is noun(q{lacunas})->singular, q{lacuna}  => q{singular: 'lacunas' --> 'lacuna'};
is noun(q{lacuna})->singular,   q{lacuna}  => q{singular: 'lacuna' --> 'lacuna'};
is noun(q{protarsi})->singular, q{protarsus}  => q{singular: 'protarsi' --> 'protarsus'};
is noun(q{protarsus})->singular,   q{protarsus}  => q{singular: 'protarsus' --> 'protarsus'};
is noun(q{umbras})->singular, q{umbra}  => q{singular: 'umbras' --> 'umbra'};
is noun(q{umbra})->singular,   q{umbra}  => q{singular: 'umbra' --> 'umbra'};
is noun(q{stylos})->singular, q{stylo}  => q{singular: 'stylos' --> 'stylo'};
is noun(q{stylo})->singular,   q{stylo}  => q{singular: 'stylo' --> 'stylo'};
is noun(q{striolae})->singular, q{striola}  => q{singular: 'striolae' --> 'striola'};
is noun(q{striola})->singular,   q{striola}  => q{singular: 'striola' --> 'striola'};
is noun(q{pupae})->singular, q{pupa}  => q{singular: 'pupae' --> 'pupa'};
is noun(q{pupa})->singular,   q{pupa}  => q{singular: 'pupa' --> 'pupa'};
is noun(q{some})->singular, q{one}  => q{singular: 'some' --> 'one'};
is noun(q{one})->singular,   q{one}  => q{singular: 'one' --> 'one'};
is noun(q{quinarii})->singular, q{quinarius}  => q{singular: 'quinarii' --> 'quinarius'};
is noun(q{quinarius})->singular,   q{quinarius}  => q{singular: 'quinarius' --> 'quinarius'};
is noun(q{hypodermata})->singular, q{hypoderma}  => q{singular: 'hypodermata' --> 'hypoderma'};
is noun(q{hypoderma})->singular,   q{hypoderma}  => q{singular: 'hypoderma' --> 'hypoderma'};
is noun(q{faeculae})->singular, q{faecula}  => q{singular: 'faeculae' --> 'faecula'};
is noun(q{faecula})->singular,   q{faecula}  => q{singular: 'faecula' --> 'faecula'};
is noun(q{confervae})->singular, q{conferva}  => q{singular: 'confervae' --> 'conferva'};
is noun(q{conferva})->singular,   q{conferva}  => q{singular: 'conferva' --> 'conferva'};
is noun(q{microfiches})->singular, q{microfiche}  => q{singular: 'microfiches' --> 'microfiche'};
is noun(q{pros})->singular, q{pro}  => q{singular: 'pros' --> 'pro'};
is noun(q{pro})->singular,   q{pro}  => q{singular: 'pro' --> 'pro'};
is noun(q{trochi})->singular, q{trochus}  => q{singular: 'trochi' --> 'trochus'};
is noun(q{trochus})->singular,   q{trochus}  => q{singular: 'trochus' --> 'trochus'};
is noun(q{syncelli})->singular, q{syncellus}  => q{singular: 'syncelli' --> 'syncellus'};
is noun(q{syncellus})->singular,   q{syncellus}  => q{singular: 'syncellus' --> 'syncellus'};
is noun(q{Polonese})->singular, q{Polonese}  => q{singular: 'Polonese' --> 'Polonese'};
is noun(q{sensoriola})->singular, q{sensoriolum}  => q{singular: 'sensoriola' --> 'sensoriolum'};
is noun(q{sensoriolum})->singular,   q{sensoriolum}  => q{singular: 'sensoriolum' --> 'sensoriolum'};
is noun(q{tuberes})->singular, q{tuber}  => q{singular: 'tuberes' --> 'tuber'};
is noun(q{tuber})->singular,   q{tuber}  => q{singular: 'tuber' --> 'tuber'};
is noun(q{mezzo-rilievos})->singular, q{mezzo-rilievo}  => q{singular: 'mezzo-rilievos' --> 'mezzo-rilievo'};
is noun(q{mezzo-rilievo})->singular,   q{mezzo-rilievo}  => q{singular: 'mezzo-rilievo' --> 'mezzo-rilievo'};
is noun(q{Ferrarese})->singular, q{Ferrarese}  => q{singular: 'Ferrarese' --> 'Ferrarese'};
is noun(q{squadre})->singular, q{squadra}  => q{singular: 'squadre' --> 'squadra'};
is noun(q{squadra})->singular,   q{squadra}  => q{singular: 'squadra' --> 'squadra'};
is noun(q{Angolese})->singular, q{Angolese}  => q{singular: 'Angolese' --> 'Angolese'};
is noun(q{pallia})->singular, q{pallium}  => q{singular: 'pallia' --> 'pallium'};
is noun(q{pallium})->singular,   q{pallium}  => q{singular: 'pallium' --> 'pallium'};
is noun(q{louis})->singular, q{louis}  => q{singular: 'louis' --> 'louis'};
is noun(q{idees fixes})->singular, q{idee fixe}  => q{singular: 'idees fixes' --> 'idee fixe'};
is noun(q{idee fixe})->singular,   q{idee fixe}  => q{singular: 'idee fixe' --> 'idee fixe'};
is noun(q{senarii})->singular, q{senarius}  => q{singular: 'senarii' --> 'senarius'};
is noun(q{senarius})->singular,   q{senarius}  => q{singular: 'senarius' --> 'senarius'};
is noun(q{hairdos})->singular, q{hairdo}  => q{singular: 'hairdos' --> 'hairdo'};
is noun(q{hairdo})->singular,   q{hairdo}  => q{singular: 'hairdo' --> 'hairdo'};
is noun(q{territoria})->singular, q{territorium}  => q{singular: 'territoria' --> 'territorium'};
is noun(q{territorium})->singular,   q{territorium}  => q{singular: 'territorium' --> 'territorium'};
is noun(q{Tyrolese})->singular, q{Tyrolese}  => q{singular: 'Tyrolese' --> 'Tyrolese'};
is noun(q{ammos})->singular, q{ammo}  => q{singular: 'ammos' --> 'ammo'};
is noun(q{ammo})->singular,   q{ammo}  => q{singular: 'ammo' --> 'ammo'};
is noun(q{cows})->singular, q{cow}  => q{singular: 'cows' --> 'cow'};
is noun(q{cow})->singular,   q{cow}  => q{singular: 'cow' --> 'cow'};
is noun(q{diabetes})->singular, q{diabetes}  => q{singular: 'diabetes' --> 'diabetes'};
is noun(q{tentacula})->singular, q{tentaculum}  => q{singular: 'tentacula' --> 'tentaculum'};
is noun(q{tentaculum})->singular,   q{tentaculum}  => q{singular: 'tentaculum' --> 'tentaculum'};
is noun(q{bassi})->singular, q{basso}  => q{singular: 'bassi' --> 'basso'};
is noun(q{basso})->singular,   q{basso}  => q{singular: 'basso' --> 'basso'};
is noun(q{areolae})->singular, q{areola}  => q{singular: 'areolae' --> 'areola'};
is noun(q{areola})->singular,   q{areola}  => q{singular: 'areola' --> 'areola'};
is noun(q{papillomata})->singular, q{papilloma}  => q{singular: 'papillomata' --> 'papilloma'};
is noun(q{papilloma})->singular,   q{papilloma}  => q{singular: 'papilloma' --> 'papilloma'};
is noun(q{Sogdianese})->singular, q{Sogdianese}  => q{singular: 'Sogdianese' --> 'Sogdianese'};
is noun(q{moduses})->singular, q{modus}  => q{singular: 'moduses' --> 'modus'};
is noun(q{modus})->singular,   q{modus}  => q{singular: 'modus' --> 'modus'};
is noun(q{novas})->singular, q{nova}  => q{singular: 'novas' --> 'nova'};
is noun(q{nova})->singular,   q{nova}  => q{singular: 'nova' --> 'nova'};
is noun(q{Gestapos})->singular, q{Gestapo}  => q{singular: 'Gestapos' --> 'Gestapo'};
is noun(q{Gestapo})->singular,   q{Gestapo}  => q{singular: 'Gestapo' --> 'Gestapo'};
is noun(q{prosodiencephala})->singular, q{prosodiencephalon}  => q{singular: 'prosodiencephala' --> 'prosodiencephalon'};
is noun(q{prosodiencephalon})->singular,   q{prosodiencephalon}  => q{singular: 'prosodiencephalon' --> 'prosodiencephalon'};
is noun(q{gymnasia})->singular, q{gymnasium}  => q{singular: 'gymnasia' --> 'gymnasium'};
is noun(q{gymnasium})->singular,   q{gymnasium}  => q{singular: 'gymnasium' --> 'gymnasium'};
is noun(q{three star generals})->singular, q{three star general}  => q{singular: 'three star generals' --> 'three star general'};
is noun(q{three star general})->singular,   q{three star general}  => q{singular: 'three star general' --> 'three star general'};
is noun(q{lines-out})->singular, q{line-out}  => q{singular: 'lines-out' --> 'line-out'};
is noun(q{line-out})->singular,   q{line-out}  => q{singular: 'line-out' --> 'line-out'};
is noun(q{tours de force})->singular, q{tour de force}  => q{singular: 'tours de force' --> 'tour de force'};
is noun(q{tour de force})->singular,   q{tour de force}  => q{singular: 'tour de force' --> 'tour de force'};
is noun(q{djinns})->singular, q{djinn}  => q{singular: 'djinns' --> 'djinn'};
is noun(q{trapezii})->singular, q{trapezius}  => q{singular: 'trapezii' --> 'trapezius'};
is noun(q{trapezius})->singular,   q{trapezius}  => q{singular: 'trapezius' --> 'trapezius'};
is noun(q{torni})->singular, q{tornus}  => q{singular: 'torni' --> 'tornus'};
is noun(q{tornus})->singular,   q{tornus}  => q{singular: 'tornus' --> 'tornus'};
is noun(q{yarramans})->singular, q{yarraman}  => q{singular: 'yarramans' --> 'yarraman'};
is noun(q{yarraman})->singular,   q{yarraman}  => q{singular: 'yarraman' --> 'yarraman'};
is noun(q{haddocks})->singular, q{haddock}  => q{singular: 'haddocks' --> 'haddock'};
is noun(q{phototaxes})->singular, q{phototaxis}  => q{singular: 'phototaxes' --> 'phototaxis'};
is noun(q{phototaxis})->singular,   q{phototaxis}  => q{singular: 'phototaxis' --> 'phototaxis'};
is noun(q{chlamydiae})->singular, q{chlamydia}  => q{singular: 'chlamydiae' --> 'chlamydia'};
is noun(q{chlamydia})->singular,   q{chlamydia}  => q{singular: 'chlamydia' --> 'chlamydia'};
is noun(q{arangoes})->singular, q{arango}  => q{singular: 'arangoes' --> 'arango'};
is noun(q{arango})->singular,   q{arango}  => q{singular: 'arango' --> 'arango'};
is noun(q{milites gloriosi})->singular, q{miles gloriosus}  => q{singular: 'milites gloriosi' --> 'miles gloriosus'};
is noun(q{miles gloriosus})->singular,   q{miles gloriosus}  => q{singular: 'miles gloriosus' --> 'miles gloriosus'};
is noun(q{sphinges})->singular, q{sphinx}  => q{singular: 'sphinges' --> 'sphinx'};
is noun(q{sphinx})->singular,   q{sphinx}  => q{singular: 'sphinx' --> 'sphinx'};
is noun(q{Porto Novos})->singular, q{Porto Novo}  => q{singular: 'Porto Novos' --> 'Porto Novo'};
is noun(q{Porto Novo})->singular,   q{Porto Novo}  => q{singular: 'Porto Novo' --> 'Porto Novo'};
is noun(q{cremasteres})->singular, q{cremaster}  => q{singular: 'cremasteres' --> 'cremaster'};
is noun(q{cremaster})->singular,   q{cremaster}  => q{singular: 'cremaster' --> 'cremaster'};
is noun(q{sternebrae})->singular, q{sternebra}  => q{singular: 'sternebrae' --> 'sternebra'};
is noun(q{sternebra})->singular,   q{sternebra}  => q{singular: 'sternebra' --> 'sternebra'};
is noun(q{glissandos})->singular, q{glissando}  => q{singular: 'glissandos' --> 'glissando'};
is noun(q{glissando})->singular,   q{glissando}  => q{singular: 'glissando' --> 'glissando'};
is noun(q{rhinophymata})->singular, q{rhinophyma}  => q{singular: 'rhinophymata' --> 'rhinophyma'};
is noun(q{rhinophyma})->singular,   q{rhinophyma}  => q{singular: 'rhinophyma' --> 'rhinophyma'};
is noun(q{chevaux})->singular, q{cheval}  => q{singular: 'chevaux' --> 'cheval'};
is noun(q{cheval})->singular,   q{cheval}  => q{singular: 'cheval' --> 'cheval'};
is noun(q{agorae})->singular, q{agora}  => q{singular: 'agorae' --> 'agora'};
is noun(q{agora})->singular,   q{agora}  => q{singular: 'agora' --> 'agora'};
is noun(q{summae})->singular, q{summa}  => q{singular: 'summae' --> 'summa'};
is noun(q{summa})->singular,   q{summa}  => q{singular: 'summa' --> 'summa'};
is noun(q{efreets})->singular, q{efreet}  => q{singular: 'efreets' --> 'efreet'};
is noun(q{efreet})->singular,   q{efreet}  => q{singular: 'efreet' --> 'efreet'};
is noun(q{us})->singular, q{me}  => q{singular: 'us' --> 'me'};
is noun(q{me})->singular,   q{me}  => q{singular: 'me' --> 'me'};
is noun(q{mantellette})->singular, q{mantelletta}  => q{singular: 'mantellette' --> 'mantelletta'};
is noun(q{mantelletta})->singular,   q{mantelletta}  => q{singular: 'mantelletta' --> 'mantelletta'};
is noun(q{memorandums})->singular, q{memorandum}  => q{singular: 'memorandums' --> 'memorandum'};
is noun(q{memorandum})->singular,   q{memorandum}  => q{singular: 'memorandum' --> 'memorandum'};
is noun(q{bifolia})->singular, q{bifolium}  => q{singular: 'bifolia' --> 'bifolium'};
is noun(q{bifolium})->singular,   q{bifolium}  => q{singular: 'bifolium' --> 'bifolium'};
is noun(q{pinons})->singular, q{pinon}  => q{singular: 'pinons' --> 'pinon'};
is noun(q{pinon})->singular,   q{pinon}  => q{singular: 'pinon' --> 'pinon'};
is noun(q{proferentes})->singular, q{proferens}  => q{singular: 'proferentes' --> 'proferens'};
is noun(q{proferens})->singular,   q{proferens}  => q{singular: 'proferens' --> 'proferens'};
is noun(q{hinaki})->singular, q{hinaki}  => q{singular: 'hinaki' --> 'hinaki'};
is noun(q{coronae})->singular, q{corona}  => q{singular: 'coronae' --> 'corona'};
is noun(q{corona})->singular,   q{corona}  => q{singular: 'corona' --> 'corona'};
is noun(q{scotomas})->singular, q{scotoma}  => q{singular: 'scotomas' --> 'scotoma'};
is noun(q{scotoma})->singular,   q{scotoma}  => q{singular: 'scotoma' --> 'scotoma'};
is noun(q{lumens})->singular, q{lumen}  => q{singular: 'lumens' --> 'lumen'};
is noun(q{lumen})->singular,   q{lumen}  => q{singular: 'lumen' --> 'lumen'};
is noun(q{flagella})->singular, q{flagellum}  => q{singular: 'flagella' --> 'flagellum'};
is noun(q{flagellum})->singular,   q{flagellum}  => q{singular: 'flagellum' --> 'flagellum'};
is noun(q{striae})->singular, q{stria}  => q{singular: 'striae' --> 'stria'};
is noun(q{stria})->singular,   q{stria}  => q{singular: 'stria' --> 'stria'};
is noun(q{scirrhusses})->singular, q{scirrhus}  => q{singular: 'scirrhusses' --> 'scirrhus'};
is noun(q{scirrhus})->singular,   q{scirrhus}  => q{singular: 'scirrhus' --> 'scirrhus'};
is noun(q{cyphellae})->singular, q{cyphella}  => q{singular: 'cyphellae' --> 'cyphella'};
is noun(q{cyphella})->singular,   q{cyphella}  => q{singular: 'cyphella' --> 'cyphella'};
is noun(q{Lyonese})->singular, q{Lyonese}  => q{singular: 'Lyonese' --> 'Lyonese'};
is noun(q{Alfurese})->singular, q{Alfurese}  => q{singular: 'Alfurese' --> 'Alfurese'};
is noun(q{matres lectionis})->singular, q{mater lectionis}  => q{singular: 'matres lectionis' --> 'mater lectionis'};
is noun(q{mater lectionis})->singular,   q{mater lectionis}  => q{singular: 'mater lectionis' --> 'mater lectionis'};
is noun(q{Sundanese})->singular, q{Sundanese}  => q{singular: 'Sundanese' --> 'Sundanese'};
is noun(q{syllabuses})->singular, q{syllabus}  => q{singular: 'syllabuses' --> 'syllabus'};
is noun(q{syllabus})->singular,   q{syllabus}  => q{singular: 'syllabus' --> 'syllabus'};
is noun(q{limaces})->singular, q{limax}  => q{singular: 'limaces' --> 'limax'};
is noun(q{limax})->singular,   q{limax}  => q{singular: 'limax' --> 'limax'};
is noun(q{fuci})->singular, q{fucus}  => q{singular: 'fuci' --> 'fucus'};
is noun(q{fucus})->singular,   q{fucus}  => q{singular: 'fucus' --> 'fucus'};
is noun(q{anthodia})->singular, q{anthodium}  => q{singular: 'anthodia' --> 'anthodium'};
is noun(q{anthodium})->singular,   q{anthodium}  => q{singular: 'anthodium' --> 'anthodium'};
is noun(q{seaquaria})->singular, q{seaquarium}  => q{singular: 'seaquaria' --> 'seaquarium'};
is noun(q{seaquarium})->singular,   q{seaquarium}  => q{singular: 'seaquarium' --> 'seaquarium'};
is noun(q{vomitoria})->singular, q{vomitorium}  => q{singular: 'vomitoria' --> 'vomitorium'};
is noun(q{vomitorium})->singular,   q{vomitorium}  => q{singular: 'vomitorium' --> 'vomitorium'};
is noun(q{pulveratrices})->singular, q{pulveratrix}  => q{singular: 'pulveratrices' --> 'pulveratrix'};
is noun(q{pulveratrix})->singular,   q{pulveratrix}  => q{singular: 'pulveratrix' --> 'pulveratrix'};
is noun(q{dogmas})->singular, q{dogma}  => q{singular: 'dogmas' --> 'dogma'};
is noun(q{dogma})->singular,   q{dogma}  => q{singular: 'dogma' --> 'dogma'};
is noun(q{typos})->singular, q{typo}  => q{singular: 'typos' --> 'typo'};
is noun(q{typo})->singular,   q{typo}  => q{singular: 'typo' --> 'typo'};
is noun(q{paths})->singular, q{path}  => q{singular: 'paths' --> 'path'};
is noun(q{path})->singular,   q{path}  => q{singular: 'path' --> 'path'};
is noun(q{nentsy})->singular, q{nenets}  => q{singular: 'nentsy' --> 'nenets'};
is noun(q{nenets})->singular,   q{nenets}  => q{singular: 'nenets' --> 'nenets'};
is noun(q{toriles})->singular, q{toril}  => q{singular: 'toriles' --> 'toril'};
is noun(q{toril})->singular,   q{toril}  => q{singular: 'toril' --> 'toril'};
is noun(q{lux})->singular, q{lux}  => q{singular: 'lux' --> 'lux'};
is noun(q{oculi})->singular, q{oculus}  => q{singular: 'oculi' --> 'oculus'};
is noun(q{oculus})->singular,   q{oculus}  => q{singular: 'oculus' --> 'oculus'};
is noun(q{lemmata})->singular, q{lemma}  => q{singular: 'lemmata' --> 'lemma'};
is noun(q{lemma})->singular,   q{lemma}  => q{singular: 'lemma' --> 'lemma'};
is noun(q{explicanda})->singular, q{explicandum}  => q{singular: 'explicanda' --> 'explicandum'};
is noun(q{explicandum})->singular,   q{explicandum}  => q{singular: 'explicandum' --> 'explicandum'};
is noun(q{pleura})->singular, q{pleura}  => q{singular: 'pleura' --> 'pleura'};
is noun(q{paise})->singular, q{paisa}  => q{singular: 'paise' --> 'paisa'};
is noun(q{paisa})->singular,   q{paisa}  => q{singular: 'paisa' --> 'paisa'};
is noun(q{uteruses})->singular, q{uterus}  => q{singular: 'uteruses' --> 'uterus'};
is noun(q{uterus})->singular,   q{uterus}  => q{singular: 'uterus' --> 'uterus'};
is noun(q{washers up})->singular, q{washer up}  => q{singular: 'washers up' --> 'washer up'};
is noun(q{washer up})->singular,   q{washer up}  => q{singular: 'washer up' --> 'washer up'};
is noun(q{scarabaei})->singular, q{scarabaeus}  => q{singular: 'scarabaei' --> 'scarabaeus'};
is noun(q{scarabaeus})->singular,   q{scarabaeus}  => q{singular: 'scarabaeus' --> 'scarabaeus'};
is noun(q{elks})->singular, q{elk}  => q{singular: 'elks' --> 'elk'};
is noun(q{soprani})->singular, q{soprano}  => q{singular: 'soprani' --> 'soprano'};
is noun(q{soprano})->singular,   q{soprano}  => q{singular: 'soprano' --> 'soprano'};
is noun(q{fedai})->singular, q{fedai}  => q{singular: 'fedai' --> 'fedai'};
is noun(q{wharves})->singular, q{wharf}  => q{singular: 'wharves' --> 'wharf'};
is noun(q{wharf})->singular,   q{wharf}  => q{singular: 'wharf' --> 'wharf'};
is noun(q{canzonettas})->singular, q{canzonetta}  => q{singular: 'canzonettas' --> 'canzonetta'};
is noun(q{canzonetta})->singular,   q{canzonetta}  => q{singular: 'canzonetta' --> 'canzonetta'};
is noun(q{sopranos})->singular, q{soprano}  => q{singular: 'sopranos' --> 'soprano'};
is noun(q{soprano})->singular,   q{soprano}  => q{singular: 'soprano' --> 'soprano'};
is noun(q{limuli})->singular, q{limulus}  => q{singular: 'limuli' --> 'limulus'};
is noun(q{limulus})->singular,   q{limulus}  => q{singular: 'limulus' --> 'limulus'};
is noun(q{contagia})->singular, q{contagium}  => q{singular: 'contagia' --> 'contagium'};
is noun(q{contagium})->singular,   q{contagium}  => q{singular: 'contagium' --> 'contagium'};
is noun(q{cubicula})->singular, q{cubiculum}  => q{singular: 'cubicula' --> 'cubiculum'};
is noun(q{cubiculum})->singular,   q{cubiculum}  => q{singular: 'cubiculum' --> 'cubiculum'};
is noun(q{odea})->singular, q{odeum}  => q{singular: 'odea' --> 'odeum'};
is noun(q{odeum})->singular,   q{odeum}  => q{singular: 'odeum' --> 'odeum'};
is noun(q{Virgos})->singular, q{Virgo}  => q{singular: 'Virgos' --> 'Virgo'};
is noun(q{Virgo})->singular,   q{Virgo}  => q{singular: 'Virgo' --> 'Virgo'};
is noun(q{plexuses})->singular, q{plexus}  => q{singular: 'plexuses' --> 'plexus'};
is noun(q{meatus})->singular, q{meatus}  => q{singular: 'meatus' --> 'meatus'};
is noun(q{lepromata})->singular, q{leproma}  => q{singular: 'lepromata' --> 'leproma'};
is noun(q{leproma})->singular,   q{leproma}  => q{singular: 'leproma' --> 'leproma'};
is noun(q{dumky})->singular, q{dumka}  => q{singular: 'dumky' --> 'dumka'};
is noun(q{dumka})->singular,   q{dumka}  => q{singular: 'dumka' --> 'dumka'};
is noun(q{convolvuluses})->singular, q{convolvulus}  => q{singular: 'convolvuluses' --> 'convolvulus'};
is noun(q{convolvulus})->singular,   q{convolvulus}  => q{singular: 'convolvulus' --> 'convolvulus'};
is noun(q{guys})->singular, q{guy}  => q{singular: 'guys' --> 'guy'};
is noun(q{guy})->singular,   q{guy}  => q{singular: 'guy' --> 'guy'};
is noun(q{alumni})->singular, q{alumnus}  => q{singular: 'alumni' --> 'alumnus'};
is noun(q{alumnus})->singular,   q{alumnus}  => q{singular: 'alumnus' --> 'alumnus'};
is noun(q{poderi})->singular, q{podere}  => q{singular: 'poderi' --> 'podere'};
is noun(q{podere})->singular,   q{podere}  => q{singular: 'podere' --> 'podere'};
is noun(q{alguacils})->singular, q{alguacil}  => q{singular: 'alguacils' --> 'alguacil'};
is noun(q{alguacil})->singular,   q{alguacil}  => q{singular: 'alguacil' --> 'alguacil'};
is noun(q{pneumothoraces})->singular, q{pneumothorax}  => q{singular: 'pneumothoraces' --> 'pneumothorax'};
is noun(q{pneumothorax})->singular,   q{pneumothorax}  => q{singular: 'pneumothorax' --> 'pneumothorax'};
is noun(q{tagmata})->singular, q{tagma}  => q{singular: 'tagmata' --> 'tagma'};
is noun(q{tagma})->singular,   q{tagma}  => q{singular: 'tagma' --> 'tagma'};
is noun(q{castrati})->singular, q{castrato}  => q{singular: 'castrati' --> 'castrato'};
is noun(q{castrato})->singular,   q{castrato}  => q{singular: 'castrato' --> 'castrato'};
is noun(q{lentigines})->singular, q{lentigo}  => q{singular: 'lentigines' --> 'lentigo'};
is noun(q{lentigo})->singular,   q{lentigo}  => q{singular: 'lentigo' --> 'lentigo'};
is noun(q{infimae species})->singular, q{infima species}  => q{singular: 'infimae species' --> 'infima species'};
is noun(q{infima species})->singular,   q{infima species}  => q{singular: 'infima species' --> 'infima species'};
is noun(q{prosae})->singular, q{prosa}  => q{singular: 'prosae' --> 'prosa'};
is noun(q{prosa})->singular,   q{prosa}  => q{singular: 'prosa' --> 'prosa'};
is noun(q{succubi})->singular, q{succubus}  => q{singular: 'succubi' --> 'succubus'};
is noun(q{succubus})->singular,   q{succubus}  => q{singular: 'succubus' --> 'succubus'};
is noun(q{veges})->singular, q{veg}  => q{singular: 'veges' --> 'veg'};
is noun(q{chateaus})->singular, q{chateau}  => q{singular: 'chateaus' --> 'chateau'};
is noun(q{chateau})->singular,   q{chateau}  => q{singular: 'chateau' --> 'chateau'};
is noun(q{res})->singular, q{res}  => q{singular: 'res' --> 'res'};
is noun(q{capos})->singular, q{capo}  => q{singular: 'capos' --> 'capo'};
is noun(q{capo})->singular,   q{capo}  => q{singular: 'capo' --> 'capo'};
is noun(q{pikes})->singular, q{pike}  => q{singular: 'pikes' --> 'pike'};
is noun(q{monochasia})->singular, q{monochasium}  => q{singular: 'monochasia' --> 'monochasium'};
is noun(q{monochasium})->singular,   q{monochasium}  => q{singular: 'monochasium' --> 'monochasium'};
is noun(q{filarias})->singular, q{filaria}  => q{singular: 'filarias' --> 'filaria'};
is noun(q{filaria})->singular,   q{filaria}  => q{singular: 'filaria' --> 'filaria'};
is noun(q{mucrones})->singular, q{mucro}  => q{singular: 'mucrones' --> 'mucro'};
is noun(q{mucro})->singular,   q{mucro}  => q{singular: 'mucro' --> 'mucro'};
is noun(q{men servants})->singular, q{man servant}  => q{singular: 'men servants' --> 'man servant'};
is noun(q{man servant})->singular,   q{man servant}  => q{singular: 'man servant' --> 'man servant'};
is noun(q{nomismata})->singular, q{nomisma}  => q{singular: 'nomismata' --> 'nomisma'};
is noun(q{nomisma})->singular,   q{nomisma}  => q{singular: 'nomisma' --> 'nomisma'};
is noun(q{finger ends})->singular, q{finger end}  => q{singular: 'finger ends' --> 'finger end'};
is noun(q{finger end})->singular,   q{finger end}  => q{singular: 'finger end' --> 'finger end'};
is noun(q{does})->singular, q{doe}  => q{singular: 'does' --> 'doe'};
is noun(q{doe})->singular,   q{doe}  => q{singular: 'doe' --> 'doe'};
is noun(q{toes})->singular, q{toe}  => q{singular: 'toes' --> 'toe'};
is noun(q{toe})->singular,   q{toe}  => q{singular: 'toe' --> 'toe'};
is noun(q{Cairos})->singular, q{Cairo}  => q{singular: 'Cairos' --> 'Cairo'};
is noun(q{Cairo})->singular,   q{Cairo}  => q{singular: 'Cairo' --> 'Cairo'};
is noun(q{trilbys})->singular, q{trilby}  => q{singular: 'trilbys' --> 'trilby'};
is noun(q{trilby})->singular,   q{trilby}  => q{singular: 'trilby' --> 'trilby'};
is noun(q{Purum})->singular, q{Purum}  => q{singular: 'Purum' --> 'Purum'};
is noun(q{dramas})->singular, q{drama}  => q{singular: 'dramas' --> 'drama'};
is noun(q{drama})->singular,   q{drama}  => q{singular: 'drama' --> 'drama'};
is noun(q{prima ballerinas})->singular, q{prima ballerina}  => q{singular: 'prima ballerinas' --> 'prima ballerina'};
is noun(q{prima ballerina})->singular,   q{prima ballerina}  => q{singular: 'prima ballerina' --> 'prima ballerina'};
is noun(q{scoriae})->singular, q{scoria}  => q{singular: 'scoriae' --> 'scoria'};
is noun(q{scoria})->singular,   q{scoria}  => q{singular: 'scoria' --> 'scoria'};
is noun(q{portmanteaus})->singular, q{portmanteau}  => q{singular: 'portmanteaus' --> 'portmanteau'};
is noun(q{portmanteau})->singular,   q{portmanteau}  => q{singular: 'portmanteau' --> 'portmanteau'};
is noun(q{vaginae})->singular, q{vagina}  => q{singular: 'vaginae' --> 'vagina'};
is noun(q{vagina})->singular,   q{vagina}  => q{singular: 'vagina' --> 'vagina'};
is noun(q{murices})->singular, q{murex}  => q{singular: 'murices' --> 'murex'};
is noun(q{murex})->singular,   q{murex}  => q{singular: 'murex' --> 'murex'};
is noun(q{whosever})->singular, q{whosever}  => q{singular: 'whosever' --> 'whosever'};
is noun(q{trousers})->singular, q{trousers}  => q{singular: 'trousers' --> 'trousers'};
is noun(q{torma})->singular, q{torma}  => q{singular: 'torma' --> 'torma'};
is noun(q{staterae})->singular, q{statera}  => q{singular: 'staterae' --> 'statera'};
is noun(q{statera})->singular,   q{statera}  => q{singular: 'statera' --> 'statera'};
is noun(q{conducti})->singular, q{conductus}  => q{singular: 'conducti' --> 'conductus'};
is noun(q{conductus})->singular,   q{conductus}  => q{singular: 'conductus' --> 'conductus'};
is noun(q{farmans})->singular, q{farman}  => q{singular: 'farmans' --> 'farman'};
is noun(q{farman})->singular,   q{farman}  => q{singular: 'farman' --> 'farman'};
is noun(q{Cantonese})->singular, q{Cantonese}  => q{singular: 'Cantonese' --> 'Cantonese'};
is noun(q{children})->singular, q{child}  => q{singular: 'children' --> 'child'};
is noun(q{child})->singular,   q{child}  => q{singular: 'child' --> 'child'};
is noun(q{series})->singular, q{series}  => q{singular: 'series' --> 'series'};
is noun(q{Nakayamans})->singular, q{Nakayaman}  => q{singular: 'Nakayamans' --> 'Nakayaman'};
is noun(q{Nakayaman})->singular,   q{Nakayaman}  => q{singular: 'Nakayaman' --> 'Nakayaman'};
is noun(q{zophori})->singular, q{zophorus}  => q{singular: 'zophori' --> 'zophorus'};
is noun(q{zophorus})->singular,   q{zophorus}  => q{singular: 'zophorus' --> 'zophorus'};
is noun(q{apteria})->singular, q{apterium}  => q{singular: 'apteria' --> 'apterium'};
is noun(q{apterium})->singular,   q{apterium}  => q{singular: 'apterium' --> 'apterium'};
is noun(q{rhizomata})->singular, q{rhizoma}  => q{singular: 'rhizomata' --> 'rhizoma'};
is noun(q{rhizoma})->singular,   q{rhizoma}  => q{singular: 'rhizoma' --> 'rhizoma'};
is noun(q{talouses})->singular, q{talouse}  => q{singular: 'talouses' --> 'talouse'};
is noun(q{talouse})->singular,   q{talouse}  => q{singular: 'talouse' --> 'talouse'};
is noun(q{pedicellariae})->singular, q{pedicellaria}  => q{singular: 'pedicellariae' --> 'pedicellaria'};
is noun(q{pedicellaria})->singular,   q{pedicellaria}  => q{singular: 'pedicellaria' --> 'pedicellaria'};
is noun(q{parerga})->singular, q{parergon}  => q{singular: 'parerga' --> 'parergon'};
is noun(q{parergon})->singular,   q{parergon}  => q{singular: 'parergon' --> 'parergon'};
is noun(q{castra})->singular, q{castrum}  => q{singular: 'castra' --> 'castrum'};
is noun(q{castrum})->singular,   q{castrum}  => q{singular: 'castrum' --> 'castrum'};
is noun(q{sets to})->singular, q{set to}  => q{singular: 'sets to' --> 'set to'};
is noun(q{set to})->singular,   q{set to}  => q{singular: 'set to' --> 'set to'};
is noun(q{bingos})->singular, q{bingo}  => q{singular: 'bingos' --> 'bingo'};
is noun(q{bingo})->singular,   q{bingo}  => q{singular: 'bingo' --> 'bingo'};
is noun(q{men midwives})->singular, q{man midwife}  => q{singular: 'men midwives' --> 'man midwife'};
is noun(q{man midwife})->singular,   q{man midwife}  => q{singular: 'man midwife' --> 'man midwife'};
is noun(q{break-aways})->singular, q{break-away}  => q{singular: 'break-aways' --> 'break-away'};
is noun(q{break-away})->singular,   q{break-away}  => q{singular: 'break-away' --> 'break-away'};
is noun(q{anathemata})->singular, q{anathema}  => q{singular: 'anathemata' --> 'anathema'};
is noun(q{anathema})->singular,   q{anathema}  => q{singular: 'anathema' --> 'anathema'};
is noun(q{fingers-ends})->singular, q{finger-end}  => q{singular: 'fingers-ends' --> 'finger-end'};
is noun(q{finger-end})->singular,   q{finger-end}  => q{singular: 'finger-end' --> 'finger-end'};
is noun(q{coxendices})->singular, q{coxendix}  => q{singular: 'coxendices' --> 'coxendix'};
is noun(q{coxendix})->singular,   q{coxendix}  => q{singular: 'coxendix' --> 'coxendix'};
is noun(q{one star generals})->singular, q{one star general}  => q{singular: 'one star generals' --> 'one star general'};
is noun(q{one star general})->singular,   q{one star general}  => q{singular: 'one star general' --> 'one star general'};
is noun(q{biases})->singular, q{bias}  => q{singular: 'biases' --> 'bias'};
is noun(q{bias})->singular,   q{bias}  => q{singular: 'bias' --> 'bias'};
is noun(q{lord lieutenants})->singular, q{lord lieutenant}  => q{singular: 'lord lieutenants' --> 'lord lieutenant'};
is noun(q{lord lieutenant})->singular,   q{lord lieutenant}  => q{singular: 'lord lieutenant' --> 'lord lieutenant'};
is noun(q{kilos})->singular, q{kilo}  => q{singular: 'kilos' --> 'kilo'};
is noun(q{kilo})->singular,   q{kilo}  => q{singular: 'kilo' --> 'kilo'};
is noun(q{sachverhalte})->singular, q{sachverhalt}  => q{singular: 'sachverhalte' --> 'sachverhalt'};
is noun(q{sachverhalt})->singular,   q{sachverhalt}  => q{singular: 'sachverhalt' --> 'sachverhalt'};
is noun(q{parhelia})->singular, q{parhelion}  => q{singular: 'parhelia' --> 'parhelion'};
is noun(q{parhelion})->singular,   q{parhelion}  => q{singular: 'parhelion' --> 'parhelion'};
is noun(q{opercula})->singular, q{operculum}  => q{singular: 'opercula' --> 'operculum'};
is noun(q{operculum})->singular,   q{operculum}  => q{singular: 'operculum' --> 'operculum'};
is noun(q{rhombohedra})->singular, q{rhombohedron}  => q{singular: 'rhombohedra' --> 'rhombohedron'};
is noun(q{rhombohedron})->singular,   q{rhombohedron}  => q{singular: 'rhombohedron' --> 'rhombohedron'};
is noun(q{cimices})->singular, q{cimex}  => q{singular: 'cimices' --> 'cimex'};
is noun(q{cimex})->singular,   q{cimex}  => q{singular: 'cimex' --> 'cimex'};
is noun(q{these})->singular, q{this}  => q{singular: 'these' --> 'this'};
is noun(q{this})->singular,   q{this}  => q{singular: 'this' --> 'this'};
is noun(q{apexes})->singular, q{apex}  => q{singular: 'apexes' --> 'apex'};
is noun(q{apex})->singular,   q{apex}  => q{singular: 'apex' --> 'apex'};
is noun(q{vomicae})->singular, q{vomica}  => q{singular: 'vomicae' --> 'vomica'};
is noun(q{vomica})->singular,   q{vomica}  => q{singular: 'vomica' --> 'vomica'};
is noun(q{myos})->singular, q{myo}  => q{singular: 'myos' --> 'myo'};
is noun(q{myo})->singular,   q{myo}  => q{singular: 'myo' --> 'myo'};
is noun(q{mottoes})->singular, q{motto}  => q{singular: 'mottoes' --> 'motto'};
is noun(q{motto})->singular,   q{motto}  => q{singular: 'motto' --> 'motto'};
is noun(q{tremolos})->singular, q{tremolo}  => q{singular: 'tremolos' --> 'tremolo'};
is noun(q{tremolo})->singular,   q{tremolo}  => q{singular: 'tremolo' --> 'tremolo'};
is noun(q{ergastula})->singular, q{ergastulum}  => q{singular: 'ergastula' --> 'ergastulum'};
is noun(q{ergastulum})->singular,   q{ergastulum}  => q{singular: 'ergastulum' --> 'ergastulum'};
is noun(q{auto de fes})->singular, q{auto de fe}  => q{singular: 'auto de fes' --> 'auto de fe'};
is noun(q{auto de fe})->singular,   q{auto de fe}  => q{singular: 'auto de fe' --> 'auto de fe'};
is noun(q{siphunculi})->singular, q{siphunculus}  => q{singular: 'siphunculi' --> 'siphunculus'};
is noun(q{siphunculus})->singular,   q{siphunculus}  => q{singular: 'siphunculus' --> 'siphunculus'};
is noun(q{purums})->singular, q{purum}  => q{singular: 'purums' --> 'purum'};
is noun(q{soldi})->singular, q{soldo}  => q{singular: 'soldi' --> 'soldo'};
is noun(q{soldo})->singular,   q{soldo}  => q{singular: 'soldo' --> 'soldo'};
is noun(q{thalamoi})->singular, q{thalamos}  => q{singular: 'thalamoi' --> 'thalamos'};
is noun(q{thalamos})->singular,   q{thalamos}  => q{singular: 'thalamos' --> 'thalamos'};
is noun(q{depositums})->singular, q{depositum}  => q{singular: 'depositums' --> 'depositum'};
is noun(q{depositum})->singular,   q{depositum}  => q{singular: 'depositum' --> 'depositum'};
is noun(q{trousseaus})->singular, q{trousseau}  => q{singular: 'trousseaus' --> 'trousseau'};
is noun(q{trousseau})->singular,   q{trousseau}  => q{singular: 'trousseau' --> 'trousseau'};
is noun(q{somatenes})->singular, q{somaten}  => q{singular: 'somatenes' --> 'somaten'};
is noun(q{somaten})->singular,   q{somaten}  => q{singular: 'somaten' --> 'somaten'};
is noun(q{amoretti})->singular, q{amoretto}  => q{singular: 'amoretti' --> 'amoretto'};
is noun(q{amoretto})->singular,   q{amoretto}  => q{singular: 'amoretto' --> 'amoretto'};
is noun(q{libidos})->singular, q{libido}  => q{singular: 'libidos' --> 'libido'};
is noun(q{libido})->singular,   q{libido}  => q{singular: 'libido' --> 'libido'};
is noun(q{Sacramentos})->singular, q{Sacramento}  => q{singular: 'Sacramentos' --> 'Sacramento'};
is noun(q{Sacramento})->singular,   q{Sacramento}  => q{singular: 'Sacramento' --> 'Sacramento'};
is noun(q{zucchinis})->singular, q{zucchini}  => q{singular: 'zucchinis' --> 'zucchini'};
is noun(q{wives})->singular, q{wife}  => q{singular: 'wives' --> 'wife'};
is noun(q{wife})->singular,   q{wife}  => q{singular: 'wife' --> 'wife'};
is noun(q{lumina})->singular, q{lumen}  => q{singular: 'lumina' --> 'lumen'};
is noun(q{lumen})->singular,   q{lumen}  => q{singular: 'lumen' --> 'lumen'};
is noun(q{blemyae})->singular, q{blemya}  => q{singular: 'blemyae' --> 'blemya'};
is noun(q{blemya})->singular,   q{blemya}  => q{singular: 'blemya' --> 'blemya'};
is noun(q{hyperbolae})->singular, q{hyperbola}  => q{singular: 'hyperbolae' --> 'hyperbola'};
is noun(q{hyperbola})->singular,   q{hyperbola}  => q{singular: 'hyperbola' --> 'hyperbola'};
is noun(q{divisional generals})->singular, q{divisional general}  => q{singular: 'divisional generals' --> 'divisional general'};
is noun(q{divisional general})->singular,   q{divisional general}  => q{singular: 'divisional general' --> 'divisional general'};
is noun(q{credos})->singular, q{credo}  => q{singular: 'credos' --> 'credo'};
is noun(q{credo})->singular,   q{credo}  => q{singular: 'credo' --> 'credo'};
is noun(q{rococos})->singular, q{rococo}  => q{singular: 'rococos' --> 'rococo'};
is noun(q{rococo})->singular,   q{rococo}  => q{singular: 'rococo' --> 'rococo'};
is noun(q{octavos})->singular, q{octavo}  => q{singular: 'octavos' --> 'octavo'};
is noun(q{octavo})->singular,   q{octavo}  => q{singular: 'octavo' --> 'octavo'};
is noun(q{entrochi})->singular, q{entrochus}  => q{singular: 'entrochi' --> 'entrochus'};
is noun(q{entrochus})->singular,   q{entrochus}  => q{singular: 'entrochus' --> 'entrochus'};
is noun(q{chevaux-de-bataille})->singular, q{cheval-de-bataille}  => q{singular: 'chevaux-de-bataille' --> 'cheval-de-bataille'};
is noun(q{cheval-de-bataille})->singular,   q{cheval-de-bataille}  => q{singular: 'cheval-de-bataille' --> 'cheval-de-bataille'};
is noun(q{gonidia})->singular, q{gonidium}  => q{singular: 'gonidia' --> 'gonidium'};
is noun(q{gonidium})->singular,   q{gonidium}  => q{singular: 'gonidium' --> 'gonidium'};
is noun(q{gaons})->singular, q{gaon}  => q{singular: 'gaons' --> 'gaon'};
is noun(q{gaon})->singular,   q{gaon}  => q{singular: 'gaon' --> 'gaon'};
is noun(q{nexuses})->singular, q{nexus}  => q{singular: 'nexuses' --> 'nexus'};
is noun(q{caffe macchiatos})->singular, q{caffe macchiato}  => q{singular: 'caffe macchiatos' --> 'caffe macchiato'};
is noun(q{caffe macchiato})->singular,   q{caffe macchiato}  => q{singular: 'caffe macchiato' --> 'caffe macchiato'};
is noun(q{supernovas})->singular, q{supernova}  => q{singular: 'supernovas' --> 'supernova'};
is noun(q{supernova})->singular,   q{supernova}  => q{singular: 'supernova' --> 'supernova'};
is noun(q{uncini})->singular, q{uncinus}  => q{singular: 'uncini' --> 'uncinus'};
is noun(q{uncinus})->singular,   q{uncinus}  => q{singular: 'uncinus' --> 'uncinus'};
is noun(q{trousseaux})->singular, q{trousseau}  => q{singular: 'trousseaux' --> 'trousseau'};
is noun(q{trousseau})->singular,   q{trousseau}  => q{singular: 'trousseau' --> 'trousseau'};
is noun(q{Hainanese})->singular, q{Hainanese}  => q{singular: 'Hainanese' --> 'Hainanese'};
is noun(q{noxae})->singular, q{noxa}  => q{singular: 'noxae' --> 'noxa'};
is noun(q{noxa})->singular,   q{noxa}  => q{singular: 'noxa' --> 'noxa'};
is noun(q{loculi})->singular, q{loculus}  => q{singular: 'loculi' --> 'loculus'};
is noun(q{loculus})->singular,   q{loculus}  => q{singular: 'loculus' --> 'loculus'};
is noun(q{Majuros})->singular, q{Majuro}  => q{singular: 'Majuros' --> 'Majuro'};
is noun(q{Majuro})->singular,   q{Majuro}  => q{singular: 'Majuro' --> 'Majuro'};
is noun(q{Filipinos})->singular, q{Filipino}  => q{singular: 'Filipinos' --> 'Filipino'};
is noun(q{Filipino})->singular,   q{Filipino}  => q{singular: 'Filipino' --> 'Filipino'};
is noun(q{Vermontese})->singular, q{Vermontese}  => q{singular: 'Vermontese' --> 'Vermontese'};
is noun(q{progymnasia})->singular, q{progymnasium}  => q{singular: 'progymnasia' --> 'progymnasium'};
is noun(q{progymnasium})->singular,   q{progymnasium}  => q{singular: 'progymnasium' --> 'progymnasium'};
is noun(q{metropolises})->singular, q{metropolis}  => q{singular: 'metropolises' --> 'metropolis'};
is noun(q{metropolis})->singular,   q{metropolis}  => q{singular: 'metropolis' --> 'metropolis'};
is noun(q{octohedrons})->singular, q{octohedron}  => q{singular: 'octohedrons' --> 'octohedron'};
is noun(q{octohedron})->singular,   q{octohedron}  => q{singular: 'octohedron' --> 'octohedron'};
is noun(q{solvi})->singular, q{solvus}  => q{singular: 'solvi' --> 'solvus'};
is noun(q{solvus})->singular,   q{solvus}  => q{singular: 'solvus' --> 'solvus'};
is noun(q{lieux})->singular, q{lieu}  => q{singular: 'lieux' --> 'lieu'};
is noun(q{lieu})->singular,   q{lieu}  => q{singular: 'lieu' --> 'lieu'};
is noun(q{Amoyese})->singular, q{Amoyese}  => q{singular: 'Amoyese' --> 'Amoyese'};
is noun(q{macaci})->singular, q{macacus}  => q{singular: 'macaci' --> 'macacus'};
is noun(q{macacus})->singular,   q{macacus}  => q{singular: 'macacus' --> 'macacus'};
is noun(q{phylae})->singular, q{phyle}  => q{singular: 'phylae' --> 'phyle'};
is noun(q{phyle})->singular,   q{phyle}  => q{singular: 'phyle' --> 'phyle'};
is noun(q{konditoreien})->singular, q{konditorei}  => q{singular: 'konditoreien' --> 'konditorei'};
is noun(q{planulae})->singular, q{planula}  => q{singular: 'planulae' --> 'planula'};
is noun(q{planula})->singular,   q{planula}  => q{singular: 'planula' --> 'planula'};
is noun(q{sigloi})->singular, q{siglos}  => q{singular: 'sigloi' --> 'siglos'};
is noun(q{siglos})->singular,   q{siglos}  => q{singular: 'siglos' --> 'siglos'};
is noun(q{hedra})->singular, q{hedron}  => q{singular: 'hedra' --> 'hedron'};
is noun(q{hedron})->singular,   q{hedron}  => q{singular: 'hedron' --> 'hedron'};
is noun(q{ancone})->singular, q{ancona}  => q{singular: 'ancone' --> 'ancona'};
is noun(q{ancona})->singular,   q{ancona}  => q{singular: 'ancona' --> 'ancona'};
is noun(q{fuzzes})->singular, q{fuzz}  => q{singular: 'fuzzes' --> 'fuzz'};
is noun(q{fuzz})->singular,   q{fuzz}  => q{singular: 'fuzz' --> 'fuzz'};
is noun(q{Congoese})->singular, q{Congoese}  => q{singular: 'Congoese' --> 'Congoese'};
is noun(q{sandrs})->singular, q{sandr}  => q{singular: 'sandrs' --> 'sandr'};
is noun(q{venae})->singular, q{vena}  => q{singular: 'venae' --> 'vena'};
is noun(q{vena})->singular,   q{vena}  => q{singular: 'vena' --> 'vena'};
is noun(q{canaliculi})->singular, q{canaliculus}  => q{singular: 'canaliculi' --> 'canaliculus'};
is noun(q{canaliculus})->singular,   q{canaliculus}  => q{singular: 'canaliculus' --> 'canaliculus'};
is noun(q{calamistra})->singular, q{calamistrum}  => q{singular: 'calamistra' --> 'calamistrum'};
is noun(q{calamistrum})->singular,   q{calamistrum}  => q{singular: 'calamistrum' --> 'calamistrum'};
is noun(q{status})->singular, q{status}  => q{singular: 'status' --> 'status'};
is noun(q{tubercula})->singular, q{tuberculum}  => q{singular: 'tubercula' --> 'tuberculum'};
is noun(q{tuberculum})->singular,   q{tuberculum}  => q{singular: 'tuberculum' --> 'tuberculum'};
is noun(q{choux})->singular, q{chou}  => q{singular: 'choux' --> 'chou'};
is noun(q{chou})->singular,   q{chou}  => q{singular: 'chou' --> 'chou'};
is noun(q{radii})->singular, q{radius}  => q{singular: 'radii' --> 'radius'};
is noun(q{radius})->singular,   q{radius}  => q{singular: 'radius' --> 'radius'};
is noun(q{trientes})->singular, q{triens}  => q{singular: 'trientes' --> 'triens'};
is noun(q{triens})->singular,   q{triens}  => q{singular: 'triens' --> 'triens'};
is noun(q{rhythmi})->singular, q{rhythmus}  => q{singular: 'rhythmi' --> 'rhythmus'};
is noun(q{rhythmus})->singular,   q{rhythmus}  => q{singular: 'rhythmus' --> 'rhythmus'};
is noun(q{prime ballerine})->singular, q{prima ballerina}  => q{singular: 'prime ballerine' --> 'prima ballerina'};
is noun(q{prima ballerina})->singular,   q{prima ballerina}  => q{singular: 'prima ballerina' --> 'prima ballerina'};
is noun(q{pueblos})->singular, q{pueblo}  => q{singular: 'pueblos' --> 'pueblo'};
is noun(q{pueblo})->singular,   q{pueblo}  => q{singular: 'pueblo' --> 'pueblo'};
is noun(q{jackanapes})->singular, q{jackanapes}  => q{singular: 'jackanapes' --> 'jackanapes'};
is noun(q{altos})->singular, q{alto}  => q{singular: 'altos' --> 'alto'};
is noun(q{alto})->singular,   q{alto}  => q{singular: 'alto' --> 'alto'};
is noun(q{Czechs})->singular, q{Czech}  => q{singular: 'Czechs' --> 'Czech'};
is noun(q{Czech})->singular,   q{Czech}  => q{singular: 'Czech' --> 'Czech'};
is noun(q{pilei})->singular, q{pileus}  => q{singular: 'pilei' --> 'pileus'};
is noun(q{pileus})->singular,   q{pileus}  => q{singular: 'pileus' --> 'pileus'};
is noun(q{zadruge})->singular, q{zadruga}  => q{singular: 'zadruge' --> 'zadruga'};
is noun(q{zadruga})->singular,   q{zadruga}  => q{singular: 'zadruga' --> 'zadruga'};
is noun(q{viruses})->singular, q{virus}  => q{singular: 'viruses' --> 'virus'};
is noun(q{virus})->singular,   q{virus}  => q{singular: 'virus' --> 'virus'};
is noun(q{scutula})->singular, q{scutulum}  => q{singular: 'scutula' --> 'scutulum'};
is noun(q{scutulum})->singular,   q{scutulum}  => q{singular: 'scutulum' --> 'scutulum'};
is noun(q{interregna})->singular, q{interregnum}  => q{singular: 'interregna' --> 'interregnum'};
is noun(q{interregnum})->singular,   q{interregnum}  => q{singular: 'interregnum' --> 'interregnum'};
is noun(q{pontifexes})->singular, q{pontifex}  => q{singular: 'pontifexes' --> 'pontifex'};
is noun(q{pontifex})->singular,   q{pontifex}  => q{singular: 'pontifex' --> 'pontifex'};
is noun(q{nidi})->singular, q{nidus}  => q{singular: 'nidi' --> 'nidus'};
is noun(q{nidus})->singular,   q{nidus}  => q{singular: 'nidus' --> 'nidus'};
is noun(q{modelletti})->singular, q{modelletto}  => q{singular: 'modelletti' --> 'modelletto'};
is noun(q{modelletto})->singular,   q{modelletto}  => q{singular: 'modelletto' --> 'modelletto'};
is noun(q{Gilbertese})->singular, q{Gilbertese}  => q{singular: 'Gilbertese' --> 'Gilbertese'};
is noun(q{responsa})->singular, q{responsum}  => q{singular: 'responsa' --> 'responsum'};
is noun(q{responsum})->singular,   q{responsum}  => q{singular: 'responsum' --> 'responsum'};
is noun(q{plateaux})->singular, q{plateau}  => q{singular: 'plateaux' --> 'plateau'};
is noun(q{plateau})->singular,   q{plateau}  => q{singular: 'plateau' --> 'plateau'};
is noun(q{quanta})->singular, q{quantum}  => q{singular: 'quanta' --> 'quantum'};
is noun(q{quantum})->singular,   q{quantum}  => q{singular: 'quantum' --> 'quantum'};
is noun(q{court martials})->singular, q{court martial}  => q{singular: 'court martials' --> 'court martial'};
is noun(q{court martial})->singular,   q{court martial}  => q{singular: 'court martial' --> 'court martial'};
is noun(q{Calabrese})->singular, q{Calabrese}  => q{singular: 'Calabrese' --> 'Calabrese'};
is noun(q{neutrinos})->singular, q{neutrino}  => q{singular: 'neutrinos' --> 'neutrino'};
is noun(q{neutrino})->singular,   q{neutrino}  => q{singular: 'neutrino' --> 'neutrino'};
is noun(q{folles})->singular, q{follis}  => q{singular: 'folles' --> 'follis'};
is noun(q{follis})->singular,   q{follis}  => q{singular: 'follis' --> 'follis'};
is noun(q{occipita})->singular, q{occiput}  => q{singular: 'occipita' --> 'occiput'};
is noun(q{occiput})->singular,   q{occiput}  => q{singular: 'occiput' --> 'occiput'};
is noun(q{sententiae})->singular, q{sententia}  => q{singular: 'sententiae' --> 'sententia'};
is noun(q{sententia})->singular,   q{sententia}  => q{singular: 'sententia' --> 'sententia'};
is noun(q{aficionados})->singular, q{aficionado}  => q{singular: 'aficionados' --> 'aficionado'};
is noun(q{aficionado})->singular,   q{aficionado}  => q{singular: 'aficionado' --> 'aficionado'};
is noun(q{phlegmasiae})->singular, q{phlegmasia}  => q{singular: 'phlegmasiae' --> 'phlegmasia'};
is noun(q{phlegmasia})->singular,   q{phlegmasia}  => q{singular: 'phlegmasia' --> 'phlegmasia'};
is noun(q{trichomata})->singular, q{trichoma}  => q{singular: 'trichomata' --> 'trichoma'};
is noun(q{trichoma})->singular,   q{trichoma}  => q{singular: 'trichoma' --> 'trichoma'};
is noun(q{alto relievos})->singular, q{alto relievo}  => q{singular: 'alto relievos' --> 'alto relievo'};
is noun(q{alto relievo})->singular,   q{alto relievo}  => q{singular: 'alto relievo' --> 'alto relievo'};
is noun(q{ranunculuses})->singular, q{ranunculus}  => q{singular: 'ranunculuses' --> 'ranunculus'};
is noun(q{ranunculus})->singular,   q{ranunculus}  => q{singular: 'ranunculus' --> 'ranunculus'};
is noun(q{Yakimans})->singular, q{Yakiman}  => q{singular: 'Yakimans' --> 'Yakiman'};
is noun(q{Yakiman})->singular,   q{Yakiman}  => q{singular: 'Yakiman' --> 'Yakiman'};
is noun(q{news})->singular, q{news}  => q{singular: 'news' --> 'news'};
is noun(q{rilievos})->singular, q{rilievo}  => q{singular: 'rilievos' --> 'rilievo'};
is noun(q{rilievo})->singular,   q{rilievo}  => q{singular: 'rilievo' --> 'rilievo'};
is noun(q{listerellae})->singular, q{listerella}  => q{singular: 'listerellae' --> 'listerella'};
is noun(q{listerella})->singular,   q{listerella}  => q{singular: 'listerella' --> 'listerella'};
is noun(q{cargadores})->singular, q{cargador}  => q{singular: 'cargadores' --> 'cargador'};
is noun(q{cargador})->singular,   q{cargador}  => q{singular: 'cargador' --> 'cargador'};
is noun(q{vela})->singular, q{velum}  => q{singular: 'vela' --> 'velum'};
is noun(q{velum})->singular,   q{velum}  => q{singular: 'velum' --> 'velum'};
is noun(q{thrasoes})->singular, q{thraso}  => q{singular: 'thrasoes' --> 'thraso'};
is noun(q{thraso})->singular,   q{thraso}  => q{singular: 'thraso' --> 'thraso'};
is noun(q{paradores})->singular, q{parador}  => q{singular: 'paradores' --> 'parador'};
is noun(q{parador})->singular,   q{parador}  => q{singular: 'parador' --> 'parador'};
is noun(q{polos})->singular, q{polo}  => q{singular: 'polos' --> 'polo'};
is noun(q{polo})->singular,   q{polo}  => q{singular: 'polo' --> 'polo'};
is noun(q{succubuses})->singular, q{succubus}  => q{singular: 'succubuses' --> 'succubus'};
is noun(q{succubus})->singular,   q{succubus}  => q{singular: 'succubus' --> 'succubus'};
is noun(q{panorpae})->singular, q{panorpa}  => q{singular: 'panorpae' --> 'panorpa'};
is noun(q{panorpa})->singular,   q{panorpa}  => q{singular: 'panorpa' --> 'panorpa'};
is noun(q{set-tos})->singular, q{set-to}  => q{singular: 'set-tos' --> 'set-to'};
is noun(q{set-to})->singular,   q{set-to}  => q{singular: 'set-to' --> 'set-to'};
is noun(q{breaks-away})->singular, q{break-away}  => q{singular: 'breaks-away' --> 'break-away'};
is noun(q{break-away})->singular,   q{break-away}  => q{singular: 'break-away' --> 'break-away'};
is noun(q{canthari})->singular, q{cantharus}  => q{singular: 'canthari' --> 'cantharus'};
is noun(q{cantharus})->singular,   q{cantharus}  => q{singular: 'cantharus' --> 'cantharus'};
is noun(q{politbureaux})->singular, q{politbureau}  => q{singular: 'politbureaux' --> 'politbureau'};
is noun(q{politbureau})->singular,   q{politbureau}  => q{singular: 'politbureau' --> 'politbureau'};
is noun(q{raggares})->singular, q{raggare}  => q{singular: 'raggares' --> 'raggare'};
is noun(q{velamina})->singular, q{velamen}  => q{singular: 'velamina' --> 'velamen'};
is noun(q{velamen})->singular,   q{velamen}  => q{singular: 'velamen' --> 'velamen'};
is noun(q{Havanese})->singular, q{Havanese}  => q{singular: 'Havanese' --> 'Havanese'};
is noun(q{clitorides})->singular, q{clitoris}  => q{singular: 'clitorides' --> 'clitoris'};
is noun(q{clitoris})->singular,   q{clitoris}  => q{singular: 'clitoris' --> 'clitoris'};
is noun(q{Nicobarese})->singular, q{Nicobarese}  => q{singular: 'Nicobarese' --> 'Nicobarese'};
is noun(q{pollices})->singular, q{pollex}  => q{singular: 'pollices' --> 'pollex'};
is noun(q{pollex})->singular,   q{pollex}  => q{singular: 'pollex' --> 'pollex'};
is noun(q{puirt-a-beul})->singular, q{port-a-beul}  => q{singular: 'puirt-a-beul' --> 'port-a-beul'};
is noun(q{port-a-beul})->singular,   q{port-a-beul}  => q{singular: 'port-a-beul' --> 'port-a-beul'};
is noun(q{parenchymata})->singular, q{parenchyma}  => q{singular: 'parenchymata' --> 'parenchyma'};
is noun(q{parenchyma})->singular,   q{parenchyma}  => q{singular: 'parenchyma' --> 'parenchyma'};
is noun(q{oratrices})->singular, q{oratrix}  => q{singular: 'oratrices' --> 'oratrix'};
is noun(q{oratrix})->singular,   q{oratrix}  => q{singular: 'oratrix' --> 'oratrix'};
is noun(q{syntaxes})->singular, q{syntaxis}  => q{singular: 'syntaxes' --> 'syntaxis'};
is noun(q{syntaxis})->singular,   q{syntaxis}  => q{singular: 'syntaxis' --> 'syntaxis'};
is noun(q{snekkjur})->singular, q{snekkja}  => q{singular: 'snekkjur' --> 'snekkja'};
is noun(q{snekkja})->singular,   q{snekkja}  => q{singular: 'snekkja' --> 'snekkja'};
is noun(q{shawabtiu})->singular, q{shawabti}  => q{singular: 'shawabtiu' --> 'shawabti'};
is noun(q{shawabti})->singular,   q{shawabti}  => q{singular: 'shawabti' --> 'shawabti'};
is noun(q{faunas})->singular, q{fauna}  => q{singular: 'faunas' --> 'fauna'};
is noun(q{fauna})->singular,   q{fauna}  => q{singular: 'fauna' --> 'fauna'};
is noun(q{set offs})->singular, q{set off}  => q{singular: 'set offs' --> 'set off'};
is noun(q{set off})->singular,   q{set off}  => q{singular: 'set off' --> 'set off'};
is noun(q{nymphaea})->singular, q{nymphaeum}  => q{singular: 'nymphaea' --> 'nymphaeum'};
is noun(q{nymphaeum})->singular,   q{nymphaeum}  => q{singular: 'nymphaeum' --> 'nymphaeum'};
is noun(q{sacculi})->singular, q{sacculus}  => q{singular: 'sacculi' --> 'sacculus'};
is noun(q{sacculus})->singular,   q{sacculus}  => q{singular: 'sacculus' --> 'sacculus'};
is noun(q{ryper})->singular, q{rype}  => q{singular: 'ryper' --> 'rype'};
is noun(q{rype})->singular,   q{rype}  => q{singular: 'rype' --> 'rype'};
is noun(q{filariae})->singular, q{filaria}  => q{singular: 'filariae' --> 'filaria'};
is noun(q{filaria})->singular,   q{filaria}  => q{singular: 'filaria' --> 'filaria'};
is noun(q{ausleses})->singular, q{auslese}  => q{singular: 'ausleses' --> 'auslese'};
is noun(q{auslese})->singular,   q{auslese}  => q{singular: 'auslese' --> 'auslese'};
is noun(q{parisa})->singular, q{parison}  => q{singular: 'parisa' --> 'parison'};
is noun(q{parison})->singular,   q{parison}  => q{singular: 'parison' --> 'parison'};
is noun(q{Johnsonese})->singular, q{Johnsonese}  => q{singular: 'Johnsonese' --> 'Johnsonese'};
is noun(q{Navarrese})->singular, q{Navarrese}  => q{singular: 'Navarrese' --> 'Navarrese'};
is noun(q{Parmese})->singular, q{Parmese}  => q{singular: 'Parmese' --> 'Parmese'};
is noun(q{lactobacilli})->singular, q{lactobacillus}  => q{singular: 'lactobacilli' --> 'lactobacillus'};
is noun(q{lactobacillus})->singular,   q{lactobacillus}  => q{singular: 'lactobacillus' --> 'lactobacillus'};
is noun(q{hemelytra})->singular, q{hemelytrum}  => q{singular: 'hemelytra' --> 'hemelytrum'};
is noun(q{hemelytrum})->singular,   q{hemelytrum}  => q{singular: 'hemelytrum' --> 'hemelytrum'};
is noun(q{terebella})->singular, q{terebellum}  => q{singular: 'terebella' --> 'terebellum'};
is noun(q{terebellum})->singular,   q{terebellum}  => q{singular: 'terebellum' --> 'terebellum'};
is noun(q{Biros})->singular, q{Biro}  => q{singular: 'Biros' --> 'Biro'};
is noun(q{Biro})->singular,   q{Biro}  => q{singular: 'Biro' --> 'Biro'};
is noun(q{tripla})->singular, q{triplum}  => q{singular: 'tripla' --> 'triplum'};
is noun(q{triplum})->singular,   q{triplum}  => q{singular: 'triplum' --> 'triplum'};
is noun(q{musae})->singular, q{musa}  => q{singular: 'musae' --> 'musa'};
is noun(q{musa})->singular,   q{musa}  => q{singular: 'musa' --> 'musa'};
is noun(q{porticoes})->singular, q{portico}  => q{singular: 'porticoes' --> 'portico'};
is noun(q{portico})->singular,   q{portico}  => q{singular: 'portico' --> 'portico'};
is noun(q{major generals})->singular, q{major general}  => q{singular: 'major generals' --> 'major general'};
is noun(q{major general})->singular,   q{major general}  => q{singular: 'major general' --> 'major general'};
is noun(q{funguses})->singular, q{fungus}  => q{singular: 'funguses' --> 'fungus'};
is noun(q{fungus})->singular,   q{fungus}  => q{singular: 'fungus' --> 'fungus'};
is noun(q{stephanions})->singular, q{stephanion}  => q{singular: 'stephanions' --> 'stephanion'};
is noun(q{stephanion})->singular,   q{stephanion}  => q{singular: 'stephanion' --> 'stephanion'};
is noun(q{semunciae})->singular, q{semuncia}  => q{singular: 'semunciae' --> 'semuncia'};
is noun(q{semuncia})->singular,   q{semuncia}  => q{singular: 'semuncia' --> 'semuncia'};
is noun(q{scolopidia})->singular, q{scolopidium}  => q{singular: 'scolopidia' --> 'scolopidium'};
is noun(q{scolopidium})->singular,   q{scolopidium}  => q{singular: 'scolopidium' --> 'scolopidium'};
is noun(q{Sarajevos})->singular, q{Sarajevo}  => q{singular: 'Sarajevos' --> 'Sarajevo'};
is noun(q{Sarajevo})->singular,   q{Sarajevo}  => q{singular: 'Sarajevo' --> 'Sarajevo'};
is noun(q{tropaeola})->singular, q{tropaeolum}  => q{singular: 'tropaeola' --> 'tropaeolum'};
is noun(q{tropaeolum})->singular,   q{tropaeolum}  => q{singular: 'tropaeolum' --> 'tropaeolum'};
is noun(q{what})->singular, q{what}  => q{singular: 'what' --> 'what'};
is noun(q{lentisci})->singular, q{lentiscus}  => q{singular: 'lentisci' --> 'lentiscus'};
is noun(q{lentiscus})->singular,   q{lentiscus}  => q{singular: 'lentiscus' --> 'lentiscus'};
is noun(q{stirpes})->singular, q{stirps}  => q{singular: 'stirpes' --> 'stirps'};
is noun(q{stirps})->singular,   q{stirps}  => q{singular: 'stirps' --> 'stirps'};
is noun(q{tondi})->singular, q{tondo}  => q{singular: 'tondi' --> 'tondo'};
is noun(q{tondo})->singular,   q{tondo}  => q{singular: 'tondo' --> 'tondo'};
is noun(q{maecenates})->singular, q{maecenas}  => q{singular: 'maecenates' --> 'maecenas'};
is noun(q{maecenas})->singular,   q{maecenas}  => q{singular: 'maecenas' --> 'maecenas'};
is noun(q{subbotniki})->singular, q{subbotnik}  => q{singular: 'subbotniki' --> 'subbotnik'};
is noun(q{subbotnik})->singular,   q{subbotnik}  => q{singular: 'subbotnik' --> 'subbotnik'};
is noun(q{syllabi})->singular, q{syllabus}  => q{singular: 'syllabi' --> 'syllabus'};
is noun(q{syllabus})->singular,   q{syllabus}  => q{singular: 'syllabus' --> 'syllabus'};
is noun(q{chromidia})->singular, q{chromidium}  => q{singular: 'chromidia' --> 'chromidium'};
is noun(q{chromidium})->singular,   q{chromidium}  => q{singular: 'chromidium' --> 'chromidium'};
is noun(q{stornelli})->singular, q{stornello}  => q{singular: 'stornelli' --> 'stornello'};
is noun(q{stornello})->singular,   q{stornello}  => q{singular: 'stornello' --> 'stornello'};
is noun(q{manteaus})->singular, q{manteau}  => q{singular: 'manteaus' --> 'manteau'};
is noun(q{manteau})->singular,   q{manteau}  => q{singular: 'manteau' --> 'manteau'};
is noun(q{guanos})->singular, q{guano}  => q{singular: 'guanos' --> 'guano'};
is noun(q{guano})->singular,   q{guano}  => q{singular: 'guano' --> 'guano'};
is noun(q{hoties})->singular, q{hoti}  => q{singular: 'hoties' --> 'hoti'};
is noun(q{hoti})->singular,   q{hoti}  => q{singular: 'hoti' --> 'hoti'};
is noun(q{guglioes})->singular, q{guglio}  => q{singular: 'guglioes' --> 'guglio'};
is noun(q{guglio})->singular,   q{guglio}  => q{singular: 'guglio' --> 'guglio'};
is noun(q{herniae})->singular, q{hernia}  => q{singular: 'herniae' --> 'hernia'};
is noun(q{hernia})->singular,   q{hernia}  => q{singular: 'hernia' --> 'hernia'};
is noun(q{contangos})->singular, q{contango}  => q{singular: 'contangos' --> 'contango'};
is noun(q{contango})->singular,   q{contango}  => q{singular: 'contango' --> 'contango'};
is noun(q{costae})->singular, q{costa}  => q{singular: 'costae' --> 'costa'};
is noun(q{costa})->singular,   q{costa}  => q{singular: 'costa' --> 'costa'};
is noun(q{umbos})->singular, q{umbo}  => q{singular: 'umbos' --> 'umbo'};
is noun(q{umbo})->singular,   q{umbo}  => q{singular: 'umbo' --> 'umbo'};
is noun(q{musiques concretes})->singular, q{musique concrete}  => q{singular: 'musiques concretes' --> 'musique concrete'};
is noun(q{musique concrete})->singular,   q{musique concrete}  => q{singular: 'musique concrete' --> 'musique concrete'};
is noun(q{guglios})->singular, q{guglio}  => q{singular: 'guglios' --> 'guglio'};
is noun(q{guglio})->singular,   q{guglio}  => q{singular: 'guglio' --> 'guglio'};
is noun(q{phalanges})->singular, q{phalanx}  => q{singular: 'phalanges' --> 'phalanx'};
is noun(q{phalanx})->singular,   q{phalanx}  => q{singular: 'phalanx' --> 'phalanx'};
is noun(q{diverticula})->singular, q{diverticulum}  => q{singular: 'diverticula' --> 'diverticulum'};
is noun(q{diverticulum})->singular,   q{diverticulum}  => q{singular: 'diverticulum' --> 'diverticulum'};
is noun(q{atlases})->singular, q{atlas}  => q{singular: 'atlases' --> 'atlas'};
is noun(q{atlas})->singular,   q{atlas}  => q{singular: 'atlas' --> 'atlas'};
is noun(q{meshummadim})->singular, q{meshummad}  => q{singular: 'meshummadim' --> 'meshummad'};
is noun(q{meshummad})->singular,   q{meshummad}  => q{singular: 'meshummad' --> 'meshummad'};
is noun(q{logodaedali})->singular, q{logodaedalus}  => q{singular: 'logodaedali' --> 'logodaedalus'};
is noun(q{logodaedalus})->singular,   q{logodaedalus}  => q{singular: 'logodaedalus' --> 'logodaedalus'};
is noun(q{fizzes})->singular, q{fizz}  => q{singular: 'fizzes' --> 'fizz'};
is noun(q{fizz})->singular,   q{fizz}  => q{singular: 'fizz' --> 'fizz'};
is noun(q{tsubas})->singular, q{tsuba}  => q{singular: 'tsubas' --> 'tsuba'};
is noun(q{men-milliners})->singular, q{man-milliner}  => q{singular: 'men-milliners' --> 'man-milliner'};
is noun(q{man-milliner})->singular,   q{man-milliner}  => q{singular: 'man-milliner' --> 'man-milliner'};
is noun(q{monosyllaba})->singular, q{monosyllabon}  => q{singular: 'monosyllaba' --> 'monosyllabon'};
is noun(q{monosyllabon})->singular,   q{monosyllabon}  => q{singular: 'monosyllabon' --> 'monosyllabon'};
is noun(q{mackerels})->singular, q{mackerel}  => q{singular: 'mackerels' --> 'mackerel'};
is noun(q{Greensboros})->singular, q{Greensboro}  => q{singular: 'Greensboros' --> 'Greensboro'};
is noun(q{Greensboro})->singular,   q{Greensboro}  => q{singular: 'Greensboro' --> 'Greensboro'};
is noun(q{sericteria})->singular, q{sericterium}  => q{singular: 'sericteria' --> 'sericterium'};
is noun(q{sericterium})->singular,   q{sericterium}  => q{singular: 'sericterium' --> 'sericterium'};
is noun(q{mousetraps})->singular, q{mousetrap}  => q{singular: 'mousetraps' --> 'mousetrap'};
is noun(q{mousetrap})->singular,   q{mousetrap}  => q{singular: 'mousetrap' --> 'mousetrap'};
is noun(q{stylopodia})->singular, q{stylopodium}  => q{singular: 'stylopodia' --> 'stylopodium'};
is noun(q{stylopodium})->singular,   q{stylopodium}  => q{singular: 'stylopodium' --> 'stylopodium'};
is noun(q{interstitia})->singular, q{interstitium}  => q{singular: 'interstitia' --> 'interstitium'};
is noun(q{interstitium})->singular,   q{interstitium}  => q{singular: 'interstitium' --> 'interstitium'};
is noun(q{eyases})->singular, q{eyas}  => q{singular: 'eyases' --> 'eyas'};
is noun(q{eyas})->singular,   q{eyas}  => q{singular: 'eyas' --> 'eyas'};
is noun(q{micrococci})->singular, q{micrococcus}  => q{singular: 'micrococci' --> 'micrococcus'};
is noun(q{micrococcus})->singular,   q{micrococcus}  => q{singular: 'micrococcus' --> 'micrococcus'};
is noun(q{minnelieder})->singular, q{minnelied}  => q{singular: 'minnelieder' --> 'minnelied'};
is noun(q{minnelied})->singular,   q{minnelied}  => q{singular: 'minnelied' --> 'minnelied'};
is noun(q{sum-totals})->singular, q{sum-total}  => q{singular: 'sum-totals' --> 'sum-total'};
is noun(q{sum-total})->singular,   q{sum-total}  => q{singular: 'sum-total' --> 'sum-total'};
is noun(q{extispices})->singular, q{extispex}  => q{singular: 'extispices' --> 'extispex'};
is noun(q{extispex})->singular,   q{extispex}  => q{singular: 'extispex' --> 'extispex'};
is noun(q{tombaroli})->singular, q{tombarolo}  => q{singular: 'tombaroli' --> 'tombarolo'};
is noun(q{tombarolo})->singular,   q{tombarolo}  => q{singular: 'tombarolo' --> 'tombarolo'};
is noun(q{mesothelia})->singular, q{mesothelium}  => q{singular: 'mesothelia' --> 'mesothelium'};
is noun(q{mesothelium})->singular,   q{mesothelium}  => q{singular: 'mesothelium' --> 'mesothelium'};
is noun(q{zoeae})->singular, q{zoea}  => q{singular: 'zoeae' --> 'zoea'};
is noun(q{zoea})->singular,   q{zoea}  => q{singular: 'zoea' --> 'zoea'};
is noun(q{corpora vilia})->singular, q{corpus vile}  => q{singular: 'corpora vilia' --> 'corpus vile'};
is noun(q{corpus vile})->singular,   q{corpus vile}  => q{singular: 'corpus vile' --> 'corpus vile'};
is noun(q{branchiopods})->singular, q{branchiopod}  => q{singular: 'branchiopods' --> 'branchiopod'};
is noun(q{branchiopod})->singular,   q{branchiopod}  => q{singular: 'branchiopod' --> 'branchiopod'};
is noun(q{sassafrases})->singular, q{sassafras}  => q{singular: 'sassafrases' --> 'sassafras'};
is noun(q{sassafras})->singular,   q{sassafras}  => q{singular: 'sassafras' --> 'sassafras'};
is noun(q{gymnoti})->singular, q{gymnotus}  => q{singular: 'gymnoti' --> 'gymnotus'};
is noun(q{gymnotus})->singular,   q{gymnotus}  => q{singular: 'gymnotus' --> 'gymnotus'};
is noun(q{elk})->singular, q{elk}  => q{singular: 'elk' --> 'elk'};
is noun(q{nimbi})->singular, q{nimbus}  => q{singular: 'nimbi' --> 'nimbus'};
is noun(q{nimbus})->singular,   q{nimbus}  => q{singular: 'nimbus' --> 'nimbus'};
is noun(q{commanding generals})->singular, q{commanding general}  => q{singular: 'commanding generals' --> 'commanding general'};
is noun(q{commanding general})->singular,   q{commanding general}  => q{singular: 'commanding general' --> 'commanding general'};
is noun(q{caffe macchiati})->singular, q{caffe macchiato}  => q{singular: 'caffe macchiati' --> 'caffe macchiato'};
is noun(q{caffe macchiato})->singular,   q{caffe macchiato}  => q{singular: 'caffe macchiato' --> 'caffe macchiato'};
is noun(q{fabellae})->singular, q{fabella}  => q{singular: 'fabellae' --> 'fabella'};
is noun(q{fabella})->singular,   q{fabella}  => q{singular: 'fabella' --> 'fabella'};
is noun(q{clausulae})->singular, q{clausula}  => q{singular: 'clausulae' --> 'clausula'};
is noun(q{clausula})->singular,   q{clausula}  => q{singular: 'clausula' --> 'clausula'};
is noun(q{parvenus})->singular, q{parvenu}  => q{singular: 'parvenus' --> 'parvenu'};
is noun(q{parvenu})->singular,   q{parvenu}  => q{singular: 'parvenu' --> 'parvenu'};
is noun(q{whose})->singular, q{whose}  => q{singular: 'whose' --> 'whose'};
is noun(q{poise})->singular, q{poise}  => q{singular: 'poise' --> 'poise'};
is noun(q{francs archers})->singular, q{franc archer}  => q{singular: 'francs archers' --> 'franc archer'};
is noun(q{franc archer})->singular,   q{franc archer}  => q{singular: 'franc archer' --> 'franc archer'};
is noun(q{dogmata})->singular, q{dogma}  => q{singular: 'dogmata' --> 'dogma'};
is noun(q{dogma})->singular,   q{dogma}  => q{singular: 'dogma' --> 'dogma'};
is noun(q{secundiparae})->singular, q{secundipara}  => q{singular: 'secundiparae' --> 'secundipara'};
is noun(q{secundipara})->singular,   q{secundipara}  => q{singular: 'secundipara' --> 'secundipara'};
is noun(q{perniones})->singular, q{pernio}  => q{singular: 'perniones' --> 'pernio'};
is noun(q{pernio})->singular,   q{pernio}  => q{singular: 'pernio' --> 'pernio'};
is noun(q{mycorhizas})->singular, q{mycorhiza}  => q{singular: 'mycorhizas' --> 'mycorhiza'};
is noun(q{mycorhiza})->singular,   q{mycorhiza}  => q{singular: 'mycorhiza' --> 'mycorhiza'};
is noun(q{lemmas})->singular, q{lemma}  => q{singular: 'lemmas' --> 'lemma'};
is noun(q{lemma})->singular,   q{lemma}  => q{singular: 'lemma' --> 'lemma'};
is noun(q{planctus})->singular, q{planctus}  => q{singular: 'planctus' --> 'planctus'};
is noun(q{felos de se})->singular, q{felo de se}  => q{singular: 'felos de se' --> 'felo de se'};
is noun(q{felo de se})->singular,   q{felo de se}  => q{singular: 'felo de se' --> 'felo de se'};
is noun(q{vermiculi})->singular, q{vermiculus}  => q{singular: 'vermiculi' --> 'vermiculus'};
is noun(q{vermiculus})->singular,   q{vermiculus}  => q{singular: 'vermiculus' --> 'vermiculus'};
is noun(q{fibromata})->singular, q{fibroma}  => q{singular: 'fibromata' --> 'fibroma'};
is noun(q{fibroma})->singular,   q{fibroma}  => q{singular: 'fibroma' --> 'fibroma'};
is noun(q{mitochondria})->singular, q{mitochondrion}  => q{singular: 'mitochondria' --> 'mitochondrion'};
is noun(q{mitochondrion})->singular,   q{mitochondrion}  => q{singular: 'mitochondrion' --> 'mitochondrion'};
is noun(q{ephemerises})->singular, q{ephemeris}  => q{singular: 'ephemerises' --> 'ephemeris'};
is noun(q{ephemeris})->singular,   q{ephemeris}  => q{singular: 'ephemeris' --> 'ephemeris'};
is noun(q{knoppern})->singular, q{knopper}  => q{singular: 'knoppern' --> 'knopper'};
is noun(q{knopper})->singular,   q{knopper}  => q{singular: 'knopper' --> 'knopper'};
is noun(q{toruli})->singular, q{torulus}  => q{singular: 'toruli' --> 'torulus'};
is noun(q{torulus})->singular,   q{torulus}  => q{singular: 'torulus' --> 'torulus'};
is noun(q{tortrices})->singular, q{tortrix}  => q{singular: 'tortrices' --> 'tortrix'};
is noun(q{tortrix})->singular,   q{tortrix}  => q{singular: 'tortrix' --> 'tortrix'};
is noun(q{ri})->singular, q{ri}  => q{singular: 'ri' --> 'ri'};
is noun(q{monoxyla})->singular, q{monoxylon}  => q{singular: 'monoxyla' --> 'monoxylon'};
is noun(q{monoxylon})->singular,   q{monoxylon}  => q{singular: 'monoxylon' --> 'monoxylon'};
is noun(q{palpi})->singular, q{palpus}  => q{singular: 'palpi' --> 'palpus'};
is noun(q{palpus})->singular,   q{palpus}  => q{singular: 'palpus' --> 'palpus'};
is noun(q{sequestra})->singular, q{sequestrum}  => q{singular: 'sequestra' --> 'sequestrum'};
is noun(q{sequestrum})->singular,   q{sequestrum}  => q{singular: 'sequestrum' --> 'sequestrum'};
is noun(q{apices})->singular, q{apex}  => q{singular: 'apices' --> 'apex'};
is noun(q{apex})->singular,   q{apex}  => q{singular: 'apex' --> 'apex'};
is noun(q{ballerine})->singular, q{ballerina}  => q{singular: 'ballerine' --> 'ballerina'};
is noun(q{ballerina})->singular,   q{ballerina}  => q{singular: 'ballerina' --> 'ballerina'};
is noun(q{fascias})->singular, q{fascia}  => q{singular: 'fascias' --> 'fascia'};
is noun(q{fascia})->singular,   q{fascia}  => q{singular: 'fascia' --> 'fascia'};
is noun(q{zizzes})->singular, q{zizz}  => q{singular: 'zizzes' --> 'zizz'};
is noun(q{zizz})->singular,   q{zizz}  => q{singular: 'zizz' --> 'zizz'};
is noun(q{zoaeae})->singular, q{zoaea}  => q{singular: 'zoaeae' --> 'zoaea'};
is noun(q{zoaea})->singular,   q{zoaea}  => q{singular: 'zoaea' --> 'zoaea'};
is noun(q{xanthomata})->singular, q{xanthoma}  => q{singular: 'xanthomata' --> 'xanthoma'};
is noun(q{xanthoma})->singular,   q{xanthoma}  => q{singular: 'xanthoma' --> 'xanthoma'};
is noun(q{umbilici})->singular, q{umbilicus}  => q{singular: 'umbilici' --> 'umbilicus'};
is noun(q{umbilicus})->singular,   q{umbilicus}  => q{singular: 'umbilicus' --> 'umbilicus'};
is noun(q{manifestos})->singular, q{manifesto}  => q{singular: 'manifestos' --> 'manifesto'};
is noun(q{manifesto})->singular,   q{manifesto}  => q{singular: 'manifesto' --> 'manifesto'};
is noun(q{Ceylonese})->singular, q{Ceylonese}  => q{singular: 'Ceylonese' --> 'Ceylonese'};
is noun(q{reiche})->singular, q{reich}  => q{singular: 'reiche' --> 'reich'};
is noun(q{reich})->singular,   q{reich}  => q{singular: 'reich' --> 'reich'};
is noun(q{prodromi})->singular, q{prodromus}  => q{singular: 'prodromi' --> 'prodromus'};
is noun(q{prodromus})->singular,   q{prodromus}  => q{singular: 'prodromus' --> 'prodromus'};
is noun(q{surimonos})->singular, q{surimono}  => q{singular: 'surimonos' --> 'surimono'};
is noun(q{surimono})->singular,   q{surimono}  => q{singular: 'surimono' --> 'surimono'};
is noun(q{maare})->singular, q{maar}  => q{singular: 'maare' --> 'maar'};
is noun(q{maar})->singular,   q{maar}  => q{singular: 'maar' --> 'maar'};
is noun(q{mice})->singular, q{mouse}  => q{singular: 'mice' --> 'mouse'};
is noun(q{mouse})->singular,   q{mouse}  => q{singular: 'mouse' --> 'mouse'};
is noun(q{liberos})->singular, q{libero}  => q{singular: 'liberos' --> 'libero'};
is noun(q{libero})->singular,   q{libero}  => q{singular: 'libero' --> 'libero'};
is noun(q{strigae})->singular, q{striga}  => q{singular: 'strigae' --> 'striga'};
is noun(q{striga})->singular,   q{striga}  => q{singular: 'striga' --> 'striga'};
is noun(q{tuberculomas})->singular, q{tuberculoma}  => q{singular: 'tuberculomas' --> 'tuberculoma'};
is noun(q{tuberculoma})->singular,   q{tuberculoma}  => q{singular: 'tuberculoma' --> 'tuberculoma'};
is noun(q{taeniae})->singular, q{taenia}  => q{singular: 'taeniae' --> 'taenia'};
is noun(q{taenia})->singular,   q{taenia}  => q{singular: 'taenia' --> 'taenia'};
is noun(q{culs-de-lampe})->singular, q{cul-de-lampe}  => q{singular: 'culs-de-lampe' --> 'cul-de-lampe'};
is noun(q{cul-de-lampe})->singular,   q{cul-de-lampe}  => q{singular: 'cul-de-lampe' --> 'cul-de-lampe'};
is noun(q{pinnae})->singular, q{pinna}  => q{singular: 'pinnae' --> 'pinna'};
is noun(q{pinna})->singular,   q{pinna}  => q{singular: 'pinna' --> 'pinna'};
is noun(q{peltae})->singular, q{pelta}  => q{singular: 'peltae' --> 'pelta'};
is noun(q{pelta})->singular,   q{pelta}  => q{singular: 'pelta' --> 'pelta'};
is noun(q{rami})->singular, q{ramus}  => q{singular: 'rami' --> 'ramus'};
is noun(q{ramus})->singular,   q{ramus}  => q{singular: 'ramus' --> 'ramus'};
is noun(q{pants})->singular, q{pant}  => q{singular: 'pants' --> 'pant'};
is noun(q{pant})->singular,   q{pant}  => q{singular: 'pant' --> 'pant'};
is noun(q{virtuosi})->singular, q{virtuoso}  => q{singular: 'virtuosi' --> 'virtuoso'};
is noun(q{virtuoso})->singular,   q{virtuoso}  => q{singular: 'virtuoso' --> 'virtuoso'};
is noun(q{oscula})->singular, q{osculum}  => q{singular: 'oscula' --> 'osculum'};
is noun(q{osculum})->singular,   q{osculum}  => q{singular: 'osculum' --> 'osculum'};
is noun(q{colonel generals})->singular, q{colonel general}  => q{singular: 'colonel generals' --> 'colonel general'};
is noun(q{colonel general})->singular,   q{colonel general}  => q{singular: 'colonel general' --> 'colonel general'};
is noun(q{vitellaria})->singular, q{vitellarium}  => q{singular: 'vitellaria' --> 'vitellarium'};
is noun(q{vitellarium})->singular,   q{vitellarium}  => q{singular: 'vitellarium' --> 'vitellarium'};
is noun(q{trabeae})->singular, q{trabea}  => q{singular: 'trabeae' --> 'trabea'};
is noun(q{trabea})->singular,   q{trabea}  => q{singular: 'trabea' --> 'trabea'};
is noun(q{Pangasinanes})->singular, q{Pangasinan}  => q{singular: 'Pangasinanes' --> 'Pangasinan'};
is noun(q{Pangasinan})->singular,   q{Pangasinan}  => q{singular: 'Pangasinan' --> 'Pangasinan'};
is noun(q{stigmas})->singular, q{stigma}  => q{singular: 'stigmas' --> 'stigma'};
is noun(q{stigma})->singular,   q{stigma}  => q{singular: 'stigma' --> 'stigma'};
is noun(q{amenta})->singular, q{amentum}  => q{singular: 'amenta' --> 'amentum'};
is noun(q{amentum})->singular,   q{amentum}  => q{singular: 'amentum' --> 'amentum'};
is noun(q{sotchs})->singular, q{sotch}  => q{singular: 'sotchs' --> 'sotch'};
is noun(q{sotch})->singular,   q{sotch}  => q{singular: 'sotch' --> 'sotch'};
is noun(q{penes})->singular, q{penis}  => q{singular: 'penes' --> 'penis'};
is noun(q{penis})->singular,   q{penis}  => q{singular: 'penis' --> 'penis'};
is noun(q{dreikanters})->singular, q{dreikanter}  => q{singular: 'dreikanters' --> 'dreikanter'};
is noun(q{paleae})->singular, q{palea}  => q{singular: 'paleae' --> 'palea'};
is noun(q{palea})->singular,   q{palea}  => q{singular: 'palea' --> 'palea'};
is noun(q{graffiti})->singular, q{graffiti}  => q{singular: 'graffiti' --> 'graffiti'};
is noun(q{rimonim})->singular, q{rimon}  => q{singular: 'rimonim' --> 'rimon'};
is noun(q{rimon})->singular,   q{rimon}  => q{singular: 'rimon' --> 'rimon'};
is noun(q{pingoes})->singular, q{pingo}  => q{singular: 'pingoes' --> 'pingo'};
is noun(q{pingo})->singular,   q{pingo}  => q{singular: 'pingo' --> 'pingo'};
is noun(q{pyritae})->singular, q{pyrites}  => q{singular: 'pyritae' --> 'pyrites'};
is noun(q{pyrites})->singular,   q{pyrites}  => q{singular: 'pyrites' --> 'pyrites'};
is noun(q{valvulae})->singular, q{valvula}  => q{singular: 'valvulae' --> 'valvula'};
is noun(q{valvula})->singular,   q{valvula}  => q{singular: 'valvula' --> 'valvula'};
is noun(q{pollinia})->singular, q{pollinium}  => q{singular: 'pollinia' --> 'pollinium'};
is noun(q{pollinium})->singular,   q{pollinium}  => q{singular: 'pollinium' --> 'pollinium'};
is noun(q{staphylococci})->singular, q{staphylococcus}  => q{singular: 'staphylococci' --> 'staphylococcus'};
is noun(q{staphylococcus})->singular,   q{staphylococcus}  => q{singular: 'staphylococcus' --> 'staphylococcus'};
is noun(q{schemas})->singular, q{schema}  => q{singular: 'schemas' --> 'schema'};
is noun(q{schema})->singular,   q{schema}  => q{singular: 'schema' --> 'schema'};
is noun(q{amphorae})->singular, q{amphora}  => q{singular: 'amphorae' --> 'amphora'};
is noun(q{amphora})->singular,   q{amphora}  => q{singular: 'amphora' --> 'amphora'};
is noun(q{isthmi})->singular, q{isthmus}  => q{singular: 'isthmi' --> 'isthmus'};
is noun(q{isthmus})->singular,   q{isthmus}  => q{singular: 'isthmus' --> 'isthmus'};
is noun(q{bilboes})->singular, q{bilbo}  => q{singular: 'bilboes' --> 'bilbo'};
is noun(q{bilbo})->singular,   q{bilbo}  => q{singular: 'bilbo' --> 'bilbo'};
is noun(q{chevaux de bataille})->singular, q{cheval de bataille}  => q{singular: 'chevaux de bataille' --> 'cheval de bataille'};
is noun(q{cheval de bataille})->singular,   q{cheval de bataille}  => q{singular: 'cheval de bataille' --> 'cheval de bataille'};
is noun(q{sulci})->singular, q{sulcus}  => q{singular: 'sulci' --> 'sulcus'};
is noun(q{sulcus})->singular,   q{sulcus}  => q{singular: 'sulcus' --> 'sulcus'};
is noun(q{aliases})->singular, q{alias}  => q{singular: 'aliases' --> 'alias'};
is noun(q{alias})->singular,   q{alias}  => q{singular: 'alias' --> 'alias'};
is noun(q{Londonese})->singular, q{Londonese}  => q{singular: 'Londonese' --> 'Londonese'};
is noun(q{terpen})->singular, q{terp}  => q{singular: 'terpen' --> 'terp'};
is noun(q{terp})->singular,   q{terp}  => q{singular: 'terp' --> 'terp'};
is noun(q{uredosori})->singular, q{uredosorus}  => q{singular: 'uredosori' --> 'uredosorus'};
is noun(q{uredosorus})->singular,   q{uredosorus}  => q{singular: 'uredosorus' --> 'uredosorus'};
is noun(q{arboreta})->singular, q{arboretum}  => q{singular: 'arboreta' --> 'arboretum'};
is noun(q{arboretum})->singular,   q{arboretum}  => q{singular: 'arboretum' --> 'arboretum'};
is noun(q{star-fishes})->singular, q{star-fish}  => q{singular: 'star-fishes' --> 'star-fish'};
is noun(q{lves})->singular, q{lf}  => q{singular: 'lves' --> 'lf'};
is noun(q{lf})->singular,   q{lf}  => q{singular: 'lf' --> 'lf'};
is noun(q{abortuses})->singular, q{abortus}  => q{singular: 'abortuses' --> 'abortus'};
is noun(q{abortus})->singular,   q{abortus}  => q{singular: 'abortus' --> 'abortus'};
is noun(q{tarsi})->singular, q{tarsus}  => q{singular: 'tarsi' --> 'tarsus'};
is noun(q{tarsus})->singular,   q{tarsus}  => q{singular: 'tarsus' --> 'tarsus'};
is noun(q{sephardin})->singular, q{sephardi}  => q{singular: 'sephardin' --> 'sephardi'};
is noun(q{sephardi})->singular,   q{sephardi}  => q{singular: 'sephardi' --> 'sephardi'};
is noun(q{technos})->singular, q{techno}  => q{singular: 'technos' --> 'techno'};
is noun(q{techno})->singular,   q{techno}  => q{singular: 'techno' --> 'techno'};
is noun(q{stipites})->singular, q{stipes}  => q{singular: 'stipites' --> 'stipes'};
is noun(q{stipes})->singular,   q{stipes}  => q{singular: 'stipes' --> 'stipes'};
is noun(q{moose})->singular, q{moose}  => q{singular: 'moose' --> 'moose'};
is noun(q{psammomata})->singular, q{psammoma}  => q{singular: 'psammomata' --> 'psammoma'};
is noun(q{psammoma})->singular,   q{psammoma}  => q{singular: 'psammoma' --> 'psammoma'};
is noun(q{Kosovos})->singular, q{Kosovo}  => q{singular: 'Kosovos' --> 'Kosovo'};
is noun(q{Kosovo})->singular,   q{Kosovo}  => q{singular: 'Kosovo' --> 'Kosovo'};
is noun(q{pluralia tantum})->singular, q{plurale tantum}  => q{singular: 'pluralia tantum' --> 'plurale tantum'};
is noun(q{plurale tantum})->singular,   q{plurale tantum}  => q{singular: 'plurale tantum' --> 'plurale tantum'};
is noun(q{phymata})->singular, q{phyma}  => q{singular: 'phymata' --> 'phyma'};
is noun(q{phyma})->singular,   q{phyma}  => q{singular: 'phyma' --> 'phyma'};
is noun(q{pliers})->singular, q{pliers}  => q{singular: 'pliers' --> 'pliers'};
is noun(q{reguli})->singular, q{regulus}  => q{singular: 'reguli' --> 'regulus'};
is noun(q{regulus})->singular,   q{regulus}  => q{singular: 'regulus' --> 'regulus'};
is noun(q{beaus})->singular, q{beau}  => q{singular: 'beaus' --> 'beau'};
is noun(q{beau})->singular,   q{beau}  => q{singular: 'beau' --> 'beau'};
is noun(q{papyruses})->singular, q{papyrus}  => q{singular: 'papyruses' --> 'papyrus'};
is noun(q{papyrus})->singular,   q{papyrus}  => q{singular: 'papyrus' --> 'papyrus'};
is noun(q{thoes})->singular, q{thos}  => q{singular: 'thoes' --> 'thos'};
is noun(q{thos})->singular,   q{thos}  => q{singular: 'thos' --> 'thos'};
is noun(q{nockerln})->singular, q{nockerl}  => q{singular: 'nockerln' --> 'nockerl'};
is noun(q{nockerl})->singular,   q{nockerl}  => q{singular: 'nockerl' --> 'nockerl'};
is noun(q{salite})->singular, q{salita}  => q{singular: 'salite' --> 'salita'};
is noun(q{salita})->singular,   q{salita}  => q{singular: 'salita' --> 'salita'};
is noun(q{nemathecia})->singular, q{nemathecium}  => q{singular: 'nemathecia' --> 'nemathecium'};
is noun(q{nemathecium})->singular,   q{nemathecium}  => q{singular: 'nemathecium' --> 'nemathecium'};
is noun(q{cantos})->singular, q{canto}  => q{singular: 'cantos' --> 'canto'};
is noun(q{canto})->singular,   q{canto}  => q{singular: 'canto' --> 'canto'};
is noun(q{burschen})->singular, q{bursch}  => q{singular: 'burschen' --> 'bursch'};
is noun(q{bursch})->singular,   q{bursch}  => q{singular: 'bursch' --> 'bursch'};
is noun(q{synaxes})->singular, q{synaxis}  => q{singular: 'synaxes' --> 'synaxis'};
is noun(q{synaxis})->singular,   q{synaxis}  => q{singular: 'synaxis' --> 'synaxis'};
is noun(q{pragmas})->singular, q{pragma}  => q{singular: 'pragmas' --> 'pragma'};
is noun(q{pragma})->singular,   q{pragma}  => q{singular: 'pragma' --> 'pragma'};
is noun(q{propria})->singular, q{proprium}  => q{singular: 'propria' --> 'proprium'};
is noun(q{proprium})->singular,   q{proprium}  => q{singular: 'proprium' --> 'proprium'};
is noun(q{tobaccos})->singular, q{tobacco}  => q{singular: 'tobaccos' --> 'tobacco'};
is noun(q{tobacco})->singular,   q{tobacco}  => q{singular: 'tobacco' --> 'tobacco'};
is noun(q{substratums})->singular, q{substratum}  => q{singular: 'substratums' --> 'substratum'};
is noun(q{substratum})->singular,   q{substratum}  => q{singular: 'substratum' --> 'substratum'};
is noun(q{peninsulae})->singular, q{peninsula}  => q{singular: 'peninsulae' --> 'peninsula'};
is noun(q{peninsula})->singular,   q{peninsula}  => q{singular: 'peninsula' --> 'peninsula'};
is noun(q{glasses})->singular, q{glass}  => q{singular: 'glasses' --> 'glass'};
is noun(q{glass})->singular,   q{glass}  => q{singular: 'glass' --> 'glass'};
is noun(q{favellae})->singular, q{favella}  => q{singular: 'favellae' --> 'favella'};
is noun(q{favella})->singular,   q{favella}  => q{singular: 'favella' --> 'favella'};
is noun(q{sancta sanctorum})->singular, q{sanctum sanctorum}  => q{singular: 'sancta sanctorum' --> 'sanctum sanctorum'};
is noun(q{sanctum sanctorum})->singular,   q{sanctum sanctorum}  => q{singular: 'sanctum sanctorum' --> 'sanctum sanctorum'};
is noun(q{maria})->singular, q{mare}  => q{singular: 'maria' --> 'mare'};
is noun(q{mare})->singular,   q{mare}  => q{singular: 'mare' --> 'mare'};
is noun(q{silbadors})->singular, q{silbador}  => q{singular: 'silbadors' --> 'silbador'};
is noun(q{silbador})->singular,   q{silbador}  => q{singular: 'silbador' --> 'silbador'};
is noun(q{trulli})->singular, q{trullo}  => q{singular: 'trulli' --> 'trullo'};
is noun(q{trullo})->singular,   q{trullo}  => q{singular: 'trullo' --> 'trullo'};
is noun(q{tomatoes})->singular, q{tomato}  => q{singular: 'tomatoes' --> 'tomato'};
is noun(q{tomato})->singular,   q{tomato}  => q{singular: 'tomato' --> 'tomato'};
is noun(q{paraselenae})->singular, q{paraselene}  => q{singular: 'paraselenae' --> 'paraselene'};
is noun(q{paraselene})->singular,   q{paraselene}  => q{singular: 'paraselene' --> 'paraselene'};
is noun(q{tetrapleurons})->singular, q{tetrapleuron}  => q{singular: 'tetrapleurons' --> 'tetrapleuron'};
is noun(q{tetrapleuron})->singular,   q{tetrapleuron}  => q{singular: 'tetrapleuron' --> 'tetrapleuron'};
is noun(q{soli})->singular, q{solo}  => q{singular: 'soli' --> 'solo'};
is noun(q{solo})->singular,   q{solo}  => q{singular: 'solo' --> 'solo'};
is noun(q{codices})->singular, q{codex}  => q{singular: 'codices' --> 'codex'};
is noun(q{codex})->singular,   q{codex}  => q{singular: 'codex' --> 'codex'};
is noun(q{uraei})->singular, q{uraeus}  => q{singular: 'uraei' --> 'uraeus'};
is noun(q{uraeus})->singular,   q{uraeus}  => q{singular: 'uraeus' --> 'uraeus'};
is noun(q{chervontzi})->singular, q{chervonetz}  => q{singular: 'chervontzi' --> 'chervonetz'};
is noun(q{chervonetz})->singular,   q{chervonetz}  => q{singular: 'chervonetz' --> 'chervonetz'};
is noun(q{sestertia})->singular, q{sestertium}  => q{singular: 'sestertia' --> 'sestertium'};
is noun(q{sestertium})->singular,   q{sestertium}  => q{singular: 'sestertium' --> 'sestertium'};
is noun(q{ourselves})->singular, q{myself}  => q{singular: 'ourselves' --> 'myself'};
is noun(q{myself})->singular,   q{myself}  => q{singular: 'myself' --> 'myself'};
is noun(q{scungilli})->singular, q{scungille}  => q{singular: 'scungilli' --> 'scungille'};
is noun(q{scungille})->singular,   q{scungille}  => q{singular: 'scungille' --> 'scungille'};
is noun(q{geisteswissenschaften})->singular, q{geisteswissenschaft}  => q{singular: 'geisteswissenschaften' --> 'geisteswissenschaft'};
is noun(q{geisteswissenschaft})->singular,   q{geisteswissenschaft}  => q{singular: 'geisteswissenschaft' --> 'geisteswissenschaft'};
is noun(q{specula})->singular, q{speculum}  => q{singular: 'specula' --> 'speculum'};
is noun(q{speculum})->singular,   q{speculum}  => q{singular: 'speculum' --> 'speculum'};
is noun(q{indexes})->singular, q{index}  => q{singular: 'indexes' --> 'index'};
is noun(q{index})->singular,   q{index}  => q{singular: 'index' --> 'index'};
is noun(q{hemangeiomas})->singular, q{hemangeioma}  => q{singular: 'hemangeiomas' --> 'hemangeioma'};
is noun(q{hemangeioma})->singular,   q{hemangeioma}  => q{singular: 'hemangeioma' --> 'hemangeioma'};
is noun(q{platypodes})->singular, q{platypus}  => q{singular: 'platypodes' --> 'platypus'};
is noun(q{platypus})->singular,   q{platypus}  => q{singular: 'platypus' --> 'platypus'};
is noun(q{directrices})->singular, q{directrix}  => q{singular: 'directrices' --> 'directrix'};
is noun(q{directrix})->singular,   q{directrix}  => q{singular: 'directrix' --> 'directrix'};
is noun(q{pence})->singular, q{penny}  => q{singular: 'pence' --> 'penny'};
is noun(q{penny})->singular,   q{penny}  => q{singular: 'penny' --> 'penny'};
is noun(q{stromodaea})->singular, q{stromodeum}  => q{singular: 'stromodaea' --> 'stromodeum'};
is noun(q{stromodeum})->singular,   q{stromodeum}  => q{singular: 'stromodeum' --> 'stromodeum'};
is noun(q{miracidia})->singular, q{miracidium}  => q{singular: 'miracidia' --> 'miracidium'};
is noun(q{miracidium})->singular,   q{miracidium}  => q{singular: 'miracidium' --> 'miracidium'};
is noun(q{calzones})->singular, q{calzone}  => q{singular: 'calzones' --> 'calzone'};
is noun(q{calzone})->singular,   q{calzone}  => q{singular: 'calzone' --> 'calzone'};
is noun(q{tractella})->singular, q{tractellum}  => q{singular: 'tractella' --> 'tractellum'};
is noun(q{tractellum})->singular,   q{tractellum}  => q{singular: 'tractellum' --> 'tractellum'};
is noun(q{zygomas})->singular, q{zygoma}  => q{singular: 'zygomas' --> 'zygoma'};
is noun(q{zygoma})->singular,   q{zygoma}  => q{singular: 'zygoma' --> 'zygoma'};
is noun(q{exanthemata})->singular, q{exanthema}  => q{singular: 'exanthemata' --> 'exanthema'};
is noun(q{exanthema})->singular,   q{exanthema}  => q{singular: 'exanthema' --> 'exanthema'};
is noun(q{atlantes})->singular, q{atlas}  => q{singular: 'atlantes' --> 'atlas'};
is noun(q{atlas})->singular,   q{atlas}  => q{singular: 'atlas' --> 'atlas'};
is noun(q{flabella})->singular, q{flabellum}  => q{singular: 'flabella' --> 'flabellum'};
is noun(q{flabellum})->singular,   q{flabellum}  => q{singular: 'flabellum' --> 'flabellum'};
is noun(q{camerae obscurae})->singular, q{camera obscura}  => q{singular: 'camerae obscurae' --> 'camera obscura'};
is noun(q{camera obscura})->singular,   q{camera obscura}  => q{singular: 'camera obscura' --> 'camera obscura'};
is noun(q{tenues})->singular, q{tenuis}  => q{singular: 'tenues' --> 'tenuis'};
is noun(q{tenuis})->singular,   q{tenuis}  => q{singular: 'tenuis' --> 'tenuis'};
is noun(q{curiosos})->singular, q{curioso}  => q{singular: 'curiosos' --> 'curioso'};
is noun(q{curioso})->singular,   q{curioso}  => q{singular: 'curioso' --> 'curioso'};
is noun(q{pimentos})->singular, q{pimento}  => q{singular: 'pimentos' --> 'pimento'};
is noun(q{pimento})->singular,   q{pimento}  => q{singular: 'pimento' --> 'pimento'};
is noun(q{byliny})->singular, q{bylina}  => q{singular: 'byliny' --> 'bylina'};
is noun(q{bylina})->singular,   q{bylina}  => q{singular: 'bylina' --> 'bylina'};
is noun(q{nexus})->singular, q{nexus}  => q{singular: 'nexus' --> 'nexus'};
is noun(q{Viennese})->singular, q{Viennese}  => q{singular: 'Viennese' --> 'Viennese'};
is noun(q{zuzzes})->singular, q{zuz}  => q{singular: 'zuzzes' --> 'zuz'};
is noun(q{zuz})->singular,   q{zuz}  => q{singular: 'zuz' --> 'zuz'};
is noun(q{bisons})->singular, q{bison}  => q{singular: 'bisons' --> 'bison'};
is noun(q{curiosi})->singular, q{curioso}  => q{singular: 'curiosi' --> 'curioso'};
is noun(q{curioso})->singular,   q{curioso}  => q{singular: 'curioso' --> 'curioso'};
is noun(q{cecidia})->singular, q{cecidium}  => q{singular: 'cecidia' --> 'cecidium'};
is noun(q{cecidium})->singular,   q{cecidium}  => q{singular: 'cecidium' --> 'cecidium'};
is noun(q{Sikkimese})->singular, q{Sikkimese}  => q{singular: 'Sikkimese' --> 'Sikkimese'};
is noun(q{nucleuses})->singular, q{nucleus}  => q{singular: 'nucleuses' --> 'nucleus'};
is noun(q{nucleus})->singular,   q{nucleus}  => q{singular: 'nucleus' --> 'nucleus'};
is noun(q{appendices})->singular, q{appendix}  => q{singular: 'appendices' --> 'appendix'};
is noun(q{appendix})->singular,   q{appendix}  => q{singular: 'appendix' --> 'appendix'};
is noun(q{bateaus})->singular, q{bateau}  => q{singular: 'bateaus' --> 'bateau'};
is noun(q{bateau})->singular,   q{bateau}  => q{singular: 'bateau' --> 'bateau'};
is noun(q{solenia})->singular, q{solenium}  => q{singular: 'solenia' --> 'solenium'};
is noun(q{solenium})->singular,   q{solenium}  => q{singular: 'solenium' --> 'solenium'};
is noun(q{oxybapha})->singular, q{oxybaphon}  => q{singular: 'oxybapha' --> 'oxybaphon'};
is noun(q{oxybaphon})->singular,   q{oxybaphon}  => q{singular: 'oxybaphon' --> 'oxybaphon'};
is noun(q{simulacrums})->singular, q{simulacrum}  => q{singular: 'simulacrums' --> 'simulacrum'};
is noun(q{simulacrum})->singular,   q{simulacrum}  => q{singular: 'simulacrum' --> 'simulacrum'};
is noun(q{trapezohedrons})->singular, q{trapezohedron}  => q{singular: 'trapezohedrons' --> 'trapezohedron'};
is noun(q{trapezohedron})->singular,   q{trapezohedron}  => q{singular: 'trapezohedron' --> 'trapezohedron'};
is noun(q{rotulae})->singular, q{rotula}  => q{singular: 'rotulae' --> 'rotula'};
is noun(q{rotula})->singular,   q{rotula}  => q{singular: 'rotula' --> 'rotula'};
is noun(q{lymphomas})->singular, q{lymphoma}  => q{singular: 'lymphomas' --> 'lymphoma'};
is noun(q{lymphoma})->singular,   q{lymphoma}  => q{singular: 'lymphoma' --> 'lymphoma'};
is noun(q{congii})->singular, q{congius}  => q{singular: 'congii' --> 'congius'};
is noun(q{congius})->singular,   q{congius}  => q{singular: 'congius' --> 'congius'};
is noun(q{mediastina})->singular, q{mediastinum}  => q{singular: 'mediastina' --> 'mediastinum'};
is noun(q{mediastinum})->singular,   q{mediastinum}  => q{singular: 'mediastinum' --> 'mediastinum'};
is noun(q{zeros})->singular, q{zero}  => q{singular: 'zeros' --> 'zero'};
is noun(q{zero})->singular,   q{zero}  => q{singular: 'zero' --> 'zero'};
is noun(q{batzes})->singular, q{batz}  => q{singular: 'batzes' --> 'batz'};
is noun(q{batz})->singular,   q{batz}  => q{singular: 'batz' --> 'batz'};
is noun(q{oedemas})->singular, q{oedema}  => q{singular: 'oedemas' --> 'oedema'};
is noun(q{oedema})->singular,   q{oedema}  => q{singular: 'oedema' --> 'oedema'};
is noun(q{lumbagos})->singular, q{lumbago}  => q{singular: 'lumbagos' --> 'lumbago'};
is noun(q{lumbago})->singular,   q{lumbago}  => q{singular: 'lumbago' --> 'lumbago'};
is noun(q{paxillae})->singular, q{paxilla}  => q{singular: 'paxillae' --> 'paxilla'};
is noun(q{paxilla})->singular,   q{paxilla}  => q{singular: 'paxilla' --> 'paxilla'};
is noun(q{vasculums})->singular, q{vasculum}  => q{singular: 'vasculums' --> 'vasculum'};
is noun(q{vasculum})->singular,   q{vasculum}  => q{singular: 'vasculum' --> 'vasculum'};
is noun(q{corps})->singular, q{corps}  => q{singular: 'corps' --> 'corps'};
is noun(q{thieves})->singular, q{thief}  => q{singular: 'thieves' --> 'thief'};
is noun(q{thief})->singular,   q{thief}  => q{singular: 'thief' --> 'thief'};
is noun(q{statuas})->singular, q{statua}  => q{singular: 'statuas' --> 'statua'};
is noun(q{statua})->singular,   q{statua}  => q{singular: 'statua' --> 'statua'};
is noun(q{dynamos})->singular, q{dynamo}  => q{singular: 'dynamos' --> 'dynamo'};
is noun(q{dynamo})->singular,   q{dynamo}  => q{singular: 'dynamo' --> 'dynamo'};
is noun(q{parapsides})->singular, q{parapsis}  => q{singular: 'parapsides' --> 'parapsis'};
is noun(q{parapsis})->singular,   q{parapsis}  => q{singular: 'parapsis' --> 'parapsis'};
is noun(q{termites})->singular, q{termes}  => q{singular: 'termites' --> 'termes'};
is noun(q{termes})->singular,   q{termes}  => q{singular: 'termes' --> 'termes'};
is noun(q{anti sera})->singular, q{anti serum}  => q{singular: 'anti sera' --> 'anti serum'};
is noun(q{anti serum})->singular,   q{anti serum}  => q{singular: 'anti serum' --> 'anti serum'};
is noun(q{nouveaux arrives})->singular, q{nouvel arrive}  => q{singular: 'nouveaux arrives' --> 'nouvel arrive'};
is noun(q{nouvel arrive})->singular,   q{nouvel arrive}  => q{singular: 'nouvel arrive' --> 'nouvel arrive'};
is noun(q{tangoes})->singular, q{tango}  => q{singular: 'tangoes' --> 'tango'};
is noun(q{tango})->singular,   q{tango}  => q{singular: 'tango' --> 'tango'};
is noun(q{molimina})->singular, q{molimen}  => q{singular: 'molimina' --> 'molimen'};
is noun(q{molimen})->singular,   q{molimen}  => q{singular: 'molimen' --> 'molimen'};
is noun(q{postpubes})->singular, q{postpubis}  => q{singular: 'postpubes' --> 'postpubis'};
is noun(q{postpubis})->singular,   q{postpubis}  => q{singular: 'postpubis' --> 'postpubis'};
is noun(q{rejones})->singular, q{rejon}  => q{singular: 'rejones' --> 'rejon'};
is noun(q{rejon})->singular,   q{rejon}  => q{singular: 'rejon' --> 'rejon'};
is noun(q{halteridia})->singular, q{halteridium}  => q{singular: 'halteridia' --> 'halteridium'};
is noun(q{halteridium})->singular,   q{halteridium}  => q{singular: 'halteridium' --> 'halteridium'};
is noun(q{serpigines})->singular, q{serpigo}  => q{singular: 'serpigines' --> 'serpigo'};
is noun(q{serpigo})->singular,   q{serpigo}  => q{singular: 'serpigo' --> 'serpigo'};
is noun(q{tabulae})->singular, q{tabula}  => q{singular: 'tabulae' --> 'tabula'};
is noun(q{tabula})->singular,   q{tabula}  => q{singular: 'tabula' --> 'tabula'};
is noun(q{vlakten})->singular, q{vlakte}  => q{singular: 'vlakten' --> 'vlakte'};
is noun(q{vlakte})->singular,   q{vlakte}  => q{singular: 'vlakte' --> 'vlakte'};
is noun(q{Portos})->singular, q{Porto}  => q{singular: 'Portos' --> 'Porto'};
is noun(q{Porto})->singular,   q{Porto}  => q{singular: 'Porto' --> 'Porto'};
is noun(q{tenacula})->singular, q{tenaculum}  => q{singular: 'tenacula' --> 'tenaculum'};
is noun(q{tenaculum})->singular,   q{tenaculum}  => q{singular: 'tenaculum' --> 'tenaculum'};
is noun(q{pianos})->singular, q{piano}  => q{singular: 'pianos' --> 'piano'};
is noun(q{piano})->singular,   q{piano}  => q{singular: 'piano' --> 'piano'};
is noun(q{women servants})->singular, q{woman servant}  => q{singular: 'women servants' --> 'woman servant'};
is noun(q{woman servant})->singular,   q{woman servant}  => q{singular: 'woman servant' --> 'woman servant'};
is noun(q{siroccos})->singular, q{sirocco}  => q{singular: 'siroccos' --> 'sirocco'};
is noun(q{sirocco})->singular,   q{sirocco}  => q{singular: 'sirocco' --> 'sirocco'};
is noun(q{shauries})->singular, q{shauri}  => q{singular: 'shauries' --> 'shauri'};
is noun(q{shauri})->singular,   q{shauri}  => q{singular: 'shauri' --> 'shauri'};
is noun(q{ephemeras})->singular, q{ephemera}  => q{singular: 'ephemeras' --> 'ephemera'};
is noun(q{ephemera})->singular,   q{ephemera}  => q{singular: 'ephemera' --> 'ephemera'};
is noun(q{carabinieri})->singular, q{carabiniere}  => q{singular: 'carabinieri' --> 'carabiniere'};
is noun(q{carabiniere})->singular,   q{carabiniere}  => q{singular: 'carabiniere' --> 'carabiniere'};
is noun(q{paterae})->singular, q{patera}  => q{singular: 'paterae' --> 'patera'};
is noun(q{patera})->singular,   q{patera}  => q{singular: 'patera' --> 'patera'};
is noun(q{shauris})->singular, q{shauri}  => q{singular: 'shauris' --> 'shauri'};
is noun(q{shauri})->singular,   q{shauri}  => q{singular: 'shauri' --> 'shauri'};
is noun(q{Hoosierese})->singular, q{Hoosierese}  => q{singular: 'Hoosierese' --> 'Hoosierese'};
is noun(q{shomrim})->singular, q{shomer}  => q{singular: 'shomrim' --> 'shomer'};
is noun(q{shomer})->singular,   q{shomer}  => q{singular: 'shomer' --> 'shomer'};
is noun(q{fermate})->singular, q{fermata}  => q{singular: 'fermate' --> 'fermata'};
is noun(q{fermata})->singular,   q{fermata}  => q{singular: 'fermata' --> 'fermata'};
is noun(q{melismas})->singular, q{melisma}  => q{singular: 'melismas' --> 'melisma'};
is noun(q{melisma})->singular,   q{melisma}  => q{singular: 'melisma' --> 'melisma'};
is noun(q{camera obscuras})->singular, q{camera obscura}  => q{singular: 'camera obscuras' --> 'camera obscura'};
is noun(q{camera obscura})->singular,   q{camera obscura}  => q{singular: 'camera obscura' --> 'camera obscura'};
is noun(q{scazons})->singular, q{scazon}  => q{singular: 'scazons' --> 'scazon'};
is noun(q{scazon})->singular,   q{scazon}  => q{singular: 'scazon' --> 'scazon'};
is noun(q{culs de four})->singular, q{cul de four}  => q{singular: 'culs de four' --> 'cul de four'};
is noun(q{cul de four})->singular,   q{cul de four}  => q{singular: 'cul de four' --> 'cul de four'};
is noun(q{fenestrae})->singular, q{fenestra}  => q{singular: 'fenestrae' --> 'fenestra'};
is noun(q{fenestra})->singular,   q{fenestra}  => q{singular: 'fenestra' --> 'fenestra'};
is noun(q{traumata})->singular, q{trauma}  => q{singular: 'traumata' --> 'trauma'};
is noun(q{trauma})->singular,   q{trauma}  => q{singular: 'trauma' --> 'trauma'};
is noun(q{momentums})->singular, q{momentum}  => q{singular: 'momentums' --> 'momentum'};
is noun(q{momentum})->singular,   q{momentum}  => q{singular: 'momentum' --> 'momentum'};
is noun(q{pulli})->singular, q{pullus}  => q{singular: 'pulli' --> 'pullus'};
is noun(q{pullus})->singular,   q{pullus}  => q{singular: 'pullus' --> 'pullus'};
is noun(q{bandeaus})->singular, q{bandeau}  => q{singular: 'bandeaus' --> 'bandeau'};
is noun(q{bandeau})->singular,   q{bandeau}  => q{singular: 'bandeau' --> 'bandeau'};
is noun(q{retinulae})->singular, q{retinula}  => q{singular: 'retinulae' --> 'retinula'};
is noun(q{retinula})->singular,   q{retinula}  => q{singular: 'retinula' --> 'retinula'};
is noun(q{Gabunese})->singular, q{Gabunese}  => q{singular: 'Gabunese' --> 'Gabunese'};
is noun(q{Kongoese})->singular, q{Kongoese}  => q{singular: 'Kongoese' --> 'Kongoese'};
is noun(q{politicos})->singular, q{politico}  => q{singular: 'politicos' --> 'politico'};
is noun(q{politico})->singular,   q{politico}  => q{singular: 'politico' --> 'politico'};
is noun(q{caducei})->singular, q{caduceus}  => q{singular: 'caducei' --> 'caduceus'};
is noun(q{caduceus})->singular,   q{caduceus}  => q{singular: 'caduceus' --> 'caduceus'};
is noun(q{uruses})->singular, q{urus}  => q{singular: 'uruses' --> 'urus'};
is noun(q{urus})->singular,   q{urus}  => q{singular: 'urus' --> 'urus'};
is noun(q{basilicas})->singular, q{basilica}  => q{singular: 'basilicas' --> 'basilica'};
is noun(q{basilica})->singular,   q{basilica}  => q{singular: 'basilica' --> 'basilica'};
is noun(q{cyanos})->singular, q{cyano}  => q{singular: 'cyanos' --> 'cyano'};
is noun(q{cyano})->singular,   q{cyano}  => q{singular: 'cyano' --> 'cyano'};
is noun(q{fibulae})->singular, q{fibula}  => q{singular: 'fibulae' --> 'fibula'};
is noun(q{fibula})->singular,   q{fibula}  => q{singular: 'fibula' --> 'fibula'};
is noun(q{them})->singular, q{it}  => q{singular: 'them' --> 'it'};
is noun(q{it})->singular,   q{it}  => q{singular: 'it' --> 'it'};
is noun(q{nentsi})->singular, q{nenets}  => q{singular: 'nentsi' --> 'nenets'};
is noun(q{nenets})->singular,   q{nenets}  => q{singular: 'nenets' --> 'nenets'};
is noun(q{lepta})->singular, q{lepton}  => q{singular: 'lepta' --> 'lepton'};
is noun(q{lepton})->singular,   q{lepton}  => q{singular: 'lepton' --> 'lepton'};
is noun(q{bon mots})->singular, q{bon mot}  => q{singular: 'bon mots' --> 'bon mot'};
is noun(q{bon mot})->singular,   q{bon mot}  => q{singular: 'bon mot' --> 'bon mot'};
is noun(q{carcinomas})->singular, q{carcinoma}  => q{singular: 'carcinomas' --> 'carcinoma'};
is noun(q{carcinoma})->singular,   q{carcinoma}  => q{singular: 'carcinoma' --> 'carcinoma'};
is noun(q{Pangasinans})->singular, q{Pangasinan}  => q{singular: 'Pangasinans' --> 'Pangasinan'};
is noun(q{Pangasinan})->singular,   q{Pangasinan}  => q{singular: 'Pangasinan' --> 'Pangasinan'};
is noun(q{regmata})->singular, q{regma}  => q{singular: 'regmata' --> 'regma'};
is noun(q{regma})->singular,   q{regma}  => q{singular: 'regma' --> 'regma'};
is noun(q{grottoes})->singular, q{grotto}  => q{singular: 'grottoes' --> 'grotto'};
is noun(q{grotto})->singular,   q{grotto}  => q{singular: 'grotto' --> 'grotto'};
is noun(q{hypnums})->singular, q{hypnum}  => q{singular: 'hypnums' --> 'hypnum'};
is noun(q{hypnum})->singular,   q{hypnum}  => q{singular: 'hypnum' --> 'hypnum'};
is noun(q{pizze})->singular, q{pizza}  => q{singular: 'pizze' --> 'pizza'};
is noun(q{pizza})->singular,   q{pizza}  => q{singular: 'pizza' --> 'pizza'};
is noun(q{vaqueros})->singular, q{vaquero}  => q{singular: 'vaqueros' --> 'vaquero'};
is noun(q{vaquero})->singular,   q{vaquero}  => q{singular: 'vaquero' --> 'vaquero'};
is noun(q{saga})->singular, q{sagum}  => q{singular: 'saga' --> 'sagum'};
is noun(q{sagum})->singular,   q{sagum}  => q{singular: 'sagum' --> 'sagum'};
is noun(q{tessellae})->singular, q{tessella}  => q{singular: 'tessellae' --> 'tessella'};
is noun(q{tessella})->singular,   q{tessella}  => q{singular: 'tessella' --> 'tessella'};
is noun(q{rondeaus})->singular, q{rondeau}  => q{singular: 'rondeaus' --> 'rondeau'};
is noun(q{rondeau})->singular,   q{rondeau}  => q{singular: 'rondeau' --> 'rondeau'};
is noun(q{mantises})->singular, q{mantis}  => q{singular: 'mantises' --> 'mantis'};
is noun(q{mantis})->singular,   q{mantis}  => q{singular: 'mantis' --> 'mantis'};
is noun(q{grottos})->singular, q{grotto}  => q{singular: 'grottos' --> 'grotto'};
is noun(q{grotto})->singular,   q{grotto}  => q{singular: 'grotto' --> 'grotto'};
is noun(q{denotata})->singular, q{denotatum}  => q{singular: 'denotata' --> 'denotatum'};
is noun(q{denotatum})->singular,   q{denotatum}  => q{singular: 'denotatum' --> 'denotatum'};
is noun(q{superstrata})->singular, q{superstratum}  => q{singular: 'superstrata' --> 'superstratum'};
is noun(q{superstratum})->singular,   q{superstratum}  => q{singular: 'superstratum' --> 'superstratum'};
is noun(q{six-star generals})->singular, q{six-star general}  => q{singular: 'six-star generals' --> 'six-star general'};
is noun(q{six-star general})->singular,   q{six-star general}  => q{singular: 'six-star general' --> 'six-star general'};
is noun(q{symposia})->singular, q{symposium}  => q{singular: 'symposia' --> 'symposium'};
is noun(q{symposium})->singular,   q{symposium}  => q{singular: 'symposium' --> 'symposium'};
is noun(q{Spaetlesen})->singular, q{Spaetlese}  => q{singular: 'Spaetlesen' --> 'Spaetlese'};
is noun(q{Spaetlese})->singular,   q{Spaetlese}  => q{singular: 'Spaetlese' --> 'Spaetlese'};
is noun(q{culs de lampe})->singular, q{cul de lampe}  => q{singular: 'culs de lampe' --> 'cul de lampe'};
is noun(q{cul de lampe})->singular,   q{cul de lampe}  => q{singular: 'cul de lampe' --> 'cul de lampe'};
is noun(q{autochthons})->singular, q{autochthon}  => q{singular: 'autochthons' --> 'autochthon'};
is noun(q{autochthon})->singular,   q{autochthon}  => q{singular: 'autochthon' --> 'autochthon'};
is noun(q{rimmonim})->singular, q{rimon}  => q{singular: 'rimmonim' --> 'rimon'};
is noun(q{rimon})->singular,   q{rimon}  => q{singular: 'rimon' --> 'rimon'};
is noun(q{Yamoussoukros})->singular, q{Yamoussoukro}  => q{singular: 'Yamoussoukros' --> 'Yamoussoukro'};
is noun(q{Yamoussoukro})->singular,   q{Yamoussoukro}  => q{singular: 'Yamoussoukro' --> 'Yamoussoukro'};
is noun(q{stromata})->singular, q{stroma}  => q{singular: 'stromata' --> 'stroma'};
is noun(q{stroma})->singular,   q{stroma}  => q{singular: 'stroma' --> 'stroma'};
is noun(q{listerias})->singular, q{listeria}  => q{singular: 'listerias' --> 'listeria'};
is noun(q{chrysalises})->singular, q{chrysalis}  => q{singular: 'chrysalises' --> 'chrysalis'};
is noun(q{chrysalis})->singular,   q{chrysalis}  => q{singular: 'chrysalis' --> 'chrysalis'};
is noun(q{modi})->singular, q{modus}  => q{singular: 'modi' --> 'modus'};
is noun(q{modus})->singular,   q{modus}  => q{singular: 'modus' --> 'modus'};
is noun(q{tentamina})->singular, q{tentamen}  => q{singular: 'tentamina' --> 'tentamen'};
is noun(q{tentamen})->singular,   q{tentamen}  => q{singular: 'tentamen' --> 'tentamen'};
is noun(q{legumina})->singular, q{legumen}  => q{singular: 'legumina' --> 'legumen'};
is noun(q{legumen})->singular,   q{legumen}  => q{singular: 'legumen' --> 'legumen'};
is noun(q{equiseta})->singular, q{equisetum}  => q{singular: 'equiseta' --> 'equisetum'};
is noun(q{equisetum})->singular,   q{equisetum}  => q{singular: 'equisetum' --> 'equisetum'};
is noun(q{minimums})->singular, q{minimum}  => q{singular: 'minimums' --> 'minimum'};
is noun(q{minimum})->singular,   q{minimum}  => q{singular: 'minimum' --> 'minimum'};
is noun(q{opuscula})->singular, q{opusculum}  => q{singular: 'opuscula' --> 'opusculum'};
is noun(q{opusculum})->singular,   q{opusculum}  => q{singular: 'opusculum' --> 'opusculum'};
is noun(q{thymiateria})->singular, q{thymiaterion}  => q{singular: 'thymiateria' --> 'thymiaterion'};
is noun(q{thymiaterion})->singular,   q{thymiaterion}  => q{singular: 'thymiaterion' --> 'thymiaterion'};
is noun(q{five-star generals})->singular, q{five-star general}  => q{singular: 'five-star generals' --> 'five-star general'};
is noun(q{five-star general})->singular,   q{five-star general}  => q{singular: 'five-star general' --> 'five-star general'};
is noun(q{sipunculi})->singular, q{sipunculus}  => q{singular: 'sipunculi' --> 'sipunculus'};
is noun(q{sipunculus})->singular,   q{sipunculus}  => q{singular: 'sipunculus' --> 'sipunculus'};
is noun(q{halibuts})->singular, q{halibut}  => q{singular: 'halibuts' --> 'halibut'};
is noun(q{alguaciles})->singular, q{alguacil}  => q{singular: 'alguaciles' --> 'alguacil'};
is noun(q{alguacil})->singular,   q{alguacil}  => q{singular: 'alguacil' --> 'alguacil'};
is noun(q{podia})->singular, q{podium}  => q{singular: 'podia' --> 'podium'};
is noun(q{podium})->singular,   q{podium}  => q{singular: 'podium' --> 'podium'};
is noun(q{purlieux})->singular, q{purlieu}  => q{singular: 'purlieux' --> 'purlieu'};
is noun(q{purlieu})->singular,   q{purlieu}  => q{singular: 'purlieu' --> 'purlieu'};
is noun(q{strobilae})->singular, q{strobila}  => q{singular: 'strobilae' --> 'strobila'};
is noun(q{strobila})->singular,   q{strobila}  => q{singular: 'strobila' --> 'strobila'};
is noun(q{thoraces})->singular, q{thorax}  => q{singular: 'thoraces' --> 'thorax'};
is noun(q{thorax})->singular,   q{thorax}  => q{singular: 'thorax' --> 'thorax'};
is noun(q{oceanaria})->singular, q{oceanarium}  => q{singular: 'oceanaria' --> 'oceanarium'};
is noun(q{oceanarium})->singular,   q{oceanarium}  => q{singular: 'oceanarium' --> 'oceanarium'};
is noun(q{sets off})->singular, q{set off}  => q{singular: 'sets off' --> 'set off'};
is noun(q{set off})->singular,   q{set off}  => q{singular: 'set off' --> 'set off'};
is noun(q{belles epoques})->singular, q{belle epoque}  => q{singular: 'belles epoques' --> 'belle epoque'};
is noun(q{belle epoque})->singular,   q{belle epoque}  => q{singular: 'belle epoque' --> 'belle epoque'};
is noun(q{bregmata})->singular, q{bregma}  => q{singular: 'bregmata' --> 'bregma'};
is noun(q{bregma})->singular,   q{bregma}  => q{singular: 'bregma' --> 'bregma'};
is noun(q{rediae})->singular, q{redia}  => q{singular: 'rediae' --> 'redia'};
is noun(q{redia})->singular,   q{redia}  => q{singular: 'redia' --> 'redia'};
is noun(q{simplexes})->singular, q{simplex}  => q{singular: 'simplexes' --> 'simplex'};
is noun(q{simplex})->singular,   q{simplex}  => q{singular: 'simplex' --> 'simplex'};
is noun(q{sandr})->singular, q{sandr}  => q{singular: 'sandr' --> 'sandr'};
is noun(q{pengoes})->singular, q{pengo}  => q{singular: 'pengoes' --> 'pengo'};
is noun(q{Malabos})->singular, q{Malabo}  => q{singular: 'Malabos' --> 'Malabo'};
is noun(q{Malabo})->singular,   q{Malabo}  => q{singular: 'Malabo' --> 'Malabo'};
is noun(q{lymphomata})->singular, q{lymphoma}  => q{singular: 'lymphomata' --> 'lymphoma'};
is noun(q{lymphoma})->singular,   q{lymphoma}  => q{singular: 'lymphoma' --> 'lymphoma'};
is noun(q{sensa})->singular, q{sensum}  => q{singular: 'sensa' --> 'sensum'};
is noun(q{sensum})->singular,   q{sensum}  => q{singular: 'sensum' --> 'sensum'};
is noun(q{pistillidia})->singular, q{pistillidium}  => q{singular: 'pistillidia' --> 'pistillidium'};
is noun(q{pistillidium})->singular,   q{pistillidium}  => q{singular: 'pistillidium' --> 'pistillidium'};
is noun(q{tibiae})->singular, q{tibia}  => q{singular: 'tibiae' --> 'tibia'};
is noun(q{tibia})->singular,   q{tibia}  => q{singular: 'tibia' --> 'tibia'};
is noun(q{prototypons})->singular, q{prototypon}  => q{singular: 'prototypons' --> 'prototypon'};
is noun(q{prototypon})->singular,   q{prototypon}  => q{singular: 'prototypon' --> 'prototypon'};
is noun(q{organa})->singular, q{organon}  => q{singular: 'organa' --> 'organon'};
is noun(q{organon})->singular,   q{organon}  => q{singular: 'organon' --> 'organon'};
is noun(q{coes})->singular, q{co}  => q{singular: 'coes' --> 'co'};
is noun(q{co})->singular,   q{co}  => q{singular: 'co' --> 'co'};
is noun(q{olfactoria})->singular, q{olfactorium}  => q{singular: 'olfactoria' --> 'olfactorium'};
is noun(q{olfactorium})->singular,   q{olfactorium}  => q{singular: 'olfactorium' --> 'olfactorium'};
is noun(q{Nankingese})->singular, q{Nankingese}  => q{singular: 'Nankingese' --> 'Nankingese'};
is noun(q{scherzos})->singular, q{scherzo}  => q{singular: 'scherzos' --> 'scherzo'};
is noun(q{scherzo})->singular,   q{scherzo}  => q{singular: 'scherzo' --> 'scherzo'};
is noun(q{sephardim})->singular, q{sephardi}  => q{singular: 'sephardim' --> 'sephardi'};
is noun(q{sephardi})->singular,   q{sephardi}  => q{singular: 'sephardi' --> 'sephardi'};
is noun(q{rarae aves})->singular, q{rara avis}  => q{singular: 'rarae aves' --> 'rara avis'};
is noun(q{rara avis})->singular,   q{rara avis}  => q{singular: 'rara avis' --> 'rara avis'};
is noun(q{Genoese})->singular, q{Genoese}  => q{singular: 'Genoese' --> 'Genoese'};
is noun(q{kovshi})->singular, q{kovsh}  => q{singular: 'kovshi' --> 'kovsh'};
is noun(q{kovsh})->singular,   q{kovsh}  => q{singular: 'kovsh' --> 'kovsh'};
is noun(q{ignoramuses})->singular, q{ignoramus}  => q{singular: 'ignoramuses' --> 'ignoramus'};
is noun(q{bustos})->singular, q{busto}  => q{singular: 'bustos' --> 'busto'};
is noun(q{busto})->singular,   q{busto}  => q{singular: 'busto' --> 'busto'};
is noun(q{lithodomi})->singular, q{lithodomus}  => q{singular: 'lithodomi' --> 'lithodomus'};
is noun(q{lithodomus})->singular,   q{lithodomus}  => q{singular: 'lithodomus' --> 'lithodomus'};
is noun(q{individua})->singular, q{individuum}  => q{singular: 'individua' --> 'individuum'};
is noun(q{individuum})->singular,   q{individuum}  => q{singular: 'individuum' --> 'individuum'};
is noun(q{atamans})->singular, q{ataman}  => q{singular: 'atamans' --> 'ataman'};
is noun(q{ataman})->singular,   q{ataman}  => q{singular: 'ataman' --> 'ataman'};
is noun(q{suggestums})->singular, q{suggestum}  => q{singular: 'suggestums' --> 'suggestum'};
is noun(q{suggestum})->singular,   q{suggestum}  => q{singular: 'suggestum' --> 'suggestum'};
is noun(q{agrogoroda})->singular, q{agrogorod}  => q{singular: 'agrogoroda' --> 'agrogorod'};
is noun(q{agrogorod})->singular,   q{agrogorod}  => q{singular: 'agrogorod' --> 'agrogorod'};
is noun(q{bureaus})->singular, q{bureau}  => q{singular: 'bureaus' --> 'bureau'};
is noun(q{bureau})->singular,   q{bureau}  => q{singular: 'bureau' --> 'bureau'};
is noun(q{pietre})->singular, q{pietra}  => q{singular: 'pietre' --> 'pietra'};
is noun(q{pietra})->singular,   q{pietra}  => q{singular: 'pietra' --> 'pietra'};
is noun(q{vortexes})->singular, q{vortex}  => q{singular: 'vortexes' --> 'vortex'};
is noun(q{vortex})->singular,   q{vortex}  => q{singular: 'vortex' --> 'vortex'};
is noun(q{soles})->singular, q{sol}  => q{singular: 'soles' --> 'sol'};
is noun(q{sol})->singular,   q{sol}  => q{singular: 'sol' --> 'sol'};
is noun(q{brethren-german})->singular, q{brother-german}  => q{singular: 'brethren-german' --> 'brother-german'};
is noun(q{brother-german})->singular,   q{brother-german}  => q{singular: 'brother-german' --> 'brother-german'};
is noun(q{stomata})->singular, q{stoma}  => q{singular: 'stomata' --> 'stoma'};
is noun(q{stoma})->singular,   q{stoma}  => q{singular: 'stoma' --> 'stoma'};
is noun(q{buzzes})->singular, q{buzz}  => q{singular: 'buzzes' --> 'buzz'};
is noun(q{buzz})->singular,   q{buzz}  => q{singular: 'buzz' --> 'buzz'};
is noun(q{caribou})->singular, q{caribou}  => q{singular: 'caribou' --> 'caribou'};
is noun(q{mangoes})->singular, q{mango}  => q{singular: 'mangoes' --> 'mango'};
is noun(q{mango})->singular,   q{mango}  => q{singular: 'mango' --> 'mango'};
is noun(q{brachiopods})->singular, q{brachiopod}  => q{singular: 'brachiopods' --> 'brachiopod'};
is noun(q{brachiopod})->singular,   q{brachiopod}  => q{singular: 'brachiopod' --> 'brachiopod'};
is noun(q{edemata})->singular, q{edema}  => q{singular: 'edemata' --> 'edema'};
is noun(q{edema})->singular,   q{edema}  => q{singular: 'edema' --> 'edema'};
is noun(q{stelae})->singular, q{stela}  => q{singular: 'stelae' --> 'stela'};
is noun(q{stela})->singular,   q{stela}  => q{singular: 'stela' --> 'stela'};
is noun(q{measles})->singular, q{measles}  => q{singular: 'measles' --> 'measles'};
is noun(q{sympodia})->singular, q{sympodium}  => q{singular: 'sympodia' --> 'sympodium'};
is noun(q{sympodium})->singular,   q{sympodium}  => q{singular: 'sympodium' --> 'sympodium'};
is noun(q{mouths})->singular, q{mouth}  => q{singular: 'mouths' --> 'mouth'};
is noun(q{mouth})->singular,   q{mouth}  => q{singular: 'mouth' --> 'mouth'};
is noun(q{messe di voce})->singular, q{messa di voce}  => q{singular: 'messe di voce' --> 'messa di voce'};
is noun(q{messa di voce})->singular,   q{messa di voce}  => q{singular: 'messa di voce' --> 'messa di voce'};
is noun(q{alani})->singular, q{alan}  => q{singular: 'alani' --> 'alan'};
is noun(q{alan})->singular,   q{alan}  => q{singular: 'alan' --> 'alan'};
is noun(q{embryomata})->singular, q{embryoma}  => q{singular: 'embryomata' --> 'embryoma'};
is noun(q{embryoma})->singular,   q{embryoma}  => q{singular: 'embryoma' --> 'embryoma'};
is noun(q{tholoi})->singular, q{tholos}  => q{singular: 'tholoi' --> 'tholos'};
is noun(q{tholos})->singular,   q{tholos}  => q{singular: 'tholos' --> 'tholos'};
is noun(q{prospectuses})->singular, q{prospectus}  => q{singular: 'prospectuses' --> 'prospectus'};
is noun(q{desmata})->singular, q{desma}  => q{singular: 'desmata' --> 'desma'};
is noun(q{desma})->singular,   q{desma}  => q{singular: 'desma' --> 'desma'};
is noun(q{poises})->singular, q{poise}  => q{singular: 'poises' --> 'poise'};
is noun(q{cremasters})->singular, q{cremaster}  => q{singular: 'cremasters' --> 'cremaster'};
is noun(q{cremaster})->singular,   q{cremaster}  => q{singular: 'cremaster' --> 'cremaster'};
is noun(q{dicta})->singular, q{dictum}  => q{singular: 'dicta' --> 'dictum'};
is noun(q{dictum})->singular,   q{dictum}  => q{singular: 'dictum' --> 'dictum'};
is noun(q{figurantes})->singular, q{figurante}  => q{singular: 'figurantes' --> 'figurante'};
is noun(q{figurante})->singular,   q{figurante}  => q{singular: 'figurante' --> 'figurante'};
is noun(q{favissae})->singular, q{favissa}  => q{singular: 'favissae' --> 'favissa'};
is noun(q{favissa})->singular,   q{favissa}  => q{singular: 'favissa' --> 'favissa'};
is noun(q{rhopalia})->singular, q{rhopalium}  => q{singular: 'rhopalia' --> 'rhopalium'};
is noun(q{rhopalium})->singular,   q{rhopalium}  => q{singular: 'rhopalium' --> 'rhopalium'};
is noun(q{serpigoes})->singular, q{serpigo}  => q{singular: 'serpigoes' --> 'serpigo'};
is noun(q{serpigo})->singular,   q{serpigo}  => q{singular: 'serpigo' --> 'serpigo'};
is noun(q{strumae})->singular, q{struma}  => q{singular: 'strumae' --> 'struma'};
is noun(q{struma})->singular,   q{struma}  => q{singular: 'struma' --> 'struma'};
is noun(q{parnassim})->singular, q{parnas}  => q{singular: 'parnassim' --> 'parnas'};
is noun(q{parnas})->singular,   q{parnas}  => q{singular: 'parnas' --> 'parnas'};
is noun(q{Idahos})->singular, q{Idaho}  => q{singular: 'Idahos' --> 'Idaho'};
is noun(q{Idaho})->singular,   q{Idaho}  => q{singular: 'Idaho' --> 'Idaho'};
is noun(q{politbureaus})->singular, q{politbureau}  => q{singular: 'politbureaus' --> 'politbureau'};
is noun(q{politbureau})->singular,   q{politbureau}  => q{singular: 'politbureau' --> 'politbureau'};
is noun(q{lingos})->singular, q{lingo}  => q{singular: 'lingos' --> 'lingo'};
is noun(q{lingo})->singular,   q{lingo}  => q{singular: 'lingo' --> 'lingo'};
is noun(q{contrafacta})->singular, q{contrafactum}  => q{singular: 'contrafacta' --> 'contrafactum'};
is noun(q{contrafactum})->singular,   q{contrafactum}  => q{singular: 'contrafactum' --> 'contrafactum'};
is noun(q{gladioli})->singular, q{gladiolus}  => q{singular: 'gladioli' --> 'gladiolus'};
is noun(q{gladiolus})->singular,   q{gladiolus}  => q{singular: 'gladiolus' --> 'gladiolus'};
is noun(q{beau gestes})->singular, q{beau geste}  => q{singular: 'beau gestes' --> 'beau geste'};
is noun(q{beau geste})->singular,   q{beau geste}  => q{singular: 'beau geste' --> 'beau geste'};
is noun(q{claustra})->singular, q{claustrum}  => q{singular: 'claustra' --> 'claustrum'};
is noun(q{claustrum})->singular,   q{claustrum}  => q{singular: 'claustrum' --> 'claustrum'};
is noun(q{scuole})->singular, q{scuola}  => q{singular: 'scuole' --> 'scuola'};
is noun(q{scuola})->singular,   q{scuola}  => q{singular: 'scuola' --> 'scuola'};
is noun(q{alumnae})->singular, q{alumna}  => q{singular: 'alumnae' --> 'alumna'};
is noun(q{alumna})->singular,   q{alumna}  => q{singular: 'alumna' --> 'alumna'};
is noun(q{stomodea})->singular, q{stomodaeum}  => q{singular: 'stomodea' --> 'stomodaeum'};
is noun(q{stomodaeum})->singular,   q{stomodaeum}  => q{singular: 'stomodaeum' --> 'stomodaeum'};
is noun(q{pyrexiae})->singular, q{pyrexia}  => q{singular: 'pyrexiae' --> 'pyrexia'};
is noun(q{pyrexia})->singular,   q{pyrexia}  => q{singular: 'pyrexia' --> 'pyrexia'};
is noun(q{faits accomplis})->singular, q{fait accompli}  => q{singular: 'faits accomplis' --> 'fait accompli'};
is noun(q{fait accompli})->singular,   q{fait accompli}  => q{singular: 'fait accompli' --> 'fait accompli'};
is noun(q{vaporetti})->singular, q{vaporetto}  => q{singular: 'vaporetti' --> 'vaporetto'};
is noun(q{vaporetto})->singular,   q{vaporetto}  => q{singular: 'vaporetto' --> 'vaporetto'};
is noun(q{asyla})->singular, q{asylum}  => q{singular: 'asyla' --> 'asylum'};
is noun(q{asylum})->singular,   q{asylum}  => q{singular: 'asylum' --> 'asylum'};
is noun(q{limos})->singular, q{limo}  => q{singular: 'limos' --> 'limo'};
is noun(q{limo})->singular,   q{limo}  => q{singular: 'limo' --> 'limo'};
is noun(q{ibises})->singular, q{ibis}  => q{singular: 'ibises' --> 'ibis'};
is noun(q{ibis})->singular,   q{ibis}  => q{singular: 'ibis' --> 'ibis'};
is noun(q{siemens})->singular, q{siemens}  => q{singular: 'siemens' --> 'siemens'};
is noun(q{diplomata})->singular, q{diploma}  => q{singular: 'diplomata' --> 'diploma'};
is noun(q{diploma})->singular,   q{diploma}  => q{singular: 'diploma' --> 'diploma'};
is noun(q{Panamans})->singular, q{Panaman}  => q{singular: 'Panamans' --> 'Panaman'};
is noun(q{Panaman})->singular,   q{Panaman}  => q{singular: 'Panaman' --> 'Panaman'};
is noun(q{otomies})->singular, q{otomi}  => q{singular: 'otomies' --> 'otomi'};
is noun(q{haemangiomata})->singular, q{haemangioma}  => q{singular: 'haemangiomata' --> 'haemangioma'};
is noun(q{haemangioma})->singular,   q{haemangioma}  => q{singular: 'haemangioma' --> 'haemangioma'};
is noun(q{Buginese})->singular, q{Buginese}  => q{singular: 'Buginese' --> 'Buginese'};
is noun(q{guardias civiles})->singular, q{guardia civil}  => q{singular: 'guardias civiles' --> 'guardia civil'};
is noun(q{guardia civil})->singular,   q{guardia civil}  => q{singular: 'guardia civil' --> 'guardia civil'};
is noun(q{dice})->singular, q{die}  => q{singular: 'dice' --> 'die'};
is noun(q{die})->singular,   q{die}  => q{singular: 'die' --> 'die'};
is noun(q{polises})->singular, q{polis}  => q{singular: 'polises' --> 'polis'};
is noun(q{polis})->singular,   q{polis}  => q{singular: 'polis' --> 'polis'};
is noun(q{corni})->singular, q{corno}  => q{singular: 'corni' --> 'corno'};
is noun(q{corno})->singular,   q{corno}  => q{singular: 'corno' --> 'corno'};
is noun(q{placita})->singular, q{placitum}  => q{singular: 'placita' --> 'placitum'};
is noun(q{placitum})->singular,   q{placitum}  => q{singular: 'placitum' --> 'placitum'};
is noun(q{cactuses})->singular, q{cactus}  => q{singular: 'cactuses' --> 'cactus'};
is noun(q{cactus})->singular,   q{cactus}  => q{singular: 'cactus' --> 'cactus'};
is noun(q{proboscides})->singular, q{proboscis}  => q{singular: 'proboscides' --> 'proboscis'};
is noun(q{proboscis})->singular,   q{proboscis}  => q{singular: 'proboscis' --> 'proboscis'};
is noun(q{inhalatoria})->singular, q{inhalatorium}  => q{singular: 'inhalatoria' --> 'inhalatorium'};
is noun(q{inhalatorium})->singular,   q{inhalatorium}  => q{singular: 'inhalatorium' --> 'inhalatorium'};
is noun(q{pyxidia})->singular, q{pyxidium}  => q{singular: 'pyxidia' --> 'pyxidium'};
is noun(q{pyxidium})->singular,   q{pyxidium}  => q{singular: 'pyxidium' --> 'pyxidium'};
is noun(q{caryopsides})->singular, q{caryopsis}  => q{singular: 'caryopsides' --> 'caryopsis'};
is noun(q{caryopsis})->singular,   q{caryopsis}  => q{singular: 'caryopsis' --> 'caryopsis'};
is noun(q{rejoneadores})->singular, q{rejoneador}  => q{singular: 'rejoneadores' --> 'rejoneador'};
is noun(q{rejoneador})->singular,   q{rejoneador}  => q{singular: 'rejoneador' --> 'rejoneador'};
is noun(q{Milanos})->singular, q{Milano}  => q{singular: 'Milanos' --> 'Milano'};
is noun(q{Milano})->singular,   q{Milano}  => q{singular: 'Milano' --> 'Milano'};
is noun(q{versiculi})->singular, q{versiculus}  => q{singular: 'versiculi' --> 'versiculus'};
is noun(q{versiculus})->singular,   q{versiculus}  => q{singular: 'versiculus' --> 'versiculus'};
is noun(q{fanfoots})->singular, q{fanfoot}  => q{singular: 'fanfoots' --> 'fanfoot'};
is noun(q{fanfoot})->singular,   q{fanfoot}  => q{singular: 'fanfoot' --> 'fanfoot'};
is noun(q{ours})->singular, q{mine}  => q{singular: 'ours' --> 'mine'};
is noun(q{mine})->singular,   q{mine}  => q{singular: 'mine' --> 'mine'};
is noun(q{patagia})->singular, q{patagium}  => q{singular: 'patagia' --> 'patagium'};
is noun(q{patagium})->singular,   q{patagium}  => q{singular: 'patagium' --> 'patagium'};
is noun(q{vibices})->singular, q{vibex}  => q{singular: 'vibices' --> 'vibex'};
is noun(q{vibex})->singular,   q{vibex}  => q{singular: 'vibex' --> 'vibex'};
is noun(q{shiftas})->singular, q{shifta}  => q{singular: 'shiftas' --> 'shifta'};
is noun(q{merides})->singular, q{meris}  => q{singular: 'merides' --> 'meris'};
is noun(q{meris})->singular,   q{meris}  => q{singular: 'meris' --> 'meris'};
is noun(q{tsuba})->singular, q{tsuba}  => q{singular: 'tsuba' --> 'tsuba'};
is noun(q{mausolea})->singular, q{mausoleum}  => q{singular: 'mausolea' --> 'mausoleum'};
is noun(q{mausoleum})->singular,   q{mausoleum}  => q{singular: 'mausoleum' --> 'mausoleum'};
is noun(q{brethren})->singular, q{brother}  => q{singular: 'brethren' --> 'brother'};
is noun(q{brother})->singular,   q{brother}  => q{singular: 'brother' --> 'brother'};
is noun(q{brothers german})->singular, q{brother german}  => q{singular: 'brothers german' --> 'brother german'};
is noun(q{brother german})->singular,   q{brother german}  => q{singular: 'brother german' --> 'brother german'};
is noun(q{culs-de-four})->singular, q{cul-de-four}  => q{singular: 'culs-de-four' --> 'cul-de-four'};
is noun(q{cul-de-four})->singular,   q{cul-de-four}  => q{singular: 'cul-de-four' --> 'cul-de-four'};
is noun(q{rezidenty})->singular, q{rezident}  => q{singular: 'rezidenty' --> 'rezident'};
is noun(q{rezident})->singular,   q{rezident}  => q{singular: 'rezident' --> 'rezident'};
is noun(q{prorae})->singular, q{prora}  => q{singular: 'prorae' --> 'prora'};
is noun(q{prora})->singular,   q{prora}  => q{singular: 'prora' --> 'prora'};
is noun(q{xanthomas})->singular, q{xanthoma}  => q{singular: 'xanthomas' --> 'xanthoma'};
is noun(q{xanthoma})->singular,   q{xanthoma}  => q{singular: 'xanthoma' --> 'xanthoma'};
is noun(q{sagos})->singular, q{sago}  => q{singular: 'sagos' --> 'sago'};
is noun(q{sago})->singular,   q{sago}  => q{singular: 'sago' --> 'sago'};
is noun(q{villanelle})->singular, q{villanella}  => q{singular: 'villanelle' --> 'villanella'};
is noun(q{villanella})->singular,   q{villanella}  => q{singular: 'villanella' --> 'villanella'};
is noun(q{Assamese})->singular, q{Assamese}  => q{singular: 'Assamese' --> 'Assamese'};
is noun(q{piscinas})->singular, q{piscina}  => q{singular: 'piscinas' --> 'piscina'};
is noun(q{piscina})->singular,   q{piscina}  => q{singular: 'piscina' --> 'piscina'};
is noun(q{acroamata})->singular, q{acroama}  => q{singular: 'acroamata' --> 'acroama'};
is noun(q{acroama})->singular,   q{acroama}  => q{singular: 'acroama' --> 'acroama'};
is noun(q{four star generals})->singular, q{four star general}  => q{singular: 'four star generals' --> 'four star general'};
is noun(q{four star general})->singular,   q{four star general}  => q{singular: 'four star general' --> 'four star general'};
is noun(q{grouses})->singular, q{grouse}  => q{singular: 'grouses' --> 'grouse'};
is noun(q{ustilagines})->singular, q{ustilago}  => q{singular: 'ustilagines' --> 'ustilago'};
is noun(q{ustilago})->singular,   q{ustilago}  => q{singular: 'ustilago' --> 'ustilago'};
is noun(q{tetanother})->singular, q{tetanothrum}  => q{singular: 'tetanother' --> 'tetanothrum'};
is noun(q{tetanothrum})->singular,   q{tetanothrum}  => q{singular: 'tetanothrum' --> 'tetanothrum'};
is noun(q{Chinese})->singular, q{Chinese}  => q{singular: 'Chinese' --> 'Chinese'};
is noun(q{thanatoria})->singular, q{thanatorium}  => q{singular: 'thanatoria' --> 'thanatorium'};
is noun(q{thanatorium})->singular,   q{thanatorium}  => q{singular: 'thanatorium' --> 'thanatorium'};
is noun(q{tazze})->singular, q{tazza}  => q{singular: 'tazze' --> 'tazza'};
is noun(q{tazza})->singular,   q{tazza}  => q{singular: 'tazza' --> 'tazza'};
is noun(q{abacuses})->singular, q{abacus}  => q{singular: 'abacuses' --> 'abacus'};
is noun(q{abacus})->singular,   q{abacus}  => q{singular: 'abacus' --> 'abacus'};
is noun(q{ostia})->singular, q{ostium}  => q{singular: 'ostia' --> 'ostium'};
is noun(q{ostium})->singular,   q{ostium}  => q{singular: 'ostium' --> 'ostium'};
is noun(q{spondyli})->singular, q{spondylus}  => q{singular: 'spondyli' --> 'spondylus'};
is noun(q{spondylus})->singular,   q{spondylus}  => q{singular: 'spondylus' --> 'spondylus'};
is noun(q{peridia})->singular, q{peridium}  => q{singular: 'peridia' --> 'peridium'};
is noun(q{peridium})->singular,   q{peridium}  => q{singular: 'peridium' --> 'peridium'};
is noun(q{court-martials})->singular, q{court martial}  => q{singular: 'court-martials' --> 'court martial'};
is noun(q{court martial})->singular,   q{court martial}  => q{singular: 'court martial' --> 'court martial'};
is noun(q{autochthones})->singular, q{autochthon}  => q{singular: 'autochthones' --> 'autochthon'};
is noun(q{autochthon})->singular,   q{autochthon}  => q{singular: 'autochthon' --> 'autochthon'};
is noun(q{macros})->singular, q{macro}  => q{singular: 'macros' --> 'macro'};
is noun(q{macro})->singular,   q{macro}  => q{singular: 'macro' --> 'macro'};
is noun(q{flocculi})->singular, q{flocculus}  => q{singular: 'flocculi' --> 'flocculus'};
is noun(q{flocculus})->singular,   q{flocculus}  => q{singular: 'flocculus' --> 'flocculus'};
is noun(q{Genevese})->singular, q{Genevese}  => q{singular: 'Genevese' --> 'Genevese'};
is noun(q{neritas})->singular, q{nerita}  => q{singular: 'neritas' --> 'nerita'};
is noun(q{nerita})->singular,   q{nerita}  => q{singular: 'nerita' --> 'nerita'};
is noun(q{gummata})->singular, q{gumma}  => q{singular: 'gummata' --> 'gumma'};
is noun(q{gumma})->singular,   q{gumma}  => q{singular: 'gumma' --> 'gumma'};
is noun(q{cherubim})->singular, q{cherub}  => q{singular: 'cherubim' --> 'cherub'};
is noun(q{cherub})->singular,   q{cherub}  => q{singular: 'cherub' --> 'cherub'};
is noun(q{gravamina})->singular, q{gravamen}  => q{singular: 'gravamina' --> 'gravamen'};
is noun(q{gravamen})->singular,   q{gravamen}  => q{singular: 'gravamen' --> 'gravamen'};
is noun(q{radialia})->singular, q{radiale}  => q{singular: 'radialia' --> 'radiale'};
is noun(q{radiale})->singular,   q{radiale}  => q{singular: 'radiale' --> 'radiale'};
is noun(q{epiphenomena})->singular, q{epiphenomenon}  => q{singular: 'epiphenomena' --> 'epiphenomenon'};
is noun(q{epiphenomenon})->singular,   q{epiphenomenon}  => q{singular: 'epiphenomenon' --> 'epiphenomenon'};
is noun(q{lenses})->singular, q{lens}  => q{singular: 'lenses' --> 'lens'};
is noun(q{lens})->singular,   q{lens}  => q{singular: 'lens' --> 'lens'};
is noun(q{metalimnia})->singular, q{metalimnion}  => q{singular: 'metalimnia' --> 'metalimnion'};
is noun(q{metalimnion})->singular,   q{metalimnion}  => q{singular: 'metalimnion' --> 'metalimnion'};
is noun(q{velaria})->singular, q{velarium}  => q{singular: 'velaria' --> 'velarium'};
is noun(q{velarium})->singular,   q{velarium}  => q{singular: 'velarium' --> 'velarium'};
is noun(q{rubashkas})->singular, q{rubashka}  => q{singular: 'rubashkas' --> 'rubashka'};
is noun(q{rubashka})->singular,   q{rubashka}  => q{singular: 'rubashka' --> 'rubashka'};
is noun(q{sacraria})->singular, q{sacrarium}  => q{singular: 'sacraria' --> 'sacrarium'};
is noun(q{sacrarium})->singular,   q{sacrarium}  => q{singular: 'sacrarium' --> 'sacrarium'};
is noun(q{quaesita})->singular, q{quaesitum}  => q{singular: 'quaesita' --> 'quaesitum'};
is noun(q{quaesitum})->singular,   q{quaesitum}  => q{singular: 'quaesitum' --> 'quaesitum'};
is noun(q{aboiteaus})->singular, q{aboiteau}  => q{singular: 'aboiteaus' --> 'aboiteau'};
is noun(q{aboiteau})->singular,   q{aboiteau}  => q{singular: 'aboiteau' --> 'aboiteau'};
is noun(q{vehicula})->singular, q{vehiculum}  => q{singular: 'vehicula' --> 'vehiculum'};
is noun(q{vehiculum})->singular,   q{vehiculum}  => q{singular: 'vehiculum' --> 'vehiculum'};
is noun(q{people})->singular, q{person}  => q{singular: 'people' --> 'person'};
is noun(q{person})->singular,   q{person}  => q{singular: 'person' --> 'person'};
is noun(q{frustums})->singular, q{frustum}  => q{singular: 'frustums' --> 'frustum'};
is noun(q{frustum})->singular,   q{frustum}  => q{singular: 'frustum' --> 'frustum'};
is noun(q{cod})->singular, q{cod}  => q{singular: 'cod' --> 'cod'};
is noun(q{starfishes})->singular, q{starfish}  => q{singular: 'starfishes' --> 'starfish'};
is noun(q{thyrsi})->singular, q{thyrsus}  => q{singular: 'thyrsi' --> 'thyrsus'};
is noun(q{thyrsus})->singular,   q{thyrsus}  => q{singular: 'thyrsus' --> 'thyrsus'};
is noun(q{agapes})->singular, q{agape}  => q{singular: 'agapes' --> 'agape'};
is noun(q{agape})->singular,   q{agape}  => q{singular: 'agape' --> 'agape'};
is noun(q{postnati})->singular, q{postnatus}  => q{singular: 'postnati' --> 'postnatus'};
is noun(q{postnatus})->singular,   q{postnatus}  => q{singular: 'postnatus' --> 'postnatus'};
is noun(q{trochuses})->singular, q{trochus}  => q{singular: 'trochuses' --> 'trochus'};
is noun(q{trochus})->singular,   q{trochus}  => q{singular: 'trochus' --> 'trochus'};
is noun(q{schemata})->singular, q{schema}  => q{singular: 'schemata' --> 'schema'};
is noun(q{schema})->singular,   q{schema}  => q{singular: 'schema' --> 'schema'};
is noun(q{craft})->singular, q{craft}  => q{singular: 'craft' --> 'craft'};
is noun(q{tragi})->singular, q{tragus}  => q{singular: 'tragi' --> 'tragus'};
is noun(q{tragus})->singular,   q{tragus}  => q{singular: 'tragus' --> 'tragus'};
is noun(q{flocci})->singular, q{floccus}  => q{singular: 'flocci' --> 'floccus'};
is noun(q{floccus})->singular,   q{floccus}  => q{singular: 'floccus' --> 'floccus'};
is noun(q{mondi})->singular, q{mondo}  => q{singular: 'mondi' --> 'mondo'};
is noun(q{mondo})->singular,   q{mondo}  => q{singular: 'mondo' --> 'mondo'};
is noun(q{pifferari})->singular, q{pifferaro}  => q{singular: 'pifferari' --> 'pifferaro'};
is noun(q{pifferaro})->singular,   q{pifferaro}  => q{singular: 'pifferaro' --> 'pifferaro'};
is noun(q{palae})->singular, q{pala}  => q{singular: 'palae' --> 'pala'};
is noun(q{pala})->singular,   q{pala}  => q{singular: 'pala' --> 'pala'};
is noun(q{tesserae})->singular, q{tessera}  => q{singular: 'tesserae' --> 'tessera'};
is noun(q{tessera})->singular,   q{tessera}  => q{singular: 'tessera' --> 'tessera'};
is noun(q{momenta})->singular, q{momentum}  => q{singular: 'momenta' --> 'momentum'};
is noun(q{momentum})->singular,   q{momentum}  => q{singular: 'momentum' --> 'momentum'};
is noun(q{styluses})->singular, q{stylus}  => q{singular: 'styluses' --> 'stylus'};
is noun(q{stylus})->singular,   q{stylus}  => q{singular: 'stylus' --> 'stylus'};
is noun(q{ambos})->singular, q{ambo}  => q{singular: 'ambos' --> 'ambo'};
is noun(q{ambo})->singular,   q{ambo}  => q{singular: 'ambo' --> 'ambo'};
is noun(q{flounder})->singular, q{flounder}  => q{singular: 'flounder' --> 'flounder'};
is noun(q{vacuums})->singular, q{vacuum}  => q{singular: 'vacuums' --> 'vacuum'};
is noun(q{vacuum})->singular,   q{vacuum}  => q{singular: 'vacuum' --> 'vacuum'};
is noun(q{Siluri})->singular, q{Silurus}  => q{singular: 'Siluri' --> 'Silurus'};
is noun(q{Silurus})->singular,   q{Silurus}  => q{singular: 'Silurus' --> 'Silurus'};
is noun(q{judicata})->singular, q{judicatum}  => q{singular: 'judicata' --> 'judicatum'};
is noun(q{judicatum})->singular,   q{judicatum}  => q{singular: 'judicatum' --> 'judicatum'};
is noun(q{herpes})->singular, q{herpes}  => q{singular: 'herpes' --> 'herpes'};
is noun(q{herren})->singular, q{herr}  => q{singular: 'herren' --> 'herr'};
is noun(q{herr})->singular,   q{herr}  => q{singular: 'herr' --> 'herr'};
is noun(q{succi})->singular, q{succus}  => q{singular: 'succi' --> 'succus'};
is noun(q{succus})->singular,   q{succus}  => q{singular: 'succus' --> 'succus'};
is noun(q{puntos blancos})->singular, q{punto blanco}  => q{singular: 'puntos blancos' --> 'punto blanco'};
is noun(q{punto blanco})->singular,   q{punto blanco}  => q{singular: 'punto blanco' --> 'punto blanco'};
is noun(q{graben})->singular, q{graben}  => q{singular: 'graben' --> 'graben'};
is noun(q{juntos})->singular, q{junto}  => q{singular: 'juntos' --> 'junto'};
is noun(q{junto})->singular,   q{junto}  => q{singular: 'junto' --> 'junto'};
is noun(q{semas})->singular, q{sema}  => q{singular: 'semas' --> 'sema'};
is noun(q{sema})->singular,   q{sema}  => q{singular: 'sema' --> 'sema'};
is noun(q{shads})->singular, q{shad}  => q{singular: 'shads' --> 'shad'};
is noun(q{Kiplingese})->singular, q{Kiplingese}  => q{singular: 'Kiplingese' --> 'Kiplingese'};
is noun(q{eucalyptuses})->singular, q{eucalyptus}  => q{singular: 'eucalyptuses' --> 'eucalyptus'};
is noun(q{eucalyptus})->singular,   q{eucalyptus}  => q{singular: 'eucalyptus' --> 'eucalyptus'};
is noun(q{mallei})->singular, q{malleus}  => q{singular: 'mallei' --> 'malleus'};
is noun(q{malleus})->singular,   q{malleus}  => q{singular: 'malleus' --> 'malleus'};
is noun(q{tuna})->singular, q{tuna}  => q{singular: 'tuna' --> 'tuna'};
is noun(q{peronia})->singular, q{peronium}  => q{singular: 'peronia' --> 'peronium'};
is noun(q{peronium})->singular,   q{peronium}  => q{singular: 'peronium' --> 'peronium'};
is noun(q{sternums})->singular, q{sternum}  => q{singular: 'sternums' --> 'sternum'};
is noun(q{sternum})->singular,   q{sternum}  => q{singular: 'sternum' --> 'sternum'};
is noun(q{pinones})->singular, q{pinon}  => q{singular: 'pinones' --> 'pinon'};
is noun(q{pinon})->singular,   q{pinon}  => q{singular: 'pinon' --> 'pinon'};
is noun(q{vedute})->singular, q{veduta}  => q{singular: 'vedute' --> 'veduta'};
is noun(q{veduta})->singular,   q{veduta}  => q{singular: 'veduta' --> 'veduta'};
is noun(q{pangasinanes})->singular, q{pangasinan}  => q{singular: 'pangasinanes' --> 'pangasinan'};
is noun(q{pangasinan})->singular,   q{pangasinan}  => q{singular: 'pangasinan' --> 'pangasinan'};
is noun(q{5 star generals})->singular, q{5 star general}  => q{singular: '5 star generals' --> '5 star general'};
is noun(q{5 star general})->singular,   q{5 star general}  => q{singular: '5 star general' --> '5 star general'};
is noun(q{itinera})->singular, q{iter}  => q{singular: 'itinera' --> 'iter'};
is noun(q{iter})->singular,   q{iter}  => q{singular: 'iter' --> 'iter'};
is noun(q{murexes})->singular, q{murex}  => q{singular: 'murexes' --> 'murex'};
is noun(q{murex})->singular,   q{murex}  => q{singular: 'murex' --> 'murex'};
is noun(q{sombreros})->singular, q{sombrero}  => q{singular: 'sombreros' --> 'sombrero'};
is noun(q{sombrero})->singular,   q{sombrero}  => q{singular: 'sombrero' --> 'sombrero'};
is noun(q{situlae})->singular, q{situla}  => q{singular: 'situlae' --> 'situla'};
is noun(q{situla})->singular,   q{situla}  => q{singular: 'situla' --> 'situla'};
is noun(q{Camaldolese})->singular, q{Camaldolese}  => q{singular: 'Camaldolese' --> 'Camaldolese'};
is noun(q{stigmata})->singular, q{stigma}  => q{singular: 'stigmata' --> 'stigma'};
is noun(q{stigma})->singular,   q{stigma}  => q{singular: 'stigma' --> 'stigma'};
is noun(q{viatica})->singular, q{viaticum}  => q{singular: 'viatica' --> 'viaticum'};
is noun(q{viaticum})->singular,   q{viaticum}  => q{singular: 'viaticum' --> 'viaticum'};
is noun(q{personas})->singular, q{persona}  => q{singular: 'personas' --> 'persona'};
is noun(q{persona})->singular,   q{persona}  => q{singular: 'persona' --> 'persona'};
is noun(q{provisos})->singular, q{proviso}  => q{singular: 'provisos' --> 'proviso'};
is noun(q{proviso})->singular,   q{proviso}  => q{singular: 'proviso' --> 'proviso'};
is noun(q{secundagravidae})->singular, q{secundagravida}  => q{singular: 'secundagravidae' --> 'secundagravida'};
is noun(q{secundagravida})->singular,   q{secundagravida}  => q{singular: 'secundagravida' --> 'secundagravida'};
is noun(q{zeitgebers})->singular, q{zeitgeber}  => q{singular: 'zeitgebers' --> 'zeitgeber'};
is noun(q{zeitgeber})->singular,   q{zeitgeber}  => q{singular: 'zeitgeber' --> 'zeitgeber'};
is noun(q{caveae})->singular, q{cavea}  => q{singular: 'caveae' --> 'cavea'};
is noun(q{cavea})->singular,   q{cavea}  => q{singular: 'cavea' --> 'cavea'};
is noun(q{axones})->singular, q{axon}  => q{singular: 'axones' --> 'axon'};
is noun(q{axon})->singular,   q{axon}  => q{singular: 'axon' --> 'axon'};
is noun(q{gallows})->singular, q{gallows}  => q{singular: 'gallows' --> 'gallows'};
is noun(q{coagula})->singular, q{coagulum}  => q{singular: 'coagula' --> 'coagulum'};
is noun(q{coagulum})->singular,   q{coagulum}  => q{singular: 'coagulum' --> 'coagulum'};
is noun(q{progymnasmata})->singular, q{progymnasma}  => q{singular: 'progymnasmata' --> 'progymnasma'};
is noun(q{progymnasma})->singular,   q{progymnasma}  => q{singular: 'progymnasma' --> 'progymnasma'};
is noun(q{rabies})->singular, q{rabies}  => q{singular: 'rabies' --> 'rabies'};
is noun(q{tempos})->singular, q{tempo}  => q{singular: 'tempos' --> 'tempo'};
is noun(q{tempo})->singular,   q{tempo}  => q{singular: 'tempo' --> 'tempo'};
is noun(q{lustrums})->singular, q{lustrum}  => q{singular: 'lustrums' --> 'lustrum'};
is noun(q{lustrum})->singular,   q{lustrum}  => q{singular: 'lustrum' --> 'lustrum'};
is noun(q{concerti grossi})->singular, q{concerto grosso}  => q{singular: 'concerti grossi' --> 'concerto grosso'};
is noun(q{concerto grosso})->singular,   q{concerto grosso}  => q{singular: 'concerto grosso' --> 'concerto grosso'};
is noun(q{stadiums})->singular, q{stadium}  => q{singular: 'stadiums' --> 'stadium'};
is noun(q{stadium})->singular,   q{stadium}  => q{singular: 'stadium' --> 'stadium'};
is noun(q{squali})->singular, q{squalus}  => q{singular: 'squali' --> 'squalus'};
is noun(q{squalus})->singular,   q{squalus}  => q{singular: 'squalus' --> 'squalus'};
is noun(q{uniones})->singular, q{unio}  => q{singular: 'uniones' --> 'unio'};
is noun(q{unio})->singular,   q{unio}  => q{singular: 'unio' --> 'unio'};
is noun(q{vaporettos})->singular, q{vaporetto}  => q{singular: 'vaporettos' --> 'vaporetto'};
is noun(q{vaporetto})->singular,   q{vaporetto}  => q{singular: 'vaporetto' --> 'vaporetto'};
is noun(q{vascula})->singular, q{vasculum}  => q{singular: 'vascula' --> 'vasculum'};
is noun(q{vasculum})->singular,   q{vasculum}  => q{singular: 'vasculum' --> 'vasculum'};
is noun(q{ballistae})->singular, q{ballista}  => q{singular: 'ballistae' --> 'ballista'};
is noun(q{ballista})->singular,   q{ballista}  => q{singular: 'ballista' --> 'ballista'};
is noun(q{naye paise})->singular, q{naya paisa}  => q{singular: 'naye paise' --> 'naya paisa'};
is noun(q{naya paisa})->singular,   q{naya paisa}  => q{singular: 'naya paisa' --> 'naya paisa'};
is noun(q{ziti})->singular, q{zita}  => q{singular: 'ziti' --> 'zita'};
is noun(q{zita})->singular,   q{zita}  => q{singular: 'zita' --> 'zita'};
is noun(q{man milliners})->singular, q{man milliner}  => q{singular: 'man milliners' --> 'man milliner'};
is noun(q{man milliner})->singular,   q{man milliner}  => q{singular: 'man milliner' --> 'man milliner'};
is noun(q{toreros})->singular, q{torero}  => q{singular: 'toreros' --> 'torero'};
is noun(q{torero})->singular,   q{torero}  => q{singular: 'torero' --> 'torero'};
is noun(q{comae})->singular, q{coma}  => q{singular: 'comae' --> 'coma'};
is noun(q{coma})->singular,   q{coma}  => q{singular: 'coma' --> 'coma'};
is noun(q{cortexes})->singular, q{cortex}  => q{singular: 'cortexes' --> 'cortex'};
is noun(q{cortex})->singular,   q{cortex}  => q{singular: 'cortex' --> 'cortex'};
is noun(q{subbotniks})->singular, q{subbotnik}  => q{singular: 'subbotniks' --> 'subbotnik'};
is noun(q{subbotnik})->singular,   q{subbotnik}  => q{singular: 'subbotnik' --> 'subbotnik'};
is noun(q{Lebanese})->singular, q{Lebanese}  => q{singular: 'Lebanese' --> 'Lebanese'};
is noun(q{lumbrici})->singular, q{lumbricus}  => q{singular: 'lumbrici' --> 'lumbricus'};
is noun(q{lumbricus})->singular,   q{lumbricus}  => q{singular: 'lumbricus' --> 'lumbricus'};
is noun(q{asteriae})->singular, q{asterias}  => q{singular: 'asteriae' --> 'asterias'};
is noun(q{asterias})->singular,   q{asterias}  => q{singular: 'asterias' --> 'asterias'};
is noun(q{magmas})->singular, q{magma}  => q{singular: 'magmas' --> 'magma'};
is noun(q{magma})->singular,   q{magma}  => q{singular: 'magma' --> 'magma'};
is noun(q{pobladores})->singular, q{poblador}  => q{singular: 'pobladores' --> 'poblador'};
is noun(q{poblador})->singular,   q{poblador}  => q{singular: 'poblador' --> 'poblador'};
is noun(q{multigravidae})->singular, q{multigravida}  => q{singular: 'multigravidae' --> 'multigravida'};
is noun(q{multigravida})->singular,   q{multigravida}  => q{singular: 'multigravida' --> 'multigravida'};
is noun(q{wildebeests})->singular, q{wildebeest}  => q{singular: 'wildebeests' --> 'wildebeest'};
is noun(q{millenniums})->singular, q{millennium}  => q{singular: 'millenniums' --> 'millennium'};
is noun(q{millennium})->singular,   q{millennium}  => q{singular: 'millennium' --> 'millennium'};
is noun(q{prytanes})->singular, q{prytanis}  => q{singular: 'prytanes' --> 'prytanis'};
is noun(q{prytanis})->singular,   q{prytanis}  => q{singular: 'prytanis' --> 'prytanis'};
is noun(q{virgae})->singular, q{virga}  => q{singular: 'virgae' --> 'virga'};
is noun(q{virga})->singular,   q{virga}  => q{singular: 'virga' --> 'virga'};
is noun(q{women-servants})->singular, q{woman-servant}  => q{singular: 'women-servants' --> 'woman-servant'};
is noun(q{woman-servant})->singular,   q{woman-servant}  => q{singular: 'woman-servant' --> 'woman-servant'};
is noun(q{cuniculi})->singular, q{cuniculus}  => q{singular: 'cuniculi' --> 'cuniculus'};
is noun(q{cuniculus})->singular,   q{cuniculus}  => q{singular: 'cuniculus' --> 'cuniculus'};
is noun(q{ambulacra})->singular, q{ambulacrum}  => q{singular: 'ambulacra' --> 'ambulacrum'};
is noun(q{ambulacrum})->singular,   q{ambulacrum}  => q{singular: 'ambulacrum' --> 'ambulacrum'};
is noun(q{pragmata})->singular, q{pragma}  => q{singular: 'pragmata' --> 'pragma'};
is noun(q{pragma})->singular,   q{pragma}  => q{singular: 'pragma' --> 'pragma'};
is noun(q{iters})->singular, q{iter}  => q{singular: 'iters' --> 'iter'};
is noun(q{iter})->singular,   q{iter}  => q{singular: 'iter' --> 'iter'};
is noun(q{cartes de visite})->singular, q{carte de visite}  => q{singular: 'cartes de visite' --> 'carte de visite'};
is noun(q{carte de visite})->singular,   q{carte de visite}  => q{singular: 'carte de visite' --> 'carte de visite'};
is noun(q{Colorados})->singular, q{Colorado}  => q{singular: 'Colorados' --> 'Colorado'};
is noun(q{Colorado})->singular,   q{Colorado}  => q{singular: 'Colorado' --> 'Colorado'};
is noun(q{who})->singular, q{who}  => q{singular: 'who' --> 'who'};
is noun(q{gonimia})->singular, q{gonimium}  => q{singular: 'gonimia' --> 'gonimium'};
is noun(q{gonimium})->singular,   q{gonimium}  => q{singular: 'gonimium' --> 'gonimium'};
is noun(q{speculums})->singular, q{speculum}  => q{singular: 'speculums' --> 'speculum'};
is noun(q{speculum})->singular,   q{speculum}  => q{singular: 'speculum' --> 'speculum'};
is noun(q{seecatchie})->singular, q{seecatch}  => q{singular: 'seecatchie' --> 'seecatch'};
is noun(q{seecatch})->singular,   q{seecatch}  => q{singular: 'seecatch' --> 'seecatch'};
is noun(q{salpae})->singular, q{salpa}  => q{singular: 'salpae' --> 'salpa'};
is noun(q{salpa})->singular,   q{salpa}  => q{singular: 'salpa' --> 'salpa'};
is noun(q{line-outs})->singular, q{line-out}  => q{singular: 'line-outs' --> 'line-out'};
is noun(q{line-out})->singular,   q{line-out}  => q{singular: 'line-out' --> 'line-out'};
is noun(q{placeboes})->singular, q{placebo}  => q{singular: 'placeboes' --> 'placebo'};
is noun(q{placebo})->singular,   q{placebo}  => q{singular: 'placebo' --> 'placebo'};
is noun(q{pyjamas})->singular, q{pyjamas}  => q{singular: 'pyjamas' --> 'pyjamas'};
is noun(q{virtuosos})->singular, q{virtuoso}  => q{singular: 'virtuosos' --> 'virtuoso'};
is noun(q{virtuoso})->singular,   q{virtuoso}  => q{singular: 'virtuoso' --> 'virtuoso'};
is noun(q{manubriums})->singular, q{manubrium}  => q{singular: 'manubriums' --> 'manubrium'};
is noun(q{manubrium})->singular,   q{manubrium}  => q{singular: 'manubrium' --> 'manubrium'};
is noun(q{malleoli})->singular, q{malleolus}  => q{singular: 'malleoli' --> 'malleolus'};
is noun(q{malleolus})->singular,   q{malleolus}  => q{singular: 'malleolus' --> 'malleolus'};
is noun(q{heroes})->singular, q{hero}  => q{singular: 'heroes' --> 'hero'};
is noun(q{hero})->singular,   q{hero}  => q{singular: 'hero' --> 'hero'};
is noun(q{romanzen})->singular, q{romanze}  => q{singular: 'romanzen' --> 'romanze'};
is noun(q{romanze})->singular,   q{romanze}  => q{singular: 'romanze' --> 'romanze'};
is noun(q{mesotheliomas})->singular, q{mesothelioma}  => q{singular: 'mesotheliomas' --> 'mesothelioma'};
is noun(q{mesothelioma})->singular,   q{mesothelioma}  => q{singular: 'mesothelioma' --> 'mesothelioma'};
is noun(q{corrigenda})->singular, q{corrigendum}  => q{singular: 'corrigenda' --> 'corrigendum'};
is noun(q{corrigendum})->singular,   q{corrigendum}  => q{singular: 'corrigendum' --> 'corrigendum'};
is noun(q{anti-serums})->singular, q{anti-serum}  => q{singular: 'anti-serums' --> 'anti-serum'};
is noun(q{anti-serum})->singular,   q{anti-serum}  => q{singular: 'anti-serum' --> 'anti-serum'};
is noun(q{urodea})->singular, q{urodeum}  => q{singular: 'urodea' --> 'urodeum'};
is noun(q{urodeum})->singular,   q{urodeum}  => q{singular: 'urodeum' --> 'urodeum'};
is noun(q{infernos})->singular, q{inferno}  => q{singular: 'infernos' --> 'inferno'};
is noun(q{inferno})->singular,   q{inferno}  => q{singular: 'inferno' --> 'inferno'};
is noun(q{oedemata})->singular, q{oedema}  => q{singular: 'oedemata' --> 'oedema'};
is noun(q{oedema})->singular,   q{oedema}  => q{singular: 'oedema' --> 'oedema'};
is noun(q{sarcomata})->singular, q{sarcoma}  => q{singular: 'sarcomata' --> 'sarcoma'};
is noun(q{sarcoma})->singular,   q{sarcoma}  => q{singular: 'sarcoma' --> 'sarcoma'};
is noun(q{phalluses})->singular, q{phallus}  => q{singular: 'phalluses' --> 'phallus'};
is noun(q{phallus})->singular,   q{phallus}  => q{singular: 'phallus' --> 'phallus'};
is noun(q{topoi})->singular, q{topos}  => q{singular: 'topoi' --> 'topos'};
is noun(q{topos})->singular,   q{topos}  => q{singular: 'topos' --> 'topos'};
is noun(q{menisci})->singular, q{meniscus}  => q{singular: 'menisci' --> 'meniscus'};
is noun(q{meniscus})->singular,   q{meniscus}  => q{singular: 'meniscus' --> 'meniscus'};
is noun(q{rugae})->singular, q{ruga}  => q{singular: 'rugae' --> 'ruga'};
is noun(q{ruga})->singular,   q{ruga}  => q{singular: 'ruga' --> 'ruga'};
is noun(q{limites})->singular, q{limes}  => q{singular: 'limites' --> 'limes'};
is noun(q{limes})->singular,   q{limes}  => q{singular: 'limes' --> 'limes'};
is noun(q{terrazzos})->singular, q{terrazzo}  => q{singular: 'terrazzos' --> 'terrazzo'};
is noun(q{terrazzo})->singular,   q{terrazzo}  => q{singular: 'terrazzo' --> 'terrazzo'};
is noun(q{involucra})->singular, q{involucrum}  => q{singular: 'involucra' --> 'involucrum'};
is noun(q{involucrum})->singular,   q{involucrum}  => q{singular: 'involucrum' --> 'involucrum'};
is noun(q{opera magna})->singular, q{opus magnum}  => q{singular: 'opera magna' --> 'opus magnum'};
is noun(q{opus magnum})->singular,   q{opus magnum}  => q{singular: 'opus magnum' --> 'opus magnum'};
is noun(q{pickerels})->singular, q{pickerel}  => q{singular: 'pickerels' --> 'pickerel'};
is noun(q{sanatoria})->singular, q{sanatorium}  => q{singular: 'sanatoria' --> 'sanatorium'};
is noun(q{sanatorium})->singular,   q{sanatorium}  => q{singular: 'sanatorium' --> 'sanatorium'};
is noun(q{afrits})->singular, q{afrit}  => q{singular: 'afrits' --> 'afrit'};
is noun(q{afrit})->singular,   q{afrit}  => q{singular: 'afrit' --> 'afrit'};
is noun(q{medulloblastomas})->singular, q{medulloblastoma}  => q{singular: 'medulloblastomas' --> 'medulloblastoma'};
is noun(q{medulloblastoma})->singular,   q{medulloblastoma}  => q{singular: 'medulloblastoma' --> 'medulloblastoma'};
is noun(q{Sangirese})->singular, q{Sangirese}  => q{singular: 'Sangirese' --> 'Sangirese'};
is noun(q{lamellae})->singular, q{lamella}  => q{singular: 'lamellae' --> 'lamella'};
is noun(q{lamella})->singular,   q{lamella}  => q{singular: 'lamella' --> 'lamella'};
is noun(q{zygomata})->singular, q{zygoma}  => q{singular: 'zygomata' --> 'zygoma'};
is noun(q{zygoma})->singular,   q{zygoma}  => q{singular: 'zygoma' --> 'zygoma'};
is noun(q{you})->singular, q{you}  => q{singular: 'you' --> 'you'};
is noun(q{gentes})->singular, q{gens}  => q{singular: 'gentes' --> 'gens'};
is noun(q{gens})->singular,   q{gens}  => q{singular: 'gens' --> 'gens'};
is noun(q{superficies})->singular, q{superficies}  => q{singular: 'superficies' --> 'superficies'};
is noun(q{hamuli})->singular, q{hamulus}  => q{singular: 'hamuli' --> 'hamulus'};
is noun(q{hamulus})->singular,   q{hamulus}  => q{singular: 'hamulus' --> 'hamulus'};
is noun(q{tonneaus})->singular, q{tonneau}  => q{singular: 'tonneaus' --> 'tonneau'};
is noun(q{tonneau})->singular,   q{tonneau}  => q{singular: 'tonneau' --> 'tonneau'};
is noun(q{moratoriums})->singular, q{moratorium}  => q{singular: 'moratoriums' --> 'moratorium'};
is noun(q{moratorium})->singular,   q{moratorium}  => q{singular: 'moratorium' --> 'moratorium'};
is noun(q{zooeae})->singular, q{zooea}  => q{singular: 'zooeae' --> 'zooea'};
is noun(q{zooea})->singular,   q{zooea}  => q{singular: 'zooea' --> 'zooea'};
is noun(q{hubrises})->singular, q{hubris}  => q{singular: 'hubrises' --> 'hubris'};
is noun(q{hubris})->singular,   q{hubris}  => q{singular: 'hubris' --> 'hubris'};
is noun(q{men children})->singular, q{man child}  => q{singular: 'men children' --> 'man child'};
is noun(q{man child})->singular,   q{man child}  => q{singular: 'man child' --> 'man child'};
is noun(q{matins})->singular, q{matin}  => q{singular: 'matins' --> 'matin'};
is noun(q{matin})->singular,   q{matin}  => q{singular: 'matin' --> 'matin'};
is noun(q{judases})->singular, q{judas}  => q{singular: 'judases' --> 'judas'};
is noun(q{judas})->singular,   q{judas}  => q{singular: 'judas' --> 'judas'};
is noun(q{micronuclei})->singular, q{micronucleus}  => q{singular: 'micronuclei' --> 'micronucleus'};
is noun(q{micronucleus})->singular,   q{micronucleus}  => q{singular: 'micronucleus' --> 'micronucleus'};
is noun(q{somata})->singular, q{soma}  => q{singular: 'somata' --> 'soma'};
is noun(q{soma})->singular,   q{soma}  => q{singular: 'soma' --> 'soma'};
is noun(q{aegises})->singular, q{aegis}  => q{singular: 'aegises' --> 'aegis'};
is noun(q{aegis})->singular,   q{aegis}  => q{singular: 'aegis' --> 'aegis'};
is noun(q{listerellas})->singular, q{listerella}  => q{singular: 'listerellas' --> 'listerella'};
is noun(q{listerella})->singular,   q{listerella}  => q{singular: 'listerella' --> 'listerella'};
is noun(q{2 star generals})->singular, q{2 star general}  => q{singular: '2 star generals' --> '2 star general'};
is noun(q{2 star general})->singular,   q{2 star general}  => q{singular: '2 star general' --> '2 star general'};
is noun(q{spermatia})->singular, q{spermatium}  => q{singular: 'spermatia' --> 'spermatium'};
is noun(q{spermatium})->singular,   q{spermatium}  => q{singular: 'spermatium' --> 'spermatium'};
is noun(q{paraganglia})->singular, q{paraganglion}  => q{singular: 'paraganglia' --> 'paraganglion'};
is noun(q{paraganglion})->singular,   q{paraganglion}  => q{singular: 'paraganglion' --> 'paraganglion'};
is noun(q{coups d'etat})->singular, q{coup d'etat}  => q{singular: 'coups d'etat' --> 'coup d'etat'};
is noun(q{coup d'etat})->singular,   q{coup d'etat}  => q{singular: 'coup d'etat' --> 'coup d'etat'};
is noun(q{consortiums})->singular, q{consortium}  => q{singular: 'consortiums' --> 'consortium'};
is noun(q{consortium})->singular,   q{consortium}  => q{singular: 'consortium' --> 'consortium'};
is noun(q{bronchitises})->singular, q{bronchitis}  => q{singular: 'bronchitises' --> 'bronchitis'};
is noun(q{bronchitis})->singular,   q{bronchitis}  => q{singular: 'bronchitis' --> 'bronchitis'};
is noun(q{medicos})->singular, q{medico}  => q{singular: 'medicos' --> 'medico'};
is noun(q{medico})->singular,   q{medico}  => q{singular: 'medico' --> 'medico'};
is noun(q{differentiae})->singular, q{differentia}  => q{singular: 'differentiae' --> 'differentia'};
is noun(q{differentia})->singular,   q{differentia}  => q{singular: 'differentia' --> 'differentia'};
is noun(q{traumas})->singular, q{trauma}  => q{singular: 'traumas' --> 'trauma'};
is noun(q{trauma})->singular,   q{trauma}  => q{singular: 'trauma' --> 'trauma'};
is noun(q{flies})->singular, q{fly}  => q{singular: 'flies' --> 'fly'};
is noun(q{fly})->singular,   q{fly}  => q{singular: 'fly' --> 'fly'};
is noun(q{whatever})->singular, q{whatever}  => q{singular: 'whatever' --> 'whatever'};
is noun(q{pyralides})->singular, q{pyralis}  => q{singular: 'pyralides' --> 'pyralis'};
is noun(q{pyralis})->singular,   q{pyralis}  => q{singular: 'pyralis' --> 'pyralis'};
is noun(q{pholades})->singular, q{pholas}  => q{singular: 'pholades' --> 'pholas'};
is noun(q{pholas})->singular,   q{pholas}  => q{singular: 'pholas' --> 'pholas'};
is noun(q{medicoes})->singular, q{medico}  => q{singular: 'medicoes' --> 'medico'};
is noun(q{medico})->singular,   q{medico}  => q{singular: 'medico' --> 'medico'};
is noun(q{trumeaux})->singular, q{trumeau}  => q{singular: 'trumeaux' --> 'trumeau'};
is noun(q{trumeau})->singular,   q{trumeau}  => q{singular: 'trumeau' --> 'trumeau'};
is noun(q{6 star generals})->singular, q{6 star general}  => q{singular: '6 star generals' --> '6 star general'};
is noun(q{6 star general})->singular,   q{6 star general}  => q{singular: '6 star general' --> '6 star general'};
is noun(q{yo-yos})->singular, q{yo-yo}  => q{singular: 'yo-yos' --> 'yo-yo'};
is noun(q{yo-yo})->singular,   q{yo-yo}  => q{singular: 'yo-yo' --> 'yo-yo'};
is noun(q{tenias})->singular, q{tenia}  => q{singular: 'tenias' --> 'tenia'};
is noun(q{tenia})->singular,   q{tenia}  => q{singular: 'tenia' --> 'tenia'};
is noun(q{star fish})->singular, q{star fish}  => q{singular: 'star fish' --> 'star fish'};
is noun(q{centesimi})->singular, q{centesimo}  => q{singular: 'centesimi' --> 'centesimo'};
is noun(q{centesimo})->singular,   q{centesimo}  => q{singular: 'centesimo' --> 'centesimo'};
is noun(q{ixodides})->singular, q{ixodid}  => q{singular: 'ixodides' --> 'ixodid'};
is noun(q{ixodid})->singular,   q{ixodid}  => q{singular: 'ixodid' --> 'ixodid'};
is noun(q{fidei defensores})->singular, q{fidei defensor}  => q{singular: 'fidei defensores' --> 'fidei defensor'};
is noun(q{fidei defensor})->singular,   q{fidei defensor}  => q{singular: 'fidei defensor' --> 'fidei defensor'};
is noun(q{mesotheliomata})->singular, q{mesothelioma}  => q{singular: 'mesotheliomata' --> 'mesothelioma'};
is noun(q{mesothelioma})->singular,   q{mesothelioma}  => q{singular: 'mesothelioma' --> 'mesothelioma'};
is noun(q{mottos})->singular, q{motto}  => q{singular: 'mottos' --> 'motto'};
is noun(q{motto})->singular,   q{motto}  => q{singular: 'motto' --> 'motto'};
is noun(q{helions})->singular, q{helion}  => q{singular: 'helions' --> 'helion'};
is noun(q{helion})->singular,   q{helion}  => q{singular: 'helion' --> 'helion'};
is noun(q{pangasinans})->singular, q{pangasinan}  => q{singular: 'pangasinans' --> 'pangasinan'};
is noun(q{pangasinan})->singular,   q{pangasinan}  => q{singular: 'pangasinan' --> 'pangasinan'};
is noun(q{volcanoes})->singular, q{volcano}  => q{singular: 'volcanoes' --> 'volcano'};
is noun(q{volcano})->singular,   q{volcano}  => q{singular: 'volcano' --> 'volcano'};
is noun(q{switchfoots})->singular, q{switchfoot}  => q{singular: 'switchfoots' --> 'switchfoot'};
is noun(q{switchfoot})->singular,   q{switchfoot}  => q{singular: 'switchfoot' --> 'switchfoot'};
is noun(q{monorchides})->singular, q{monorchis}  => q{singular: 'monorchides' --> 'monorchis'};
is noun(q{monorchis})->singular,   q{monorchis}  => q{singular: 'monorchis' --> 'monorchis'};
is noun(q{veg})->singular, q{veg}  => q{singular: 'veg' --> 'veg'};
is noun(q{fulcra})->singular, q{fulcrum}  => q{singular: 'fulcra' --> 'fulcrum'};
is noun(q{fulcrum})->singular,   q{fulcrum}  => q{singular: 'fulcrum' --> 'fulcrum'};
is noun(q{Lucchese})->singular, q{Lucchese}  => q{singular: 'Lucchese' --> 'Lucchese'};
is noun(q{mediums})->singular, q{medium}  => q{singular: 'mediums' --> 'medium'};
is noun(q{medium})->singular,   q{medium}  => q{singular: 'medium' --> 'medium'};
is noun(q{Hunanese})->singular, q{Hunanese}  => q{singular: 'Hunanese' --> 'Hunanese'};
is noun(q{tomia})->singular, q{tomium}  => q{singular: 'tomia' --> 'tomium'};
is noun(q{tomium})->singular,   q{tomium}  => q{singular: 'tomium' --> 'tomium'};
is noun(q{remiges})->singular, q{remex}  => q{singular: 'remiges' --> 'remex'};
is noun(q{remex})->singular,   q{remex}  => q{singular: 'remex' --> 'remex'};
is noun(q{pyrophori})->singular, q{pyrophorus}  => q{singular: 'pyrophori' --> 'pyrophorus'};
is noun(q{pyrophorus})->singular,   q{pyrophorus}  => q{singular: 'pyrophorus' --> 'pyrophorus'};
is noun(q{bison})->singular, q{bison}  => q{singular: 'bison' --> 'bison'};
is noun(q{vertebrae})->singular, q{vertebra}  => q{singular: 'vertebrae' --> 'vertebra'};
is noun(q{vertebra})->singular,   q{vertebra}  => q{singular: 'vertebra' --> 'vertebra'};
is noun(q{auroras})->singular, q{aurora}  => q{singular: 'auroras' --> 'aurora'};
is noun(q{aurora})->singular,   q{aurora}  => q{singular: 'aurora' --> 'aurora'};
is noun(q{Torontos})->singular, q{Toronto}  => q{singular: 'Torontos' --> 'Toronto'};
is noun(q{Toronto})->singular,   q{Toronto}  => q{singular: 'Toronto' --> 'Toronto'};
is noun(q{leptospirae})->singular, q{leptospira}  => q{singular: 'leptospirae' --> 'leptospira'};
is noun(q{leptospira})->singular,   q{leptospira}  => q{singular: 'leptospira' --> 'leptospira'};
is noun(q{monies})->singular, q{money}  => q{singular: 'monies' --> 'money'};
is noun(q{money})->singular,   q{money}  => q{singular: 'money' --> 'money'};
is noun(q{lemans})->singular, q{leman}  => q{singular: 'lemans' --> 'leman'};
is noun(q{leman})->singular,   q{leman}  => q{singular: 'leman' --> 'leman'};
is noun(q{logodaedale})->singular, q{logodaedalus}  => q{singular: 'logodaedale' --> 'logodaedalus'};
is noun(q{logodaedalus})->singular,   q{logodaedalus}  => q{singular: 'logodaedalus' --> 'logodaedalus'};
is noun(q{tableaus})->singular, q{tableau}  => q{singular: 'tableaus' --> 'tableau'};
is noun(q{tableau})->singular,   q{tableau}  => q{singular: 'tableau' --> 'tableau'};
is noun(q{protomas})->singular, q{protoma}  => q{singular: 'protomas' --> 'protoma'};
is noun(q{protoma})->singular,   q{protoma}  => q{singular: 'protoma' --> 'protoma'};
is noun(q{cladi})->singular, q{cladus}  => q{singular: 'cladi' --> 'cladus'};
is noun(q{cladus})->singular,   q{cladus}  => q{singular: 'cladus' --> 'cladus'};

done_testing();
