##########################################
## NOTE: This module was autogenerated. ##
## Contains no user-servicable parts!!! ##
##########################################

package Lingua::EN::Inflexion::Nouns;
use 5.010; use strict; use warnings; use re q{eval};
no if $] >= 5.018, warnings => "experimental::smartmatch";

our $VERSION = 20230704.182645;

my $modern_plural_of = {
  " ox"                    => " oxen",
  "-ox"                    => "-oxen",
  "1 star general"         => "1 star generals",
  "1-star general"         => "1-star generals",
  "2 star general"         => "2 star generals",
  "2-star general"         => "2-star generals",
  "3 star general"         => "3 star generals",
  "3-star general"         => "3-star generals",
  "4 star general"         => "4 star generals",
  "4-star general"         => "4-star generals",
  "5 star general"         => "5 star generals",
  "5-star general"         => "5-star generals",
  "6 star general"         => "6 star generals",
  "6-star general"         => "6-star generals",
  "abacus"                 => "abacuses",
  "aboiteau"               => "aboiteaus",
  "abortorium"             => "abortoria",
  "abortus"                => "abortuses",
  "abscissa"               => "abscissas",
  "abstractum"             => "abstracta",
  "acarus"                 => "acari",
  "Achinese"               => "Achinese",
  "acicula"                => "aciculae",
  "acinus"                 => "acini",
  "acroama"                => "acroamata",
  "acropolis"              => "acropolises",
  "actinia"                => "actinias",
  "aculeus"                => "aculei",
  "addendum"               => "addendums",
  "adieu"                  => "adieus",
  "adminiculum"            => "adminicula",
  "ado"                    => "ados",
  "adviso"                 => "advisoes",
  "adytum"                 => "adyta",
  "aecidium"               => "aecidia",
  "aegis"                  => "aegises",
  "aelf"                   => "aelfe",
  "aficionado"             => "aficionados",
  "afreet"                 => "afreets",
  "afrit"                  => "afrits",
  "agape"                  => "agapes",
  "agend"                  => "agends",
  "agendum"                => "agenda",
  "agent provocateur"      => "agents provocateurs",
  "aggro"                  => "aggros",
  "agon"                   => "agones",
  "agora"                  => "agorae",
  "agrogorod"              => "agrogoroda",
  "aide de camp"           => "aides de camp",
  "aide-de-camp"           => "aides-de-camp",
  "ala"                    => "alae",
  "alan"                   => "alans",
  "albergo"                => "alberghi",
  "albino"                 => "albinos",
  "ale wife"               => "ale wives",
  "ale-wife"               => "ale-wives",
  "Alfurese"               => "Alfurese",
  "alga"                   => "algae",
  "alguacil"               => "alguacils",
  "alias"                  => "aliases",
  "allargando"             => "allargandi",
  "allegro"                => "allegros",
  "alluvium"               => "alluviums",
  "alto"                   => "altos",
  "alto relievo"           => "alto relievos",
  "alto-relievo"           => "alto-relievos",
  "altorelievo"            => "altorelievos",
  "alula"                  => "alulae",
  "alumna"                 => "alumnae",
  "alumnus"                => "alumni",
  "alveolus"               => "alveoli",
  "ambo"                   => "ambos",
  "Amboinese"              => "Amboinese",
  "ambulacrum"             => "ambulacra",
  "ambuscado"              => "ambuscados",
  "amentum"                => "amenta",
  "Americanese"            => "Americanese",
  "amicus curiae"          => "amici curiae",
  "ammo"                   => "ammos",
  "amoeba"                 => "amoebas",
  "amoretto"               => "amoretti",
  "amorino"                => "amorini",
  "Amoyese"                => "Amoyese",
  "amphipneust"            => "amphipneusts",
  "amphora"                => "amphorae",
  "anacoluthon"            => "anacoluthons",
  "anathema"               => "anathemas",
  "ancona"                 => "ancone",
  "Andamanese"             => "Andamanese",
  "angioma"                => "angiomata",
  "Angolese"               => "Angolese",
  "angustia"               => "angustiae",
  "anlage"                 => "anlages",
  "Annamese"               => "Annamese",
  "anta"                   => "antae",
  "Antananarivo"           => "Antananarivos",
  "antefix"                => "antifixes",
  "antenna"                => "antennas",
  "anthemion"              => "anthemia",
  "anthodium"              => "anthodia",
  "anti serum"             => "anti serums",
  "anti-serum"             => "anti-serums",
  "antiserum"              => "antisera",
  "antrum"                 => "antra",
  "apex"                   => "apexes",
  "aphelion"               => "aphelia",
  "aphis"                  => "aphides",
  "apothecium"             => "apothecia",
  "apparatchik"            => "apparatchiks",
  "apparatus"              => "apparatuses",
  "appendix"               => "appendixes",
  "appressorium"           => "appressoria",
  "apsis"                  => "apsides",
  "apterium"               => "apteria",
  "aptychus"               => "aptychi",
  "aquarium"               => "aquariums",
  "Aragonese"              => "Aragonese",
  "Arakanese"              => "Arakanese",
  "arango"                 => "arangoes",
  "arboretum"              => "arboreta",
  "arcanum"                => "arcana",
  "archegonium"            => "archegonia",
  "archipelago"            => "archipelagos",
  "arcosolium"             => "arcosolia",
  "areola"                 => "areolae",
  "arf"                    => "arves",
  "argumentum"             => "argumenta",
  "arista"                 => "aristae",
  "armadillo"              => "armadillos",
  "army corps general"     => "army corps generals",
  "army-corps general"     => "army-corps generals",
  "arrha"                  => "arrhae",
  "asbestos"               => "asbestoses",
  "ascidium"               => "ascidia",
  "Asherah"                => "Asherahs",
  "Assamese"               => "Assamese",
  "asterias"               => "asteriae",
  "astrocytoma"            => "astrocytomas",
  "asylum"                 => "asylums",
  "asyndeton"              => "asyndeta",
  "ataman"                 => "atamans",
  "atlas"                  => "atlases",
  "Atlas"                  => "Atlantes",
  "atman"                  => "atmas",
  "aureus"                 => "aurei",
  "aurora"                 => "auroras",
  "Auslese"                => "Auslesen",
  "auslese"                => "ausleses",
  "auspex"                 => "auspices",
  "auto"                   => "autos",
  "auto de fe"             => "auto de fes",
  "auto-de-fe"             => "auto-de-fes",
  "autobahn"               => "autobahns",
  "autochthon"             => "autochthons",
  "autostrada"             => "autostradas",
  "avicularium"            => "avicularia",
  "Avignonese"             => "Avignonese",
  "aviso"                  => "avisos",
  "avocado"                => "avocados",
  "ax"                     => "axes",
  "axe"                    => "axes",
  "axilla"                 => "axillae",
  "axis"                   => "axes",
  "axon"                   => "axons",
  "axopodium"              => "axopodia",
  "Azerbaijanese"          => "Azerbaijanese",
  "baal"                   => "baals",
  "bacillus"               => "bacilli",
  "bacterium"              => "bacteria",
  "Bahaman"                => "Bahamans",
  "bajocco"                => "bajocchi",
  "Balinese"               => "Balinese",
  "ballabile"              => "ballabili",
  "ballata"                => "ballate",
  "ballerina"              => "ballerinas",
  "ballista"               => "ballistas",
  "Bamako"                 => "Bamakos",
  "bandeau"                => "bandeaux",
  "bandit"                 => "bandits",
  "Barquisimeto"           => "Barquisimetos",
  "barrico"                => "barricoes",
  "base"                   => "bases",
  "basilica"               => "basilicas",
  "basis"                  => "bases",
  "bass"                   => "basses",
  "basso"                  => "bassos",
  "bateau"                 => "bateaux",
  "bath"                   => "baths",
  "bathos"                 => "bathoses",
  "batz"                   => "batzes",
  "beau"                   => "beaus",
  "beau geste"             => "beau gestes",
  "bechuana"               => "bechuanas",
  "beef"                   => "beefs",
  "beerenauslese"          => "beerenauslesen",
  "bel esprit"             => "beaux esprits",
  "bel homme"              => "beaux hommes",
  "bel-esprit"             => "beaux esprits",
  "belle epoque"           => "belle epoques",
  "bema"                   => "bemas",
  "Bengalese"              => "Bengalese",
  "Bernese"                => "Bernese",
  "bersagliere"            => "bersaglieri",
  "bhikshu"                => "bhikshus",
  "Bhutanese"              => "Bhutanese",
  "bias"                   => "biases",
  "bierstube"              => "bierstubes",
  "bifolium"               => "bifolia",
  "bijou"                  => "bijoux",
  "bilbo"                  => "bilboes",
  "bimbo"                  => "bimbos",
  "bingo"                  => "bingos",
  "Biro"                   => "Biros",
  "biscotto"               => "biscotti",
  "bison"                  => "bisons",
  "blastema"               => "blastemata",
  "blemya"                 => "blemyae",
  "blin"                   => "blinis",
  "blitz"                  => "blitzes",
  "blouse"                 => "blouses",
  "blue"                   => "blues",
  "blues"                  => "blues",
  "bodegon"                => "bodegones",
  "bolero"                 => "boleros",
  "Bolognese"              => "Bolognese",
  "bolus"                  => "boluses",
  "Bolzano"                => "Bolzanos",
  "bon mot"                => "bon mots",
  "bon vivant"             => "bon vivants",
  "bona fides"             => "bonis fidebus",
  "bongo"                  => "bongos",
  "bordereau"              => "bordereaux",
  "Borghese"               => "Borghese",
  "Bostonese"              => "Bostonese",
  "Boto"                   => "Botos",
  "bozzetto"               => "bozzetti",
  "braccio"                => "braccia",
  "brachiopod"             => "brachiopods",
  "branchiopod"            => "branchiopods",
  "bratwurst"              => "bratwursts",
  "bravo"                  => "bravos",
  "break away"             => "break aways",
  "break-away"             => "break-aways",
  "breakaway"              => "breakaways",
  "bream"                  => "bream",
  "breech"                 => "breeches",
  "breeches"               => "breeches",
  "bregma"                 => "bregmata",
  "brigadier general"      => "brigadier generals",
  "britches"               => "britches",
  "bronchitis"             => "bronchitises",
  "bronchus"               => "bronchi",
  "brother"                => "brothers",
  "brother german"         => "brothers german",
  "brother-german"         => "brothers-german",
  "bruschetta"             => "bruschette",
  "bubo"                   => "buboes",
  "buffalo"                => "buffalos",
  "Buginese"               => "Buginese",
  "bulimus"                => "bulimi",
  "bulla"                  => "bullae",
  "bureau"                 => "bureaus",
  "Burman"                 => "Burmans",
  "Burmese"                => "Burmese",
  "burro"                  => "burros",
  "bursa"                  => "bursae",
  "bursch"                 => "burschen",
  "bursitis"               => "bursitises",
  "busto"                  => "bustos",
  "buzz"                   => "buzzes",
  "bylina"                 => "bylinas",
  "cabaletta"              => "cabalettas",
  "cactus"                 => "cactuses",
  "caddis"                 => "caddises",
  "caduceus"               => "caducei",
  "caecum"                 => "caeca",
  "caffe macchiato"        => "caffe macchiatos",
  "caffe ristretto"        => "caffe ristrettos",
  "caiman"                 => "caimans",
  "Cairo"                  => "Cairos",
  "Calabrese"              => "Calabrese",
  "calamistrum"            => "calamistra",
  "calathus"               => "calathi",
  "calix"                  => "calices",
  "callus"                 => "calluses",
  "calypso"                => "calypsos",
  "calzone"                => "calzones",
  "Camaldolese"            => "Camaldolese",
  "camera obscura"         => "camera obscuras",
  "canaliculus"            => "canaliculi",
  "candelabrum"            => "candelabra",
  "cannabis"               => "cannabises",
  "cantharus"              => "canthari",
  "canto"                  => "cantos",
  "Cantonese"              => "Cantonese",
  "cantus"                 => "cantuses",
  "canvas"                 => "canvases",
  "canzonetta"             => "canzonettas",
  "capataz"                => "capataces",
  "capo"                   => "capos",
  "cappuccino"             => "cappuccinos",
  "captain general"        => "captain generals",
  "carabiniere"            => "carabinieri",
  "carcinoma"              => "carcinomas",
  "cardo"                  => "cardines",
  "cardophagus"            => "cardophagi",
  "carex"                  => "carices",
  "cargador"               => "cargadores",
  "caribou"                => "caribous",
  "Carlylese"              => "Carlylese",
  "carmen"                 => "carmens",
  "carp"                   => "carp",
  "carte de visite"        => "cartes de visite",
  "carte-de-visite"        => "cartes-de-visite",
  "caryatid"               => "caryatids",
  "caryopsis"              => "caryopsides",
  "casino"                 => "casinos",
  "Cassinese"              => "Cassinese",
  "cassone"                => "cassones",
  "castrato"               => "castrati",
  "castrum"                => "castra",
  "casus belli"            => "casus belli",
  "cathisma"               => "cathismata",
  "caudex"                 => "caudices",
  "caulis"                 => "caules",
  "cavea"                  => "caveae",
  "cayman"                 => "caymans",
  "cecidium"               => "cecidia",
  "Celanese"               => "Celanese",
  "celia"                  => "celiae",
  "cello"                  => "cellos",
  "cementoma"              => "cementomata",
  "centesimo"              => "centesimi",
  "centumvir"              => "centumviri",
  "cercus"                 => "cerci",
  "ceriman"                => "cerimans",
  "Ceylonese"              => "Ceylonese",
  "chaeta"                 => "chaetae",
  "chaos"                  => "chaoses",
  "chapeau"                => "chapeaux",
  "chapplis"               => "chapplies",
  "charisma"               => "charismas",
  "chassis"                => "chassis",
  "chateau"                => "chateaux",
  "cherub"                 => "cherubs",
  "chervonetz"             => "chervontzi",
  "cheval"                 => "chevaux",
  "cheval de bataille"     => "chevaux de bataille",
  "cheval-de-bataille"     => "chevaux-de-bataille",
  "Chicago"                => "Chicagos",
  "child"                  => "children",
  "Chimango"               => "Chimangos",
  "Chinese"                => "Chinese",
  "chintz"                 => "chintzes",
  "chitarrone"             => "chitarroni",
  "chlamydia"              => "chlamydias",
  "choana"                 => "choanae",
  "chorda"                 => "chordae",
  "chorus"                 => "choruses",
  "chou"                   => "choux",
  "chromidium"             => "chromidia",
  "chromonema"             => "chromonemata",
  "chrysalis"              => "chrysalises",
  "cicatrix"               => "cicatrices",
  "cilantro"               => "cilantros",
  "cimex"                  => "cimices",
  "cinclis"                => "cinclides",
  "cistophorus"            => "cistophorori",
  "cladus"                 => "cladi",
  "claustrum"              => "claustra",
  "clausula"               => "clausulae",
  "clavula"                => "clavulae",
  "cleithrum"              => "cleithra",
  "clepsydra"              => "clepsydras",
  "clipper"                => "clippers",
  "clippers"               => "clippers",
  "clitoris"               => "clitorises",
  "clostridium"            => "clostridia",
  "co"                     => "coes",
  "coagulum"               => "coagula",
  "coccidium"              => "coccidia",
  "cochito"                => "cochitos",
  "coco"                   => "cocos",
  "cod"                    => "cod",
  "codex"                  => "codices",
  "coe"                    => "coes",
  "coelia"                 => "coeliae",
  "cognoscente"            => "cognoscenti",
  "coitus"                 => "coituses",
  "collegium"              => "collegia",
  "collegium musicum"      => "collegia musica",
  "Colombo"                => "Colombos",
  "colonel general"        => "colonel generals",
  "Colorado"               => "Colorados",
  "columbarium"            => "columbaria",
  "columna"                => "columnae",
  "coma"                   => "comae",
  "comatula"               => "comatulae",
  "commanding general"     => "commanding generals",
  "commando"               => "commandos",
  "compendium"             => "compendiums",
  "competent"              => "competentes",
  "concertino"             => "concertinos",
  "concerto grosso"        => "concerti grossi",
  "concetto"               => "concetti",
  "condo"                  => "condos",
  "condottiere"            => "condottieri",
  "conductus"              => "conducti",
  "coney"                  => "coneys",
  "conferva"               => "confervae",
  "confluvium"             => "confluvia",
  "congius"                => "congii",
  "Congoese"               => "Congoese",
  "Congolese"              => "Congolese",
  "conidium"               => "conidia",
  "conoscente"             => "conoscenti",
  "consortium"             => "consortiums",
  "contadina"              => "contadine",
  "contadino"              => "contadini",
  "contagium"              => "contagia",
  "contango"               => "contangos",
  "contrafactum"           => "contrafacta",
  "contralto"              => "contraltos",
  "contretemps"            => "contretemps",
  "conversazione"          => "conversaziones",
  "convolvulus"            => "convolvuluses",
  "cony"                   => "conys",
  "corgi"                  => "corgis",
  "corgy"                  => "corgys",
  "cornetto"               => "cornetti",
  "corno"                  => "corni",
  "cornu"                  => "cornua",
  "corona"                 => "coronas",
  "corps"                  => "corps",
  "corps general"          => "corps generals",
  "corpus"                 => "corpuses",
  "corpus vile"            => "corpora vilia",
  "corpusculum"            => "corpuscula",
  "corrigendum"            => "corrigenda",
  "cortex"                 => "cortexes",
  "cosmos"                 => "cosmoses",
  "costa"                  => "costae",
  "coup d'etat"            => "coups d'etat",
  "court martial"          => "court-martials",
  "court-martial"          => "court-martials",
  "cow"                    => "cows",
  "coxendix"               => "coxendices",
  "coz"                    => "cozes",
  "craft"                  => "craft",
  "crafts child"           => "crafts childer",
  "crafts-child"           => "crafts-childer",
  "cranium"                => "craniums",
  "craspedon"              => "craspeda",
  "craspedum"              => "craspeda",
  "crazia"                 => "crazie",
  "credo"                  => "credos",
  "cremaster"              => "cremasters",
  "crescendo"              => "crescendos",
  "cri de coeur"           => "cris de coeur",
  "crista"                 => "cristae",
  "criterion"              => "criteria",
  "crowfoot"               => "crowfoots",
  "crus"                   => "crura",
  "crusta"                 => "crustae",
  "cubiculum"              => "cubicula",
  "cul de four"            => "culs de four",
  "cul de lampe"           => "culs de lampe",
  "cul de sac"             => "culs de sac",
  "cul-de-four"            => "culs-de-four",
  "cul-de-lampe"           => "culs-de-lampe",
  "cul-de-sac"             => "culs-de-sac",
  "cultellus"              => "cultelli",
  "cumulus"                => "cumuli",
  "cuniculus"              => "cuniculi",
  "curioso"                => "curiosos",
  "curriculum"             => "curriculums",
  "cuspis"                 => "cuspides",
  "cyano"                  => "cyanos",
  "cyathus"                => "cyathi",
  "cyclops"                => "cyclopses",
  "cynocephalus"           => "cynocephali",
  "cyphella"               => "cyphellae",
  "cysticercus"            => "cysticerci",
  "cystidium"              => "cystidia",
  "cystoma"                => "cystomata",
  "Czech"                  => "Czechs",
  "dace"                   => "daces",
  "dais"                   => "daises",
  "datum"                  => "data",
  "debris"                 => "debris",
  "decennium"              => "decennia",
  "deer"                   => "deer",
  "delirium"               => "deliriums",
  "demo"                   => "demos",
  "denarius"               => "denarii",
  "denkmal"                => "denkmaler",
  "denotatum"              => "denotata",
  "dentalium"              => "dentalia",
  "depositum"              => "depositums",
  "descriptum"             => "descripta",
  "desideratum"            => "desiderata",
  "designatum"             => "designata",
  "desma"                  => "desmas",
  "desman"                 => "desmans",
  "devoto"                 => "devotos",
  "diabetes"               => "diabetes",
  "diastema"               => "diastemata",
  "dichasium"              => "dichasia",
  "dictum"                 => "dictums",
  "didymis"                => "didymes",
  "die"                    => "dice",
  "differentia"            => "differentiae",
  "digitalis"              => "digitalises",
  "dilettante"             => "dilettantes",
  "diplococcus"            => "diplococci",
  "diploma"                => "diplomas",
  "diporpa"                => "diporpae",
  "dipsas"                 => "dipsades",
  "directrix"              => "directrices",
  "ditto"                  => "dittos",
  "diverticulum"           => "diverticula",
  "divertimento"           => "divertimentos",
  "divisional general"     => "divisional generals",
  "djinn"                  => "djinns",
  "do"                     => "does",
  "doe"                    => "does",
  "dogma"                  => "dogmas",
  "dolman"                 => "dolmans",
  "dolphinarium"           => "dolphinariums",
  "Dongolese"              => "Dongolese",
  "Draco"                  => "Dracos",
  "dragoman"               => "dragomen",
  "drama"                  => "dramas",
  "dreikanter"             => "dreikanters",
  "dumka"                  => "dumkas",
  "duumvir"                => "duumvirs",
  "dynamo"                 => "dynamos",
  "edema"                  => "edemas",
  "editio princeps"        => "editiones principes",
  "efreet"                 => "efreets",
  "eland"                  => "elands",
  "elf"                    => "elves",
  "elk"                    => "elks",
  "ellipse"                => "ellipses",
  "ellipsis"               => "ellipses",
  "emblema"                => "emblememata",
  "embryo"                 => "embryos",
  "embryoma"               => "embryomata",
  "emporium"               => "emporiums",
  "enconium"               => "enconiums",
  "endothelioma"           => "endotheliomata",
  "enema"                  => "enemas",
  "enigma"                 => "enigmas",
  "ens rationis"           => "entia rationis",
  "ens reale"              => "entia realia",
  "entente cordiale"       => "ententes cordiales",
  "enteron"                => "entera",
  "entrochus"              => "entrochi",
  "ephelis"                => "ephelides",
  "ephemera"               => "ephemeras",
  "ephemeris"              => "ephemerises",
  "epicardium"             => "epicardia",
  "epidermis"              => "epidermises",
  "epididymis"             => "epididymises",
  "epilimnion"             => "epilimnia",
  "epimeron"               => "epimera",
  "epiphenomenon"          => "epiphenomena",
  "epithelioma"            => "epitheliomata",
  "epyllion"               => "epyllia",
  "equinoctium"            => "equinoctiums",
  "equisetum"              => "equisetums",
  "erf"                    => "erfs",
  "ergastulum"             => "ergastula",
  "eros"                   => "eroses",
  "erratum"                => "errata",
  "espanol"                => "espanoles",
  "Esperanto"              => "Esperantos",
  "espresso"               => "espressos",
  "ethos"                  => "ethoses",
  "eucalyptus"             => "eucalyptuses",
  "eunuch"                 => "eunuchs",
  "euporiston"             => "euporista",
  "euro"                   => "euros",
  "evirato"                => "evirati",
  "ex"                     => "exes",
  "exanthema"              => "exanthemata",
  "exemplum"               => "exempla",
  "exencephalus"           => "exencephali",
  "explanandum"            => "explananda",
  "explicandum"            => "explicanda",
  "extispex"               => "extispices",
  "extremum"               => "extremums",
  "eyas"                   => "eyases",
  "fabella"                => "fabellae",
  "fabliau"                => "fabliaux",
  "faciendum"              => "facienda",
  "faecula"                => "faeculae",
  "fait accompli"          => "faits accomplis",
  "falsetto"               => "falsettos",
  "falx"                   => "falces",
  "familia"                => "familiae",
  "famulus"                => "famuli",
  "fanfoot"                => "fanfoots",
  "farman"                 => "farmans",
  "Faro"                   => "Faros",
  "Faroese"                => "Faroese",
  "fascia"                 => "fascias",
  "fasciculus"             => "fasciculi",
  "fauna"                  => "faunas",
  "favella"                => "favellae",
  "faveolus"               => "faveoli",
  "favissa"                => "favissae",
  "fecula"                 => "feculae",
  "fedai"                  => "fedais",
  "feis"                   => "fess",
  "felo"                   => "felones",
  "felo de se"             => "felos de se",
  "felo-de-se"             => "felos-de-se",
  "felsenmeer"             => "felsenmeere",
  "femur"                  => "femurs",
  "fenestra"               => "fenestrae",
  "fermata"                => "fermatas",
  "Ferrarese"              => "Ferrarese",
  "fiasco"                 => "fiascos",
  "fibra"                  => "fibrae",
  "fibrilla"               => "fibrillae",
  "fibroma"                => "fibromata",
  "fibula"                 => "fibulas",
  "fidei defensor"         => "fidei defensores",
  "figurante"              => "figurantes",
  "filaria"                => "filarias",
  "Filipino"               => "Filipinos",
  "finger end"             => "finger ends",
  "finger-end"             => "finger-ends",
  "fioritura"              => "fioriture",
  "fish"                   => "fish",
  "five star general"      => "five star generals",
  "five-star general"      => "five-star generals",
  "fizz"                   => "fizzes",
  "flabellum"              => "flabella",
  "flag staff"             => "flag staffs",
  "flag-staff"             => "flag-staffs",
  "flagellum"              => "flagella",
  "flamenco"               => "flamencos",
  "flatfoot"               => "flatfoots",
  "flatus"                 => "flatuses",
  "flocculus"              => "flocculi",
  "floccus"                => "flocci",
  "flora"                  => "floras",
  "flounder"               => "flounder",
  "fly"                    => "flies",
  "focus"                  => "focuses",
  "follis"                 => "folles",
  "fomes"                  => "fomites",
  "Foochowese"             => "Foochowese",
  "foot"                   => "feet",
  "foramen"                => "foramens",
  "formula"                => "formulas",
  "forum"                  => "forums",
  "fossa"                  => "fossae",
  "four star general"      => "four star generals",
  "four-star general"      => "four-star generals",
  "fowl"                   => "fowls",
  "fraenum"                => "fraena",
  "franc archer"           => "franc archers",
  "franc-archer"           => "franc-archers",
  "frate"                  => "frati",
  "frenum"                 => "frena",
  "fricandeau"             => "fricandeaux",
  "frizz"                  => "frizzes",
  "fro"                    => "froes",
  "froe"                   => "froes",
  "frottola"               => "frottole",
  "frustulum"              => "frustula",
  "frustum"                => "frustums",
  "fucus"                  => "fuci",
  "fulcrum"                => "fulcra",
  "funambulus"             => "funambuli",
  "fundamentum divisionis" => "fundamenta divisionis",
  "fungo porcino"          => "funghi porchini",
  "fungus"                 => "funguses",
  "furfur"                 => "furfures",
  "furioso"                => "furiosos",
  "fuzz"                   => "fuzzes",
  "Gabunese"               => "Gabunese",
  "Galla"                  => "Gallas",
  "galla"                  => "gallas",
  "gallows"                => "gallows",
  "gametangium"            => "gametangia",
  "ganglion"               => "ganglions",
  "gaon"                   => "gaons",
  "gastrocnemius"          => "gastrocnemii",
  "geisha"                 => "geishas",
  "geisteswissenschaft"    => "geisteswissenschaften",
  "gemma"                  => "gemmae",
  "gena"                   => "genae",
  "generalissimo"          => "generalissimos",
  "Genevese"               => "Genevese",
  "genie"                  => "genies",
  "genius"                 => "geniuses",
  "Genoese"                => "Genoese",
  "gens"                   => "gentes",
  "genus"                  => "genera",
  "German"                 => "Germans",
  "germarium"              => "germaria",
  "Gestapo"                => "Gestapos",
  "ghetto"                 => "ghettos",
  "gigolo"                 => "gigolos",
  "Gilbertese"             => "Gilbertese",
  "giuncus"                => "giunchi",
  "gizmo"                  => "gizmos",
  "glacis"                 => "glacises",
  "gladiolus"              => "gladioluses",
  "glass"                  => "glasses",
  "glasses"                => "glasses",
  "glioma"                 => "gliomata",
  "gliosarcoma"            => "gliosarcomata",
  "glissando"              => "glissandos",
  "globigerina"            => "globigerinae",
  "glochidium"             => "glochidia",
  "glomus"                 => "glomera",
  "glutaeus"               => "glutei",
  "gluteus"                => "glutei",
  "gmina"                  => "gminy",
  "go"                     => "goes",
  "Goanese"                => "Goanese",
  "gonangium"              => "gonangia",
  "gonidium"               => "gonidia",
  "gonimium"               => "gonimia",
  "goose"                  => "geese",
  "gorgonia"               => "gorgonias",
  "gousblom"               => "gousblomme",
  "goy"                    => "goys",
  "graben"                 => "grabens",
  "graffiti"               => "graffiti",
  "graffito"               => "graffiti",
  "granita"                => "granite",
  "grano"                  => "grani",
  "granula"                => "granulae",
  "gravamen"               => "gravamina",
  "Greensboro"             => "Greensboros",
  "gringo"                 => "gringos",
  "grissino"               => "grissini",
  "grotto"                 => "grottos",
  "grouse"                 => "grouses",
  "Guaiabero"              => "Guaiaberos",
  "guano"                  => "guanos",
  "guardia civil"          => "guardias civiles",
  "gubernaculum"           => "gubernacula",
  "guglio"                 => "guglios",
  "Guianese"               => "Guianese",
  "gumbo"                  => "gumbos",
  "gumma"                  => "gummas",
  "guttus"                 => "gutti",
  "guy"                    => "guys",
  "gymnasium"              => "gymnasiums",
  "gymnotus"               => "gymnoti",
  "gyro"                   => "gyros",
  "gyrus"                  => "gyri",
  "haddock"                => "haddocks",
  "haemangioma"            => "haemangiomas",
  "haggis"                 => "haggis",
  "Hainanese"              => "Hainanese",
  "hairdo"                 => "hairdos",
  "hake"                   => "hakes",
  "halibut"                => "halibuts",
  "hallux"                 => "halluces",
  "halteridium"            => "halteridia",
  "hamadryad"              => "hamadrayads",
  "hamulus"                => "hamuli",
  "hapax legomenon"        => "hapax legomenons",
  "hapteron"               => "haptera",
  "Hararese"               => "Hararese",
  "Harlemese"              => "Harlemese",
  "harman"                 => "harmans",
  "haruspex"               => "haruspices",
  "haustellum"             => "haustella",
  "haustorium"             => "haustoria",
  "haustrum"               => "haustra",
  "Havanese"               => "Havanese",
  "he"                     => "they",
  "headquarters"           => "headquarters",
  "Heavenese"              => "Heavenese",
  "hedron"                 => "hedrons",
  "heft"                   => "hefte",
  "helion"                 => "helions",
  "helix"                  => "helices",
  "hemangeioma"            => "hemangeiomas",
  "hemangioma"             => "hemangiomas",
  "hemelytrum"             => "hemelytra",
  "hemera"                 => "hemerae",
  "hemi elytrum"           => "hemi elytra",
  "hemi-elytrum"           => "hemi-elytra",
  "her"                    => "them",
  "hernia"                 => "hernias",
  "hero"                   => "heroes",
  "heroon"                 => "heroa",
  "heroum"                 => "heroa",
  "herpes"                 => "herpes",
  "herr"                   => "herren",
  "herring"                => "herrings",
  "hers"                   => "theirs",
  "herself"                => "themselves",
  "hertz"                  => "hertz",
  "hetaera"                => "hetaerae",
  "hetaira"                => "hetaerae",
  "hetman"                 => "hetmans",
  "hiatus"                 => "hiatuses",
  "hijinks"                => "hijinks",
  "him"                    => "them",
  "himself"                => "themselves",
  "hinaki"                 => "hinaki",
  "hippo"                  => "hippos",
  "hippocampus"            => "hippocampi",
  "hippopotamus"           => "hippopotamuses",
  "Hiroshiman"             => "Hiroshimans",
  "his"                    => "theirs",
  "ho"                     => "hoes",
  "hoe"                    => "hoes",
  "holothuria"             => "holothurias",
  "honorarium"             => "honorariums",
  "hoof"                   => "hoofs",
  "Hoosierese"             => "Hoosierese",
  "hordeolum"              => "hordeola",
  "hormogonium"            => "hormogonia",
  "hoti"                   => "hoties",
  "Hottentotese"           => "Hottentotese",
  "hsien"                  => "heen",
  "hubris"                 => "hubrises",
  "human"                  => "humans",
  "humerus"                => "humeri",
  "Hunanese"               => "Hunanese",
  "hydra"                  => "hydras",
  "hydraulicon"            => "hydraulica",
  "hydria"                 => "hydriae",
  "hymenium"               => "hymenia",
  "hymnarium"              => "hymnaria",
  "hyperbaton"             => "hyperbata",
  "hyperbola"              => "hyperbolas",
  "hypha"                  => "hyphae",
  "hypnum"                 => "hypnums",
  "hypoderma"              => "hypodermata",
  "hypolimnion"            => "hypolimnia",
  "I"                      => "we",
  "ibis"                   => "ibises",
  "ichthyosaurus"          => "ichthyosauri",
  "Idaho"                  => "Idahos",
  "idee fixe"              => "idees fixes",
  "idolon"                 => "idola",
  "idolum"                 => "idola",
  "ignoramus"              => "ignoramuses",
  "ilium"                  => "ilia",
  "imago"                  => "imagos",
  "imbrex"                 => "imbrices",
  "impetigo"               => "impetigos",
  "impetus"                => "impetuses",
  "improperium"            => "improperia",
  "improvisatrice"         => "improvisatrici",
  "incubus"                => "incubuses",
  "index"                  => "indexes",
  "indicium"               => "indicia",
  "indigena"               => "indigenae",
  "individuum"             => "individuums",
  "Indochinese"            => "Indochinese",
  "indumentum"             => "indumenta",
  "indusium"               => "indusia",
  "inferno"                => "infernos",
  "infima species"         => "infimae species",
  "info"                   => "infos",
  "inhalatorium"           => "inhalatoria",
  "innings"                => "innings",
  "inoculum"               => "inocula",
  "insula"                 => "insulae",
  "intaglio"               => "intaglios",
  "interambulacrum"        => "interambulacra",
  "interaxis"              => "interaxes",
  "intercalarium"          => "intercalaria",
  "interleaf"              => "leaves",
  "intermaxilla"           => "intermaxillae",
  "intermedium"            => "intermedia",
  "intermezzo"             => "intermezzos",
  "internodium"            => "internodia",
  "interphenomenon"        => "interphenomena",
  "interradius"            => "interradii",
  "interregnum"            => "interregnums",
  "interrex"               => "interreges",
  "interstitium"           => "interstitiums",
  "intertrigo"             => "intertrigos",
  "intervallum"            => "intervallums",
  "intichiuma"             => "intichiuma",
  "inuk"                   => "inuit",
  "inukshuk"               => "inukshuit",
  "involucrum"             => "involucra",
  "ipse dixit"             => "ipse dixits",
  "Iquico"                 => "Iquicos",
  "iris"                   => "irises",
  "ischium"                => "ischia",
  "isidium"                => "isidia",
  "ispravnik"              => "ispravniks",
  "isthmus"                => "isthmuses",
  "it"                     => "they",
  "iter"                   => "iters",
  "its"                    => "theirs",
  "itself"                 => "themselves",
  "ixodid"                 => "ixodides",
  "jackanapes"             => "jackanapes",
  "jacobus"                => "jacobuses",
  "jalapeno"               => "jalapenos",
  "jambeau"                => "jambeaus",
  "Japanese"               => "Japanese",
  "Javanese"               => "Javanese",
  "jazz"                   => "jazzes",
  "jerry"                  => "jerries",
  "Jerry"                  => "Jerrys",
  "jeu"                    => "jeux",
  "jo"                     => "joes",
  "joe"                    => "joes",
  "Johnsonese"             => "Johnsonese",
  "judas"                  => "judases",
  "judicatum"              => "judicata",
  "juelet"                 => "iueles",
  "jugum"                  => "juga",
  "jumbo"                  => "jumbos",
  "junto"                  => "juntos",
  "Kakapo"                 => "Kakapos",
  "Kanarese"               => "Kanarese",
  "kantharos"              => "kantharoi",
  "kar"                    => "kars",
  "karakia"                => "karakias",
  "karrenfeld"             => "karrenfelds",
  "kernos"                 => "kernoi",
  "kibbutz"                => "kibbutzes",
  "kilo"                   => "kilos",
  "kimono"                 => "kimonos",
  "Kinkimavo"              => "Kinkimavos",
  "kioko"                  => "kiokos",
  "Kiplingese"             => "Kiplingese",
  "kletterschuh"           => "kletterschuhe",
  "knife"                  => "knives",
  "knopper"                => "knoppers",
  "kobo"                   => "kobo",
  "Kokako"                 => "Kokakos",
  "konditorei"             => "konditorei",
  "Kongoese"               => "Kongoese",
  "Kongolese"              => "Kongolese",
  "Kosovo"                 => "Kosovos",
  "kouros"                 => "kouroi",
  "kovsh"                  => "kovshi",
  "kuvasz"                 => "kuvaszok",
  "kylix"                  => "kylixes",
  "labrum"                 => "labra",
  "lacinia"                => "laciniae",
  "lactobacillus"          => "lactobacilli",
  "lacuna"                 => "lacunas",
  "lacunar"                => "lacunars",
  "laika"                  => "laiki",
  "lamella"                => "lamellae",
  "lamina"                 => "laminae",
  "lapith"                 => "lapiths",
  "Lapith"                 => "Lapiths",
  "Lapponese"              => "Lapponese",
  "lar"                    => "lars",
  "larnax"                 => "larnakes",
  "larynx"                 => "larynges",
  "latex"                  => "latexes",
  "leaf"                   => "leaves",
  "Lebanese"               => "Lebanese",
  "lebensform"             => "lebensformen",
  "legionella"             => "legionellae",
  "legomenon"              => "legomena",
  "legumen"                => "legumens",
  "leishmania"             => "leishmanias",
  "leman"                  => "lemans",
  "lemma"                  => "lemmas",
  "lemniscus"              => "lemnisci",
  "lemur"                  => "lemurs",
  "lens"                   => "lenses",
  "lentigo"                => "lentigines",
  "lentiscus"              => "lentisci",
  "Leonese"                => "Leonese",
  "leproma"                => "lepromas",
  "leprosarium"            => "leprosaria",
  "leptomonas"             => "leptomonas",
  "lepton"                 => "lepta",
  "leptospira"             => "leptospirae",
  "Lesotho"                => "Lesothos",
  "leu"                    => "lei",
  "lex humana"             => "leges humanae",
  "lf"                     => "lves",
  "libero"                 => "liberos",
  "libido"                 => "libidos",
  "libretto"               => "librettos",
  "lido"                   => "lidos",
  "lied"                   => "lieder",
  "lieu"                   => "lieus",
  "lieutenant general"     => "lieutenant generals",
  "life"                   => "lives",
  "ligamentum"             => "ligamenta",
  "likuta"                 => "makuta",
  "Lilo"                   => "Lilos",
  "Liman"                  => "Limans",
  "limax"                  => "limaces",
  "limbo"                  => "limbos",
  "limes"                  => "limites",
  "limo"                   => "limos",
  "limulus"                => "limuli",
  "linctus"                => "linctuses",
  "line out"               => "line outs",
  "line-out"               => "line-outs",
  "linea"                  => "lineae",
  "lineno"                 => "linenos",
  "lingo"                  => "lingos",
  "lingula"                => "lingulae",
  "lino"                   => "linos",
  "lipoma"                 => "lipomata",
  "lis"                    => "lisses",
  "listerella"             => "listerellas",
  "listeria"               => "listerias",
  "lithodomus"             => "lithodomi",
  "lithophyton"            => "lithophyta",
  "livedo"                 => "livedos",
  "lixivium"               => "lixivia",
  "loa"                    => "loas",
  "loaf"                   => "loaves",
  "lobulus"                => "lobuli",
  "lochus"                 => "lochi",
  "loco"                   => "locos",
  "loculus"                => "loculi",
  "locus"                  => "loci",
  "loggia"                 => "loggias",
  "logion"                 => "logia",
  "logo"                   => "logos",
  "logodaedalus"           => "logodaedali",
  "loma"                   => "lomata",
  "lomentum"               => "lomenta",
  "Londonese"              => "Londonese",
  "lord lieutenant"        => "lord lieutenants",
  "lord-lieutenant"        => "lord-lieutenants",
  "Lorrainese"             => "Lorrainese",
  "lorum"                  => "lora",
  "louis"                  => "louis",
  "louse"                  => "lice",
  "lowlife"                => "lowlifes",
  "lox"                    => "loxes",
  "Lucchese"               => "Lucchese",
  "lumbago"                => "lumbagos",
  "lumbricus"              => "lumbrici",
  "lumen"                  => "lumens",
  "lustrum"                => "lustrums",
  "lux"                    => "lux",
  "lymphangioma"           => "lymphangiomata",
  "lymphoma"               => "lymphomas",
  "Lyonese"                => "Lyonese",
  "lyssa"                  => "lyssae",
  "maar"                   => "maars",
  "macacus"                => "macaci",
  "Macanese"               => "Macanese",
  "macaroni"               => "macaronies",
  "Macassarese"            => "Macassarese",
  "macho"                  => "machos",
  "mackerel"               => "mackerels",
  "macro"                  => "macros",
  "macula"                 => "maculas",
  "Madurese"               => "Madurese",
  "maecenas"               => "maecenases",
  "maestro"                => "maestros",
  "mafiosa"                => "mafiose",
  "mafioso"                => "mafiosi",
  "magilus"                => "magili",
  "magma"                  => "magmas",
  "magneto"                => "magnetos",
  "magnifico"              => "magnificos",
  "magnum opus"            => "magnum opuses",
  "magus"                  => "magi",
  "major general"          => "major generals",
  "Majuro"                 => "Majuros",
  "Malabarese"             => "Malabarese",
  "Malabo"                 => "Malabos",
  "malagma"                => "malagmata",
  "malleolus"              => "malleoli",
  "malleus"                => "mallei",
  "Maltese"                => "Maltese",
  "malum in se"            => "mala in se",
  "man"                    => "men",
  "man child"              => "men children",
  "man midwife"            => "men midwives",
  "man milliner"           => "man milliners",
  "man servant"            => "men servants",
  "man-child"              => "men-children",
  "man-midwife"            => "men-midwives",
  "man-milliner"           => "man-milliners",
  "man-servant"            => "men-servants",
  "manchild"               => "menchildren",
  "mango"                  => "mangos",
  "manifesto"              => "manifestos",
  "manservant"             => "menservants",
  "manteau"                => "manteaus",
  "mantelletta"            => "mantellette",
  "mantis"                 => "mantises",
  "manubrium"              => "manubriums",
  "Maputo"                 => "Maputos",
  "maquereau"              => "maquereaux",
  "Maracaibo"              => "Maracaibos",
  "mare"                   => "mares",
  "maremma"                => "maremme",
  "marquis"                => "marquises",
  "mary"                   => "maries",
  "Mary"                   => "Marys",
  "mater lectionis"        => "matres lectionis",
  "math"                   => "maths",
  "matin"                  => "matins",
  "matinee musicale"       => "matinees musicales",
  "matzah"                 => "matzahs",
  "mausoleum"              => "mausoleums",
  "maxilla"                => "maxillae",
  "maximum"                => "maximums",
  "me"                     => "us",
  "measles"                => "measles",
  "meatus"                 => "meatuses",
  "mediastinum"            => "mediastina",
  "mediatrix"              => "mediatrices",
  "medico"                 => "medicos",
  "medium"                 => "mediums",
  "medulloblastoma"        => "medulloblastomas",
  "medusa"                 => "medusas",
  "megalosaurus"           => "megalosauri",
  "megatherium"            => "megatheria",
  "melanoma"               => "melanomas",
  "melastoma"              => "melastomas",
  "meliceris"              => "melicerides",
  "melisma"                => "melismas",
  "memento"                => "mementos",
  "memo"                   => "memos",
  "memorandum"             => "memorandums",
  "menage a quatre"        => "menages a quatre",
  "menage a trois"         => "menages a trois",
  "meningioma"             => "meningiomas",
  "meniscus"               => "menisci",
  "menu"                   => "menus",
  "meretrix"               => "meretrices",
  "meris"                  => "merides",
  "meshumad"               => "meshumadim",
  "meshummad"              => "meshummadim",
  "mesothelioma"           => "mesotheliomas",
  "mesothelium"            => "mesothelia",
  "messa di voce"          => "messe di voce",
  "Messinese"              => "Messinese",
  "meta"                   => "metae",
  "metalimnion"            => "metalimnia",
  "metapleuron"            => "metapleura",
  "metatarsus"             => "metatarsi",
  "metro"                  => "metros",
  "metropolis"             => "metropolises",
  "mew"                    => "mews",
  "mews"                   => "mews",
  "Mexico"                 => "Mexicos",
  "mezuza"                 => "mezuzoth",
  "mezuzah"                => "mezuzoth",
  "mezzo rilievo"          => "mezzo rilievos",
  "mezzo-rilievo"          => "mezzo-rilievos",
  "miasma"                 => "miasmas",
  "micro"                  => "micros",
  "microbion"              => "microbia",
  "microcephalus"          => "microcephali",
  "micrococcus"            => "micrococci",
  "microfiche"             => "microfiches",
  "micronucleus"           => "micronuclei",
  "Milanese"               => "Milanese",
  "Milano"                 => "Milanos",
  "miles gloriosus"        => "milites gloriosi",
  "milieu"                 => "milieus",
  "milieu interieur"       => "milieux interieurs",
  "miliola"                => "miliolae",
  "millennium"             => "millenniums",
  "mimosa"                 => "mimosas",
  "mine"                   => "ours",
  "minimum"                => "minimums",
  "minnelied"              => "minnelieder",
  "minutia"                => "minutias",
  "minyan"                 => "minyanim",
  "miracidium"             => "miracidia",
  "mithraeum"              => "mithraea",
  "mitochondrion"          => "mitochondria",
  "mixolimnion"            => "mixolimnia",
  "mo"                     => "moes",
  "moaks"                  => "moakses",
  "modelletto"             => "modelletti",
  "modello"                => "modellos",
  "Modenese"               => "Modenese",
  "modernus"               => "moderni",
  "modius"                 => "modii",
  "modulus"                => "moduluses",
  "modus"                  => "moduses",
  "moe"                    => "moes",
  "molimen"                => "molimina",
  "momentum"               => "momentums",
  "Monaco"                 => "Monacos",
  "monas"                  => "monades",
  "mondo"                  => "mondi",
  "money"                  => "monies",
  "mongoose"               => "mongooses",
  "monimolimnion"          => "monimolimnia",
  "mono"                   => "monos",
  "monochasium"            => "monochasia",
  "monorchis"              => "monorchides",
  "monosyllabon"           => "monosyllaba",
  "monota"                 => "monotae",
  "monoxylon"              => "monoxyla",
  "mons"                   => "montes",
  "monseigneur"            => "monsiegneurs",
  "monsignor"              => "monsignors",
  "monsignore"             => "monsignori",
  "monstre sacre"          => "monstres sacres",
  "Montenegro"             => "Montenegros",
  "moose"                  => "moose",
  "moratorium"             => "moratoriums",
  "morceau"                => "morceaux",
  "Morocco"                => "Moroccos",
  "moroso"                 => "morosi",
  "mortadella"             => "mortadellas",
  "mortarium"              => "mortaria",
  "moscardino"             => "moscardini",
  "motoscafo"              => "motoscafi",
  "motto"                  => "mottos",
  "mouse"                  => "mice",
  "mousetrap"              => "mousetraps",
  "mouth"                  => "mouths",
  "mucro"                  => "mucros",
  "mukim"                  => "mukims",
  "multigravida"           => "multigravidas",
  "mumps"                  => "mumps",
  "municipium"             => "municipia",
  "Muqdisho"               => "Muqdishos",
  "Muranese"               => "Muranese",
  "murex"                  => "murexes",
  "musa"                   => "musas",
  "musee imaginaire"       => "musees imaginaires",
  "musique concrete"       => "musiques concretes",
  "mustachio"              => "mustachios",
  "muzz"                   => "muzzes",
  "mya"                    => "myas",
  "mycoplasma"             => "mycoplasmas",
  "mycorhiza"              => "mycorhizas",
  "mycorrhiza"             => "mycorrhizas",
  "myeloma"                => "myelomas",
  "myo"                    => "myos",
  "myself"                 => "ourselves",
  "mythos"                 => "mythoi",
  "myxoma"                 => "myxomata",
  "nachtlokal"             => "nachtlokale",
  "nagaika"                => "nagaikas",
  "Nakayaman"              => "Nakayamans",
  "Nankingese"             => "Nankingese",
  "nasutus"                => "nasuti",
  "naumachia"              => "naumachias",
  "nauplius"               => "nauplii",
  "nautilus"               => "nautiluses",
  "Navarrese"              => "Navarrese",
  "naya paisa"             => "naye paise",
  "nebenkern"              => "nebenkerne",
  "nebula"                 => "nebulas",
  "nectocalyx"             => "nectocalyces",
  "nemathecium"            => "nemathecia",
  "nenets"                 => "nentsi",
  "Nenets"                 => "Nenets",
  "Nepalese"               => "Nepalese",
  "nephridium"             => "nephridia",
  "nerita"                 => "neritas",
  "neuma"                  => "neumas",
  "neurinoma"              => "neurinomas",
  "neuroma"                => "neuromata",
  "neurula"                => "neurulae",
  "neutrino"               => "neutrinos",
  "news"                   => "news",
  "nexus"                  => "nexuses",
  "ngwee"                  => "ngwee",
  "Niasese"                => "Niasese",
  "Nicobarese"             => "Nicobarese",
  "nidus"                  => "niduses",
  "niello"                 => "niellos",
  "nimbus"                 => "nimbuses",
  "Ningbo"                 => "Ningbos",
  "Nipponese"              => "Nipponese",
  "nockerl"                => "nockerln",
  "noctiluca"              => "noctilucae",
  "nodum"                  => "noda",
  "nodus"                  => "nodi",
  "noema"                  => "noemata",
  "nomisma"                => "nomismata",
  "non ens"                => "nonentia",
  "non-ens"                => "nonentia",
  "Norman"                 => "Normans",
  "noumenon"               => "noumena",
  "nouveau pauvre"         => "nouvelle pauvre",
  "nouveau riche"          => "nouvelle riche",
  "nouvel arrive"          => "nouveaux arrives",
  "nova"                   => "novas",
  "novus homo"             => "novi homines",
  "noxa"                   => "noxae",
  "nse"                    => "nses",
  "nubecula"               => "nubeculae",
  "nucleolonema"           => "nucleolonemas",
  "nucleolus"              => "nucleoluses",
  "nucleus"                => "nuclei",
  "numen"                  => "numina",
  "nuntius"                => "nuntii",
  "nympha"                 => "nymphae",
  "nymphaeum"              => "nymphea",
  "nympheum"               => "nymphea",
  "oath"                   => "oaths",
  "obelus"                 => "obeli",
  "obolus"                 => "oboli",
  "occiput"                => "occiputs",
  "oceanarium"             => "oceanaria",
  "ocellus"                => "ocelli",
  "octavo"                 => "octavos",
  "octohedron"             => "octohedrons",
  "octopus"                => "octopuses",
  "oculus"                 => "oculi",
  "odeum"                  => "odea",
  "oedema"                 => "oedemas",
  "offspring"              => "offspring",
  "ogle"                   => "oglys",
  "Oklahoman"              => "Oklahomans",
  "olfactorium"            => "olfactoria",
  "omentum"                => "omenta",
  "ommatidium"             => "ommatidia",
  "onager"                 => "onagers",
  "one"                    => "some",
  "one star general"       => "one star generals",
  "one-star general"       => "one-star generals",
  "operculum"              => "opercula",
  "ophiophagus"            => "ophiophagi",
  "optimum"                => "optimums",
  "opus"                   => "opuses",
  "opus magnum"            => "opera magna",
  "opusculum"              => "opuscula",
  "oratrix"                => "oratrices",
  "oregano"                => "oreganos",
  "organon"                => "organa",
  "Orinoco"                => "Orinocos",
  "Orlando"                => "Orlandos",
  "orthoceras"             => "orthocerata",
  "osculum"                => "oscula",
  "Oslo"                   => "Oslos",
  "osmaterium"             => "osmateria",
  "osmeterium"             => "osmeteria",
  "ossiculum"              => "ossicula",
  "osteoclastoma"          => "osteoclastomas",
  "osteoma"                => "osteomata",
  "ostium"                 => "ostia",
  "oto"                    => "otos",
  "Otomi"                  => "Otomies",
  "otomi"                  => "otomies",
  "ottoman"                => "ottomans",
  "ovarium"                => "ovaria",
  "ovolo"                  => "ovoli",
  "ovulum"                 => "ovula",
  "ovum"                   => "ova",
  "ox"                     => "oxen",
  "oxybaphon"              => "oxybapha",
  "oxymoron"               => "oxymorons",
  "oxyuris"                => "oxyurides",
  "paha"                   => "paha",
  "paisa"                  => "paisas",
  "pajamas"                => "pajamas",
  "pala"                   => "palae",
  "palea"                  => "paleae",
  "pallium"                => "pallia",
  "palpebra"               => "palpebrae",
  "palpus"                 => "palpi",
  "palus"                  => "pali",
  "Panaman"                => "Panamans",
  "Pangasinan"             => "Pangasinans",
  "pangasinan"             => "pangasinans",
  "panino"                 => "panini",
  "panorpa"                => "panorpae",
  "pant"                   => "pants",
  "panto"                  => "pantos",
  "pants"                  => "pants",
  "paparrazo"              => "paparrazi",
  "papilla"                => "papillae",
  "papilloma"              => "papillomata",
  "papula"                 => "papulae",
  "papyrus"                => "papyruses",
  "parabola"               => "parabolas",
  "parabolanus"            => "parabolani",
  "parador"                => "paradors",
  "paraganglioma"          => "paragangliomas",
  "paraganglion"           => "paraganglia",
  "paraglossa"             => "paraglossae",
  "Paramaribo"             => "Paramaribos",
  "paranucleus"            => "paranuclei",
  "parapleura"             => "parapleura",
  "parapleurum"            => "parapleura",
  "parapsis"               => "parapsides",
  "paraselene"             => "paraselenae",
  "parc ferme"             => "parcs fermes",
  "Pardusco"               => "Parduscos",
  "parenchyma"             => "parenchymata",
  "parergon"               => "parerga",
  "parhelion"              => "parhelions",
  "paries"                 => "parietes",
  "parison"                => "parisa",
  "Parmese"                => "Parmese",
  "parnas"                 => "parnassim",
  "parnass"                => "parnassim",
  "parvenu"                => "parvenus",
  "pasteurella"            => "pasteurellas",
  "pastorale"              => "pastorales",
  "patagium"               => "patagia",
  "patera"                 => "paterae",
  "path"                   => "paths",
  "pathos"                 => "pathoses",
  "paxilla"                => "paxillae",
  "pecia"                  => "pecias",
  "pecten"                 => "pectens",
  "pectus"                 => "pectora",
  "pedalo"                 => "pedalos",
  "pedicellaria"           => "pedicellariae",
  "pediluvium"             => "pediluvia",
  "pedion"                 => "pedia",
  "Pekingese"              => "Pekingese",
  "pelta"                  => "peltae",
  "pelvis"                 => "pelvises",
  "pence"                  => "pence",
  "pendulum"               => "pendulums",
  "pengo"                  => "pengo",
  "penicillus"             => "penicilli",
  "peninsula"              => "peninsulas",
  "penis"                  => "penises",
  "penni"                  => "pennia",
  "penny"                  => "pennies",
  "pensiero"               => "pensieri",
  "perceptum"              => "percepta",
  "peridium"               => "peridia",
  "perikaryon"             => "perikarya",
  "perithecium"            => "perithecia",
  "pernio"                 => "perniones",
  "peronium"               => "peronia",
  "perradius"              => "perradii",
  "person"                 => "people",
  "persona"                => "personas",
  "pes"                    => "pedes",
  "phalangium"             => "phalangia",
  "phalanx"                => "phalanxes",
  "phallos"                => "phalloi",
  "phallus"                => "phalluses",
  "pharmakos"              => "pharmakoi",
  "phenomenon"             => "phenomena",
  "phlegmasia"             => "phlegmasiae",
  "phoca"                  => "phocas",
  "pholas"                 => "pholades",
  "photo"                  => "photos",
  "phototaxis"             => "phototaxes",
  "phragma"                => "phragmata",
  "phren"                  => "phrenes",
  "phyle"                  => "phylae",
  "phyllobranchia"         => "phyllobranchiae",
  "phylum"                 => "phylums",
  "phyma"                  => "phymata",
  "phyogemmarium"          => "phyogemmaria",
  "piano"                  => "pianos",
  "pickerel"               => "pickerels",
  "pied a terre"           => "pieds a terre",
  "pied noir"              => "pieds noirs",
  "Piedmontese"            => "Piedmontese",
  "pietra"                 => "pietre",
  "pifferaro"              => "pifferari",
  "pike"                   => "pikes",
  "pileus"                 => "pilei",
  "pillie"                 => "pilleis",
  "pilus"                  => "pili",
  "pimento"                => "pimentos",
  "pina colada"            => "pina coladas",
  "pinax"                  => "pinaces",
  "pincer"                 => "pincers",
  "pincers"                => "pincers",
  "pinetum"                => "pinetums",
  "pingo"                  => "pingos",
  "pinna"                  => "pinnas",
  "pinon"                  => "pinons",
  "pinto"                  => "pintos",
  "pipkrake"               => "pipkrakes",
  "piscina"                => "piscinas",
  "pistillidium"           => "pistillidia",
  "Pistoiese"              => "Pistoiese",
  "pithos"                 => "pithoi",
  "pizza"                  => "pizzas",
  "placebo"                => "placebos",
  "placitum"               => "placita",
  "planctus"               => "planctus",
  "plankter"               => "plankton",
  "planula"                => "planulae",
  "plasmalemma"            => "plasmalemmas",
  "plasmodium"             => "plasmodia",
  "plasmolyticum"          => "plasmolytica",
  "plasmoma"               => "plasmomata",
  "plateau"                => "plateaus",
  "platypus"               => "platypuses",
  "pleco"                  => "plecos",
  "plectrum"               => "plectra",
  "plenarium"              => "plenaria",
  "plesiosaurus"           => "plesiosauri",
  "plethron"               => "plethra",
  "pleura"                 => "pleura",
  "pleuron"                => "pleura",
  "pleurum"                => "pleura",
  "plexus"                 => "plexuses",
  "plica"                  => "plicae",
  "pliers"                 => "pliers",
  "ploshchadka"            => "ploshchadki",
  "plurale tantum"         => "pluralia tantum",
  "pluteus"                => "plutei",
  "Pluto"                  => "Plutos",
  "pneumothorax"           => "pneumothoraxes",
  "po"                     => "poes",
  "poblador"               => "pobladores",
  "poculum"                => "pocula",
  "podere"                 => "poderi",
  "podetium"               => "podetia",
  "podion"                 => "podia",
  "podium"                 => "podiums",
  "poe"                    => "poes",
  "pogo"                   => "pogos",
  "poise"                  => "poises",
  "polis"                  => "polises",
  "politbureau"            => "politbureaus",
  "politico"               => "politicos",
  "pollex"                 => "pollices",
  "pollinarium"            => "pollinaria",
  "pollinium"              => "pollinia",
  "polo"                   => "polos",
  "Polonese"               => "Polonese",
  "polythecium"            => "polythecia",
  "pomme de terre"         => "pommes de terre",
  "poncho"                 => "ponchos",
  "pontifex"               => "pontifexes",
  "porcino"                => "porcini",
  "porion"                 => "poria",
  "porron"                 => "porrons",
  "port a beul"            => "puirt a beul",
  "port de bras"           => "ports de bras",
  "port-a-beul"            => "puirt-a-beul",
  "portico"                => "porticos",
  "portiforium"            => "portiforia",
  "portmanteau"            => "portmanteaus",
  "Porto"                  => "Portos",
  "Porto Novo"             => "Porto Novos",
  "Porto-Novo"             => "Porto-Novos",
  "portrait parle"         => "portraits parles",
  "Portuguese"             => "Portuguese",
  "postnatus"              => "postnati",
  "postpubis"              => "postpubes",
  "postulatum"             => "postulata",
  "potato"                 => "potatoes",
  "potestas"               => "potestates",
  "pox"                    => "pox",
  "praecognitum"           => "praecognita",
  "pragma"                 => "pragmas",
  "precis"                 => "precis",
  "precognitum"            => "precognita",
  "premier danseur"        => "premiers danseurs",
  "prepenna"               => "prepennae",
  "prima ballerina"        => "prima ballerinas",
  "prima donna"            => "prima donnas",
  "primigravida"           => "primigravidae",
  "primordium"             => "primordia",
  "principium"             => "principia",
  "pro"                    => "pros",
  "proavis"                => "proaves",
  "proboscis"              => "proboscises",
  "proceedings"            => "proceedings",
  "procoelia"              => "procoeliae",
  "prodromus"              => "prodromi",
  "proferens"              => "proferentes",
  "profluvium"             => "profluvia",
  "proglottis"             => "proglottides",
  "programma"              => "programmata",
  "progymnasium"           => "progymnasia",
  "progymnasma"            => "progymnasmata",
  "prokaryon"              => "prokarya",
  "prolabium"              => "prolabia",
  "prolegomenon"           => "prolegomena",
  "promerops"              => "promeropes",
  "propleuron"             => "propleura",
  "propodium"              => "propodia",
  "propositus"             => "propositi",
  "proprium"               => "propria",
  "propylaeum"             => "propylaea",
  "propylon"               => "propylons",
  "prora"                  => "prorae",
  "prosa"                  => "prosae",
  "proscenium"             => "proscenia",
  "proscolla"              => "proscollae",
  "prosecutrix"            => "prosecutrices",
  "prosencephalon"         => "prosencephala",
  "proseucha"              => "proseuchae",
  "prosodiencephalon"      => "prosodiencephala",
  "prosopium"              => "prosopia",
  "prospectus"             => "prospectuses",
  "prosula"                => "prosulae",
  "protarsus"              => "protarsi",
  "prothallium"            => "prothallia",
  "prothallus"             => "prothalli",
  "protococcus"            => "protococci",
  "protoma"                => "protomas",
  "protonema"              => "protonemata",
  "prototypon"             => "prototypons",
  "protypon"               => "protypa",
  "proviso"                => "provisos",
  "prytanis"               => "prytanes",
  "psammoma"               => "psammomata",
  "pseudopodium"           => "pseudopodia",
  "pseudostoma"            => "pseudostomata",
  "psycho"                 => "psychos",
  "psydracium"             => "psydracia",
  "pteroma"                => "pteromata",
  "pteropus"               => "pteropi",
  "pteryla"                => "pterylae",
  "pueblo"                 => "pueblos",
  "pul"                    => "puls",
  "pullus"                 => "pulli",
  "pulmonarium"            => "pulmonaria",
  "pulsellum"              => "pulsella",
  "pulveratrix"            => "pulveratrices",
  "punctum"                => "puncta",
  "punto blanco"           => "puntos blancos",
  "pupa"                   => "pupae",
  "purlieu"                => "purlieus",
  "Purum"                  => "Purums",
  "purum"                  => "purums",
  "putto"                  => "putti",
  "puttony"                => "puttonys",
  "pycnidium"              => "pycnidia",
  "pycnis"                 => "pycnides",
  "pycnium"                => "pycnia",
  "pyjamas"                => "pyjamas",
  "pyla"                   => "pylae",
  "pyralis"                => "pyralides",
  "pyramidion"             => "pyramidions",
  "pyrexia"                => "pyrexiae",
  "pyrites"                => "pyritae",
  "pyrophorus"             => "pyrophori",
  "pyxidium"               => "pyxidia",
  "quadratrix"             => "quadratrices",
  "quaesitum"              => "quaesita",
  "quantum"                => "quantums",
  "quarto"                 => "quartos",
  "quartz"                 => "quartzes",
  "quid"                   => "quid",
  "quinarius"              => "quinarii",
  "quinquennium"           => "quinquennia",
  "Quito"                  => "Quitos",
  "rabies"                 => "rabies",
  "rad"                    => "rads",
  "radiale"                => "radialia",
  "radius"                 => "radiuses",
  "radix"                  => "radixes",
  "ragazza"                => "ragazze",
  "ragazzo"                => "ragazzi",
  "raggare"                => "raggares",
  "ramulus"                => "ramuli",
  "ramus"                  => "rami",
  "ranunculus"             => "ranunculuses",
  "rara avis"              => "rara avises",
  "razz"                   => "razzes",
  "rectus"                 => "recti",
  "redia"                  => "rediae",
  "reductio"               => "reductiones",
  "referendum"             => "referendums",
  "refugium"               => "refugia",
  "regidor"                => "regidors",
  "regma"                  => "regmata",
  "regulus"                => "reguli",
  "reich"                  => "reiche",
  "rejon"                  => "rejones",
  "rejoneador"             => "rejoneadores",
  "relatum"                => "relata",
  "rem"                    => "rems",
  "remex"                  => "remexes",
  "remous"                 => "remous",
  "replum"                 => "repla",
  "representamen"          => "representamens",
  "res"                    => "res",
  "residuum"               => "residuums",
  "responsum"              => "responsa",
  "rete"                   => "retia",
  "retinaculum"            => "retinacula",
  "retinula"               => "retinulae",
  "rezident"               => "rezidenty",
  "rezidentsia"            => "rezidentsii",
  "rhino"                  => "rhinos",
  "rhinoceros"             => "rhinoceroses",
  "rhinophyma"             => "rhinophymas",
  "rhizoma"                => "rhizomas",
  "rhododendron"           => "rhododendrons",
  "rhombohedron"           => "rhombohedrons",
  "rhomboideus"            => "rhomboidei",
  "rhopalium"              => "rhopalia",
  "rhynchodaeum"           => "rhynchodaea",
  "rhythmus"               => "rhythmi",
  "ri"                     => "ri",
  "ricercar"               => "ricercars",
  "ricercata"              => "ricercate",
  "ricordo"                => "ricordi",
  "rideau"                 => "rideaus",
  "rilievo"                => "rilievos",
  "rimon"                  => "rimonim",
  "rione"                  => "rioni",
  "risotto"                => "risottos",
  "ritardando"             => "ritardandos",
  "rite de passage"        => "rites de passage",
  "rococo"                 => "rococos",
  "roe"                    => "roes",
  "Rom"                    => "Roma",
  "rom"                    => "roms",
  "Romagnese"              => "Romagnese",
  "Roman"                  => "Romans",
  "Romanese"               => "Romanese",
  "Romany"                 => "Romanies",
  "romanze"                => "romanzen",
  "rond de jambe"          => "rond de jambes",
  "rondeau"                => "rondeaus",
  "rondo"                  => "rondos",
  "rostrum"                => "rostrums",
  "rotula"                 => "rotulae",
  "route nationale"        => "routes nationales",
  "rubashka"               => "rubashkas",
  "ruga"                   => "rugae",
  "ruse de guerre"         => "ruses de guerre",
  "rype"                   => "ryper",
  "sabertooth"             => "sabertooths",
  "sacculus"               => "sacculi",
  "sacellum"               => "sacella",
  "sachverhalt"            => "sachverhalte",
  "Sacramento"             => "Sacramentos",
  "sacrarium"              => "sacraria",
  "sacrum"                 => "sacrums",
  "saddo"                  => "saddos",
  "saffo"                  => "saffi",
  "sago"                   => "sagos",
  "sagum"                  => "saga",
  "salita"                 => "salitas",
  "salivarium"             => "salivaria",
  "salmon"                 => "salmon",
  "salpa"                  => "salpas",
  "salvo"                  => "salvos",
  "sambo"                  => "sambos",
  "samurai"                => "samurai",
  "sanatorium"             => "sanatoriums",
  "sanctum sanctorum"      => "sancta sanctorum",
  "sandr"                  => "sandrs",
  "Sangirese"              => "Sangirese",
  "Santiago"               => "Santiagos",
  "Sapporo"                => "Sapporos",
  "Sarajevo"               => "Sarajevos",
  "Sarawakese"             => "Sarawakese",
  "sarcina"                => "sarcinae",
  "sarcoma"                => "sarcomas",
  "sarcophagus"            => "sarcophagi",
  "sarissa"                => "sarissae",
  "sassafras"              => "sassafrases",
  "satelles"               => "satellites",
  "saxicava"               => "saxicavae",
  "sbirro"                 => "sbirri",
  "scalenus"               => "scaleni",
  "scandalum magnatum"     => "scandala magnatum",
  "scapula"                => "scapulas",
  "scapus"                 => "scapi",
  "scarabaeus"             => "scarabaei",
  "scarus"                 => "scari",
  "scazon"                 => "scazontes",
  "sceat"                  => "sceattas",
  "schema"                 => "schemas",
  "scherzando"             => "scherzandos",
  "scherzo"                => "scherzos",
  "schisma"                => "schismata",
  "schistosomulum"         => "schistosomula",
  "schizostylis"           => "schizostylis",
  "scholium"               => "scholia",
  "sciolus"                => "scioli",
  "scirrhus"               => "scirrhusses",
  "scissors"               => "scissors",
  "scolex"                 => "scoleces",
  "scolopidium"            => "scolopidia",
  "scomber"                => "scombri",
  "scoria"                 => "scorias",
  "scotoma"                => "scotomas",
  "scriptorium"            => "scriptoriums",
  "scudo"                  => "scudi",
  "scungille"              => "scungilli",
  "scuola"                 => "scuole",
  "scutellum"              => "scutella",
  "scutulum"               => "scutula",
  "scutum"                 => "scuta",
  "scyphus"                => "scyphi",
  "seaquarium"             => "seaquaria",
  "secans"                 => "secantes",
  "secretum"               => "secreta",
  "secundagravida"         => "secundagravidas",
  "secundigravida"         => "secundigravidas",
  "secundipara"            => "secundiparas",
  "sedes"                  => "sedes",
  "sedile"                 => "sedilia",
  "seecatch"               => "seecatchie",
  "seed"                   => "seeds",
  "Selman"                 => "Selmans",
  "sema"                   => "semas",
  "seminium"               => "seminia",
  "semuncia"               => "semunciae",
  "senarius"               => "senarii",
  "Senegalese"             => "Senegalese",
  "senex"                  => "senes",
  "sensedatum"             => "sensedata",
  "sensillum"              => "sensilla",
  "sensoriolum"            => "sensoriola",
  "sensum"                 => "sensa",
  "sententia"              => "sententiae",
  "separatrix"             => "separatrices",
  "sephardi"               => "sephardim",
  "septarium"              => "septaria",
  "septemvir"              => "septemviri",
  "septenarius"            => "septenarii",
  "septum"                 => "septa",
  "sequela"                => "sequelae",
  "sequestrum"             => "sequestra",
  "seraph"                 => "seraphs",
  "sericterium"            => "sericteria",
  "series"                 => "series",
  "serir"                  => "serirs",
  "serpigo"                => "serpigoes",
  "serpula"                => "serpulae",
  "serra"                  => "serrae",
  "sertularia"             => "sertularias",
  "serum"                  => "serums",
  "sestertium"             => "sestertia",
  "sestiere"               => "sestieri",
  "set off"                => "set offs",
  "set out"                => "set outs",
  "set to"                 => "set tos",
  "set-off"                => "set-offs",
  "set-out"                => "set-outs",
  "set-to"                 => "set-tos",
  "seta"                   => "setae",
  "sezession"              => "sezessionen",
  "sforzato"               => "sforzatos",
  "sgraffiato"             => "sgraffiati",
  "shad"                   => "shads",
  "shaman"                 => "shamans",
  "shauri"                 => "shauris",
  "Shavese"                => "Shavese",
  "shawabti"               => "shawabtis",
  "Shawanese"              => "Shawanese",
  "she"                    => "they",
  "shear"                  => "shears",
  "shears"                 => "shears",
  "sheep"                  => "sheep",
  "shelf"                  => "shelves",
  "shifta"                 => "shiftas",
  "shochet"                => "shochetim",
  "shomer"                 => "shomrim",
  "short"                  => "shorts",
  "shorts"                 => "shorts",
  "Siamese"                => "Siamese",
  "siemens"                => "siemens",
  "Sienese"                => "Sienese",
  "siglos"                 => "sigli",
  "signum"                 => "signa",
  "Sikkimese"              => "Sikkimese",
  "silbador"               => "silbadors",
  "silenus"                => "sileni",
  "silex"                  => "silices",
  "siliqua"                => "siliquae",
  "silo"                   => "silos",
  "Silurus"                => "Siluri",
  "simia"                  => "simiae",
  "simplex"                => "simplexes",
  "simpulum"               => "simpula",
  "simulacrum"             => "simulacrums",
  "sinfonia"               => "sinfonias",
  "Singhalese"             => "Singhalese",
  "Sinhalese"              => "Sinhalese",
  "sinus"                  => "sinuses",
  "siphunculus"            => "siphunculi",
  "sipunculus"             => "sipunculi",
  "sirocco"                => "siroccos",
  "sis"                    => "ses",
  "sistrum"                => "sistrums",
  "situla"                 => "situlas",
  "six star general"       => "six star generals",
  "six-star general"       => "six-star generals",
  "sizz"                   => "sizzes",
  "ski"                    => "skis",
  "snekkja"                => "snekkjur",
  "snipe"                  => "snipes",
  "snooze"                 => "snoozes",
  "so"                     => "soes",
  "soe"                    => "soes",
  "Sogdianese"             => "Sogdianese",
  "sol"                    => "soles",
  "solarium"               => "solaria",
  "soldo"                  => "soldi",
  "solenium"               => "solenia",
  "solfeggio"              => "solfeggios",
  "solidus"                => "solidi",
  "solo"                   => "solos",
  "solstitium"             => "solstitia",
  "solvus"                 => "solvi",
  "soma"                   => "somas",
  "somaten"                => "somatenes",
  "sombrero"               => "sombreros",
  "Sonaman"                => "Sonamans",
  "soprano"                => "sopranos",
  "soralium"               => "soralia",
  "soredium"               => "soredia",
  "sorus"                  => "sori",
  "soshi"                  => "soshi",
  "sotch"                  => "sotches",
  "souvlaki"               => "souvlakis",
  "spadix"                 => "spadixes",
  "Spaetlese"              => "Spaetlesen",
  "sparus"                 => "spari",
  "spasmus"                => "spasmi",
  "spatha"                 => "spathae",
  "species"                => "species",
  "spectrum"               => "spectrums",
  "speculum"               => "speculums",
  "sperma"                 => "spermata",
  "spermarium"             => "spermaria",
  "spermatheca"            => "spermathecae",
  "spermatium"             => "spermatia",
  "spermatoon"             => "spermatoa",
  "spermogonium"           => "spermogonia",
  "sphaeridium"            => "sphaeridia",
  "sphagnum"               => "sphagnums",
  "sphex"                  => "spheges",
  "sphinx"                 => "sphinxes",
  "spiculum"               => "spicula",
  "spiraculum"             => "spiracula",
  "spirillum"              => "spirilla",
  "spondylus"              => "spondyli",
  "sporodochium"           => "sporodochia",
  "sputum"                 => "sputa",
  "squadra"                => "squadre",
  "squadrist"              => "squadrists",
  "squalus"                => "squali",
  "squama"                 => "squamae",
  "squilla"                => "squillae",
  "stabilimentum"          => "stabilimenta",
  "staccato"               => "staccatos",
  "stadium"                => "stadiums",
  "stalactite"             => "stalactites",
  "stamen"                 => "stamen",
  "staminidium"            => "staminidia",
  "staphylococcus"         => "staphylococci",
  "star fish"              => "star fishes",
  "star-fish"              => "star-fishes",
  "starets"                => "startsy",
  "staretz"                => "startzy",
  "starfish"               => "starfishes",
  "starosta"               => "starosti",
  "starover"               => "starovers",
  "stasimon"               => "stasimons",
  "statera"                => "staterae",
  "statua"                 => "statuas",
  "status"                 => "statuses",
  "stela"                  => "stelas",
  "stella"                 => "stellae",
  "stemma"                 => "stemmata",
  "stephanion"             => "stephanions",
  "sterigma"               => "sterigmata",
  "sternebra"              => "sternebrae",
  "sterno"                 => "sternos",
  "sternum"                => "sternums",
  "stichidium"             => "stichidia",
  "stichos"                => "stichoi",
  "stigma"                 => "stigmas",
  "stigmaria"              => "stigmariae",
  "stiletto"               => "stilettoes",
  "stillicidium"           => "stillicidia",
  "stimulus"               => "stimuli",
  "stipes"                 => "stipites",
  "stipula"                => "stipulas",
  "stirps"                 => "stirpes",
  "stoa"                   => "stoas",
  "stolo"                  => "stolones",
  "stoma"                  => "stomas",
  "stomach"                => "stomachs",
  "stomatium"              => "stomatia",
  "stomion"                => "stomia",
  "stomodaeum"             => "stomodea",
  "storey"                 => "storeys",
  "stornello"              => "stornelli",
  "strambotto"             => "strambotti",
  "strategos"              => "strategoi",
  "strategus"              => "strategi",
  "stratum"                => "stratums",
  "streptococcus"          => "streptococci",
  "streptothrix"           => "streptothrices",
  "stria"                  => "striae",
  "striatum"               => "striata",
  "striga"                 => "strigae",
  "striola"                => "striolae",
  "strobila"               => "strobilae",
  "strobilus"              => "strobili",
  "stroma"                 => "stromata",
  "stromodeum"             => "stromodea",
  "struma"                 => "strumae",
  "stryddag"               => "stryddae",
  "stucco"                 => "stuccos",
  "studium generale"       => "studia generali",
  "stylo"                  => "stylos",
  "stylopodium"            => "stylopodia",
  "stylus"                 => "styluses",
  "subbotnik"              => "subbotniks",
  "subsellium"             => "subsellia",
  "subsidium"              => "subsidia",
  "substratum"             => "substratums",
  "succinea"               => "succineas",
  "succubus"               => "succubuses",
  "succus"                 => "succi",
  "Sudanese"               => "Sudanese",
  "suffrutex"              => "suffrutices",
  "suggestio falsi"        => "suggestiones falsi",
  "suggestum"              => "suggestums",
  "sulcus"                 => "sulci",
  "sum total"              => "sum totals",
  "sum-total"              => "sum-totals",
  "summa"                  => "summae",
  "summum bonum"           => "summa bona",
  "summum genus"           => "summa genera",
  "sumo"                   => "sumos",
  "Sundanese"              => "Sundanese",
  "supercilium"            => "supercilia",
  "superficies"            => "superficies",
  "supernova"              => "supernovas",
  "superstratum"           => "superstrata",
  "suppositum"             => "supposita",
  "supracleithrum"         => "supracleithra",
  "suprascapula"           => "suprascapulae",
  "surculus"               => "surculi",
  "surimono"               => "surimonos",
  "sustentaculum"          => "sustentacula",
  "Swahilese"              => "Swahilese",
  "swine"                  => "swine",
  "switchfoot"             => "switchfoots",
  "syllabarium"            => "syllabaria",
  "syllabus"               => "syllabuses",
  "symplasma"              => "symplasmata",
  "sympodium"              => "sympodia",
  "symposium"              => "symposiums",
  "synaesthesia"           => "synaesthesiae",
  "synangium"              => "synangia",
  "synapticula"            => "synapticulas",
  "synaxarion"             => "synaxaria",
  "synaxarium"             => "synaxaria",
  "synaxis"                => "synaxes",
  "syncellus"              => "syncelli",
  "syncytium"              => "syncytia",
  "syndendrium"            => "syndendria",
  "synechia"               => "synechiae",
  "synedrion"              => "synedria",
  "synedrium"              => "synedria",
  "synesthesia"            => "synesthesiae",
  "syntagma"               => "syntagmas",
  "syntaxis"               => "syntaxes",
  "synthronus"             => "synthroni",
  "synusia"                => "synusiae",
  "syphiloma"              => "syphilomata",
  "syringe"                => "syringes",
  "syrinx"                 => "syrinxes",
  "syrphus"                => "syrphi",
  "syrtis"                 => "syrtes",
  "tabella"                => "tabellae",
  "tableau"                => "tableaus",
  "tablinum"               => "tablina",
  "tabula"                 => "tabulae",
  "Tacoman"                => "Tacomans",
  "taenia"                 => "taenias",
  "tagma"                  => "tagmata",
  "Taiko"                  => "Taikos",
  "talea"                  => "taleae",
  "talisman"               => "talismans",
  "talouse"                => "talouses",
  "talus"                  => "tali",
  "tango"                  => "tangos",
  "tarantata"              => "tarantate",
  "tarantato"              => "tarantati",
  "tarsus"                 => "tarsi",
  "taxis"                  => "taxes",
  "taxon"                  => "taxa",
  "tazza"                  => "tazze",
  "teal"                   => "teals",
  "techno"                 => "technos",
  "tegmen"                 => "tegmina",
  "tegmentum"              => "tegmenta",
  "tegula"                 => "tegulae",
  "telamon"                => "telamones",
  "telium"                 => "telia",
  "temblor"                => "temblores",
  "tempietto"              => "tempietti",
  "tempo"                  => "tempos",
  "tenaculum"              => "tenacula",
  "tenderfoot"             => "tenderfoots",
  "Tenggerese"             => "Tenggerese",
  "tenia"                  => "tenias",
  "tenorino"               => "tenorini",
  "tentaculum"             => "tentacula",
  "tentamen"               => "tentamina",
  "tenuis"                 => "tenues",
  "tepidarium"             => "tepidaria",
  "teratoma"               => "teratomata",
  "terebellum"             => "terebella",
  "terebratula"            => "terebratulas",
  "teredo"                 => "teredos",
  "tergum"                 => "terga",
  "termes"                 => "termites",
  "terminus"               => "terminuses",
  "terp"                   => "terps",
  "terrae filius"          => "terrae filii",
  "terramara"              => "terremare",
  "terrarium"              => "terrariums",
  "terrazzo"               => "terrazzos",
  "territorium"            => "territoria",
  "terzetto"               => "terzetti",
  "tessella"               => "tessellas",
  "tessera"                => "tesserae",
  "testes"                 => "testes",
  "testis"                 => "testes",
  "testudo"                => "testudos",
  "tetanothrum"            => "tetanothra",
  "tete a tete"            => "tete a tetes",
  "tete-a-tete"            => "tete-a-tetes",
  "tetracolon"             => "tetracola",
  "tetragrammaton"         => "tetragrammata",
  "tetrahedron"            => "tetrahedrons",
  "tetrapleuron"           => "tetrapleurons",
  "tetrasporangium"        => "tetrasporangia",
  "thalamos"               => "thalamoi",
  "thalamus"               => "thalami",
  "thanatorium"            => "thanatoria",
  "that"                   => "those",
  "thaumaturgus"           => "thaumaturgi",
  "thebe"                  => "thebe",
  "theca"                  => "thecae",
  "theirs"                 => "theirs",
  "thelycum"               => "thelyca",
  "them"                   => "them",
  "thema"                  => "themata",
  "themself"               => "themselves",
  "themselves"             => "themselves",
  "theologoumenon"         => "theologoumena",
  "thesaurus"              => "thesauruses",
  "they"                   => "they",
  "thief"                  => "thieves",
  "this"                   => "these",
  "tholos"                 => "tholoi",
  "tholus"                 => "tholi",
  "thorax"                 => "thoraxes",
  "thos"                   => "thoes",
  "thraso"                 => "thrasoes",
  "three star general"     => "three star generals",
  "three-star general"     => "three-star generals",
  "thymiaterion"           => "thymiateria",
  "thymus"                 => "thymi",
  "thyridium"              => "thyridia",
  "thyrsus"                => "thyrsi",
  "tibia"                  => "tibiae",
  "Timorese"               => "Timorese",
  "timpano"                => "timpanos",
  "tintinnabulum"          => "tintinnabula",
  "tipula"                 => "tipulae",
  "tiro"                   => "tiros",
  "Tirolese"               => "Tirolese",
  "to"                     => "toes",
  "tobacco"                => "tobaccos",
  "Tocharese"              => "Tocharese",
  "toe"                    => "toes",
  "Togo"                   => "Togos",
  "Tokyo"                  => "Tokyos",
  "tolkach"                => "tolkachi",
  "tomato"                 => "tomatoes",
  "tombarolo"              => "tombaroli",
  "tomium"                 => "tomia",
  "tondo"                  => "tondi",
  "tong"                   => "tongs",
  "tongs"                  => "tongs",
  "Tonkinese"              => "Tonkinese",
  "tonneau"                => "tonneaus",
  "tooth"                  => "teeth",
  "topaz"                  => "topazes",
  "topos"                  => "topoi",
  "torero"                 => "toreros",
  "toril"                  => "toriles",
  "Torinese"               => "Torinese",
  "Torino"                 => "Torinos",
  "torma"                  => "tormas",
  "Tornese"                => "Tornesi",
  "tornus"                 => "torni",
  "Toronto"                => "Torontos",
  "torso"                  => "torsos",
  "tortilla espanola"      => "tortillas espanolas",
  "tortrix"                => "tortrices",
  "torula"                 => "torulae",
  "torulus"                => "toruli",
  "torus"                  => "toruses",
  "tour de force"          => "tours de force",
  "toxicum"                => "toxica",
  "toxius"                 => "toxii",
  "toxoplasma"             => "toxoplasmata",
  "trabea"                 => "trabeae",
  "trabecula"              => "trabeculae",
  "trachea"                => "tracheae",
  "tractatrix"             => "tractatrices",
  "tractellum"             => "tractella",
  "tractrix"               => "tractrices",
  "tragus"                 => "tragi",
  "trapezium"              => "trapeziums",
  "trapezius"              => "trapezii",
  "trapezohedron"          => "trapezohedrons",
  "trattoria"              => "trattorias",
  "trauma"                 => "traumas",
  "trellis"                => "trellises",
  "tremolo"                => "tremolos",
  "treponema"              => "treponemata",
  "trichidium"             => "trichidia",
  "trichina"               => "trichine",
  "trichoma"               => "trichomata",
  "triclinium"             => "triclinia",
  "triens"                 => "trientes",
  "triforium"              => "triforia",
  "trilby"                 => "trilbys",
  "triplum"                => "tripla",
  "triradius"              => "triradii",
  "triumvir"               => "triumvirs",
  "trochus"                => "trochuses",
  "trockenbeerenauslese"   => "trockenbeerenauslesen",
  "tropaeolum"             => "tropaeolums",
  "troparion"              => "troparia",
  "tropis"                 => "tropides",
  "trousers"               => "trousers",
  "trousseau"              => "trousseaus",
  "trout"                  => "trout",
  "trullo"                 => "trulli",
  "trumeau"                => "trumeaux",
  "tsuba"                  => "tsubas",
  "tsubo"                  => "tsubos",
  "tuber"                  => "tuberes",
  "tuberculoma"            => "tuberculomas",
  "tuberculum"             => "tubercula",
  "tubulus"                => "tubuli",
  "tumulus"                => "tumuli",
  "tuna"                   => "tuna",
  "turbot"                 => "turbots",
  "turf"                   => "turfs",
  "turron"                 => "turrons",
  "two star general"       => "two star generals",
  "two-star general"       => "two-star generals",
  "tympanum"               => "tympana",
  "typo"                   => "typos",
  "tyro"                   => "tyros",
  "Tyrolese"               => "Tyrolese",
  "udarnik"                => "udarniki",
  "ulpan"                  => "ulpanim",
  "ultimatum"              => "ultimatums",
  "umbilicus"              => "umbilicuses",
  "umbo"                   => "umbos",
  "umbra"                  => "umbras",
  "umwelt"                 => "umwelten",
  "uncia"                  => "unciae",
  "uncinus"                => "uncini",
  "uncus"                  => "unci",
  "unguis"                 => "ungues",
  "unio"                   => "unios",
  "uomo"                   => "uomini",
  "uomo universale"        => "uomini universali",
  "uraeus"                 => "uraei",
  "uredinium"              => "uredinia",
  "uredium"                => "uredia",
  "uredosorus"             => "uredosori",
  "urodaeum"               => "urodaea",
  "urodeum"                => "urodea",
  "urus"                   => "uruses",
  "usnea"                  => "usneas",
  "ustilago"               => "ustilagines",
  "uterus"                 => "uteruses",
  "utricularia"            => "utriculariae",
  "uva"                    => "uvae",
  "vaalpens"               => "vaalpens",
  "vacuum"                 => "vacuums",
  "vagina"                 => "vaginas",
  "vaginula"               => "vaginulae",
  "vagus"                  => "vagi",
  "vallecula"              => "valleculae",
  "valuta"                 => "valute",
  "valvula"                => "valvulae",
  "vaporetto"              => "vaporettos",
  "vaquero"                => "vaqueros",
  "varella"                => "varellaes",
  "varia lectio"           => "variae lectiones",
  "varix"                  => "varices",
  "vas"                    => "vasa",
  "vasculitis"             => "vasculitises",
  "vasculum"               => "vasculums",
  "veduta"                 => "vedutas",
  "veg"                    => "veges",
  "vehiculum"              => "vehicula",
  "velamen"                => "velamina",
  "velarium"               => "velaria",
  "velum"                  => "velums",
  "vena"                   => "venae",
  "venus"                  => "venuses",
  "vermicello"             => "vermicellos",
  "vermiculus"             => "vermiculi",
  "Vermontese"             => "Vermontese",
  "Veronese"               => "Veronese",
  "verruca"                => "verrucae",
  "vers libre"             => "vers libres",
  "versiculus"             => "versiculi",
  "verso"                  => "versos",
  "vertebra"               => "vertebrae",
  "vertex"                 => "vertexes",
  "verticillus"            => "verticilli",
  "vesicula"               => "vesiculae",
  "vestigium"              => "vestigia",
  "vetturino"              => "vetturini",
  "viale"                  => "viali",
  "viaticum"               => "viatica",
  "vibex"                  => "vibices",
  "vibraculum"             => "vibracula",
  "vibrato"                => "vibratos",
  "vibrio"                 => "vibrios",
  "Viennese"               => "Viennese",
  "Vietnamese"             => "Vietnamese",
  "vila"                   => "vilas",
  "villanella"             => "villanelle",
  "villino"                => "villini",
  "villus"                 => "villi",
  "vinculum"               => "vincula",
  "violetta"               => "violette",
  "violoncello"            => "violoncellos",
  "virga"                  => "virgae",
  "Virgo"                  => "Virgos",
  "virtuoso"               => "virtuosos",
  "virus"                  => "viruses",
  "vis"                    => "vires",
  "viscus"                 => "viscera",
  "vitellarium"            => "vitellaria",
  "vitta"                  => "vittae",
  "vivarium"               => "vivariums",
  "vlakte"                 => "vlaktes",
  "voeu"                   => "voeux",
  "volcanello"             => "volcanelli",
  "volcano"                => "volcanos",
  "vomica"                 => "vomicas",
  "vomitorium"             => "vomitoriums",
  "voorbok"                => "voorbokke",
  "vorspiel"               => "vorspiele",
  "vorstellung"            => "vorstellungen",
  "vortex"                 => "vortexes",
  "wadi"                   => "wadies",
  "wady"                   => "wadies",
  "waldo"                  => "waldos",
  "waltz"                  => "waltzes",
  "wanderjahr"             => "wanderjahre",
  "wandervogel"            => "wandervogel",
  "washer up"              => "washers up",
  "washer-up"              => "washers-up",
  "weirdo"                 => "weirdos",
  "Wenchowese"             => "Wenchowese",
  "wharf"                  => "wharfs",
  "what"                   => "what",
  "whatever"               => "whatever",
  "whatsoever"             => "whatsoever",
  "white staff"            => "white staves",
  "whiting"                => "whiting",
  "Whitmanese"             => "Whitmanese",
  "who"                    => "who",
  "whoever"                => "whoever",
  "whom"                   => "whom",
  "whomever"               => "whomever",
  "whomsoever"             => "whomsoever",
  "whose"                  => "whose",
  "whosesoever"            => "whosesoever",
  "whosever"               => "whosever",
  "whosoever"              => "whosoever",
  "wife"                   => "wives",
  "wildebeest"             => "wildebeests",
  "wolf"                   => "wolves",
  "woman child"            => "women children",
  "woman servant"          => "women servants",
  "woman-child"            => "women-children",
  "woman-servant"          => "women-servants",
  "womanchild"             => "womenchildren",
  "wreath"                 => "wreaths",
  "xanthoma"               => "xanthomas",
  "xiphiplastron"          => "xiphiplastra",
  "xiphopagus"             => "xiphopagi",
  "xiphoplastron"          => "xiphoplastra",
  "xoanon"                 => "xoana",
  "xystus"                 => "xysti",
  "Yakiman"                => "Yakimans",
  "Yamoussoukro"           => "Yamoussoukros",
  "yarraman"               => "yarramen",
  "Yengeese"               => "Yengeese",
  "yes"                    => "yeses",
  "yo"                     => "yoes",
  "yo yo"                  => "yo yos",
  "yo-yo"                  => "yo-yos",
  "yoe"                    => "yoes",
  "Yokohaman"              => "Yokohamans",
  "you"                    => "you",
  "yours"                  => "yours",
  "yourself"               => "yourselves",
  "Yuman"                  => "Yumans",
  "Yunnanese"              => "Yunnanese",
  "yuo"                    => "yuon",
  "zadruga"                => "zadrugas",
  "zeitgeber"              => "zeitgebers",
  "zemirah"                => "zemiroth",
  "zeppole"                => "zeppoli",
  "zero"                   => "zeros",
  "Zibo"                   => "Zibos",
  "zingano"                => "zingani",
  "zita"                   => "ziti",
  "zitella"                => "zitelle",
  "zizz"                   => "zizzes",
  "zloty"                  => "zlotys",
  "zoaea"                  => "zoaeae",
  "zoarium"                => "zoaria",
  "zoea"                   => "zoeas",
  "zooea"                  => "zooeae",
  "zooecium"               => "zooecia",
  "zoon"                   => "zoa",
  "zoophorus"              => "zoophori",
  "zoosporangium"          => "zoosporangia",
  "zophorus"               => "zophori",
  "zucca"                  => "zucche",
  "zucchini"               => "zucchinis",
  "zuppa"                  => "zuppe",
  "zuz"                    => "zuzzes",
  "zygantrum"              => "zygantra",
  "zygoma"                 => "zygomas",
  "zygon"                  => "zyga",
};

my $classical_plural_of = {
  " ox"                    => " oxen",
  "-ox"                    => "-oxen",
  "1 star general"         => "1 star generals",
  "1-star general"         => "1-star generals",
  "2 star general"         => "2 star generals",
  "2-star general"         => "2-star generals",
  "3 star general"         => "3 star generals",
  "3-star general"         => "3-star generals",
  "4 star general"         => "4 star generals",
  "4-star general"         => "4-star generals",
  "5 star general"         => "5 star generals",
  "5-star general"         => "5-star generals",
  "6 star general"         => "6 star generals",
  "6-star general"         => "6-star generals",
  "abacus"                 => "abacuses",
  "aboiteau"               => "aboiteaux",
  "abortorium"             => "abortoria",
  "abortus"                => "abortuses",
  "abscissa"               => "abscissae",
  "abstractum"             => "abstracta",
  "acarus"                 => "acari",
  "Achinese"               => "Achinese",
  "acicula"                => "aciculae",
  "acinus"                 => "acini",
  "acroama"                => "acroamata",
  "acropolis"              => "acropolises",
  "actinia"                => "actiniae",
  "aculeus"                => "aculei",
  "addendum"               => "addenda",
  "adieu"                  => "adieux",
  "adminiculum"            => "adminicula",
  "ado"                    => "ados",
  "adviso"                 => "advisoes",
  "adytum"                 => "adyta",
  "aecidium"               => "aecidia",
  "aegis"                  => "aegises",
  "aelf"                   => "aelfe",
  "aficionado"             => "aficionados",
  "afreet"                 => "afreeti",
  "afrit"                  => "afriti",
  "agape"                  => "agapae",
  "agend"                  => "agenda",
  "agendum"                => "agenda",
  "agent provocateur"      => "agents provocateurs",
  "aggro"                  => "aggros",
  "agon"                   => "agones",
  "agora"                  => "agorae",
  "agrogorod"              => "agrogoroda",
  "aide de camp"           => "aides de camp",
  "aide-de-camp"           => "aides-de-camp",
  "ala"                    => "alae",
  "alan"                   => "alani",
  "albergo"                => "alberghi",
  "albino"                 => "albinos",
  "ale wife"               => "ale wives",
  "ale-wife"               => "ale-wives",
  "Alfurese"               => "Alfurese",
  "alga"                   => "algae",
  "alguacil"               => "alguaciles",
  "alias"                  => "aliases",
  "allargando"             => "allargandi",
  "allegro"                => "allegros",
  "alluvium"               => "alluvia",
  "alto"                   => "alti",
  "alto relievo"           => "alto relievos",
  "alto-relievo"           => "alto-relievos",
  "altorelievo"            => "altorelievos",
  "alula"                  => "alulae",
  "alumna"                 => "alumnae",
  "alumnus"                => "alumni",
  "alveolus"               => "alveoli",
  "ambo"                   => "ambones",
  "Amboinese"              => "Amboinese",
  "ambulacrum"             => "ambulacra",
  "ambuscado"              => "ambuscadoes",
  "amentum"                => "amenta",
  "Americanese"            => "Americanese",
  "amicus curiae"          => "amici curiae",
  "ammo"                   => "ammos",
  "amoeba"                 => "amoebae",
  "amoretto"               => "amoretti",
  "amorino"                => "amorini",
  "Amoyese"                => "Amoyese",
  "amphipneust"            => "amphipneusta",
  "amphora"                => "amphorae",
  "anacoluthon"            => "anacolutha",
  "anathema"               => "anathemata",
  "ancona"                 => "ancone",
  "Andamanese"             => "Andamanese",
  "angioma"                => "angiomata",
  "Angolese"               => "Angolese",
  "angustia"               => "angustiae",
  "anlage"                 => "anlagen",
  "Annamese"               => "Annamese",
  "anta"                   => "antae",
  "Antananarivo"           => "Antananarivos",
  "antefix"                => "antefixa",
  "antenna"                => "antennae",
  "anthemion"              => "anthemia",
  "anthodium"              => "anthodia",
  "anti serum"             => "anti sera",
  "anti-serum"             => "anti-sera",
  "antiserum"              => "antisera",
  "antrum"                 => "antra",
  "apex"                   => "apices",
  "aphelion"               => "aphelia",
  "aphis"                  => "aphides",
  "apothecium"             => "apothecia",
  "apparatchik"            => "apparatchiki",
  "apparatus"              => "apparatus",
  "appendix"               => "appendices",
  "appressorium"           => "appressoria",
  "apsis"                  => "apsides",
  "apterium"               => "apteria",
  "aptychus"               => "aptychi",
  "aquarium"               => "aquaria",
  "Aragonese"              => "Aragonese",
  "Arakanese"              => "Arakanese",
  "arango"                 => "arangoes",
  "arboretum"              => "arboreta",
  "arcanum"                => "arcana",
  "archegonium"            => "archegonia",
  "archipelago"            => "archipelagoes",
  "arcosolium"             => "arcosolia",
  "areola"                 => "areolae",
  "arf"                    => "arves",
  "argumentum"             => "argumenta",
  "arista"                 => "aristae",
  "armadillo"              => "armadillos",
  "army corps general"     => "army corps generals",
  "army-corps general"     => "army-corps generals",
  "arrha"                  => "arrhae",
  "asbestos"               => "asbestoses",
  "ascidium"               => "ascidia",
  "Asherah"                => "Asherim",
  "Assamese"               => "Assamese",
  "asterias"               => "asteriae",
  "astrocytoma"            => "astrocytomata",
  "asylum"                 => "asyla",
  "asyndeton"              => "asyndeta",
  "ataman"                 => "atamans",
  "atlas"                  => "atlantes",
  "Atlas"                  => "Atlantes",
  "atman"                  => "atmas",
  "aureus"                 => "aurei",
  "aurora"                 => "aurorae",
  "Auslese"                => "Auslesen",
  "auslese"                => "auslesen",
  "auspex"                 => "auspices",
  "auto"                   => "autos",
  "auto de fe"             => "autos de fes",
  "auto-de-fe"             => "autos-de-fes",
  "autobahn"               => "autobahnen",
  "autochthon"             => "autochthones",
  "autostrada"             => "autostrade",
  "avicularium"            => "avicularia",
  "Avignonese"             => "Avignonese",
  "aviso"                  => "avisos",
  "avocado"                => "avocados",
  "ax"                     => "axes",
  "axe"                    => "axes",
  "axilla"                 => "axillae",
  "axis"                   => "axes",
  "axon"                   => "axones",
  "axopodium"              => "axopodia",
  "Azerbaijanese"          => "Azerbaijanese",
  "baal"                   => "baalim",
  "bacillus"               => "bacilli",
  "bacterium"              => "bacteria",
  "Bahaman"                => "Bahamans",
  "bajocco"                => "bajocchi",
  "Balinese"               => "Balinese",
  "ballabile"              => "ballabili",
  "ballata"                => "ballate",
  "ballerina"              => "ballerine",
  "ballista"               => "ballistae",
  "Bamako"                 => "Bamakos",
  "bandeau"                => "bandeaux",
  "bandit"                 => "banditti",
  "Barquisimeto"           => "Barquisimetos",
  "barrico"                => "barricoes",
  "base"                   => "bases",
  "basilica"               => "basilicae",
  "basis"                  => "bases",
  "bass"                   => "bass",
  "basso"                  => "bassi",
  "bateau"                 => "bateaux",
  "bath"                   => "baths",
  "bathos"                 => "bathoses",
  "batz"                   => "batzes",
  "beau"                   => "beaux",
  "beau geste"             => "beaux gestes",
  "bechuana"               => "bechuana",
  "beef"                   => "beeves",
  "beerenauslese"          => "beerenauslesen",
  "bel esprit"             => "beaux esprits",
  "bel homme"              => "beaux hommes",
  "bel-esprit"             => "beaux esprits",
  "belle epoque"           => "belles epoques",
  "bema"                   => "bemata",
  "Bengalese"              => "Bengalese",
  "Bernese"                => "Bernese",
  "bersagliere"            => "bersaglieri",
  "bhikshu"                => "bhikshook",
  "Bhutanese"              => "Bhutanese",
  "bias"                   => "biases",
  "bierstube"              => "bierstuben",
  "bifolium"               => "bifolia",
  "bijou"                  => "bijoux",
  "bilbo"                  => "bilboes",
  "bimbo"                  => "bimbos",
  "bingo"                  => "bingos",
  "Biro"                   => "Biros",
  "biscotto"               => "biscotti",
  "bison"                  => "bison",
  "blastema"               => "blastemata",
  "blemya"                 => "blemyae",
  "blin"                   => "blini",
  "blitz"                  => "blitzes",
  "blouse"                 => "blouses",
  "blue"                   => "blues",
  "blues"                  => "blues",
  "bodegon"                => "bodegones",
  "bolero"                 => "boleros",
  "Bolognese"              => "Bolognese",
  "bolus"                  => "boluses",
  "Bolzano"                => "Bolzanos",
  "bon mot"                => "bons mots",
  "bon vivant"             => "bons vivants",
  "bona fides"             => "bonis fidebus",
  "bongo"                  => "bongoes",
  "bordereau"              => "bordereaux",
  "Borghese"               => "Borghese",
  "Bostonese"              => "Bostonese",
  "Boto"                   => "Botos",
  "bozzetto"               => "bozzetti",
  "braccio"                => "braccia",
  "brachiopod"             => "brachiopoda",
  "branchiopod"            => "branchiopoda",
  "bratwurst"              => "bratwurste",
  "bravo"                  => "bravoes",
  "break away"             => "breaks away",
  "break-away"             => "breaks-away",
  "breakaway"              => "breaksaway",
  "bream"                  => "bream",
  "breech"                 => "breeches",
  "breeches"               => "breeches",
  "bregma"                 => "bregmata",
  "brigadier general"      => "brigadier generals",
  "britches"               => "britches",
  "bronchitis"             => "bronchitises",
  "bronchus"               => "bronchi",
  "brother"                => "brethren",
  "brother german"         => "brethren german",
  "brother-german"         => "brethren-german",
  "bruschetta"             => "bruschette",
  "bubo"                   => "buboes",
  "buffalo"                => "buffalo",
  "Buginese"               => "Buginese",
  "bulimus"                => "bulimi",
  "bulla"                  => "bullae",
  "bureau"                 => "bureaux",
  "Burman"                 => "Burmans",
  "Burmese"                => "Burmese",
  "burro"                  => "burros",
  "bursa"                  => "bursae",
  "bursch"                 => "burschen",
  "bursitis"               => "bursitises",
  "busto"                  => "bustoes",
  "buzz"                   => "buzzes",
  "bylina"                 => "byliny",
  "cabaletta"              => "cabalette",
  "cactus"                 => "cacti",
  "caddis"                 => "caddises",
  "caduceus"               => "caducei",
  "caecum"                 => "caeca",
  "caffe macchiato"        => "caffe macchiati",
  "caffe ristretto"        => "caffe ristretti",
  "caiman"                 => "caimans",
  "Cairo"                  => "Cairos",
  "Calabrese"              => "Calabrese",
  "calamistrum"            => "calamistra",
  "calathus"               => "calathi",
  "calix"                  => "calices",
  "callus"                 => "calluses",
  "calypso"                => "calypsos",
  "calzone"                => "calzoni",
  "Camaldolese"            => "Camaldolese",
  "camera obscura"         => "camerae obscurae",
  "canaliculus"            => "canaliculi",
  "candelabrum"            => "candelabra",
  "cannabis"               => "cannabises",
  "cantharus"              => "canthari",
  "canto"                  => "cantos",
  "Cantonese"              => "Cantonese",
  "cantus"                 => "cantus",
  "canvas"                 => "canvases",
  "canzonetta"             => "canzonette",
  "capataz"                => "capataces",
  "capo"                   => "capi",
  "cappuccino"             => "cappuccinos",
  "captain general"        => "captain generals",
  "carabiniere"            => "carabinieri",
  "carcinoma"              => "carcinomata",
  "cardo"                  => "cardines",
  "cardophagus"            => "cardophagi",
  "carex"                  => "carices",
  "cargador"               => "cargadores",
  "caribou"                => "caribou",
  "Carlylese"              => "Carlylese",
  "carmen"                 => "carmina",
  "carp"                   => "carp",
  "carte de visite"        => "cartes de visite",
  "carte-de-visite"        => "cartes-de-visite",
  "caryatid"               => "caryatides",
  "caryopsis"              => "caryopsides",
  "casino"                 => "casinos",
  "Cassinese"              => "Cassinese",
  "cassone"                => "cassoni",
  "castrato"               => "castrati",
  "castrum"                => "castra",
  "casus belli"            => "casus belli",
  "cathisma"               => "cathismata",
  "caudex"                 => "caudices",
  "caulis"                 => "caules",
  "cavea"                  => "caveae",
  "cayman"                 => "caymans",
  "cecidium"               => "cecidia",
  "Celanese"               => "Celanese",
  "celia"                  => "celiae",
  "cello"                  => "cellos",
  "cementoma"              => "cementomata",
  "centesimo"              => "centesimi",
  "centumvir"              => "centumviri",
  "cercus"                 => "cerci",
  "ceriman"                => "cerimans",
  "Ceylonese"              => "Ceylonese",
  "chaeta"                 => "chaetae",
  "chaos"                  => "chaoses",
  "chapeau"                => "chapeaux",
  "chapplis"               => "chapplies",
  "charisma"               => "charismata",
  "chassis"                => "chassis",
  "chateau"                => "chateaux",
  "cherub"                 => "cherubim",
  "chervonetz"             => "chervontzi",
  "cheval"                 => "chevaux",
  "cheval de bataille"     => "chevaux de bataille",
  "cheval-de-bataille"     => "chevaux-de-bataille",
  "Chicago"                => "Chicagos",
  "child"                  => "children",
  "Chimango"               => "Chimangos",
  "Chinese"                => "Chinese",
  "chintz"                 => "chintzes",
  "chitarrone"             => "chitarroni",
  "chlamydia"              => "chlamydiae",
  "choana"                 => "choanae",
  "chorda"                 => "chordae",
  "chorus"                 => "choruses",
  "chou"                   => "choux",
  "chromidium"             => "chromidia",
  "chromonema"             => "chromonemata",
  "chrysalis"              => "chrysalides",
  "cicatrix"               => "cicatrices",
  "cilantro"               => "cilantros",
  "cimex"                  => "cimices",
  "cinclis"                => "cinclides",
  "cistophorus"            => "cistophorori",
  "cladus"                 => "cladi",
  "claustrum"              => "claustra",
  "clausula"               => "clausulae",
  "clavula"                => "clavulae",
  "cleithrum"              => "cleithra",
  "clepsydra"              => "clepsydrae",
  "clipper"                => "clippers",
  "clippers"               => "clippers",
  "clitoris"               => "clitorides",
  "clostridium"            => "clostridia",
  "co"                     => "coes",
  "coagulum"               => "coagula",
  "coccidium"              => "coccidia",
  "cochito"                => "cochitos",
  "coco"                   => "cocos",
  "cod"                    => "cod",
  "codex"                  => "codices",
  "coe"                    => "coes",
  "coelia"                 => "coeliae",
  "cognoscente"            => "cognoscenti",
  "coitus"                 => "coitus",
  "collegium"              => "collegia",
  "collegium musicum"      => "collegia musica",
  "Colombo"                => "Colombos",
  "colonel general"        => "colonel generals",
  "Colorado"               => "Colorados",
  "columbarium"            => "columbaria",
  "columna"                => "columnae",
  "coma"                   => "comae",
  "comatula"               => "comatulae",
  "commanding general"     => "commanding generals",
  "commando"               => "commandos",
  "compendium"             => "compendia",
  "competent"              => "competentes",
  "concertino"             => "concertinos",
  "concerto grosso"        => "concerti grossi",
  "concetto"               => "concetti",
  "condo"                  => "condos",
  "condottiere"            => "condottieri",
  "conductus"              => "conducti",
  "coney"                  => "conies",
  "conferva"               => "confervae",
  "confluvium"             => "confluvia",
  "congius"                => "congii",
  "Congoese"               => "Congoese",
  "Congolese"              => "Congolese",
  "conidium"               => "conidia",
  "conoscente"             => "conoscenti",
  "consortium"             => "consortia",
  "contadina"              => "contadine",
  "contadino"              => "contadini",
  "contagium"              => "contagia",
  "contango"               => "contangos",
  "contrafactum"           => "contrafacta",
  "contralto"              => "contralti",
  "contretemps"            => "contretemps",
  "conversazione"          => "conversazioni",
  "convolvulus"            => "convolvuli",
  "cony"                   => "conies",
  "corgi"                  => "corgwn",
  "corgy"                  => "corgwn",
  "cornetto"               => "cornetti",
  "corno"                  => "corni",
  "cornu"                  => "cornua",
  "corona"                 => "coronae",
  "corps"                  => "corps",
  "corps general"          => "corps generals",
  "corpus"                 => "corpora",
  "corpus vile"            => "corpora vilia",
  "corpusculum"            => "corpuscula",
  "corrigendum"            => "corrigenda",
  "cortex"                 => "cortices",
  "cosmos"                 => "cosmoses",
  "costa"                  => "costae",
  "coup d'etat"            => "coups d'etat",
  "court martial"          => "courts martial",
  "court-martial"          => "courts-martial",
  "cow"                    => "kine",
  "coxendix"               => "coxendices",
  "coz"                    => "cozes",
  "craft"                  => "craft",
  "crafts child"           => "crafts childer",
  "crafts-child"           => "crafts-childer",
  "cranium"                => "crania",
  "craspedon"              => "craspeda",
  "craspedum"              => "craspeda",
  "crazia"                 => "crazie",
  "credo"                  => "credos",
  "cremaster"              => "cremasteres",
  "crescendo"              => "crescendos",
  "cri de coeur"           => "cris de coeur",
  "crista"                 => "cristae",
  "criterion"              => "criteria",
  "crowfoot"               => "crowfoots",
  "crus"                   => "crura",
  "crusta"                 => "crustae",
  "cubiculum"              => "cubicula",
  "cul de four"            => "culs de four",
  "cul de lampe"           => "culs de lampe",
  "cul de sac"             => "culs de sac",
  "cul-de-four"            => "culs-de-four",
  "cul-de-lampe"           => "culs-de-lampe",
  "cul-de-sac"             => "culs-de-sac",
  "cultellus"              => "cultelli",
  "cumulus"                => "cumuli",
  "cuniculus"              => "cuniculi",
  "curioso"                => "curiosi",
  "curriculum"             => "curricula",
  "cuspis"                 => "cuspides",
  "cyano"                  => "cyanos",
  "cyathus"                => "cyathi",
  "cyclops"                => "cyclopes",
  "cynocephalus"           => "cynocephali",
  "cyphella"               => "cyphellae",
  "cysticercus"            => "cysticerci",
  "cystidium"              => "cystidia",
  "cystoma"                => "cystomata",
  "Czech"                  => "Czechs",
  "dace"                   => "dace",
  "dais"                   => "daises",
  "datum"                  => "data",
  "debris"                 => "debris",
  "decennium"              => "decennia",
  "deer"                   => "deer",
  "delirium"               => "deliria",
  "demo"                   => "demos",
  "denarius"               => "denarii",
  "denkmal"                => "denkmaler",
  "denotatum"              => "denotata",
  "dentalium"              => "dentalia",
  "depositum"              => "deposita",
  "descriptum"             => "descripta",
  "desideratum"            => "desiderata",
  "designatum"             => "designata",
  "desma"                  => "desmata",
  "desman"                 => "desmans",
  "devoto"                 => "devoti",
  "diabetes"               => "diabetes",
  "diastema"               => "diastemata",
  "dichasium"              => "dichasia",
  "dictum"                 => "dicta",
  "didymis"                => "didymes",
  "die"                    => "dies",
  "differentia"            => "differentiae",
  "digitalis"              => "digitalises",
  "dilettante"             => "dilettanti",
  "diplococcus"            => "diplococci",
  "diploma"                => "diplomata",
  "diporpa"                => "diporpae",
  "dipsas"                 => "dipsades",
  "directrix"              => "directrices",
  "ditto"                  => "dittos",
  "diverticulum"           => "diverticula",
  "divertimento"           => "divertimenti",
  "divisional general"     => "divisional generals",
  "djinn"                  => "djinn",
  "do"                     => "does",
  "doe"                    => "does",
  "dogma"                  => "dogmata",
  "dolman"                 => "dolmans",
  "dolphinarium"           => "dolphinaria",
  "Dongolese"              => "Dongolese",
  "Draco"                  => "Dracos",
  "dragoman"               => "dragomans",
  "drama"                  => "dramas",
  "dreikanter"             => "dreikanter",
  "dumka"                  => "dumky",
  "duumvir"                => "duumviri",
  "dynamo"                 => "dynamos",
  "edema"                  => "edemata",
  "editio princeps"        => "editiones principes",
  "efreet"                 => "efreeti",
  "eland"                  => "eland",
  "elf"                    => "elves",
  "elk"                    => "elk",
  "ellipse"                => "ellipses",
  "ellipsis"               => "ellipses",
  "emblema"                => "emblememata",
  "embryo"                 => "embryos",
  "embryoma"               => "embryomata",
  "emporium"               => "emporia",
  "enconium"               => "enconia",
  "endothelioma"           => "endotheliomata",
  "enema"                  => "enemata",
  "enigma"                 => "enigmata",
  "ens rationis"           => "entia rationis",
  "ens reale"              => "entia realia",
  "entente cordiale"       => "ententes cordiales",
  "enteron"                => "entera",
  "entrochus"              => "entrochi",
  "ephelis"                => "ephelides",
  "ephemera"               => "ephemerae",
  "ephemeris"              => "ephemerides",
  "epicardium"             => "epicardia",
  "epidermis"              => "epidermises",
  "epididymis"             => "epididymides",
  "epilimnion"             => "epilimnia",
  "epimeron"               => "epimera",
  "epiphenomenon"          => "epiphenomena",
  "epithelioma"            => "epitheliomata",
  "epyllion"               => "epyllia",
  "equinoctium"            => "equinoctia",
  "equisetum"              => "equiseta",
  "erf"                    => "erven",
  "ergastulum"             => "ergastula",
  "eros"                   => "erotes",
  "erratum"                => "errata",
  "espanol"                => "espanoles",
  "Esperanto"              => "Esperantos",
  "espresso"               => "espressos",
  "ethos"                  => "ethoses",
  "eucalyptus"             => "eucalypti",
  "eunuch"                 => "eunuchs",
  "euporiston"             => "euporista",
  "euro"                   => "euros",
  "evirato"                => "evirati",
  "ex"                     => "exes",
  "exanthema"              => "exanthemata",
  "exemplum"               => "exempla",
  "exencephalus"           => "exencephali",
  "explanandum"            => "explananda",
  "explicandum"            => "explicanda",
  "extispex"               => "extispices",
  "extremum"               => "extrema",
  "eyas"                   => "eyases",
  "fabella"                => "fabellae",
  "fabliau"                => "fabliaux",
  "faciendum"              => "facienda",
  "faecula"                => "faeculae",
  "fait accompli"          => "faits accomplis",
  "falsetto"               => "falsettos",
  "falx"                   => "falces",
  "familia"                => "familiae",
  "famulus"                => "famuli",
  "fanfoot"                => "fanfoots",
  "farman"                 => "farmans",
  "Faro"                   => "Faros",
  "Faroese"                => "Faroese",
  "fascia"                 => "fasciae",
  "fasciculus"             => "fasciculi",
  "fauna"                  => "faunae",
  "favella"                => "favellae",
  "faveolus"               => "faveoli",
  "favissa"                => "favissae",
  "fecula"                 => "feculae",
  "fedai"                  => "fedai",
  "feis"                   => "feiseanna",
  "felo"                   => "felones",
  "felo de se"             => "felones de se",
  "felo-de-se"             => "felones-de-se",
  "felsenmeer"             => "felsenmeere",
  "femur"                  => "femora",
  "fenestra"               => "fenestrae",
  "fermata"                => "fermate",
  "Ferrarese"              => "Ferrarese",
  "fiasco"                 => "fiascos",
  "fibra"                  => "fibrae",
  "fibrilla"               => "fibrillae",
  "fibroma"                => "fibromata",
  "fibula"                 => "fibulae",
  "fidei defensor"         => "fidei defensores",
  "figurante"              => "figuranti",
  "filaria"                => "filariae",
  "Filipino"               => "Filipinos",
  "finger end"             => "fingers ends",
  "finger-end"             => "fingers-ends",
  "fioritura"              => "fioriture",
  "fish"                   => "fish",
  "five star general"      => "five star generals",
  "five-star general"      => "five-star generals",
  "fizz"                   => "fizzes",
  "flabellum"              => "flabella",
  "flag staff"             => "flag staves",
  "flag-staff"             => "flag-staves",
  "flagellum"              => "flagella",
  "flamenco"               => "flamencos",
  "flatfoot"               => "flatfoots",
  "flatus"                 => "flatuses",
  "flocculus"              => "flocculi",
  "floccus"                => "flocci",
  "flora"                  => "florae",
  "flounder"               => "flounder",
  "fly"                    => "flys",
  "focus"                  => "foci",
  "follis"                 => "folles",
  "fomes"                  => "fomites",
  "Foochowese"             => "Foochowese",
  "foot"                   => "feet",
  "foramen"                => "foramina",
  "formula"                => "formulae",
  "forum"                  => "fora",
  "fossa"                  => "fossae",
  "four star general"      => "four star generals",
  "four-star general"      => "four-star generals",
  "fowl"                   => "fowl",
  "fraenum"                => "fraena",
  "franc archer"           => "francs archers",
  "franc-archer"           => "francs-archers",
  "frate"                  => "frati",
  "frenum"                 => "fraena",
  "fricandeau"             => "fricandeaux",
  "frizz"                  => "frizzes",
  "fro"                    => "froes",
  "froe"                   => "froes",
  "frottola"               => "frottole",
  "frustulum"              => "frustula",
  "frustum"                => "frusta",
  "fucus"                  => "fuci",
  "fulcrum"                => "fulcra",
  "funambulus"             => "funambuli",
  "fundamentum divisionis" => "fundamenta divisionis",
  "fungo porcino"          => "funghi porchini",
  "fungus"                 => "fungi",
  "furfur"                 => "furfures",
  "furioso"                => "furiosos",
  "fuzz"                   => "fuzzes",
  "Gabunese"               => "Gabunese",
  "Galla"                  => "Galla",
  "galla"                  => "galla",
  "gallows"                => "gallows",
  "gametangium"            => "gametangia",
  "ganglion"               => "ganglia",
  "gaon"                   => "gaonim",
  "gastrocnemius"          => "gastrocnemii",
  "geisha"                 => "geisha",
  "geisteswissenschaft"    => "geisteswissenschaften",
  "gemma"                  => "gemmae",
  "gena"                   => "genae",
  "generalissimo"          => "generalissimos",
  "Genevese"               => "Genevese",
  "genie"                  => "genii",
  "genius"                 => "genii",
  "Genoese"                => "Genoese",
  "gens"                   => "gentes",
  "genus"                  => "genera",
  "German"                 => "Germans",
  "germarium"              => "germaria",
  "Gestapo"                => "Gestapos",
  "ghetto"                 => "ghettos",
  "gigolo"                 => "gigolos",
  "Gilbertese"             => "Gilbertese",
  "giuncus"                => "giunchi",
  "gizmo"                  => "gizmos",
  "glacis"                 => "glacis",
  "gladiolus"              => "gladioli",
  "glass"                  => "glasses",
  "glasses"                => "glasses",
  "glioma"                 => "gliomata",
  "gliosarcoma"            => "gliosarcomata",
  "glissando"              => "glissandi",
  "globigerina"            => "globigerinae",
  "glochidium"             => "glochidia",
  "glomus"                 => "glomera",
  "glutaeus"               => "glutaei",
  "gluteus"                => "glutaei",
  "gmina"                  => "gminy",
  "go"                     => "goes",
  "Goanese"                => "Goanese",
  "gonangium"              => "gonangia",
  "gonidium"               => "gonidia",
  "gonimium"               => "gonimia",
  "goose"                  => "geese",
  "gorgonia"               => "gorgoniae",
  "gousblom"               => "gousblomme",
  "goy"                    => "goyim",
  "graben"                 => "graben",
  "graffiti"               => "graffiti",
  "graffito"               => "graffiti",
  "granita"                => "granite",
  "grano"                  => "grani",
  "granula"                => "granulae",
  "gravamen"               => "gravamina",
  "Greensboro"             => "Greensboros",
  "gringo"                 => "gringos",
  "grissino"               => "grissini",
  "grotto"                 => "grottoes",
  "grouse"                 => "grouse",
  "Guaiabero"              => "Guaiaberos",
  "guano"                  => "guanos",
  "guardia civil"          => "guardias civiles",
  "gubernaculum"           => "gubernacula",
  "guglio"                 => "guglioes",
  "Guianese"               => "Guianese",
  "gumbo"                  => "gumbos",
  "gumma"                  => "gummata",
  "guttus"                 => "gutti",
  "guy"                    => "guys",
  "gymnasium"              => "gymnasia",
  "gymnotus"               => "gymnoti",
  "gyro"                   => "gyros",
  "gyrus"                  => "gyri",
  "haddock"                => "haddock",
  "haemangioma"            => "haemangiomata",
  "haggis"                 => "haggis",
  "Hainanese"              => "Hainanese",
  "hairdo"                 => "hairdos",
  "hake"                   => "hake",
  "halibut"                => "halibut",
  "hallux"                 => "halluces",
  "halteridium"            => "halteridia",
  "hamadryad"              => "hamadryades",
  "hamulus"                => "hamuli",
  "hapax legomenon"        => "hapax legomena",
  "hapteron"               => "haptera",
  "Hararese"               => "Hararese",
  "Harlemese"              => "Harlemese",
  "harman"                 => "harmans",
  "haruspex"               => "haruspices",
  "haustellum"             => "haustella",
  "haustorium"             => "haustoria",
  "haustrum"               => "haustra",
  "Havanese"               => "Havanese",
  "he"                     => "they",
  "headquarters"           => "headquarters",
  "Heavenese"              => "Heavenese",
  "hedron"                 => "hedra",
  "heft"                   => "hefte",
  "helion"                 => "helia",
  "helix"                  => "helices",
  "hemangeioma"            => "hemangeiomata",
  "hemangioma"             => "hemangiomata",
  "hemelytrum"             => "hemelytra",
  "hemera"                 => "hemerae",
  "hemi elytrum"           => "hemi elytra",
  "hemi-elytrum"           => "hemi-elytra",
  "her"                    => "them",
  "hernia"                 => "herniae",
  "hero"                   => "heroes",
  "heroon"                 => "heroa",
  "heroum"                 => "heroa",
  "herpes"                 => "herpes",
  "herr"                   => "herren",
  "herring"                => "herring",
  "hers"                   => "theirs",
  "herself"                => "themselves",
  "hertz"                  => "hertz",
  "hetaera"                => "hetairai",
  "hetaira"                => "hetairai",
  "hetman"                 => "hetmans",
  "hiatus"                 => "hiatus",
  "hijinks"                => "hijinks",
  "him"                    => "them",
  "himself"                => "themselves",
  "hinaki"                 => "hinaki",
  "hippo"                  => "hippos",
  "hippocampus"            => "hippocampi",
  "hippopotamus"           => "hippopotami",
  "Hiroshiman"             => "Hiroshimans",
  "his"                    => "theirs",
  "ho"                     => "hoes",
  "hoe"                    => "hoes",
  "holothuria"             => "holothuriae",
  "honorarium"             => "honoraria",
  "hoof"                   => "hooves",
  "Hoosierese"             => "Hoosierese",
  "hordeolum"              => "hordeola",
  "hormogonium"            => "hormogonia",
  "hoti"                   => "hoties",
  "Hottentotese"           => "Hottentotese",
  "hsien"                  => "heen",
  "hubris"                 => "hubrises",
  "human"                  => "humans",
  "humerus"                => "humeri",
  "Hunanese"               => "Hunanese",
  "hydra"                  => "hydrae",
  "hydraulicon"            => "hydraulica",
  "hydria"                 => "hydriae",
  "hymenium"               => "hymenia",
  "hymnarium"              => "hymnaria",
  "hyperbaton"             => "hyperbata",
  "hyperbola"              => "hyperbolae",
  "hypha"                  => "hyphae",
  "hypnum"                 => "hypna",
  "hypoderma"              => "hypodermata",
  "hypolimnion"            => "hypolimnia",
  "I"                      => "we",
  "ibis"                   => "ibises",
  "ichthyosaurus"          => "ichthyosauri",
  "Idaho"                  => "Idahos",
  "idee fixe"              => "idees fixes",
  "idolon"                 => "idola",
  "idolum"                 => "idola",
  "ignoramus"              => "ignoramus",
  "ilium"                  => "ilia",
  "imago"                  => "imagines",
  "imbrex"                 => "imbrices",
  "impetigo"               => "impetigos",
  "impetus"                => "impetus",
  "improperium"            => "improperia",
  "improvisatrice"         => "improvisatrici",
  "incubus"                => "incubi",
  "index"                  => "indices",
  "indicium"               => "indicia",
  "indigena"               => "indigenae",
  "individuum"             => "individua",
  "Indochinese"            => "Indochinese",
  "indumentum"             => "indumenta",
  "indusium"               => "indusia",
  "inferno"                => "infernos",
  "infima species"         => "infimae species",
  "info"                   => "infos",
  "inhalatorium"           => "inhalatoria",
  "innings"                => "innings",
  "inoculum"               => "inocula",
  "insula"                 => "insulae",
  "intaglio"               => "intaglios",
  "interambulacrum"        => "interambulacra",
  "interaxis"              => "interaxes",
  "intercalarium"          => "intercalare",
  "interleaf"              => "leaves",
  "intermaxilla"           => "intermaxillae",
  "intermedium"            => "intermedia",
  "intermezzo"             => "intermezzos",
  "internodium"            => "internodia",
  "interphenomenon"        => "interphenomena",
  "interradius"            => "interradii",
  "interregnum"            => "interregna",
  "interrex"               => "interreges",
  "interstitium"           => "interstitia",
  "intertrigo"             => "intertrigos",
  "intervallum"            => "intervalla",
  "intichiuma"             => "intichiuma",
  "inuk"                   => "inuit",
  "inukshuk"               => "inukshuit",
  "involucrum"             => "involucra",
  "ipse dixit"             => "ipse dixits",
  "Iquico"                 => "Iquicos",
  "iris"                   => "irides",
  "ischium"                => "ischia",
  "isidium"                => "isidia",
  "ispravnik"              => "ispravniki",
  "isthmus"                => "isthmi",
  "it"                     => "they",
  "iter"                   => "itinera",
  "its"                    => "theirs",
  "itself"                 => "themselves",
  "ixodid"                 => "ixodides",
  "jackanapes"             => "jackanapes",
  "jacobus"                => "jacobus",
  "jalapeno"               => "jalapenos",
  "jambeau"                => "jambeaux",
  "Japanese"               => "Japanese",
  "Javanese"               => "Javanese",
  "jazz"                   => "jazzes",
  "jerry"                  => "jerries",
  "Jerry"                  => "Jerrys",
  "jeu"                    => "jeux",
  "jo"                     => "joes",
  "joe"                    => "joes",
  "Johnsonese"             => "Johnsonese",
  "judas"                  => "judases",
  "judicatum"              => "judicata",
  "juelet"                 => "iueles",
  "jugum"                  => "juga",
  "jumbo"                  => "jumbos",
  "junto"                  => "juntos",
  "Kakapo"                 => "Kakapos",
  "Kanarese"               => "Kanarese",
  "kantharos"              => "kantharoi",
  "kar"                    => "kare",
  "karakia"                => "karakia",
  "karrenfeld"             => "karrenfelder",
  "kernos"                 => "kernoi",
  "kibbutz"                => "kibbutzim",
  "kilo"                   => "kilos",
  "kimono"                 => "kimonos",
  "Kinkimavo"              => "Kinkimavos",
  "kioko"                  => "kioko",
  "Kiplingese"             => "Kiplingese",
  "kletterschuh"           => "kletterschuhe",
  "knife"                  => "knives",
  "knopper"                => "knoppern",
  "kobo"                   => "kobo",
  "Kokako"                 => "Kokakos",
  "konditorei"             => "konditoreien",
  "Kongoese"               => "Kongoese",
  "Kongolese"              => "Kongolese",
  "Kosovo"                 => "Kosovos",
  "kouros"                 => "kouroi",
  "kovsh"                  => "kovshi",
  "kuvasz"                 => "kuvaszok",
  "kylix"                  => "kylikes",
  "labrum"                 => "labra",
  "lacinia"                => "laciniae",
  "lactobacillus"          => "lactobacilli",
  "lacuna"                 => "lacunae",
  "lacunar"                => "lacunaria",
  "laika"                  => "laiki",
  "lamella"                => "lamellae",
  "lamina"                 => "laminae",
  "lapith"                 => "lapithae",
  "Lapith"                 => "Lapithae",
  "Lapponese"              => "Lapponese",
  "lar"                    => "lares",
  "larnax"                 => "larnakes",
  "larynx"                 => "larynges",
  "latex"                  => "latices",
  "leaf"                   => "leaves",
  "Lebanese"               => "Lebanese",
  "lebensform"             => "lebensformen",
  "legionella"             => "legionellae",
  "legomenon"              => "legomena",
  "legumen"                => "legumina",
  "leishmania"             => "leishmaniae",
  "leman"                  => "lemans",
  "lemma"                  => "lemmata",
  "lemniscus"              => "lemnisci",
  "lemur"                  => "lemures",
  "lens"                   => "lenses",
  "lentigo"                => "lentigines",
  "lentiscus"              => "lentisci",
  "Leonese"                => "Leonese",
  "leproma"                => "lepromata",
  "leprosarium"            => "leprosaria",
  "leptomonas"             => "leptomonas",
  "lepton"                 => "lepta",
  "leptospira"             => "leptospirae",
  "Lesotho"                => "Lesothos",
  "leu"                    => "lei",
  "lex humana"             => "leges humanae",
  "lf"                     => "lves",
  "libero"                 => "liberos",
  "libido"                 => "libidos",
  "libretto"               => "libretti",
  "lido"                   => "lidos",
  "lied"                   => "lieder",
  "lieu"                   => "lieux",
  "lieutenant general"     => "lieutenant generals",
  "life"                   => "lives",
  "ligamentum"             => "ligamenta",
  "likuta"                 => "makuta",
  "Lilo"                   => "Lilos",
  "Liman"                  => "Limans",
  "limax"                  => "limaces",
  "limbo"                  => "limbos",
  "limes"                  => "limites",
  "limo"                   => "limos",
  "limulus"                => "limuli",
  "linctus"                => "linctuses",
  "line out"               => "lines out",
  "line-out"               => "lines-out",
  "linea"                  => "lineae",
  "lineno"                 => "linenos",
  "lingo"                  => "lingos",
  "lingula"                => "lingulae",
  "lino"                   => "linos",
  "lipoma"                 => "lipomata",
  "lis"                    => "lis",
  "listerella"             => "listerellae",
  "listeria"               => "listeria",
  "lithodomus"             => "lithodomi",
  "lithophyton"            => "lithophyta",
  "livedo"                 => "livedos",
  "lixivium"               => "lixivia",
  "loa"                    => "loa",
  "loaf"                   => "loaves",
  "lobulus"                => "lobuli",
  "lochus"                 => "lochi",
  "loco"                   => "locos",
  "loculus"                => "loculi",
  "locus"                  => "loci",
  "loggia"                 => "loggie",
  "logion"                 => "logia",
  "logo"                   => "logos",
  "logodaedalus"           => "logodaedale",
  "loma"                   => "lomata",
  "lomentum"               => "lomenta",
  "Londonese"              => "Londonese",
  "lord lieutenant"        => "lords lieutenant",
  "lord-lieutenant"        => "lords-lieutenant",
  "Lorrainese"             => "Lorrainese",
  "lorum"                  => "lora",
  "louis"                  => "louis",
  "louse"                  => "lice",
  "lowlife"                => "lowlifes",
  "lox"                    => "lox",
  "Lucchese"               => "Lucchese",
  "lumbago"                => "lumbagos",
  "lumbricus"              => "lumbrici",
  "lumen"                  => "lumina",
  "lustrum"                => "lustra",
  "lux"                    => "lux",
  "lymphangioma"           => "lymphangiomata",
  "lymphoma"               => "lymphomata",
  "Lyonese"                => "Lyonese",
  "lyssa"                  => "lyssae",
  "maar"                   => "maare",
  "macacus"                => "macaci",
  "Macanese"               => "Macanese",
  "macaroni"               => "macaronies",
  "Macassarese"            => "Macassarese",
  "macho"                  => "machos",
  "mackerel"               => "mackerel",
  "macro"                  => "macros",
  "macula"                 => "maculae",
  "Madurese"               => "Madurese",
  "maecenas"               => "maecenates",
  "maestro"                => "maestri",
  "mafiosa"                => "mafiose",
  "mafioso"                => "mafiosi",
  "magilus"                => "magili",
  "magma"                  => "magmata",
  "magneto"                => "magnetos",
  "magnifico"              => "magnificos",
  "magnum opus"            => "magna opera",
  "magus"                  => "magi",
  "major general"          => "major generals",
  "Majuro"                 => "Majuros",
  "Malabarese"             => "Malabarese",
  "Malabo"                 => "Malabos",
  "malagma"                => "malagmata",
  "malleolus"              => "malleoli",
  "malleus"                => "mallei",
  "Maltese"                => "Maltese",
  "malum in se"            => "mala in se",
  "man"                    => "men",
  "man child"              => "men children",
  "man midwife"            => "men midwives",
  "man milliner"           => "men milliners",
  "man servant"            => "men servants",
  "man-child"              => "men-children",
  "man-midwife"            => "men-midwives",
  "man-milliner"           => "men-milliners",
  "man-servant"            => "men-servants",
  "manchild"               => "menchildren",
  "mango"                  => "mangoes",
  "manifesto"              => "manifestos",
  "manservant"             => "menservants",
  "manteau"                => "manteaux",
  "mantelletta"            => "mantellette",
  "mantis"                 => "mantises",
  "manubrium"              => "manubria",
  "Maputo"                 => "Maputos",
  "maquereau"              => "maquereaux",
  "Maracaibo"              => "Maracaibos",
  "mare"                   => "maria",
  "maremma"                => "maremme",
  "marquis"                => "marquises",
  "mary"                   => "maries",
  "Mary"                   => "Marys",
  "mater lectionis"        => "matres lectionis",
  "math"                   => "maths",
  "matin"                  => "matins",
  "matinee musicale"       => "matinees musicales",
  "matzah"                 => "matzot",
  "mausoleum"              => "mausolea",
  "maxilla"                => "maxillae",
  "maximum"                => "maxima",
  "me"                     => "us",
  "measles"                => "measles",
  "meatus"                 => "meatus",
  "mediastinum"            => "mediastina",
  "mediatrix"              => "mediatrices",
  "medico"                 => "medicoes",
  "medium"                 => "media",
  "medulloblastoma"        => "medulloblastomata",
  "medusa"                 => "medusae",
  "megalosaurus"           => "megalosauri",
  "megatherium"            => "megatheria",
  "melanoma"               => "melanomata",
  "melastoma"              => "melastomae",
  "meliceris"              => "melicerides",
  "melisma"                => "melismata",
  "memento"                => "mementoes",
  "memo"                   => "memos",
  "memorandum"             => "memoranda",
  "menage a quatre"        => "menages a quatre",
  "menage a trois"         => "menages a trois",
  "meningioma"             => "meningiomata",
  "meniscus"               => "menisci",
  "menu"                   => "menus",
  "meretrix"               => "meretrices",
  "meris"                  => "merides",
  "meshumad"               => "meshumadim",
  "meshummad"              => "meshummadim",
  "mesothelioma"           => "mesotheliomata",
  "mesothelium"            => "mesothelia",
  "messa di voce"          => "messe di voce",
  "Messinese"              => "Messinese",
  "meta"                   => "metae",
  "metalimnion"            => "metalimnia",
  "metapleuron"            => "metapleura",
  "metatarsus"             => "metatarsi",
  "metro"                  => "metros",
  "metropolis"             => "metropolises",
  "mew"                    => "mews",
  "mews"                   => "mews",
  "Mexico"                 => "Mexicos",
  "mezuza"                 => "mezuzoth",
  "mezuzah"                => "mezuzoth",
  "mezzo rilievo"          => "mezzo rilievos",
  "mezzo-rilievo"          => "mezzo-rilievos",
  "miasma"                 => "miasmata",
  "micro"                  => "micros",
  "microbion"              => "microbia",
  "microcephalus"          => "microcephali",
  "micrococcus"            => "micrococci",
  "microfiche"             => "microfiche",
  "micronucleus"           => "micronuclei",
  "Milanese"               => "Milanese",
  "Milano"                 => "Milanos",
  "miles gloriosus"        => "milites gloriosi",
  "milieu"                 => "milieux",
  "milieu interieur"       => "milieux interieurs",
  "miliola"                => "miliolae",
  "millennium"             => "millennia",
  "mimosa"                 => "mimosae",
  "mine"                   => "ours",
  "minimum"                => "minima",
  "minnelied"              => "minnelieder",
  "minutia"                => "minutiae",
  "minyan"                 => "minyanim",
  "miracidium"             => "miracidia",
  "mithraeum"              => "mithraea",
  "mitochondrion"          => "mitochondria",
  "mixolimnion"            => "mixolimnia",
  "mo"                     => "moes",
  "moaks"                  => "moakses",
  "modelletto"             => "modelletti",
  "modello"                => "modelli",
  "Modenese"               => "Modenese",
  "modernus"               => "moderni",
  "modius"                 => "modii",
  "modulus"                => "moduli",
  "modus"                  => "modi",
  "moe"                    => "moes",
  "molimen"                => "molimina",
  "momentum"               => "momenta",
  "Monaco"                 => "Monacos",
  "monas"                  => "monades",
  "mondo"                  => "mondi",
  "money"                  => "monies",
  "mongoose"               => "mongooses",
  "monimolimnion"          => "monimolimnia",
  "mono"                   => "monos",
  "monochasium"            => "monochasia",
  "monorchis"              => "monorchides",
  "monosyllabon"           => "monosyllaba",
  "monota"                 => "monotae",
  "monoxylon"              => "monoxyla",
  "mons"                   => "montes",
  "monseigneur"            => "messeigneurs",
  "monsignor"              => "monsignori",
  "monsignore"             => "monsignori",
  "monstre sacre"          => "monstres sacres",
  "Montenegro"             => "Montenegros",
  "moose"                  => "moose",
  "moratorium"             => "moratoria",
  "morceau"                => "morceaux",
  "Morocco"                => "Moroccos",
  "moroso"                 => "morosi",
  "mortadella"             => "mortadelle",
  "mortarium"              => "mortaria",
  "moscardino"             => "moscardini",
  "motoscafo"              => "motoscafi",
  "motto"                  => "mottoes",
  "mouse"                  => "mice",
  "mousetrap"              => "micetraps",
  "mouth"                  => "mouths",
  "mucro"                  => "mucrones",
  "mukim"                  => "mukim",
  "multigravida"           => "multigravidae",
  "mumps"                  => "mumps",
  "municipium"             => "municipia",
  "Muqdisho"               => "Muqdishos",
  "Muranese"               => "Muranese",
  "murex"                  => "murices",
  "musa"                   => "musae",
  "musee imaginaire"       => "musees imaginaires",
  "musique concrete"       => "musiques concretes",
  "mustachio"              => "mustachios",
  "muzz"                   => "muzzes",
  "mya"                    => "myae",
  "mycoplasma"             => "mycoplasmata",
  "mycorhiza"              => "mycorhizae",
  "mycorrhiza"             => "mycorrhizae",
  "myeloma"                => "myelomata",
  "myo"                    => "myos",
  "myself"                 => "ourselves",
  "mythos"                 => "mythoi",
  "myxoma"                 => "myxomata",
  "nachtlokal"             => "nachtlokale",
  "nagaika"                => "nagaiki",
  "Nakayaman"              => "Nakayamans",
  "Nankingese"             => "Nankingese",
  "nasutus"                => "nasuti",
  "naumachia"              => "naumachiae",
  "nauplius"               => "nauplii",
  "nautilus"               => "nautili",
  "Navarrese"              => "Navarrese",
  "naya paisa"             => "naye paise",
  "nebenkern"              => "nebenkerne",
  "nebula"                 => "nebulae",
  "nectocalyx"             => "nectocalyces",
  "nemathecium"            => "nemathecia",
  "nenets"                 => "nentsy",
  "Nenets"                 => "Nentsi",
  "Nepalese"               => "Nepalese",
  "nephridium"             => "nephridia",
  "nerita"                 => "neritae",
  "neuma"                  => "neumata",
  "neurinoma"              => "neurinomata",
  "neuroma"                => "neuromata",
  "neurula"                => "neurulae",
  "neutrino"               => "neutrinos",
  "news"                   => "news",
  "nexus"                  => "nexus",
  "ngwee"                  => "ngwee",
  "Niasese"                => "Niasese",
  "Nicobarese"             => "Nicobarese",
  "nidus"                  => "nidi",
  "niello"                 => "nielli",
  "nimbus"                 => "nimbi",
  "Ningbo"                 => "Ningbos",
  "Nipponese"              => "Nipponese",
  "nockerl"                => "nockerln",
  "noctiluca"              => "noctilucae",
  "nodum"                  => "noda",
  "nodus"                  => "nodi",
  "noema"                  => "noemata",
  "nomisma"                => "nomismata",
  "non ens"                => "nonentia",
  "non-ens"                => "nonentia",
  "Norman"                 => "Normans",
  "noumenon"               => "noumena",
  "nouveau pauvre"         => "nouveaux pauvres",
  "nouveau riche"          => "nouveaux riches",
  "nouvel arrive"          => "nouveaux arrives",
  "nova"                   => "novae",
  "novus homo"             => "novi homines",
  "noxa"                   => "noxae",
  "nse"                    => "nses",
  "nubecula"               => "nubeculae",
  "nucleolonema"           => "nucleolonemata",
  "nucleolus"              => "nucleoli",
  "nucleus"                => "nuclei",
  "numen"                  => "numina",
  "nuntius"                => "nuntii",
  "nympha"                 => "nymphae",
  "nymphaeum"              => "nymphaea",
  "nympheum"               => "nymphaea",
  "oath"                   => "oaths",
  "obelus"                 => "obeli",
  "obolus"                 => "oboli",
  "occiput"                => "occipita",
  "oceanarium"             => "oceanaria",
  "ocellus"                => "ocelli",
  "octavo"                 => "octavos",
  "octohedron"             => "octohedra",
  "octopus"                => "octopuses",
  "oculus"                 => "oculi",
  "odeum"                  => "odea",
  "oedema"                 => "oedemata",
  "offspring"              => "offspring",
  "ogle"                   => "oglys",
  "Oklahoman"              => "Oklahomans",
  "olfactorium"            => "olfactoria",
  "omentum"                => "omenta",
  "ommatidium"             => "ommatidia",
  "onager"                 => "onagri",
  "one"                    => "some",
  "one star general"       => "one star generals",
  "one-star general"       => "one-star generals",
  "operculum"              => "opercula",
  "ophiophagus"            => "ophiophagi",
  "optimum"                => "optima",
  "opus"                   => "opuses",
  "opus magnum"            => "opera magna",
  "opusculum"              => "opuscula",
  "oratrix"                => "oratrices",
  "oregano"                => "oreganos",
  "organon"                => "organa",
  "Orinoco"                => "Orinocos",
  "Orlando"                => "Orlandos",
  "orthoceras"             => "orthocerata",
  "osculum"                => "oscula",
  "Oslo"                   => "Oslos",
  "osmaterium"             => "osmateria",
  "osmeterium"             => "osmeteria",
  "ossiculum"              => "ossicula",
  "osteoclastoma"          => "osteoclastomata",
  "osteoma"                => "osteomata",
  "ostium"                 => "ostia",
  "oto"                    => "otos",
  "Otomi"                  => "Otomi",
  "otomi"                  => "otomi",
  "ottoman"                => "ottomans",
  "ovarium"                => "ovaria",
  "ovolo"                  => "ovoli",
  "ovulum"                 => "ovula",
  "ovum"                   => "ova",
  "ox"                     => "oxen",
  "oxybaphon"              => "oxybapha",
  "oxymoron"               => "oxymora",
  "oxyuris"                => "oxyurides",
  "paha"                   => "paha",
  "paisa"                  => "paise",
  "pajamas"                => "pajamas",
  "pala"                   => "palae",
  "palea"                  => "paleae",
  "pallium"                => "pallia",
  "palpebra"               => "palpebrae",
  "palpus"                 => "palpi",
  "palus"                  => "pali",
  "Panaman"                => "Panamans",
  "Pangasinan"             => "Pangasinanes",
  "pangasinan"             => "pangasinanes",
  "panino"                 => "panini",
  "panorpa"                => "panorpae",
  "pant"                   => "pants",
  "panto"                  => "pantos",
  "pants"                  => "pants",
  "paparrazo"              => "paparrazi",
  "papilla"                => "papillae",
  "papilloma"              => "papillomata",
  "papula"                 => "papulae",
  "papyrus"                => "papyri",
  "parabola"               => "parabolae",
  "parabolanus"            => "parabolani",
  "parador"                => "paradores",
  "paraganglioma"          => "paragangliomata",
  "paraganglion"           => "paraganglia",
  "paraglossa"             => "paraglossae",
  "Paramaribo"             => "Paramaribos",
  "paranucleus"            => "paranuclei",
  "parapleura"             => "parapleura",
  "parapleurum"            => "parapleura",
  "parapsis"               => "parapsides",
  "paraselene"             => "paraselenae",
  "parc ferme"             => "parcs fermes",
  "Pardusco"               => "Parduscos",
  "parenchyma"             => "parenchymata",
  "parergon"               => "parerga",
  "parhelion"              => "parhelia",
  "paries"                 => "parietes",
  "parison"                => "parisa",
  "Parmese"                => "Parmese",
  "parnas"                 => "parnassim",
  "parnass"                => "parnassim",
  "parvenu"                => "parvenus",
  "pasteurella"            => "pasteurellae",
  "pastorale"              => "pastorali",
  "patagium"               => "patagia",
  "patera"                 => "paterae",
  "path"                   => "paths",
  "pathos"                 => "pathoses",
  "paxilla"                => "paxillae",
  "pecia"                  => "peciae",
  "pecten"                 => "pectines",
  "pectus"                 => "pectora",
  "pedalo"                 => "pedalos",
  "pedicellaria"           => "pedicellariae",
  "pediluvium"             => "pediluvia",
  "pedion"                 => "pedia",
  "Pekingese"              => "Pekingese",
  "pelta"                  => "peltae",
  "pelvis"                 => "pelves",
  "pence"                  => "pence",
  "pendulum"               => "pendula",
  "pengo"                  => "pengoes",
  "penicillus"             => "penicilli",
  "peninsula"              => "peninsulae",
  "penis"                  => "penes",
  "penni"                  => "pennia",
  "penny"                  => "pence",
  "pensiero"               => "pensieri",
  "perceptum"              => "percepta",
  "peridium"               => "peridia",
  "perikaryon"             => "perikarya",
  "perithecium"            => "perithecia",
  "pernio"                 => "perniones",
  "peronium"               => "peronia",
  "perradius"              => "perradii",
  "person"                 => "persons",
  "persona"                => "personae",
  "pes"                    => "pedes",
  "phalangium"             => "phalangia",
  "phalanx"                => "phalanges",
  "phallos"                => "phalloi",
  "phallus"                => "phalli",
  "pharmakos"              => "pharmakoi",
  "phenomenon"             => "phenomena",
  "phlegmasia"             => "phlegmasiae",
  "phoca"                  => "phocae",
  "pholas"                 => "pholades",
  "photo"                  => "photos",
  "phototaxis"             => "phototaxes",
  "phragma"                => "phragmata",
  "phren"                  => "phrenes",
  "phyle"                  => "phylae",
  "phyllobranchia"         => "phyllobranchiae",
  "phylum"                 => "phyla",
  "phyma"                  => "phymata",
  "phyogemmarium"          => "phyogemmaria",
  "piano"                  => "piani",
  "pickerel"               => "pickerel",
  "pied a terre"           => "pieds a terre",
  "pied noir"              => "pieds noirs",
  "Piedmontese"            => "Piedmontese",
  "pietra"                 => "pietre",
  "pifferaro"              => "pifferari",
  "pike"                   => "pike",
  "pileus"                 => "pilei",
  "pillie"                 => "pilleis",
  "pilus"                  => "pili",
  "pimento"                => "pimentos",
  "pina colada"            => "pinas coladas",
  "pinax"                  => "pinaces",
  "pincer"                 => "pincers",
  "pincers"                => "pincers",
  "pinetum"                => "pineta",
  "pingo"                  => "pingoes",
  "pinna"                  => "pinnae",
  "pinon"                  => "pinones",
  "pinto"                  => "pintos",
  "pipkrake"               => "pipkraker",
  "piscina"                => "piscinae",
  "pistillidium"           => "pistillidia",
  "Pistoiese"              => "Pistoiese",
  "pithos"                 => "pithoi",
  "pizza"                  => "pizze",
  "placebo"                => "placeboes",
  "placitum"               => "placita",
  "planctus"               => "planctus",
  "plankter"               => "plankton",
  "planula"                => "planulae",
  "plasmalemma"            => "plasmalemmae",
  "plasmodium"             => "plasmodia",
  "plasmolyticum"          => "plasmolytica",
  "plasmoma"               => "plasmomata",
  "plateau"                => "plateaux",
  "platypus"               => "platypodes",
  "pleco"                  => "plecos",
  "plectrum"               => "plectra",
  "plenarium"              => "plenaria",
  "plesiosaurus"           => "plesiosauri",
  "plethron"               => "plether",
  "pleura"                 => "pleura",
  "pleuron"                => "pleura",
  "pleurum"                => "pleura",
  "plexus"                 => "plexus",
  "plica"                  => "plicae",
  "pliers"                 => "pliers",
  "ploshchadka"            => "ploshchadki",
  "plurale tantum"         => "pluralia tantum",
  "pluteus"                => "plutei",
  "Pluto"                  => "Plutos",
  "pneumothorax"           => "pneumothoraces",
  "po"                     => "poes",
  "poblador"               => "pobladores",
  "poculum"                => "pocula",
  "podere"                 => "poderi",
  "podetium"               => "podetia",
  "podion"                 => "podia",
  "podium"                 => "podia",
  "poe"                    => "poes",
  "pogo"                   => "pogos",
  "poise"                  => "poise",
  "polis"                  => "polises",
  "politbureau"            => "politbureaux",
  "politico"               => "politicoes",
  "pollex"                 => "pollices",
  "pollinarium"            => "pollinaria",
  "pollinium"              => "pollinia",
  "polo"                   => "polos",
  "Polonese"               => "Polonese",
  "polythecium"            => "polythecia",
  "pomme de terre"         => "pommes de terre",
  "poncho"                 => "ponchos",
  "pontifex"               => "pontifices",
  "porcino"                => "porcini",
  "porion"                 => "poria",
  "porron"                 => "porrones",
  "port a beul"            => "puirt a beul",
  "port de bras"           => "ports de bras",
  "port-a-beul"            => "puirt-a-beul",
  "portico"                => "porticoes",
  "portiforium"            => "portiforia",
  "portmanteau"            => "portmanteaux",
  "Porto"                  => "Portos",
  "Porto Novo"             => "Porto Novos",
  "Porto-Novo"             => "Porto-Novos",
  "portrait parle"         => "portraits parles",
  "Portuguese"             => "Portuguese",
  "postnatus"              => "postnati",
  "postpubis"              => "postpubes",
  "postulatum"             => "postulata",
  "potato"                 => "potatoes",
  "potestas"               => "potestates",
  "pox"                    => "pox",
  "praecognitum"           => "praecognita",
  "pragma"                 => "pragmata",
  "precis"                 => "precis",
  "precognitum"            => "precognita",
  "premier danseur"        => "premiers danseurs",
  "prepenna"               => "prepennae",
  "prima ballerina"        => "prime ballerine",
  "prima donna"            => "prime donne",
  "primigravida"           => "primigravidae",
  "primordium"             => "primordia",
  "principium"             => "principia",
  "pro"                    => "pros",
  "proavis"                => "proaves",
  "proboscis"              => "proboscides",
  "proceedings"            => "proceedings",
  "procoelia"              => "procoeliae",
  "prodromus"              => "prodromi",
  "proferens"              => "proferentes",
  "profluvium"             => "profluvia",
  "proglottis"             => "proglottides",
  "programma"              => "programmata",
  "progymnasium"           => "progymnasia",
  "progymnasma"            => "progymnasmata",
  "prokaryon"              => "prokarya",
  "prolabium"              => "prolabia",
  "prolegomenon"           => "prolegomena",
  "promerops"              => "promeropes",
  "propleuron"             => "propleura",
  "propodium"              => "propodia",
  "propositus"             => "propositi",
  "proprium"               => "propria",
  "propylaeum"             => "propylaea",
  "propylon"               => "propyla",
  "prora"                  => "prorae",
  "prosa"                  => "prosae",
  "proscenium"             => "proscenia",
  "proscolla"              => "proscollae",
  "prosecutrix"            => "prosecutrices",
  "prosencephalon"         => "prosencephala",
  "proseucha"              => "proseuchae",
  "prosodiencephalon"      => "prosodiencephala",
  "prosopium"              => "prosopia",
  "prospectus"             => "prospectus",
  "prosula"                => "prosulae",
  "protarsus"              => "protarsi",
  "prothallium"            => "prothallia",
  "prothallus"             => "prothalli",
  "protococcus"            => "protococci",
  "protoma"                => "protomae",
  "protonema"              => "protonemata",
  "prototypon"             => "prototypa",
  "protypon"               => "protypa",
  "proviso"                => "provisoes",
  "prytanis"               => "prytan",
  "psammoma"               => "psammomata",
  "pseudopodium"           => "pseudopodia",
  "pseudostoma"            => "pseudostomata",
  "psycho"                 => "psychos",
  "psydracium"             => "psydracia",
  "pteroma"                => "pteromata",
  "pteropus"               => "pteropi",
  "pteryla"                => "pterylae",
  "pueblo"                 => "pueblos",
  "pul"                    => "puli",
  "pullus"                 => "pulli",
  "pulmonarium"            => "pulmonaria",
  "pulsellum"              => "pulsella",
  "pulveratrix"            => "pulveratrices",
  "punctum"                => "puncta",
  "punto blanco"           => "punti blanchi",
  "pupa"                   => "pupae",
  "purlieu"                => "purlieux",
  "Purum"                  => "Purum",
  "purum"                  => "purum",
  "putto"                  => "putti",
  "puttony"                => "puttonys",
  "pycnidium"              => "pycnidia",
  "pycnis"                 => "pycnides",
  "pycnium"                => "pycnia",
  "pyjamas"                => "pyjamas",
  "pyla"                   => "pylae",
  "pyralis"                => "pyralides",
  "pyramidion"             => "pyramidia",
  "pyrexia"                => "pyrexiae",
  "pyrites"                => "pirrites",
  "pyrophorus"             => "pyrophori",
  "pyxidium"               => "pyxidia",
  "quadratrix"             => "quadratrices",
  "quaesitum"              => "quaesita",
  "quantum"                => "quanta",
  "quarto"                 => "quartos",
  "quartz"                 => "quartzes",
  "quid"                   => "quid",
  "quinarius"              => "quinarii",
  "quinquennium"           => "quinquennia",
  "Quito"                  => "Quitos",
  "rabies"                 => "rabies",
  "rad"                    => "rad",
  "radiale"                => "radialia",
  "radius"                 => "radii",
  "radix"                  => "radices",
  "ragazza"                => "ragazze",
  "ragazzo"                => "ragazzi",
  "raggare"                => "raggare",
  "ramulus"                => "ramuli",
  "ramus"                  => "rami",
  "ranunculus"             => "ranunculi",
  "rara avis"              => "rarae aves",
  "razz"                   => "razzes",
  "rectus"                 => "recti",
  "redia"                  => "rediae",
  "reductio"               => "reductiones",
  "referendum"             => "referenda",
  "refugium"               => "refugia",
  "regidor"                => "regidores",
  "regma"                  => "regmata",
  "regulus"                => "reguli",
  "reich"                  => "reiche",
  "rejon"                  => "rejones",
  "rejoneador"             => "rejoneadores",
  "relatum"                => "relata",
  "rem"                    => "rem",
  "remex"                  => "remiges",
  "remous"                 => "remou",
  "replum"                 => "repla",
  "representamen"          => "representamina",
  "res"                    => "res",
  "residuum"               => "residua",
  "responsum"              => "responsa",
  "rete"                   => "retia",
  "retinaculum"            => "retinacula",
  "retinula"               => "retinulae",
  "rezident"               => "rezidenty",
  "rezidentsia"            => "rezidentsii",
  "rhino"                  => "rhinos",
  "rhinoceros"             => "rhinoceros",
  "rhinophyma"             => "rhinophymata",
  "rhizoma"                => "rhizomata",
  "rhododendron"           => "rhododendra",
  "rhombohedron"           => "rhombohedra",
  "rhomboideus"            => "rhomboidei",
  "rhopalium"              => "rhopalia",
  "rhynchodaeum"           => "rhynchodaea",
  "rhythmus"               => "rhythmi",
  "ri"                     => "ri",
  "ricercar"               => "ricercari",
  "ricercata"              => "ricercate",
  "ricordo"                => "ricordi",
  "rideau"                 => "rideaux",
  "rilievo"                => "rilievos",
  "rimon"                  => "rimmonim",
  "rione"                  => "rioni",
  "risotto"                => "risottos",
  "ritardando"             => "ritardandi",
  "rite de passage"        => "rites de passage",
  "rococo"                 => "rococos",
  "roe"                    => "roe",
  "Rom"                    => "Roma",
  "rom"                    => "roms",
  "Romagnese"              => "Romagnese",
  "Roman"                  => "Romans",
  "Romanese"               => "Romanese",
  "Romany"                 => "Romanies",
  "romanze"                => "romanzen",
  "rond de jambe"          => "ronds de jambes",
  "rondeau"                => "rondeaux",
  "rondo"                  => "rondos",
  "rostrum"                => "rostra",
  "rotula"                 => "rotulae",
  "route nationale"        => "routes nationales",
  "rubashka"               => "rubashki",
  "ruga"                   => "rugae",
  "ruse de guerre"         => "ruses de guerre",
  "rype"                   => "ryper",
  "sabertooth"             => "sabertooths",
  "sacculus"               => "sacculi",
  "sacellum"               => "sacella",
  "sachverhalt"            => "sachverhalte",
  "Sacramento"             => "Sacramentos",
  "sacrarium"              => "sacraria",
  "sacrum"                 => "sacra",
  "saddo"                  => "saddos",
  "saffo"                  => "saffi",
  "sago"                   => "sagos",
  "sagum"                  => "saga",
  "salita"                 => "salite",
  "salivarium"             => "salivaria",
  "salmon"                 => "salmon",
  "salpa"                  => "salpae",
  "salvo"                  => "salvos",
  "sambo"                  => "samboes",
  "samurai"                => "samurai",
  "sanatorium"             => "sanatoria",
  "sanctum sanctorum"      => "sancta sanctorum",
  "sandr"                  => "sandr",
  "Sangirese"              => "Sangirese",
  "Santiago"               => "Santiagos",
  "Sapporo"                => "Sapporos",
  "Sarajevo"               => "Sarajevos",
  "Sarawakese"             => "Sarawakese",
  "sarcina"                => "sarcinae",
  "sarcoma"                => "sarcomata",
  "sarcophagus"            => "sarcophagi",
  "sarissa"                => "sarissae",
  "sassafras"              => "sassafrases",
  "satelles"               => "satellites",
  "saxicava"               => "saxicavae",
  "sbirro"                 => "sbirri",
  "scalenus"               => "scaleni",
  "scandalum magnatum"     => "scandala magnatum",
  "scapula"                => "scapulae",
  "scapus"                 => "scapi",
  "scarabaeus"             => "scarabaei",
  "scarus"                 => "scari",
  "scazon"                 => "scazons",
  "sceat"                  => "sceattas",
  "schema"                 => "schemata",
  "scherzando"             => "scherzandos",
  "scherzo"                => "scherzos",
  "schisma"                => "schismata",
  "schistosomulum"         => "schistosomula",
  "schizostylis"           => "schizostylis",
  "scholium"               => "scholia",
  "sciolus"                => "scioli",
  "scirrhus"               => "scirrhi",
  "scissors"               => "scissors",
  "scolex"                 => "scoleces",
  "scolopidium"            => "scolopidia",
  "scomber"                => "scombri",
  "scoria"                 => "scoriae",
  "scotoma"                => "scotomata",
  "scriptorium"            => "scriptoria",
  "scudo"                  => "scudi",
  "scungille"              => "scungilli",
  "scuola"                 => "scuole",
  "scutellum"              => "scutella",
  "scutulum"               => "scutula",
  "scutum"                 => "scuta",
  "scyphus"                => "scyphi",
  "seaquarium"             => "seaquaria",
  "secans"                 => "secantes",
  "secretum"               => "secreta",
  "secundagravida"         => "secundagravidae",
  "secundigravida"         => "secundigravidae",
  "secundipara"            => "secundiparae",
  "sedes"                  => "sedes",
  "sedile"                 => "sedilia",
  "seecatch"               => "seecatchie",
  "seed"                   => "seed",
  "Selman"                 => "Selmans",
  "sema"                   => "semata",
  "seminium"               => "seminia",
  "semuncia"               => "semunciae",
  "senarius"               => "senarii",
  "Senegalese"             => "Senegalese",
  "senex"                  => "senes",
  "sensedatum"             => "sensedata",
  "sensillum"              => "sensilla",
  "sensoriolum"            => "sensoriola",
  "sensum"                 => "sensa",
  "sententia"              => "sententiae",
  "separatrix"             => "separatrices",
  "sephardi"               => "sephardin",
  "septarium"              => "septaria",
  "septemvir"              => "septemviri",
  "septenarius"            => "septenarii",
  "septum"                 => "septa",
  "sequela"                => "sequelae",
  "sequestrum"             => "sequestra",
  "seraph"                 => "seraphim",
  "sericterium"            => "sericteria",
  "series"                 => "series",
  "serir"                  => "serir",
  "serpigo"                => "serpigines",
  "serpula"                => "serpulae",
  "serra"                  => "serrae",
  "sertularia"             => "sertulariae",
  "serum"                  => "sera",
  "sestertium"             => "sestertia",
  "sestiere"               => "sestieri",
  "set off"                => "sets off",
  "set out"                => "sets out",
  "set to"                 => "sets to",
  "set-off"                => "sets-off",
  "set-out"                => "sets-out",
  "set-to"                 => "sets-to",
  "seta"                   => "setae",
  "sezession"              => "sezessionen",
  "sforzato"               => "sforzati",
  "sgraffiato"             => "sgraffiati",
  "shad"                   => "shad",
  "shaman"                 => "shamans",
  "shauri"                 => "shauries",
  "Shavese"                => "Shavese",
  "shawabti"               => "shawabtiu",
  "Shawanese"              => "Shawanese",
  "she"                    => "they",
  "shear"                  => "shears",
  "shears"                 => "shears",
  "sheep"                  => "sheep",
  "shelf"                  => "shelves",
  "shifta"                 => "shifta",
  "shochet"                => "shochetim",
  "shomer"                 => "shomrim",
  "short"                  => "shorts",
  "shorts"                 => "shorts",
  "Siamese"                => "Siamese",
  "siemens"                => "siemens",
  "Sienese"                => "Sienese",
  "siglos"                 => "sigloi",
  "signum"                 => "signa",
  "Sikkimese"              => "Sikkimese",
  "silbador"               => "silbadores",
  "silenus"                => "sileni",
  "silex"                  => "silices",
  "siliqua"                => "siliquae",
  "silo"                   => "silos",
  "Silurus"                => "Siluri",
  "simia"                  => "simiae",
  "simplex"                => "simplices",
  "simpulum"               => "simpula",
  "simulacrum"             => "simulacra",
  "sinfonia"               => "sinfonie",
  "Singhalese"             => "Singhalese",
  "Sinhalese"              => "Sinhalese",
  "sinus"                  => "sinus",
  "siphunculus"            => "siphunculi",
  "sipunculus"             => "sipunculi",
  "sirocco"                => "siroccos",
  "sis"                    => "ses",
  "sistrum"                => "sistra",
  "situla"                 => "situlae",
  "six star general"       => "six star generals",
  "six-star general"       => "six-star generals",
  "sizz"                   => "sizzes",
  "ski"                    => "skis",
  "snekkja"                => "snekkjur",
  "snipe"                  => "snipe",
  "snooze"                 => "snoozes",
  "so"                     => "soes",
  "soe"                    => "soes",
  "Sogdianese"             => "Sogdianese",
  "sol"                    => "soles",
  "solarium"               => "solaria",
  "soldo"                  => "soldi",
  "solenium"               => "solenia",
  "solfeggio"              => "solfeggi",
  "solidus"                => "solidos",
  "solo"                   => "soli",
  "solstitium"             => "solstitia",
  "solvus"                 => "solvi",
  "soma"                   => "somata",
  "somaten"                => "somatenes",
  "sombrero"               => "sombreros",
  "Sonaman"                => "Sonamans",
  "soprano"                => "soprani",
  "soralium"               => "soralia",
  "soredium"               => "soredia",
  "sorus"                  => "sori",
  "soshi"                  => "soshi",
  "sotch"                  => "sotchs",
  "souvlaki"               => "souvlakia",
  "spadix"                 => "spadices",
  "Spaetlese"              => "Spaetlesen",
  "sparus"                 => "spari",
  "spasmus"                => "spasmi",
  "spatha"                 => "spathae",
  "species"                => "species",
  "spectrum"               => "spectra",
  "speculum"               => "specula",
  "sperma"                 => "spermata",
  "spermarium"             => "spermaria",
  "spermatheca"            => "spermathecae",
  "spermatium"             => "spermatia",
  "spermatoon"             => "spermatoa",
  "spermogonium"           => "spermogonia",
  "sphaeridium"            => "sphaerideum",
  "sphagnum"               => "sphagna",
  "sphex"                  => "spheges",
  "sphinx"                 => "sphinges",
  "spiculum"               => "spicula",
  "spiraculum"             => "spiracula",
  "spirillum"              => "spirilla",
  "spondylus"              => "spondyli",
  "sporodochium"           => "sporodochia",
  "sputum"                 => "sputa",
  "squadra"                => "squadre",
  "squadrist"              => "squadristi",
  "squalus"                => "squali",
  "squama"                 => "squamae",
  "squilla"                => "squillae",
  "stabilimentum"          => "stabilimenta",
  "staccato"               => "staccatos",
  "stadium"                => "stadia",
  "stalactite"             => "stalactitae",
  "stamen"                 => "stamina",
  "staminidium"            => "staminidia",
  "staphylococcus"         => "staphylococci",
  "star fish"              => "star fish",
  "star-fish"              => "star-fish",
  "starets"                => "startsy",
  "staretz"                => "startzy",
  "starfish"               => "starfish",
  "starosta"               => "starosti",
  "starover"               => "starovery",
  "stasimon"               => "stasima",
  "statera"                => "staterae",
  "statua"                 => "statuae",
  "status"                 => "status",
  "stela"                  => "stelae",
  "stella"                 => "stellae",
  "stemma"                 => "stemmata",
  "stephanion"             => "stephania",
  "sterigma"               => "sterigmata",
  "sternebra"              => "sternebrae",
  "sterno"                 => "sternos",
  "sternum"                => "sterna",
  "stichidium"             => "stichidia",
  "stichos"                => "stichoi",
  "stigma"                 => "stigmata",
  "stigmaria"              => "stigmariae",
  "stiletto"               => "stilettoes",
  "stillicidium"           => "stillicidia",
  "stimulus"               => "stimuli",
  "stipes"                 => "stipites",
  "stipula"                => "stipulae",
  "stirps"                 => "stirpes",
  "stoa"                   => "stoai",
  "stolo"                  => "stolones",
  "stoma"                  => "stomata",
  "stomach"                => "stomachs",
  "stomatium"              => "stomatia",
  "stomion"                => "stomia",
  "stomodaeum"             => "stomodaea",
  "storey"                 => "storeys",
  "stornello"              => "stornelli",
  "strambotto"             => "strambotti",
  "strategos"              => "strategoi",
  "strategus"              => "strategi",
  "stratum"                => "strata",
  "streptococcus"          => "streptococci",
  "streptothrix"           => "streptothrices",
  "stria"                  => "striae",
  "striatum"               => "striata",
  "striga"                 => "strigae",
  "striola"                => "striolae",
  "strobila"               => "strobilae",
  "strobilus"              => "strobili",
  "stroma"                 => "stromata",
  "stromodeum"             => "stromodaea",
  "struma"                 => "strumae",
  "stryddag"               => "stryddae",
  "stucco"                 => "stuccos",
  "studium generale"       => "studia generali",
  "stylo"                  => "stylos",
  "stylopodium"            => "stylopodia",
  "stylus"                 => "styli",
  "subbotnik"              => "subbotniki",
  "subsellium"             => "subsellia",
  "subsidium"              => "subsidia",
  "substratum"             => "substrata",
  "succinea"               => "succineae",
  "succubus"               => "succubi",
  "succus"                 => "succi",
  "Sudanese"               => "Sudanese",
  "suffrutex"              => "suffrutices",
  "suggestio falsi"        => "suggestiones falsi",
  "suggestum"              => "suggesta",
  "sulcus"                 => "sulci",
  "sum total"              => "sums total",
  "sum-total"              => "sums-total",
  "summa"                  => "summae",
  "summum bonum"           => "summa bona",
  "summum genus"           => "summa genera",
  "sumo"                   => "sumos",
  "Sundanese"              => "Sundanese",
  "supercilium"            => "supercilia",
  "superficies"            => "superficies",
  "supernova"              => "supernovae",
  "superstratum"           => "superstrata",
  "suppositum"             => "supposita",
  "supracleithrum"         => "supracleithra",
  "suprascapula"           => "suprascapulae",
  "surculus"               => "surculi",
  "surimono"               => "surimonos",
  "sustentaculum"          => "sustentacula",
  "Swahilese"              => "Swahilese",
  "swine"                  => "swines",
  "switchfoot"             => "switchfoots",
  "syllabarium"            => "syllabaria",
  "syllabus"               => "syllabi",
  "symplasma"              => "symplasmata",
  "sympodium"              => "sympodia",
  "symposium"              => "symposia",
  "synaesthesia"           => "synaesthesiae",
  "synangium"              => "synangia",
  "synapticula"            => "synapticulae",
  "synaxarion"             => "synaxaria",
  "synaxarium"             => "synaxaria",
  "synaxis"                => "synaxes",
  "syncellus"              => "syncelli",
  "syncytium"              => "syncytia",
  "syndendrium"            => "syndendria",
  "synechia"               => "synechiae",
  "synedrion"              => "synedria",
  "synedrium"              => "synedria",
  "synesthesia"            => "synesthesiae",
  "syntagma"               => "syntagmata",
  "syntaxis"               => "syntaxes",
  "synthronus"             => "synthroni",
  "synusia"                => "synusiae",
  "syphiloma"              => "syphilomata",
  "syringe"                => "syringes",
  "syrinx"                 => "syringes",
  "syrphus"                => "syrphi",
  "syrtis"                 => "syrtes",
  "tabella"                => "tabellae",
  "tableau"                => "tableaux",
  "tablinum"               => "tablina",
  "tabula"                 => "tabulae",
  "Tacoman"                => "Tacomans",
  "taenia"                 => "taeniae",
  "tagma"                  => "tagmata",
  "Taiko"                  => "Taikos",
  "talea"                  => "taleae",
  "talisman"               => "talismans",
  "talouse"                => "talouses",
  "talus"                  => "tali",
  "tango"                  => "tangoes",
  "tarantata"              => "tarantate",
  "tarantato"              => "tarantati",
  "tarsus"                 => "tarsi",
  "taxis"                  => "taxes",
  "taxon"                  => "taxa",
  "tazza"                  => "tazze",
  "teal"                   => "teal",
  "techno"                 => "technos",
  "tegmen"                 => "tegmina",
  "tegmentum"              => "tegmenta",
  "tegula"                 => "tegulae",
  "telamon"                => "telamones",
  "telium"                 => "telia",
  "temblor"                => "temblores",
  "tempietto"              => "tempietti",
  "tempo"                  => "tempi",
  "tenaculum"              => "tenacula",
  "tenderfoot"             => "tenderfoots",
  "Tenggerese"             => "Tenggerese",
  "tenia"                  => "teniae",
  "tenorino"               => "tenorini",
  "tentaculum"             => "tentacula",
  "tentamen"               => "tentamina",
  "tenuis"                 => "tenues",
  "tepidarium"             => "tepidaria",
  "teratoma"               => "teratomata",
  "terebellum"             => "terebella",
  "terebratula"            => "terebratulae",
  "teredo"                 => "teredines",
  "tergum"                 => "terga",
  "termes"                 => "termites",
  "terminus"               => "termini",
  "terp"                   => "terpen",
  "terrae filius"          => "terrae filii",
  "terramara"              => "terremare",
  "terrarium"              => "terraria",
  "terrazzo"               => "terrazzos",
  "territorium"            => "territoria",
  "terzetto"               => "terzetti",
  "tessella"               => "tessellae",
  "tessera"                => "tesserae",
  "testes"                 => "testes",
  "testis"                 => "testes",
  "testudo"                => "testudos",
  "tetanothrum"            => "tetanother",
  "tete a tete"            => "tete a tetes",
  "tete-a-tete"            => "tete-a-tetes",
  "tetracolon"             => "tetracola",
  "tetragrammaton"         => "tetragrammata",
  "tetrahedron"            => "tetrahedra",
  "tetrapleuron"           => "tetrapleura",
  "tetrasporangium"        => "tetrasporangia",
  "thalamos"               => "thalamoi",
  "thalamus"               => "thalami",
  "thanatorium"            => "thanatoria",
  "that"                   => "those",
  "thaumaturgus"           => "thaumaturgi",
  "thebe"                  => "thebe",
  "theca"                  => "thecae",
  "theirs"                 => "theirs",
  "thelycum"               => "thelyca",
  "them"                   => "them",
  "thema"                  => "themata",
  "themself"               => "themselves",
  "themselves"             => "themselves",
  "theologoumenon"         => "theologoumena",
  "thesaurus"              => "thesauri",
  "they"                   => "they",
  "thief"                  => "thieves",
  "this"                   => "these",
  "tholos"                 => "tholoi",
  "tholus"                 => "tholi",
  "thorax"                 => "thoraces",
  "thos"                   => "thoes",
  "thraso"                 => "thrasones",
  "three star general"     => "three star generals",
  "three-star general"     => "three-star generals",
  "thymiaterion"           => "thymiateria",
  "thymus"                 => "thymi",
  "thyridium"              => "thyridia",
  "thyrsus"                => "thyrsi",
  "tibia"                  => "tibiae",
  "Timorese"               => "Timorese",
  "timpano"                => "timpanos",
  "tintinnabulum"          => "tintinnabula",
  "tipula"                 => "tipulae",
  "tiro"                   => "tiros",
  "Tirolese"               => "Tirolese",
  "to"                     => "toes",
  "tobacco"                => "tobaccos",
  "Tocharese"              => "Tocharese",
  "toe"                    => "toes",
  "Togo"                   => "Togos",
  "Tokyo"                  => "Tokyos",
  "tolkach"                => "tolkachi",
  "tomato"                 => "tomatoes",
  "tombarolo"              => "tombaroli",
  "tomium"                 => "tomia",
  "tondo"                  => "tondi",
  "tong"                   => "tongs",
  "tongs"                  => "tongs",
  "Tonkinese"              => "Tonkinese",
  "tonneau"                => "tonneaux",
  "tooth"                  => "teeth",
  "topaz"                  => "topazes",
  "topos"                  => "topoi",
  "torero"                 => "toreros",
  "toril"                  => "toriles",
  "Torinese"               => "Torinese",
  "Torino"                 => "Torinos",
  "torma"                  => "torma",
  "Tornese"                => "Tornesi",
  "tornus"                 => "torni",
  "Toronto"                => "Torontos",
  "torso"                  => "torsos",
  "tortilla espanola"      => "tortillas espanolas",
  "tortrix"                => "tortrices",
  "torula"                 => "torulae",
  "torulus"                => "toruli",
  "torus"                  => "tori",
  "tour de force"          => "tours de force",
  "toxicum"                => "toxica",
  "toxius"                 => "toxii",
  "toxoplasma"             => "toxoplasmata",
  "trabea"                 => "trabeae",
  "trabecula"              => "trabeculae",
  "trachea"                => "tracheae",
  "tractatrix"             => "tractatrices",
  "tractellum"             => "tractella",
  "tractrix"               => "tractrices",
  "tragus"                 => "tragi",
  "trapezium"              => "trapezia",
  "trapezius"              => "trapezii",
  "trapezohedron"          => "trapezohedra",
  "trattoria"              => "trattorie",
  "trauma"                 => "traumata",
  "trellis"                => "trellises",
  "tremolo"                => "tremolos",
  "treponema"              => "treponemata",
  "trichidium"             => "trichidia",
  "trichina"               => "trichinae",
  "trichoma"               => "trichomata",
  "triclinium"             => "triclinia",
  "triens"                 => "trientes",
  "triforium"              => "triforia",
  "trilby"                 => "trilbys",
  "triplum"                => "tripla",
  "triradius"              => "triradii",
  "triumvir"               => "triumviri",
  "trochus"                => "trochi",
  "trockenbeerenauslese"   => "trockenbeerenauslesen",
  "tropaeolum"             => "tropaeola",
  "troparion"              => "troparia",
  "tropis"                 => "tropides",
  "trousers"               => "trousers",
  "trousseau"              => "trousseaux",
  "trout"                  => "trout",
  "trullo"                 => "trulli",
  "trumeau"                => "trumeaux",
  "tsuba"                  => "tsuba",
  "tsubo"                  => "tsubo",
  "tuber"                  => "tuberes",
  "tuberculoma"            => "tuberculomata",
  "tuberculum"             => "tubercula",
  "tubulus"                => "tubuli",
  "tumulus"                => "tumuli",
  "tuna"                   => "tuna",
  "turbot"                 => "turbot",
  "turf"                   => "turves",
  "turron"                 => "turrones",
  "two star general"       => "two star generals",
  "two-star general"       => "two-star generals",
  "tympanum"               => "tympana",
  "typo"                   => "typos",
  "tyro"                   => "tyros",
  "Tyrolese"               => "Tyrolese",
  "udarnik"                => "udarniki",
  "ulpan"                  => "ulpanim",
  "ultimatum"              => "ultimata",
  "umbilicus"              => "umbilici",
  "umbo"                   => "umbones",
  "umbra"                  => "umbrae",
  "umwelt"                 => "umwelten",
  "uncia"                  => "unciae",
  "uncinus"                => "uncini",
  "uncus"                  => "unci",
  "unguis"                 => "ungues",
  "unio"                   => "uniones",
  "uomo"                   => "uomini",
  "uomo universale"        => "uomini universali",
  "uraeus"                 => "uraei",
  "uredinium"              => "uredinia",
  "uredium"                => "uredia",
  "uredosorus"             => "uredosori",
  "urodaeum"               => "urodaea",
  "urodeum"                => "urodea",
  "urus"                   => "uri",
  "usnea"                  => "usneae",
  "ustilago"               => "ustilagines",
  "uterus"                 => "uteri",
  "utricularia"            => "utriculariae",
  "uva"                    => "uvae",
  "vaalpens"               => "vaalpensen",
  "vacuum"                 => "vacua",
  "vagina"                 => "vaginae",
  "vaginula"               => "vaginulae",
  "vagus"                  => "vagi",
  "vallecula"              => "valleculae",
  "valuta"                 => "valuten",
  "valvula"                => "valvulae",
  "vaporetto"              => "vaporetti",
  "vaquero"                => "vaqueros",
  "varella"                => "varely",
  "varia lectio"           => "variae lectiones",
  "varix"                  => "varices",
  "vas"                    => "vasa",
  "vasculitis"             => "vasculitides",
  "vasculum"               => "vascula",
  "veduta"                 => "vedute",
  "veg"                    => "veg",
  "vehiculum"              => "vehicula",
  "velamen"                => "velamina",
  "velarium"               => "velaria",
  "velum"                  => "vela",
  "vena"                   => "venae",
  "venus"                  => "veneres",
  "vermicello"             => "vermicellos",
  "vermiculus"             => "vermiculi",
  "Vermontese"             => "Vermontese",
  "Veronese"               => "Veronese",
  "verruca"                => "verrucae",
  "vers libre"             => "vers libres",
  "versiculus"             => "versiculi",
  "verso"                  => "versos",
  "vertebra"               => "vertebrae",
  "vertex"                 => "vertices",
  "verticillus"            => "verticilli",
  "vesicula"               => "vesiculae",
  "vestigium"              => "vestigia",
  "vetturino"              => "vetturini",
  "viale"                  => "viali",
  "viaticum"               => "viatica",
  "vibex"                  => "vibices",
  "vibraculum"             => "vibracula",
  "vibrato"                => "vibratos",
  "vibrio"                 => "vibriones",
  "Viennese"               => "Viennese",
  "Vietnamese"             => "Vietnamese",
  "vila"                   => "vile",
  "villanella"             => "villanelle",
  "villino"                => "villini",
  "villus"                 => "villi",
  "vinculum"               => "vincula",
  "violetta"               => "violette",
  "violoncello"            => "violoncellos",
  "virga"                  => "virgae",
  "Virgo"                  => "Virgos",
  "virtuoso"               => "virtuosi",
  "virus"                  => "viruses",
  "vis"                    => "vires",
  "viscus"                 => "viscera",
  "vitellarium"            => "vitellaria",
  "vitta"                  => "vittae",
  "vivarium"               => "vivaria",
  "vlakte"                 => "vlakten",
  "voeu"                   => "voeux",
  "volcanello"             => "volcanelli",
  "volcano"                => "volcanoes",
  "vomica"                 => "vomicae",
  "vomitorium"             => "vomitoria",
  "voorbok"                => "voorbokke",
  "vorspiel"               => "vorspiele",
  "vorstellung"            => "vorstellungen",
  "vortex"                 => "vortices",
  "wadi"                   => "wadis",
  "wady"                   => "wadys",
  "waldo"                  => "waldoes",
  "waltz"                  => "waltzes",
  "wanderjahr"             => "wanderjahre",
  "wandervogel"            => "wandervogel",
  "washer up"              => "washers up",
  "washer-up"              => "washers-up",
  "weirdo"                 => "weirdos",
  "Wenchowese"             => "Wenchowese",
  "wharf"                  => "wharves",
  "what"                   => "what",
  "whatever"               => "whatever",
  "whatsoever"             => "whatsoever",
  "white staff"            => "white staves",
  "whiting"                => "whiting",
  "Whitmanese"             => "Whitmanese",
  "who"                    => "who",
  "whoever"                => "whoever",
  "whom"                   => "whom",
  "whomever"               => "whomever",
  "whomsoever"             => "whomsoever",
  "whose"                  => "whose",
  "whosesoever"            => "whosesoever",
  "whosever"               => "whosever",
  "whosoever"              => "whosoever",
  "wife"                   => "wives",
  "wildebeest"             => "wildebeest",
  "wolf"                   => "wolves",
  "woman child"            => "women children",
  "woman servant"          => "women servants",
  "woman-child"            => "women-children",
  "woman-servant"          => "women-servants",
  "womanchild"             => "womenchildren",
  "wreath"                 => "wreaths",
  "xanthoma"               => "xanthomata",
  "xiphiplastron"          => "xiphiplastra",
  "xiphopagus"             => "xiphopagi",
  "xiphoplastron"          => "xiphoplastra",
  "xoanon"                 => "xoana",
  "xystus"                 => "xysti",
  "Yakiman"                => "Yakimans",
  "Yamoussoukro"           => "Yamoussoukros",
  "yarraman"               => "yarramans",
  "Yengeese"               => "Yengeese",
  "yes"                    => "yeses",
  "yo"                     => "yoes",
  "yo yo"                  => "yo yos",
  "yo-yo"                  => "yo-yos",
  "yoe"                    => "yoes",
  "Yokohaman"              => "Yokohamans",
  "you"                    => "you",
  "yours"                  => "yours",
  "yourself"               => "yourselves",
  "Yuman"                  => "Yumans",
  "Yunnanese"              => "Yunnanese",
  "yuo"                    => "yuon",
  "zadruga"                => "zadruge",
  "zeitgeber"              => "zeitgebers",
  "zemirah"                => "zemirot",
  "zeppole"                => "zeppoli",
  "zero"                   => "zeros",
  "Zibo"                   => "Zibos",
  "zingano"                => "zingani",
  "zita"                   => "zite",
  "zitella"                => "zitelle",
  "zizz"                   => "zizzes",
  "zloty"                  => "zloty",
  "zoaea"                  => "zoaeae",
  "zoarium"                => "zoaria",
  "zoea"                   => "zoeae",
  "zooea"                  => "zooeae",
  "zooecium"               => "zooecia",
  "zoon"                   => "zoa",
  "zoophorus"              => "zoophori",
  "zoosporangium"          => "zoosporangia",
  "zophorus"               => "zophori",
  "zucca"                  => "zucche",
  "zucchini"               => "zucchini",
  "zuppa"                  => "zuppe",
  "zuz"                    => "zuzim",
  "zygantrum"              => "zygantra",
  "zygoma"                 => "zygomata",
  "zygon"                  => "zyga",
};

my $singular_of = {
  " oxen"                 => " ox",
  "-oxen"                 => "-ox",
  "1 star generals"       => "1 star general",
  "1-star generals"       => "1-star general",
  "2 star generals"       => "2 star general",
  "2-star generals"       => "2-star general",
  "3 star generals"       => "3 star general",
  "3-star generals"       => "3-star general",
  "4 star generals"       => "4 star general",
  "4-star generals"       => "4-star general",
  "5 star generals"       => "5 star general",
  "5-star generals"       => "5-star general",
  "6 star generals"       => "6 star general",
  "6-star generals"       => "6-star general",
  "abacuses"              => "abacus",
  "aboiteaus"             => "aboiteau",
  "aboiteaux"             => "aboiteau",
  "abortoria"             => "abortorium",
  "abortuses"             => "abortus",
  "abscissae"             => "abscissa",
  "abscissas"             => "abscissa",
  "abstracta"             => "abstractum",
  "acari"                 => "acarus",
  "Achinese"              => "Achinese",
  "aciculae"              => "acicula",
  "acini"                 => "acinus",
  "acroamata"             => "acroama",
  "acropolises"           => "acropolis",
  "actiniae"              => "actinia",
  "actinias"              => "actinia",
  "aculei"                => "aculeus",
  "addenda"               => "addendum",
  "addendums"             => "addendum",
  "adieus"                => "adieu",
  "adieux"                => "adieu",
  "adminicula"            => "adminiculum",
  "ados"                  => "ado",
  "advisoes"              => "adviso",
  "adyta"                 => "adytum",
  "aecidia"               => "aecidium",
  "aegises"               => "aegis",
  "aelfe"                 => "aelf",
  "aficionados"           => "aficionado",
  "afreeti"               => "afreet",
  "afreets"               => "afreet",
  "afriti"                => "afrit",
  "afrits"                => "afrit",
  "agapae"                => "agape",
  "agapes"                => "agape",
  "agenda"                => "agendum",
  "agends"                => "agend",
  "agents provocateurs"   => "agent provocateur",
  "aggros"                => "aggro",
  "agones"                => "agon",
  "agorae"                => "agora",
  "agrogoroda"            => "agrogorod",
  "aides de camp"         => "aide de camp",
  "aides-de-camp"         => "aide-de-camp",
  "alae"                  => "ala",
  "alani"                 => "alan",
  "alans"                 => "alan",
  "alberghi"              => "albergo",
  "albinos"               => "albino",
  "ale wives"             => "ale wife",
  "ale-wives"             => "ale-wife",
  "Alfurese"              => "Alfurese",
  "algae"                 => "alga",
  "alguaciles"            => "alguacil",
  "alguacils"             => "alguacil",
  "aliases"               => "alias",
  "allargandi"            => "allargando",
  "allegros"              => "allegro",
  "alluvia"               => "alluvium",
  "alluviums"             => "alluvium",
  "alti"                  => "alto",
  "alto relievos"         => "alto relievo",
  "alto-relievos"         => "alto-relievo",
  "altorelievos"          => "altorelievo",
  "altos"                 => "alto",
  "alulae"                => "alula",
  "alumnae"               => "alumna",
  "alumni"                => "alumnus",
  "alveoli"               => "alveolus",
  "Amboinese"             => "Amboinese",
  "ambones"               => "ambo",
  "ambos"                 => "ambo",
  "ambulacra"             => "ambulacrum",
  "ambuscadoes"           => "ambuscado",
  "ambuscados"            => "ambuscado",
  "amenta"                => "amentum",
  "Americanese"           => "Americanese",
  "amici curiae"          => "amicus curiae",
  "ammos"                 => "ammo",
  "amoebae"               => "amoeba",
  "amoebas"               => "amoeba",
  "amoretti"              => "amoretto",
  "amorini"               => "amorino",
  "Amoyese"               => "Amoyese",
  "amphipneusta"          => "amphipneust",
  "amphipneusts"          => "amphipneust",
  "amphorae"              => "amphora",
  "anacolutha"            => "anacoluthon",
  "anacoluthons"          => "anacoluthon",
  "anathemas"             => "anathema",
  "anathemata"            => "anathema",
  "ancone"                => "ancona",
  "Andamanese"            => "Andamanese",
  "angiomata"             => "angioma",
  "Angolese"              => "Angolese",
  "angustiae"             => "angustia",
  "anlagen"               => "anlage",
  "anlages"               => "anlage",
  "Annamese"              => "Annamese",
  "antae"                 => "anta",
  "Antananarivos"         => "Antananarivo",
  "antefixa"              => "antefix",
  "antennae"              => "antenna",
  "antennas"              => "antenna",
  "anthemia"              => "anthemion",
  "anthodia"              => "anthodium",
  "anti sera"             => "anti serum",
  "anti serums"           => "anti serum",
  "anti-sera"             => "anti-serum",
  "anti-serums"           => "anti-serum",
  "antifixes"             => "antefix",
  "antisera"              => "antiserum",
  "antra"                 => "antrum",
  "apexes"                => "apex",
  "aphelia"               => "aphelion",
  "aphides"               => "aphis",
  "apices"                => "apex",
  "apothecia"             => "apothecium",
  "apparatchiki"          => "apparatchik",
  "apparatchiks"          => "apparatchik",
  "apparatus"             => "apparatus",
  "apparatuses"           => "apparatus",
  "appendices"            => "appendix",
  "appendixes"            => "appendix",
  "appressoria"           => "appressorium",
  "apsides"               => "apsis",
  "apteria"               => "apterium",
  "aptychi"               => "aptychus",
  "aquaria"               => "aquarium",
  "aquariums"             => "aquarium",
  "Aragonese"             => "Aragonese",
  "Arakanese"             => "Arakanese",
  "arangoes"              => "arango",
  "arboreta"              => "arboretum",
  "arcana"                => "arcanum",
  "archegonia"            => "archegonium",
  "archipelagoes"         => "archipelago",
  "archipelagos"          => "archipelago",
  "arcosolia"             => "arcosolium",
  "areolae"               => "areola",
  "argumenta"             => "argumentum",
  "aristae"               => "arista",
  "armadillos"            => "armadillo",
  "army corps generals"   => "army corps general",
  "army-corps generals"   => "army-corps general",
  "arrhae"                => "arrha",
  "arves"                 => "arf",
  "asbestoses"            => "asbestos",
  "ascidia"               => "ascidium",
  "Asherahs"              => "Asherah",
  "Asherim"               => "Asherah",
  "Assamese"              => "Assamese",
  "asteriae"              => "asterias",
  "astrocytomas"          => "astrocytoma",
  "astrocytomata"         => "astrocytoma",
  "asyla"                 => "asylum",
  "asylums"               => "asylum",
  "asyndeta"              => "asyndeton",
  "atamans"               => "ataman",
  "atlantes"              => "atlas",
  "Atlantes"              => "Atlas",
  "atlases"               => "atlas",
  "atmas"                 => "atman",
  "aurei"                 => "aureus",
  "aurorae"               => "aurora",
  "auroras"               => "aurora",
  "auslesen"              => "auslese",
  "Auslesen"              => "Auslese",
  "ausleses"              => "auslese",
  "auspices"              => "auspex",
  "auto de fes"           => "auto de fe",
  "auto-de-fes"           => "auto-de-fe",
  "autobahnen"            => "autobahn",
  "autobahns"             => "autobahn",
  "autochthones"          => "autochthon",
  "autochthons"           => "autochthon",
  "autos"                 => "auto",
  "autos de fes"          => "auto de fe",
  "autos-de-fes"          => "auto-de-fe",
  "autostradas"           => "autostrada",
  "autostrade"            => "autostrada",
  "avicularia"            => "avicularium",
  "Avignonese"            => "Avignonese",
  "avisos"                => "aviso",
  "avocados"              => "avocado",
  "axes"                  => "axe",
  "axillae"               => "axilla",
  "axones"                => "axon",
  "axons"                 => "axon",
  "axopodia"              => "axopodium",
  "Azerbaijanese"         => "Azerbaijanese",
  "baalim"                => "baal",
  "baals"                 => "baal",
  "bacilli"               => "bacillus",
  "bacteria"              => "bacterium",
  "Bahamans"              => "Bahaman",
  "bajocchi"              => "bajocco",
  "Balinese"              => "Balinese",
  "ballabili"             => "ballabile",
  "ballate"               => "ballata",
  "ballerinas"            => "ballerina",
  "ballerine"             => "ballerina",
  "ballistae"             => "ballista",
  "ballistas"             => "ballista",
  "Bamakos"               => "Bamako",
  "bandeaus"              => "bandeau",
  "bandeaux"              => "bandeau",
  "bandits"               => "bandit",
  "banditti"              => "bandit",
  "Barquisimetos"         => "Barquisimeto",
  "barricoes"             => "barrico",
  "bases"                 => "base",
  "basilicae"             => "basilica",
  "basilicas"             => "basilica",
  "bass"                  => "bass",
  "basses"                => "bass",
  "bassi"                 => "basso",
  "bassos"                => "basso",
  "bateaus"               => "bateau",
  "bateaux"               => "bateau",
  "bathoses"              => "bathos",
  "baths"                 => "bath",
  "batzes"                => "batz",
  "beau gestes"           => "beau geste",
  "beaus"                 => "beau",
  "beaux"                 => "beau",
  "beaux esprits"         => "bel-esprit",
  "beaux gestes"          => "beau geste",
  "beaux hommes"          => "bel homme",
  "bechuana"              => "bechuana",
  "bechuanas"             => "bechuana",
  "beefs"                 => "beef",
  "beerenauslesen"        => "beerenauslese",
  "beeves"                => "beef",
  "belle epoques"         => "belle epoque",
  "belles epoques"        => "belle epoque",
  "bemas"                 => "bema",
  "bemata"                => "bema",
  "Bengalese"             => "Bengalese",
  "Bernese"               => "Bernese",
  "bersaglieri"           => "bersagliere",
  "bhikshook"             => "bhikshu",
  "bhikshus"              => "bhikshu",
  "Bhutanese"             => "Bhutanese",
  "biases"                => "bias",
  "bierstuben"            => "bierstube",
  "bierstubes"            => "bierstube",
  "bifolia"               => "bifolium",
  "bijoux"                => "bijou",
  "bilboes"               => "bilbo",
  "bimbos"                => "bimbo",
  "bingos"                => "bingo",
  "Biros"                 => "Biro",
  "biscotti"              => "biscotto",
  "bison"                 => "bison",
  "bisons"                => "bison",
  "blastemata"            => "blastema",
  "blemyae"               => "blemya",
  "blini"                 => "blin",
  "blinis"                => "blin",
  "blitzes"               => "blitz",
  "blouses"               => "blouse",
  "blues"                 => "blue",
  "bodegones"             => "bodegon",
  "boleros"               => "bolero",
  "Bolognese"             => "Bolognese",
  "boluses"               => "bolus",
  "Bolzanos"              => "Bolzano",
  "bon mots"              => "bon mot",
  "bon vivants"           => "bon vivant",
  "bongoes"               => "bongo",
  "bongos"                => "bongo",
  "bonis fidebus"         => "bona fides",
  "bons mots"             => "bon mot",
  "bons vivants"          => "bon vivant",
  "bordereaux"            => "bordereau",
  "Borghese"              => "Borghese",
  "Bostonese"             => "Bostonese",
  "Botos"                 => "Boto",
  "bozzetti"              => "bozzetto",
  "braccia"               => "braccio",
  "brachiopoda"           => "brachiopod",
  "brachiopods"           => "brachiopod",
  "branchiopoda"          => "branchiopod",
  "branchiopods"          => "branchiopod",
  "bratwurste"            => "bratwurst",
  "bratwursts"            => "bratwurst",
  "bravoes"               => "bravo",
  "bravos"                => "bravo",
  "break aways"           => "break away",
  "break-aways"           => "break-away",
  "breakaways"            => "breakaway",
  "breaks away"           => "break away",
  "breaks-away"           => "break-away",
  "breaksaway"            => "breakaway",
  "bream"                 => "bream",
  "breeches"              => "breech",
  "bregmata"              => "bregma",
  "brethren"              => "brother",
  "brethren german"       => "brother german",
  "brethren-german"       => "brother-german",
  "brigadier generals"    => "brigadier general",
  "britches"              => "britches",
  "bronchi"               => "bronchus",
  "bronchitises"          => "bronchitis",
  "brothers"              => "brother",
  "brothers german"       => "brother german",
  "brothers-german"       => "brother-german",
  "bruschette"            => "bruschetta",
  "buboes"                => "bubo",
  "buffalo"               => "buffalo",
  "buffalos"              => "buffalo",
  "Buginese"              => "Buginese",
  "bulimi"                => "bulimus",
  "bullae"                => "bulla",
  "bureaus"               => "bureau",
  "bureaux"               => "bureau",
  "Burmans"               => "Burman",
  "Burmese"               => "Burmese",
  "burros"                => "burro",
  "bursae"                => "bursa",
  "burschen"              => "bursch",
  "bursitises"            => "bursitis",
  "bustoes"               => "busto",
  "bustos"                => "busto",
  "buzzes"                => "buzz",
  "bylinas"               => "bylina",
  "byliny"                => "bylina",
  "cabalettas"            => "cabaletta",
  "cabalette"             => "cabaletta",
  "cacti"                 => "cactus",
  "cactuses"              => "cactus",
  "caddises"              => "caddis",
  "caducei"               => "caduceus",
  "caeca"                 => "caecum",
  "caffe macchiati"       => "caffe macchiato",
  "caffe macchiatos"      => "caffe macchiato",
  "caffe ristretti"       => "caffe ristretto",
  "caffe ristrettos"      => "caffe ristretto",
  "caimans"               => "caiman",
  "Cairos"                => "Cairo",
  "Calabrese"             => "Calabrese",
  "calamistra"            => "calamistrum",
  "calathi"               => "calathus",
  "calices"               => "calix",
  "calluses"              => "callus",
  "calypsos"              => "calypso",
  "calzones"              => "calzone",
  "calzoni"               => "calzone",
  "Camaldolese"           => "Camaldolese",
  "camera obscuras"       => "camera obscura",
  "camerae obscurae"      => "camera obscura",
  "canaliculi"            => "canaliculus",
  "candelabra"            => "candelabrum",
  "cannabises"            => "cannabis",
  "canthari"              => "cantharus",
  "Cantonese"             => "Cantonese",
  "cantos"                => "canto",
  "cantus"                => "cantus",
  "cantuses"              => "cantus",
  "canvases"              => "canvas",
  "canzonettas"           => "canzonetta",
  "canzonette"            => "canzonetta",
  "capataces"             => "capataz",
  "capi"                  => "capo",
  "capos"                 => "capo",
  "cappuccinos"           => "cappuccino",
  "captain generals"      => "captain general",
  "carabinieri"           => "carabiniere",
  "carcinomas"            => "carcinoma",
  "carcinomata"           => "carcinoma",
  "cardines"              => "cardo",
  "cardophagi"            => "cardophagus",
  "cargadores"            => "cargador",
  "caribou"               => "caribou",
  "caribous"              => "caribou",
  "carices"               => "carex",
  "Carlylese"             => "Carlylese",
  "carmens"               => "carmen",
  "carmina"               => "carmen",
  "carp"                  => "carp",
  "cartes de visite"      => "carte de visite",
  "cartes-de-visite"      => "carte-de-visite",
  "caryatides"            => "caryatid",
  "caryatids"             => "caryatid",
  "caryopsides"           => "caryopsis",
  "casinos"               => "casino",
  "Cassinese"             => "Cassinese",
  "cassones"              => "cassone",
  "cassoni"               => "cassone",
  "castra"                => "castrum",
  "castrati"              => "castrato",
  "casus belli"           => "casus belli",
  "cathismata"            => "cathisma",
  "caudices"              => "caudex",
  "caules"                => "caulis",
  "caveae"                => "cavea",
  "caymans"               => "cayman",
  "cecidia"               => "cecidium",
  "Celanese"              => "Celanese",
  "celiae"                => "celia",
  "cellos"                => "cello",
  "cementomata"           => "cementoma",
  "centesimi"             => "centesimo",
  "centumviri"            => "centumvir",
  "cerci"                 => "cercus",
  "cerimans"              => "ceriman",
  "Ceylonese"             => "Ceylonese",
  "chaetae"               => "chaeta",
  "chaoses"               => "chaos",
  "chapeaus"              => "chapeau",
  "chapeaux"              => "chapeau",
  "chapplies"             => "chapplis",
  "charismas"             => "charisma",
  "charismata"            => "charisma",
  "chassis"               => "chassis",
  "chateaus"              => "chateau",
  "chateaux"              => "chateau",
  "cherubim"              => "cherub",
  "cherubs"               => "cherub",
  "chervontzi"            => "chervonetz",
  "chevaux"               => "cheval",
  "chevaux de bataille"   => "cheval de bataille",
  "chevaux-de-bataille"   => "cheval-de-bataille",
  "Chicagos"              => "Chicago",
  "children"              => "child",
  "Chimangos"             => "Chimango",
  "Chinese"               => "Chinese",
  "chintzes"              => "chintz",
  "chitarroni"            => "chitarrone",
  "chlamydiae"            => "chlamydia",
  "chlamydias"            => "chlamydia",
  "choanae"               => "choana",
  "chordae"               => "chorda",
  "choruses"              => "chorus",
  "choux"                 => "chou",
  "chromidia"             => "chromidium",
  "chromonemata"          => "chromonema",
  "chrysalides"           => "chrysalis",
  "chrysalises"           => "chrysalis",
  "cicatrices"            => "cicatrix",
  "cilantros"             => "cilantro",
  "cimices"               => "cimex",
  "cinclides"             => "cinclis",
  "cistophorori"          => "cistophorus",
  "cladi"                 => "cladus",
  "claustra"              => "claustrum",
  "clausulae"             => "clausula",
  "clavulae"              => "clavula",
  "cleithra"              => "cleithrum",
  "clepsydrae"            => "clepsydra",
  "clepsydras"            => "clepsydra",
  "clippers"              => "clippers",
  "clitorides"            => "clitoris",
  "clitorises"            => "clitoris",
  "clostridia"            => "clostridium",
  "coagula"               => "coagulum",
  "coccidia"              => "coccidium",
  "cochitos"              => "cochito",
  "cocos"                 => "coco",
  "cod"                   => "cod",
  "codices"               => "codex",
  "coeliae"               => "coelia",
  "coes"                  => "co",
  "cognoscenti"           => "cognoscente",
  "coitus"                => "coitus",
  "coituses"              => "coitus",
  "collegia"              => "collegium",
  "collegia musica"       => "collegium musicum",
  "Colombos"              => "Colombo",
  "colonel generals"      => "colonel general",
  "Colorados"             => "Colorado",
  "columbaria"            => "columbarium",
  "columnae"              => "columna",
  "comae"                 => "coma",
  "comatulae"             => "comatula",
  "commanding generals"   => "commanding general",
  "commandos"             => "commando",
  "compendia"             => "compendium",
  "compendiums"           => "compendium",
  "competentes"           => "competent",
  "concerti grossi"       => "concerto grosso",
  "concertinos"           => "concertino",
  "concetti"              => "concetto",
  "condos"                => "condo",
  "condottieri"           => "condottiere",
  "conducti"              => "conductus",
  "coneys"                => "coney",
  "confervae"             => "conferva",
  "confluvia"             => "confluvium",
  "congii"                => "congius",
  "Congoese"              => "Congoese",
  "Congolese"             => "Congolese",
  "conidia"               => "conidium",
  "conies"                => "coney",
  "conoscenti"            => "conoscente",
  "consortia"             => "consortium",
  "consortiums"           => "consortium",
  "contadine"             => "contadina",
  "contadini"             => "contadino",
  "contagia"              => "contagium",
  "contangos"             => "contango",
  "contrafacta"           => "contrafactum",
  "contralti"             => "contralto",
  "contraltos"            => "contralto",
  "contretemps"           => "contretemps",
  "conversaziones"        => "conversazione",
  "conversazioni"         => "conversazione",
  "convolvuli"            => "convolvulus",
  "convolvuluses"         => "convolvulus",
  "conys"                 => "cony",
  "corgis"                => "corgi",
  "corgwn"                => "corgi",
  "corgys"                => "corgy",
  "cornetti"              => "cornetto",
  "corni"                 => "corno",
  "cornua"                => "cornu",
  "coronae"               => "corona",
  "coronas"               => "corona",
  "corpora"               => "corpus",
  "corpora vilia"         => "corpus vile",
  "corps"                 => "corps",
  "corps generals"        => "corps general",
  "corpuscula"            => "corpusculum",
  "corpuses"              => "corpus",
  "corrigenda"            => "corrigendum",
  "cortexes"              => "cortex",
  "cortices"              => "cortex",
  "cosmoses"              => "cosmos",
  "costae"                => "costa",
  "coups d'etat"          => "coup d'etat",
  "court martials"        => "court martial",
  "court-martials"        => "court martial",
  "courts martial"        => "court martial",
  "courts-martial"        => "court-martial",
  "cows"                  => "cow",
  "coxendices"            => "coxendix",
  "cozes"                 => "coz",
  "craft"                 => "craft",
  "crafts childer"        => "crafts child",
  "crafts-childer"        => "crafts-child",
  "crania"                => "cranium",
  "craniums"              => "cranium",
  "craspeda"              => "craspedum",
  "crazie"                => "crazia",
  "credos"                => "credo",
  "cremasteres"           => "cremaster",
  "cremasters"            => "cremaster",
  "crescendos"            => "crescendo",
  "cris de coeur"         => "cri de coeur",
  "cristae"               => "crista",
  "criteria"              => "criterion",
  "crowfoots"             => "crowfoot",
  "crura"                 => "crus",
  "crustae"               => "crusta",
  "cubicula"              => "cubiculum",
  "culs de four"          => "cul de four",
  "culs de lampe"         => "cul de lampe",
  "culs de sac"           => "cul de sac",
  "culs-de-four"          => "cul-de-four",
  "culs-de-lampe"         => "cul-de-lampe",
  "culs-de-sac"           => "cul-de-sac",
  "cultelli"              => "cultellus",
  "cumuli"                => "cumulus",
  "cuniculi"              => "cuniculus",
  "curiosi"               => "curioso",
  "curiosos"              => "curioso",
  "curricula"             => "curriculum",
  "curriculums"           => "curriculum",
  "cuspides"              => "cuspis",
  "cyanos"                => "cyano",
  "cyathi"                => "cyathus",
  "cyclopes"              => "cyclops",
  "cyclopses"             => "cyclops",
  "cynocephali"           => "cynocephalus",
  "cyphellae"             => "cyphella",
  "cysticerci"            => "cysticercus",
  "cystidia"              => "cystidium",
  "cystomata"             => "cystoma",
  "Czechs"                => "Czech",
  "dace"                  => "dace",
  "daces"                 => "dace",
  "daises"                => "dais",
  "data"                  => "datum",
  "debris"                => "debris",
  "decennia"              => "decennium",
  "deer"                  => "deer",
  "deliria"               => "delirium",
  "deliriums"             => "delirium",
  "demos"                 => "demo",
  "denarii"               => "denarius",
  "denkmaler"             => "denkmal",
  "denotata"              => "denotatum",
  "dentalia"              => "dentalium",
  "deposita"              => "depositum",
  "depositums"            => "depositum",
  "descripta"             => "descriptum",
  "desiderata"            => "desideratum",
  "designata"             => "designatum",
  "desmans"               => "desman",
  "desmas"                => "desma",
  "desmata"               => "desma",
  "devoti"                => "devoto",
  "devotos"               => "devoto",
  "diabetes"              => "diabetes",
  "diastemata"            => "diastema",
  "dice"                  => "die",
  "dichasia"              => "dichasium",
  "dicta"                 => "dictum",
  "dictums"               => "dictum",
  "didymes"               => "didymis",
  "dies"                  => "die",
  "differentiae"          => "differentia",
  "digitalises"           => "digitalis",
  "dilettantes"           => "dilettante",
  "dilettanti"            => "dilettante",
  "diplococci"            => "diplococcus",
  "diplomas"              => "diploma",
  "diplomata"             => "diploma",
  "diporpae"              => "diporpa",
  "dipsades"              => "dipsas",
  "directrices"           => "directrix",
  "dittos"                => "ditto",
  "diverticula"           => "diverticulum",
  "divertimenti"          => "divertimento",
  "divertimentos"         => "divertimento",
  "divisional generals"   => "divisional general",
  "djinn"                 => "djinn",
  "djinns"                => "djinn",
  "does"                  => "doe",
  "dogmas"                => "dogma",
  "dogmata"               => "dogma",
  "dolmans"               => "dolman",
  "dolphinaria"           => "dolphinarium",
  "dolphinariums"         => "dolphinarium",
  "Dongolese"             => "Dongolese",
  "Dracos"                => "Draco",
  "dragomans"             => "dragoman",
  "dragomen"              => "dragoman",
  "dramas"                => "drama",
  "dreikanter"            => "dreikanter",
  "dreikanters"           => "dreikanter",
  "dumkas"                => "dumka",
  "dumky"                 => "dumka",
  "duumviri"              => "duumvir",
  "duumvirs"              => "duumvir",
  "dynamos"               => "dynamo",
  "edemas"                => "edema",
  "edemata"               => "edema",
  "editiones principes"   => "editio princeps",
  "efreeti"               => "efreet",
  "efreets"               => "efreet",
  "eland"                 => "eland",
  "elands"                => "eland",
  "elk"                   => "elk",
  "elks"                  => "elk",
  "ellipses"              => "ellipse",
  "elves"                 => "elf",
  "emblememata"           => "emblema",
  "embryomata"            => "embryoma",
  "embryos"               => "embryo",
  "emporia"               => "emporium",
  "emporiums"             => "emporium",
  "enconia"               => "enconium",
  "enconiums"             => "enconium",
  "endotheliomata"        => "endothelioma",
  "enemas"                => "enema",
  "enemata"               => "enema",
  "enigmas"               => "enigma",
  "enigmata"              => "enigma",
  "ententes cordiales"    => "entente cordiale",
  "entera"                => "enteron",
  "entia rationis"        => "ens rationis",
  "entia realia"          => "ens reale",
  "entrochi"              => "entrochus",
  "ephelides"             => "ephelis",
  "ephemerae"             => "ephemera",
  "ephemeras"             => "ephemera",
  "ephemerides"           => "ephemeris",
  "ephemerises"           => "ephemeris",
  "epicardia"             => "epicardium",
  "epidermises"           => "epidermis",
  "epididymides"          => "epididymis",
  "epididymises"          => "epididymis",
  "epilimnia"             => "epilimnion",
  "epimera"               => "epimeron",
  "epiphenomena"          => "epiphenomenon",
  "epitheliomata"         => "epithelioma",
  "epyllia"               => "epyllion",
  "equinoctia"            => "equinoctium",
  "equinoctiums"          => "equinoctium",
  "equiseta"              => "equisetum",
  "equisetums"            => "equisetum",
  "erfs"                  => "erf",
  "ergastula"             => "ergastulum",
  "eroses"                => "eros",
  "erotes"                => "eros",
  "errata"                => "erratum",
  "erven"                 => "erf",
  "espanoles"             => "espanol",
  "Esperantos"            => "Esperanto",
  "espressos"             => "espresso",
  "ethoses"               => "ethos",
  "eucalypti"             => "eucalyptus",
  "eucalyptuses"          => "eucalyptus",
  "eunuchs"               => "eunuch",
  "euporista"             => "euporiston",
  "euros"                 => "euro",
  "evirati"               => "evirato",
  "exanthemata"           => "exanthema",
  "exempla"               => "exemplum",
  "exencephali"           => "exencephalus",
  "exes"                  => "ex",
  "explananda"            => "explanandum",
  "explicanda"            => "explicandum",
  "extispices"            => "extispex",
  "extrema"               => "extremum",
  "extremums"             => "extremum",
  "eyases"                => "eyas",
  "fabellae"              => "fabella",
  "fabliaux"              => "fabliau",
  "facienda"              => "faciendum",
  "faeculae"              => "faecula",
  "faits accomplis"       => "fait accompli",
  "falces"                => "falx",
  "falsettos"             => "falsetto",
  "familiae"              => "familia",
  "famuli"                => "famulus",
  "fanfoots"              => "fanfoot",
  "farmans"               => "farman",
  "Faroese"               => "Faroese",
  "Faros"                 => "Faro",
  "fasciae"               => "fascia",
  "fascias"               => "fascia",
  "fasciculi"             => "fasciculus",
  "faunae"                => "fauna",
  "faunas"                => "fauna",
  "favellae"              => "favella",
  "faveoli"               => "faveolus",
  "favissae"              => "favissa",
  "feculae"               => "fecula",
  "fedai"                 => "fedai",
  "fedais"                => "fedai",
  "feet"                  => "foot",
  "feiseanna"             => "feis",
  "felones"               => "felo",
  "felones de se"         => "felo de se",
  "felones-de-se"         => "felo-de-se",
  "felos de se"           => "felo de se",
  "felos-de-se"           => "felo-de-se",
  "felsenmeere"           => "felsenmeer",
  "femora"                => "femur",
  "femurs"                => "femur",
  "fenestrae"             => "fenestra",
  "fermatas"              => "fermata",
  "fermate"               => "fermata",
  "Ferrarese"             => "Ferrarese",
  "fess"                  => "feis",
  "fiascos"               => "fiasco",
  "fibrae"                => "fibra",
  "fibrillae"             => "fibrilla",
  "fibromata"             => "fibroma",
  "fibulae"               => "fibula",
  "fibulas"               => "fibula",
  "fidei defensores"      => "fidei defensor",
  "figurantes"            => "figurante",
  "figuranti"             => "figurante",
  "filariae"              => "filaria",
  "filarias"              => "filaria",
  "Filipinos"             => "Filipino",
  "finger ends"           => "finger end",
  "finger-ends"           => "finger-end",
  "fingers ends"          => "finger end",
  "fingers-ends"          => "finger-end",
  "fioriture"             => "fioritura",
  "fish"                  => "fish",
  "five star generals"    => "five star general",
  "five-star generals"    => "five-star general",
  "fizzes"                => "fizz",
  "flabella"              => "flabellum",
  "flag staffs"           => "flag staff",
  "flag staves"           => "flag staff",
  "flag-staffs"           => "flag-staff",
  "flag-staves"           => "flag-staff",
  "flagella"              => "flagellum",
  "flamencos"             => "flamenco",
  "flatfoots"             => "flatfoot",
  "flatuses"              => "flatus",
  "flies"                 => "fly",
  "flocci"                => "floccus",
  "flocculi"              => "flocculus",
  "florae"                => "flora",
  "floras"                => "flora",
  "flounder"              => "flounder",
  "flys"                  => "fly",
  "foci"                  => "focus",
  "focuses"               => "focus",
  "folles"                => "follis",
  "fomites"               => "fomes",
  "Foochowese"            => "Foochowese",
  "fora"                  => "forum",
  "foramens"              => "foramen",
  "foramina"              => "foramen",
  "formulae"              => "formula",
  "formulas"              => "formula",
  "forums"                => "forum",
  "fossae"                => "fossa",
  "four star generals"    => "four star general",
  "four-star generals"    => "four-star general",
  "fowl"                  => "fowl",
  "fowls"                 => "fowl",
  "fraena"                => "fraenum",
  "franc archers"         => "franc archer",
  "franc-archers"         => "franc-archer",
  "francs archers"        => "franc archer",
  "francs-archers"        => "franc-archer",
  "frati"                 => "frate",
  "frena"                 => "frenum",
  "fricandeaux"           => "fricandeau",
  "frizzes"               => "frizz",
  "froes"                 => "fro",
  "frottole"              => "frottola",
  "frusta"                => "frustum",
  "frustula"              => "frustulum",
  "frustums"              => "frustum",
  "fuci"                  => "fucus",
  "fulcra"                => "fulcrum",
  "funambuli"             => "funambulus",
  "fundamenta divisionis" => "fundamentum divisionis",
  "funghi porchini"       => "fungo porcino",
  "fungi"                 => "fungus",
  "funguses"              => "fungus",
  "furfures"              => "furfur",
  "furiosos"              => "furioso",
  "fuzzes"                => "fuzz",
  "Gabunese"              => "Gabunese",
  "galla"                 => "galla",
  "Galla"                 => "Galla",
  "gallas"                => "galla",
  "Gallas"                => "Galla",
  "gallows"               => "gallows",
  "gametangia"            => "gametangium",
  "ganglia"               => "ganglion",
  "ganglions"             => "ganglion",
  "gaonim"                => "gaon",
  "gaons"                 => "gaon",
  "gastrocnemii"          => "gastrocnemius",
  "geese"                 => "goose",
  "geisha"                => "geisha",
  "geishas"               => "geisha",
  "geisteswissenschaften" => "geisteswissenschaft",
  "gemmae"                => "gemma",
  "genae"                 => "gena",
  "genera"                => "genus",
  "generalissimos"        => "generalissimo",
  "Genevese"              => "Genevese",
  "genies"                => "genie",
  "genii"                 => "genie",
  "geniuses"              => "genius",
  "Genoese"               => "Genoese",
  "gentes"                => "gens",
  "Germans"               => "German",
  "germaria"              => "germarium",
  "Gestapos"              => "Gestapo",
  "ghettos"               => "ghetto",
  "gigolos"               => "gigolo",
  "Gilbertese"            => "Gilbertese",
  "giunchi"               => "giuncus",
  "gizmos"                => "gizmo",
  "glacis"                => "glacis",
  "glacises"              => "glacis",
  "gladioli"              => "gladiolus",
  "gladioluses"           => "gladiolus",
  "glasses"               => "glass",
  "gliomata"              => "glioma",
  "gliosarcomata"         => "gliosarcoma",
  "glissandi"             => "glissando",
  "glissandos"            => "glissando",
  "globigerinae"          => "globigerina",
  "glochidia"             => "glochidium",
  "glomera"               => "glomus",
  "glutaei"               => "glutaeus",
  "glutei"                => "glutaeus",
  "gminy"                 => "gmina",
  "Goanese"               => "Goanese",
  "goes"                  => "go",
  "gonangia"              => "gonangium",
  "gonidia"               => "gonidium",
  "gonimia"               => "gonimium",
  "gorgoniae"             => "gorgonia",
  "gorgonias"             => "gorgonia",
  "gousblomme"            => "gousblom",
  "goyim"                 => "goy",
  "goys"                  => "goy",
  "graben"                => "graben",
  "grabens"               => "graben",
  "graffiti"              => "graffiti",
  "grani"                 => "grano",
  "granite"               => "granita",
  "granulae"              => "granula",
  "gravamina"             => "gravamen",
  "Greensboros"           => "Greensboro",
  "gringos"               => "gringo",
  "grissini"              => "grissino",
  "grottoes"              => "grotto",
  "grottos"               => "grotto",
  "grouse"                => "grouse",
  "grouses"               => "grouse",
  "Guaiaberos"            => "Guaiabero",
  "guanos"                => "guano",
  "guardias civiles"      => "guardia civil",
  "gubernacula"           => "gubernaculum",
  "guglioes"              => "guglio",
  "guglios"               => "guglio",
  "Guianese"              => "Guianese",
  "gumbos"                => "gumbo",
  "gummas"                => "gumma",
  "gummata"               => "gumma",
  "gutti"                 => "guttus",
  "guys"                  => "guy",
  "gymnasia"              => "gymnasium",
  "gymnasiums"            => "gymnasium",
  "gymnoti"               => "gymnotus",
  "gyri"                  => "gyrus",
  "gyros"                 => "gyro",
  "haddock"               => "haddock",
  "haddocks"              => "haddock",
  "haemangiomas"          => "haemangioma",
  "haemangiomata"         => "haemangioma",
  "haggis"                => "haggis",
  "Hainanese"             => "Hainanese",
  "hairdos"               => "hairdo",
  "hake"                  => "hake",
  "hakes"                 => "hake",
  "halibut"               => "halibut",
  "halibuts"              => "halibut",
  "halluces"              => "hallux",
  "halteridia"            => "halteridium",
  "hamadrayads"           => "hamadryad",
  "hamadryades"           => "hamadryad",
  "hamuli"                => "hamulus",
  "hapax legomena"        => "hapax legomenon",
  "hapax legomenons"      => "hapax legomenon",
  "haptera"               => "hapteron",
  "Hararese"              => "Hararese",
  "Harlemese"             => "Harlemese",
  "harmans"               => "harman",
  "haruspices"            => "haruspex",
  "haustella"             => "haustellum",
  "haustoria"             => "haustorium",
  "haustra"               => "haustrum",
  "Havanese"              => "Havanese",
  "headquarters"          => "headquarters",
  "Heavenese"             => "Heavenese",
  "hedra"                 => "hedron",
  "hedrons"               => "hedron",
  "heen"                  => "hsien",
  "hefte"                 => "heft",
  "helia"                 => "helion",
  "helices"               => "helix",
  "helions"               => "helion",
  "hemangeiomas"          => "hemangeioma",
  "hemangeiomata"         => "hemangeioma",
  "hemangiomas"           => "hemangioma",
  "hemangiomata"          => "hemangioma",
  "hemelytra"             => "hemelytrum",
  "hemerae"               => "hemera",
  "hemi elytra"           => "hemi elytrum",
  "hemi-elytra"           => "hemi-elytrum",
  "herniae"               => "hernia",
  "hernias"               => "hernia",
  "heroa"                 => "heroon",
  "heroes"                => "hero",
  "herpes"                => "herpes",
  "herren"                => "herr",
  "herring"               => "herring",
  "herrings"              => "herring",
  "hertz"                 => "hertz",
  "hetaerae"              => "hetaera",
  "hetairai"              => "hetaera",
  "hetmans"               => "hetman",
  "hiatus"                => "hiatus",
  "hiatuses"              => "hiatus",
  "hijinks"               => "hijinks",
  "hinaki"                => "hinaki",
  "hippocampi"            => "hippocampus",
  "hippopotami"           => "hippopotamus",
  "hippopotamuses"        => "hippopotamus",
  "hippos"                => "hippo",
  "Hiroshimans"           => "Hiroshiman",
  "hoes"                  => "hoe",
  "holothuriae"           => "holothuria",
  "holothurias"           => "holothuria",
  "honoraria"             => "honorarium",
  "honorariums"           => "honorarium",
  "hoofs"                 => "hoof",
  "Hoosierese"            => "Hoosierese",
  "hooves"                => "hoof",
  "hordeola"              => "hordeolum",
  "hormogonia"            => "hormogonium",
  "hoties"                => "hoti",
  "Hottentotese"          => "Hottentotese",
  "hubrises"              => "hubris",
  "humans"                => "human",
  "humeri"                => "humerus",
  "Hunanese"              => "Hunanese",
  "hydrae"                => "hydra",
  "hydras"                => "hydra",
  "hydraulica"            => "hydraulicon",
  "hydriae"               => "hydria",
  "hymenia"               => "hymenium",
  "hymnaria"              => "hymnarium",
  "hyperbata"             => "hyperbaton",
  "hyperbolae"            => "hyperbola",
  "hyperbolas"            => "hyperbola",
  "hyphae"                => "hypha",
  "hypna"                 => "hypnum",
  "hypnums"               => "hypnum",
  "hypodermata"           => "hypoderma",
  "hypolimnia"            => "hypolimnion",
  "ibises"                => "ibis",
  "ichthyosauri"          => "ichthyosaurus",
  "Idahos"                => "Idaho",
  "idees fixes"           => "idee fixe",
  "idola"                 => "idolum",
  "ignoramus"             => "ignoramus",
  "ignoramuses"           => "ignoramus",
  "ilia"                  => "ilium",
  "imagines"              => "imago",
  "imagos"                => "imago",
  "imbrices"              => "imbrex",
  "impetigos"             => "impetigo",
  "impetus"               => "impetus",
  "impetuses"             => "impetus",
  "improperia"            => "improperium",
  "improvisatrici"        => "improvisatrice",
  "incubi"                => "incubus",
  "incubuses"             => "incubus",
  "indexes"               => "index",
  "indices"               => "index",
  "indicia"               => "indicium",
  "indigenae"             => "indigena",
  "individua"             => "individuum",
  "individuums"           => "individuum",
  "Indochinese"           => "Indochinese",
  "indumenta"             => "indumentum",
  "indusia"               => "indusium",
  "infernos"              => "inferno",
  "infimae species"       => "infima species",
  "infos"                 => "info",
  "inhalatoria"           => "inhalatorium",
  "innings"               => "innings",
  "inocula"               => "inoculum",
  "insulae"               => "insula",
  "intaglios"             => "intaglio",
  "interambulacra"        => "interambulacrum",
  "interaxes"             => "interaxis",
  "intercalare"           => "intercalarium",
  "intercalaria"          => "intercalarium",
  "intermaxillae"         => "intermaxilla",
  "intermedia"            => "intermedium",
  "intermezzos"           => "intermezzo",
  "internodia"            => "internodium",
  "interphenomena"        => "interphenomenon",
  "interradii"            => "interradius",
  "interreges"            => "interrex",
  "interregna"            => "interregnum",
  "interregnums"          => "interregnum",
  "interstitia"           => "interstitium",
  "interstitiums"         => "interstitium",
  "intertrigos"           => "intertrigo",
  "intervalla"            => "intervallum",
  "intervallums"          => "intervallum",
  "intichiuma"            => "intichiuma",
  "inuit"                 => "inuk",
  "inukshuit"             => "inukshuk",
  "involucra"             => "involucrum",
  "ipse dixits"           => "ipse dixit",
  "Iquicos"               => "Iquico",
  "irides"                => "iris",
  "irises"                => "iris",
  "ischia"                => "ischium",
  "isidia"                => "isidium",
  "ispravniki"            => "ispravnik",
  "ispravniks"            => "ispravnik",
  "isthmi"                => "isthmus",
  "isthmuses"             => "isthmus",
  "iters"                 => "iter",
  "itinera"               => "iter",
  "iueles"                => "juelet",
  "ixodides"              => "ixodid",
  "jackanapes"            => "jackanapes",
  "jacobus"               => "jacobus",
  "jacobuses"             => "jacobus",
  "jalapenos"             => "jalapeno",
  "jambeaus"              => "jambeau",
  "jambeaux"              => "jambeau",
  "Japanese"              => "Japanese",
  "Javanese"              => "Javanese",
  "jazzes"                => "jazz",
  "jerries"               => "jerry",
  "Jerrys"                => "Jerry",
  "jeux"                  => "jeu",
  "joes"                  => "joe",
  "Johnsonese"            => "Johnsonese",
  "judases"               => "judas",
  "judicata"              => "judicatum",
  "juga"                  => "jugum",
  "jumbos"                => "jumbo",
  "juntos"                => "junto",
  "Kakapos"               => "Kakapo",
  "Kanarese"              => "Kanarese",
  "kantharoi"             => "kantharos",
  "karakia"               => "karakia",
  "karakias"              => "karakia",
  "kare"                  => "kar",
  "karrenfelder"          => "karrenfeld",
  "karrenfelds"           => "karrenfeld",
  "kars"                  => "kar",
  "kernoi"                => "kernos",
  "kibbutzes"             => "kibbutz",
  "kibbutzim"             => "kibbutz",
  "kilos"                 => "kilo",
  "kimonos"               => "kimono",
  "kine"                  => "cow",
  "Kinkimavos"            => "Kinkimavo",
  "kioko"                 => "kioko",
  "kiokos"                => "kioko",
  "Kiplingese"            => "Kiplingese",
  "kletterschuhe"         => "kletterschuh",
  "knives"                => "knife",
  "knoppern"              => "knopper",
  "knoppers"              => "knopper",
  "kobo"                  => "kobo",
  "Kokakos"               => "Kokako",
  "konditorei"            => "konditorei",
  "konditoreien"          => "konditorei",
  "Kongoese"              => "Kongoese",
  "Kongolese"             => "Kongolese",
  "Kosovos"               => "Kosovo",
  "kouroi"                => "kouros",
  "kovshi"                => "kovsh",
  "kuvaszok"              => "kuvasz",
  "kylikes"               => "kylix",
  "kylixes"               => "kylix",
  "labra"                 => "labrum",
  "laciniae"              => "lacinia",
  "lactobacilli"          => "lactobacillus",
  "lacunae"               => "lacuna",
  "lacunaria"             => "lacunar",
  "lacunars"              => "lacunar",
  "lacunas"               => "lacuna",
  "laiki"                 => "laika",
  "lamellae"              => "lamella",
  "laminae"               => "lamina",
  "lapithae"              => "lapith",
  "Lapithae"              => "Lapith",
  "lapiths"               => "lapith",
  "Lapiths"               => "Lapith",
  "Lapponese"             => "Lapponese",
  "lares"                 => "lar",
  "larnakes"              => "larnax",
  "lars"                  => "lar",
  "larynges"              => "larynx",
  "latexes"               => "latex",
  "latices"               => "latex",
  "leaves"                => "leaf",
  "Lebanese"              => "Lebanese",
  "lebensformen"          => "lebensform",
  "leges humanae"         => "lex humana",
  "legionellae"           => "legionella",
  "legomena"              => "legomenon",
  "legumens"              => "legumen",
  "legumina"              => "legumen",
  "lei"                   => "leu",
  "leishmaniae"           => "leishmania",
  "leishmanias"           => "leishmania",
  "lemans"                => "leman",
  "lemmas"                => "lemma",
  "lemmata"               => "lemma",
  "lemnisci"              => "lemniscus",
  "lemures"               => "lemur",
  "lemurs"                => "lemur",
  "lenses"                => "lens",
  "lentigines"            => "lentigo",
  "lentisci"              => "lentiscus",
  "Leonese"               => "Leonese",
  "lepromas"              => "leproma",
  "lepromata"             => "leproma",
  "leprosaria"            => "leprosarium",
  "lepta"                 => "lepton",
  "leptomonas"            => "leptomonas",
  "leptospirae"           => "leptospira",
  "Lesothos"              => "Lesotho",
  "liberos"               => "libero",
  "libidos"               => "libido",
  "libretti"              => "libretto",
  "librettos"             => "libretto",
  "lice"                  => "louse",
  "lidos"                 => "lido",
  "lieder"                => "lied",
  "lieus"                 => "lieu",
  "lieutenant generals"   => "lieutenant general",
  "lieux"                 => "lieu",
  "ligamenta"             => "ligamentum",
  "Lilos"                 => "Lilo",
  "limaces"               => "limax",
  "Limans"                => "Liman",
  "limbos"                => "limbo",
  "limites"               => "limes",
  "limos"                 => "limo",
  "limuli"                => "limulus",
  "linctuses"             => "linctus",
  "line outs"             => "line out",
  "line-outs"             => "line-out",
  "lineae"                => "linea",
  "linenos"               => "lineno",
  "lines out"             => "line out",
  "lines-out"             => "line-out",
  "lingos"                => "lingo",
  "lingulae"              => "lingula",
  "linos"                 => "lino",
  "lipomata"              => "lipoma",
  "lis"                   => "lis",
  "lisses"                => "lis",
  "listerellae"           => "listerella",
  "listerellas"           => "listerella",
  "listeria"              => "listeria",
  "listerias"             => "listeria",
  "lithodomi"             => "lithodomus",
  "lithophyta"            => "lithophyton",
  "livedos"               => "livedo",
  "lives"                 => "life",
  "lixivia"               => "lixivium",
  "loa"                   => "loa",
  "loas"                  => "loa",
  "loaves"                => "loaf",
  "lobuli"                => "lobulus",
  "lochi"                 => "lochus",
  "loci"                  => "locus",
  "locos"                 => "loco",
  "loculi"                => "loculus",
  "loggias"               => "loggia",
  "loggie"                => "loggia",
  "logia"                 => "logion",
  "logodaedale"           => "logodaedalus",
  "logodaedali"           => "logodaedalus",
  "logos"                 => "logo",
  "lomata"                => "loma",
  "lomenta"               => "lomentum",
  "Londonese"             => "Londonese",
  "lora"                  => "lorum",
  "lord lieutenants"      => "lord lieutenant",
  "lord-lieutenants"      => "lord-lieutenant",
  "lords lieutenant"      => "lord lieutenant",
  "lords-lieutenant"      => "lord-lieutenant",
  "Lorrainese"            => "Lorrainese",
  "louis"                 => "louis",
  "lowlifes"              => "lowlife",
  "lox"                   => "lox",
  "loxes"                 => "lox",
  "Lucchese"              => "Lucchese",
  "lumbagos"              => "lumbago",
  "lumbrici"              => "lumbricus",
  "lumens"                => "lumen",
  "lumina"                => "lumen",
  "lustra"                => "lustrum",
  "lustrums"              => "lustrum",
  "lux"                   => "lux",
  "lves"                  => "lf",
  "lymphangiomata"        => "lymphangioma",
  "lymphomas"             => "lymphoma",
  "lymphomata"            => "lymphoma",
  "Lyonese"               => "Lyonese",
  "lyssae"                => "lyssa",
  "maare"                 => "maar",
  "maars"                 => "maar",
  "macaci"                => "macacus",
  "Macanese"              => "Macanese",
  "macaronies"            => "macaroni",
  "Macassarese"           => "Macassarese",
  "machos"                => "macho",
  "mackerel"              => "mackerel",
  "mackerels"             => "mackerel",
  "macros"                => "macro",
  "maculae"               => "macula",
  "maculas"               => "macula",
  "Madurese"              => "Madurese",
  "maecenases"            => "maecenas",
  "maecenates"            => "maecenas",
  "maestri"               => "maestro",
  "maestros"              => "maestro",
  "mafiose"               => "mafiosa",
  "mafiosi"               => "mafioso",
  "mafiosos"              => "mafioso",
  "magi"                  => "magus",
  "magili"                => "magilus",
  "magmas"                => "magma",
  "magmata"               => "magma",
  "magna opera"           => "magnum opus",
  "magnetos"              => "magneto",
  "magnificos"            => "magnifico",
  "magnum opuses"         => "magnum opus",
  "major generals"        => "major general",
  "Majuros"               => "Majuro",
  "makuta"                => "likuta",
  "mala in se"            => "malum in se",
  "Malabarese"            => "Malabarese",
  "Malabos"               => "Malabo",
  "malagmata"             => "malagma",
  "mallei"                => "malleus",
  "malleoli"              => "malleolus",
  "Maltese"               => "Maltese",
  "man milliners"         => "man milliner",
  "man-milliners"         => "man-milliner",
  "mangoes"               => "mango",
  "mangos"                => "mango",
  "manifestos"            => "manifesto",
  "manteaus"              => "manteau",
  "manteaux"              => "manteau",
  "mantellette"           => "mantelletta",
  "mantises"              => "mantis",
  "manubria"              => "manubrium",
  "manubriums"            => "manubrium",
  "Maputos"               => "Maputo",
  "maquereaux"            => "maquereau",
  "Maracaibos"            => "Maracaibo",
  "maremme"               => "maremma",
  "mares"                 => "mare",
  "maria"                 => "mare",
  "maries"                => "mary",
  "marquises"             => "marquis",
  "Marys"                 => "Mary",
  "maths"                 => "math",
  "matinees musicales"    => "matinee musicale",
  "matins"                => "matin",
  "matres lectionis"      => "mater lectionis",
  "matzahs"               => "matzah",
  "matzot"                => "matzah",
  "mausolea"              => "mausoleum",
  "mausoleums"            => "mausoleum",
  "maxillae"              => "maxilla",
  "maxima"                => "maximum",
  "maximums"              => "maximum",
  "measles"               => "measles",
  "meatus"                => "meatus",
  "meatuses"              => "meatus",
  "media"                 => "medium",
  "mediastina"            => "mediastinum",
  "mediatrices"           => "mediatrix",
  "medicoes"              => "medico",
  "medicos"               => "medico",
  "mediums"               => "medium",
  "medulloblastomas"      => "medulloblastoma",
  "medulloblastomata"     => "medulloblastoma",
  "medusae"               => "medusa",
  "medusas"               => "medusa",
  "megalosauri"           => "megalosaurus",
  "megatheria"            => "megatherium",
  "melanomas"             => "melanoma",
  "melanomata"            => "melanoma",
  "melastomae"            => "melastoma",
  "melastomas"            => "melastoma",
  "melicerides"           => "meliceris",
  "melismas"              => "melisma",
  "melismata"             => "melisma",
  "mementoes"             => "memento",
  "mementos"              => "memento",
  "memoranda"             => "memorandum",
  "memorandums"           => "memorandum",
  "memos"                 => "memo",
  "men"                   => "man",
  "men children"          => "man child",
  "men midwives"          => "man midwife",
  "men milliners"         => "man milliner",
  "men servants"          => "man servant",
  "men-children"          => "man-child",
  "men-midwives"          => "man-midwife",
  "men-milliners"         => "man-milliner",
  "men-servants"          => "man-servant",
  "menages a quatre"      => "menage a quatre",
  "menages a trois"       => "menage a trois",
  "menchildren"           => "manchild",
  "meningiomas"           => "meningioma",
  "meningiomata"          => "meningioma",
  "menisci"               => "meniscus",
  "menservants"           => "manservant",
  "menus"                 => "menu",
  "meretrices"            => "meretrix",
  "merides"               => "meris",
  "meshumadim"            => "meshumad",
  "meshummadim"           => "meshummad",
  "mesothelia"            => "mesothelium",
  "mesotheliomas"         => "mesothelioma",
  "mesotheliomata"        => "mesothelioma",
  "messe di voce"         => "messa di voce",
  "messeigneurs"          => "monseigneur",
  "Messinese"             => "Messinese",
  "metae"                 => "meta",
  "metalimnia"            => "metalimnion",
  "metapleura"            => "metapleuron",
  "metatarsi"             => "metatarsus",
  "metropolises"          => "metropolis",
  "metros"                => "metro",
  "mews"                  => "mew",
  "Mexicos"               => "Mexico",
  "mezuzoth"              => "mezuza",
  "mezzo rilievos"        => "mezzo rilievo",
  "mezzo-rilievos"        => "mezzo-rilievo",
  "miasmas"               => "miasma",
  "miasmata"              => "miasma",
  "mice"                  => "mouse",
  "micetraps"             => "mousetrap",
  "microbia"              => "microbion",
  "microcephali"          => "microcephalus",
  "micrococci"            => "micrococcus",
  "microfiche"            => "microfiche",
  "microfiches"           => "microfiche",
  "micronuclei"           => "micronucleus",
  "micros"                => "micro",
  "Milanese"              => "Milanese",
  "Milanos"               => "Milano",
  "milieus"               => "milieu",
  "milieux"               => "milieu",
  "milieux interieurs"    => "milieu interieur",
  "miliolae"              => "miliola",
  "milites gloriosi"      => "miles gloriosus",
  "millennia"             => "millennium",
  "millenniums"           => "millennium",
  "mimosae"               => "mimosa",
  "mimosas"               => "mimosa",
  "minima"                => "minimum",
  "minimums"              => "minimum",
  "minnelieder"           => "minnelied",
  "minutiae"              => "minutia",
  "minutias"              => "minutia",
  "minyanim"              => "minyan",
  "miracidia"             => "miracidium",
  "mithraea"              => "mithraeum",
  "mitochondria"          => "mitochondrion",
  "mixolimnia"            => "mixolimnion",
  "moakses"               => "moaks",
  "modelletti"            => "modelletto",
  "modelli"               => "modello",
  "modellos"              => "modello",
  "Modenese"              => "Modenese",
  "moderni"               => "modernus",
  "modi"                  => "modus",
  "modii"                 => "modius",
  "moduli"                => "modulus",
  "moduluses"             => "modulus",
  "moduses"               => "modus",
  "moes"                  => "moe",
  "molimina"              => "molimen",
  "momenta"               => "momentum",
  "momentums"             => "momentum",
  "Monacos"               => "Monaco",
  "monades"               => "monas",
  "mondi"                 => "mondo",
  "mongooses"             => "mongoose",
  "monies"                => "money",
  "monimolimnia"          => "monimolimnion",
  "monochasia"            => "monochasium",
  "monorchides"           => "monorchis",
  "monos"                 => "mono",
  "monosyllaba"           => "monosyllabon",
  "monotae"               => "monota",
  "monoxyla"              => "monoxylon",
  "monsiegneurs"          => "monseigneur",
  "monsignori"            => "monsignore",
  "monsignors"            => "monsignor",
  "monstres sacres"       => "monstre sacre",
  "Montenegros"           => "Montenegro",
  "montes"                => "mons",
  "moose"                 => "moose",
  "moratoria"             => "moratorium",
  "moratoriums"           => "moratorium",
  "morceaux"              => "morceau",
  "Moroccos"              => "Morocco",
  "morosi"                => "moroso",
  "mortadellas"           => "mortadella",
  "mortadelle"            => "mortadella",
  "mortaria"              => "mortarium",
  "moscardini"            => "moscardino",
  "motoscafi"             => "motoscafo",
  "mottoes"               => "motto",
  "mottos"                => "motto",
  "mousetraps"            => "mousetrap",
  "mouths"                => "mouth",
  "mucrones"              => "mucro",
  "mucros"                => "mucro",
  "mukim"                 => "mukim",
  "mukims"                => "mukim",
  "multigravidae"         => "multigravida",
  "multigravidas"         => "multigravida",
  "mumps"                 => "mumps",
  "municipia"             => "municipium",
  "Muqdishos"             => "Muqdisho",
  "Muranese"              => "Muranese",
  "murexes"               => "murex",
  "murices"               => "murex",
  "musae"                 => "musa",
  "musas"                 => "musa",
  "musees imaginaires"    => "musee imaginaire",
  "musiques concretes"    => "musique concrete",
  "mustachios"            => "mustachio",
  "muzzes"                => "muzz",
  "myae"                  => "mya",
  "myas"                  => "mya",
  "mycoplasmas"           => "mycoplasma",
  "mycoplasmata"          => "mycoplasma",
  "mycorhizae"            => "mycorhiza",
  "mycorhizas"            => "mycorhiza",
  "mycorrhizae"           => "mycorrhiza",
  "mycorrhizas"           => "mycorrhiza",
  "myelomas"              => "myeloma",
  "myelomata"             => "myeloma",
  "myos"                  => "myo",
  "mythoi"                => "mythos",
  "myxomata"              => "myxoma",
  "nachtlokale"           => "nachtlokal",
  "nagaikas"              => "nagaika",
  "nagaiki"               => "nagaika",
  "Nakayamans"            => "Nakayaman",
  "Nankingese"            => "Nankingese",
  "nasuti"                => "nasutus",
  "naumachiae"            => "naumachia",
  "naumachias"            => "naumachia",
  "nauplii"               => "nauplius",
  "nautili"               => "nautilus",
  "nautiluses"            => "nautilus",
  "Navarrese"             => "Navarrese",
  "naye paise"            => "naya paisa",
  "nebenkerne"            => "nebenkern",
  "nebulae"               => "nebula",
  "nebulas"               => "nebula",
  "nectocalyces"          => "nectocalyx",
  "nemathecia"            => "nemathecium",
  "Nenets"                => "Nenets",
  "Nentsi"                => "Nenets",
  "nentsi"                => "nenets",
  "nentsy"                => "nenets",
  "Nepalese"              => "Nepalese",
  "nephridia"             => "nephridium",
  "neritae"               => "nerita",
  "neritas"               => "nerita",
  "neumas"                => "neuma",
  "neumata"               => "neuma",
  "neurinomas"            => "neurinoma",
  "neurinomata"           => "neurinoma",
  "neuromata"             => "neuroma",
  "neurulae"              => "neurula",
  "neutrinos"             => "neutrino",
  "news"                  => "news",
  "nexus"                 => "nexus",
  "nexuses"               => "nexus",
  "ngwee"                 => "ngwee",
  "Niasese"               => "Niasese",
  "Nicobarese"            => "Nicobarese",
  "nidi"                  => "nidus",
  "niduses"               => "nidus",
  "nielli"                => "niello",
  "niellos"               => "niello",
  "nimbi"                 => "nimbus",
  "nimbuses"              => "nimbus",
  "Ningbos"               => "Ningbo",
  "Nipponese"             => "Nipponese",
  "nockerln"              => "nockerl",
  "noctilucae"            => "noctiluca",
  "noda"                  => "nodum",
  "nodi"                  => "nodus",
  "noemata"               => "noema",
  "nomismata"             => "nomisma",
  "nonentia"              => "non-ens",
  "Normans"               => "Norman",
  "noumena"               => "noumenon",
  "nouveaux arrives"      => "nouvel arrive",
  "nouveaux pauvres"      => "nouveau pauvre",
  "nouveaux riches"       => "nouveau riche",
  "nouvelle pauvre"       => "nouveau pauvre",
  "nouvelle riche"        => "nouveau riche",
  "novae"                 => "nova",
  "novas"                 => "nova",
  "novi homines"          => "novus homo",
  "noxae"                 => "noxa",
  "nses"                  => "nse",
  "nubeculae"             => "nubecula",
  "nuclei"                => "nucleus",
  "nucleoli"              => "nucleolus",
  "nucleolonemas"         => "nucleolonema",
  "nucleolonemata"        => "nucleolonema",
  "nucleoluses"           => "nucleolus",
  "nucleuses"             => "nucleus",
  "numina"                => "numen",
  "nuntii"                => "nuntius",
  "nymphae"               => "nympha",
  "nymphaea"              => "nymphaeum",
  "nymphea"               => "nymphaeum",
  "oaths"                 => "oath",
  "obeli"                 => "obelus",
  "oboli"                 => "obolus",
  "occipita"              => "occiput",
  "occiputs"              => "occiput",
  "oceanaria"             => "oceanarium",
  "ocelli"                => "ocellus",
  "octavos"               => "octavo",
  "octohedra"             => "octohedron",
  "octohedrons"           => "octohedron",
  "octopi"                => "octopus",
  "octopodes"             => "octopus",
  "octopuses"             => "octopus",
  "oculi"                 => "oculus",
  "odea"                  => "odeum",
  "oedemas"               => "oedema",
  "oedemata"              => "oedema",
  "offspring"             => "offspring",
  "oglys"                 => "ogle",
  "Oklahomans"            => "Oklahoman",
  "olfactoria"            => "olfactorium",
  "omenta"                => "omentum",
  "ommatidia"             => "ommatidium",
  "onagers"               => "onager",
  "onagri"                => "onager",
  "one star generals"     => "one star general",
  "one-star generals"     => "one-star general",
  "opera magna"           => "opus magnum",
  "opercula"              => "operculum",
  "ophiophagi"            => "ophiophagus",
  "optima"                => "optimum",
  "optimums"              => "optimum",
  "opuscula"              => "opusculum",
  "opuses"                => "opus",
  "oratrices"             => "oratrix",
  "oreganos"              => "oregano",
  "organa"                => "organon",
  "Orinocos"              => "Orinoco",
  "Orlandos"              => "Orlando",
  "orthocerata"           => "orthoceras",
  "oscula"                => "osculum",
  "Oslos"                 => "Oslo",
  "osmateria"             => "osmaterium",
  "osmeteria"             => "osmeterium",
  "ossicula"              => "ossiculum",
  "osteoclastomas"        => "osteoclastoma",
  "osteoclastomata"       => "osteoclastoma",
  "osteomata"             => "osteoma",
  "ostia"                 => "ostium",
  "Otomi"                 => "Otomi",
  "otomi"                 => "otomi",
  "Otomies"               => "Otomi",
  "otomies"               => "otomi",
  "otos"                  => "oto",
  "ottomans"              => "ottoman",
  "ours"                  => "mine",
  "ourselves"             => "myself",
  "ova"                   => "ovum",
  "ovaria"                => "ovarium",
  "ovoli"                 => "ovolo",
  "ovula"                 => "ovulum",
  "oxen"                  => "ox",
  "oxybapha"              => "oxybaphon",
  "oxymora"               => "oxymoron",
  "oxymorons"             => "oxymoron",
  "oxyurides"             => "oxyuris",
  "paha"                  => "paha",
  "paisas"                => "paisa",
  "paise"                 => "paisa",
  "pajamas"               => "pajamas",
  "palae"                 => "pala",
  "paleae"                => "palea",
  "pali"                  => "palus",
  "pallia"                => "pallium",
  "palpebrae"             => "palpebra",
  "palpi"                 => "palpus",
  "Panamans"              => "Panaman",
  "Pangasinanes"          => "Pangasinan",
  "pangasinanes"          => "pangasinan",
  "Pangasinans"           => "Pangasinan",
  "pangasinans"           => "pangasinan",
  "panini"                => "panino",
  "panorpae"              => "panorpa",
  "pantos"                => "panto",
  "pants"                 => "pant",
  "paparrazi"             => "paparrazo",
  "papillae"              => "papilla",
  "papillomata"           => "papilloma",
  "papulae"               => "papula",
  "papyri"                => "papyrus",
  "papyruses"             => "papyrus",
  "parabolae"             => "parabola",
  "parabolani"            => "parabolanus",
  "parabolas"             => "parabola",
  "paradores"             => "parador",
  "paradors"              => "parador",
  "paraganglia"           => "paraganglion",
  "paragangliomas"        => "paraganglioma",
  "paragangliomata"       => "paraganglioma",
  "paraglossae"           => "paraglossa",
  "Paramaribos"           => "Paramaribo",
  "paranuclei"            => "paranucleus",
  "parapleura"            => "parapleura",
  "parapsides"            => "parapsis",
  "paraselenae"           => "paraselene",
  "parcs fermes"          => "parc ferme",
  "Parduscos"             => "Pardusco",
  "parenchymata"          => "parenchyma",
  "parerga"               => "parergon",
  "parhelia"              => "parhelion",
  "parhelions"            => "parhelion",
  "parietes"              => "paries",
  "parisa"                => "parison",
  "Parmese"               => "Parmese",
  "parnassim"             => "parnas",
  "parvenus"              => "parvenu",
  "pasteurellae"          => "pasteurella",
  "pasteurellas"          => "pasteurella",
  "pastorales"            => "pastorale",
  "pastorali"             => "pastorale",
  "patagia"               => "patagium",
  "paterae"               => "patera",
  "pathoses"              => "pathos",
  "paths"                 => "path",
  "paxillae"              => "paxilla",
  "peciae"                => "pecia",
  "pecias"                => "pecia",
  "pectens"               => "pecten",
  "pectines"              => "pecten",
  "pectora"               => "pectus",
  "pedalos"               => "pedalo",
  "pedes"                 => "pes",
  "pedia"                 => "pedion",
  "pedicellariae"         => "pedicellaria",
  "pediluvia"             => "pediluvium",
  "Pekingese"             => "Pekingese",
  "peltae"                => "pelta",
  "pelves"                => "pelvis",
  "pelvises"              => "pelvis",
  "pence"                 => "penny",
  "pendula"               => "pendulum",
  "pendulums"             => "pendulum",
  "penes"                 => "penis",
  "pengo"                 => "pengo",
  "pengoes"               => "pengo",
  "penicilli"             => "penicillus",
  "peninsulae"            => "peninsula",
  "peninsulas"            => "peninsula",
  "penises"               => "penis",
  "pennia"                => "penni",
  "pennies"               => "penny",
  "pensieri"              => "pensiero",
  "people"                => "person",
  "percepta"              => "perceptum",
  "peridia"               => "peridium",
  "perikarya"             => "perikaryon",
  "perithecia"            => "perithecium",
  "perniones"             => "pernio",
  "peronia"               => "peronium",
  "perradii"              => "perradius",
  "personae"              => "persona",
  "personas"              => "persona",
  "persons"               => "person",
  "phalanges"             => "phalanx",
  "phalangia"             => "phalangium",
  "phalanxes"             => "phalanx",
  "phalli"                => "phallus",
  "phalloi"               => "phallos",
  "phalluses"             => "phallus",
  "pharmakoi"             => "pharmakos",
  "phenomena"             => "phenomenon",
  "phlegmasiae"           => "phlegmasia",
  "phocae"                => "phoca",
  "phocas"                => "phoca",
  "pholades"              => "pholas",
  "photos"                => "photo",
  "phototaxes"            => "phototaxis",
  "phragmata"             => "phragma",
  "phrenes"               => "phren",
  "phyla"                 => "phylum",
  "phylae"                => "phyle",
  "phyllobranchiae"       => "phyllobranchia",
  "phylums"               => "phylum",
  "phymata"               => "phyma",
  "phyogemmaria"          => "phyogemmarium",
  "piani"                 => "piano",
  "pianos"                => "piano",
  "pickerel"              => "pickerel",
  "pickerels"             => "pickerel",
  "Piedmontese"           => "Piedmontese",
  "pieds a terre"         => "pied a terre",
  "pieds noirs"           => "pied noir",
  "pietre"                => "pietra",
  "pifferari"             => "pifferaro",
  "pike"                  => "pike",
  "pikes"                 => "pike",
  "pilei"                 => "pileus",
  "pili"                  => "pilus",
  "pilleis"               => "pillie",
  "pimentos"              => "pimento",
  "pina coladas"          => "pina colada",
  "pinaces"               => "pinax",
  "pinas coladas"         => "pina colada",
  "pincers"               => "pincer",
  "pineta"                => "pinetum",
  "pinetums"              => "pinetum",
  "pingoes"               => "pingo",
  "pingos"                => "pingo",
  "pinnae"                => "pinna",
  "pinnas"                => "pinna",
  "pinones"               => "pinon",
  "pinons"                => "pinon",
  "pintos"                => "pinto",
  "pipkraker"             => "pipkrake",
  "pipkrakes"             => "pipkrake",
  "pirrites"              => "pyrites",
  "piscinae"              => "piscina",
  "piscinas"              => "piscina",
  "pistillidia"           => "pistillidium",
  "Pistoiese"             => "Pistoiese",
  "pithoi"                => "pithos",
  "pizzas"                => "pizza",
  "pizze"                 => "pizza",
  "placeboes"             => "placebo",
  "placebos"              => "placebo",
  "placita"               => "placitum",
  "planctus"              => "planctus",
  "plankton"              => "plankter",
  "planulae"              => "planula",
  "plasmalemmae"          => "plasmalemma",
  "plasmalemmas"          => "plasmalemma",
  "plasmodia"             => "plasmodium",
  "plasmolytica"          => "plasmolyticum",
  "plasmomata"            => "plasmoma",
  "plateaus"              => "plateau",
  "plateaux"              => "plateau",
  "platypodes"            => "platypus",
  "platypuses"            => "platypus",
  "plecos"                => "pleco",
  "plectra"               => "plectrum",
  "plenaria"              => "plenarium",
  "plesiosauri"           => "plesiosaurus",
  "plether"               => "plethron",
  "plethra"               => "plethron",
  "pleura"                => "pleura",
  "plexus"                => "plexus",
  "plexuses"              => "plexus",
  "plicae"                => "plica",
  "pliers"                => "pliers",
  "ploshchadki"           => "ploshchadka",
  "pluralia tantum"       => "plurale tantum",
  "plutei"                => "pluteus",
  "Plutos"                => "Pluto",
  "pneumothoraces"        => "pneumothorax",
  "pneumothoraxes"        => "pneumothorax",
  "pobladores"            => "poblador",
  "pocula"                => "poculum",
  "poderi"                => "podere",
  "podetia"               => "podetium",
  "podia"                 => "podium",
  "podiums"               => "podium",
  "poes"                  => "po",
  "pogos"                 => "pogo",
  "poise"                 => "poise",
  "poises"                => "poise",
  "polises"               => "polis",
  "politbureaus"          => "politbureau",
  "politbureaux"          => "politbureau",
  "politicoes"            => "politico",
  "politicos"             => "politico",
  "pollices"              => "pollex",
  "pollinaria"            => "pollinarium",
  "pollinia"              => "pollinium",
  "Polonese"              => "Polonese",
  "polos"                 => "polo",
  "polythecia"            => "polythecium",
  "pommes de terre"       => "pomme de terre",
  "ponchos"               => "poncho",
  "pontifexes"            => "pontifex",
  "pontifices"            => "pontifex",
  "porcini"               => "porcino",
  "poria"                 => "porion",
  "porrones"              => "porron",
  "porrons"               => "porron",
  "porticoes"             => "portico",
  "porticos"              => "portico",
  "portiforia"            => "portiforium",
  "portmanteaus"          => "portmanteau",
  "portmanteaux"          => "portmanteau",
  "Porto Novos"           => "Porto Novo",
  "Porto-Novos"           => "Porto-Novo",
  "Portos"                => "Porto",
  "portraits parles"      => "portrait parle",
  "ports de bras"         => "port de bras",
  "Portuguese"            => "Portuguese",
  "pos"                   => "po",
  "postnati"              => "postnatus",
  "postpubes"             => "postpubis",
  "postulata"             => "postulatum",
  "potatoes"              => "potato",
  "potestates"            => "potestas",
  "pox"                   => "pox",
  "praecognita"           => "praecognitum",
  "pragmas"               => "pragma",
  "pragmata"              => "pragma",
  "precis"                => "precis",
  "precognita"            => "precognitum",
  "premiers danseurs"     => "premier danseur",
  "prepennae"             => "prepenna",
  "prima ballerinas"      => "prima ballerina",
  "prima donnas"          => "prima donna",
  "prime ballerine"       => "prima ballerina",
  "prime donne"           => "prima donna",
  "primigravidae"         => "primigravida",
  "primordia"             => "primordium",
  "principia"             => "principium",
  "proaves"               => "proavis",
  "proboscides"           => "proboscis",
  "proboscises"           => "proboscis",
  "proceedings"           => "proceedings",
  "procoeliae"            => "procoelia",
  "prodromi"              => "prodromus",
  "proferentes"           => "proferens",
  "profluvia"             => "profluvium",
  "proglottides"          => "proglottis",
  "programmata"           => "programma",
  "progymnasia"           => "progymnasium",
  "progymnasmata"         => "progymnasma",
  "prokarya"              => "prokaryon",
  "prolabia"              => "prolabium",
  "prolegomena"           => "prolegomenon",
  "promeropes"            => "promerops",
  "propleura"             => "propleuron",
  "propodia"              => "propodium",
  "propositi"             => "propositus",
  "propria"               => "proprium",
  "propyla"               => "propylon",
  "propylaea"             => "propylaeum",
  "propylons"             => "propylon",
  "prorae"                => "prora",
  "pros"                  => "pro",
  "prosae"                => "prosa",
  "proscenia"             => "proscenium",
  "proscollae"            => "proscolla",
  "prosecutrices"         => "prosecutrix",
  "prosencephala"         => "prosencephalon",
  "proseuchae"            => "proseucha",
  "prosodiencephala"      => "prosodiencephalon",
  "prosopia"              => "prosopium",
  "prospectus"            => "prospectus",
  "prospectuses"          => "prospectus",
  "prosulae"              => "prosula",
  "protarsi"              => "protarsus",
  "prothalli"             => "prothallus",
  "prothallia"            => "prothallium",
  "protococci"            => "protococcus",
  "protomae"              => "protoma",
  "protomas"              => "protoma",
  "protonemata"           => "protonema",
  "prototypa"             => "prototypon",
  "prototypons"           => "prototypon",
  "protypa"               => "protypon",
  "provisoes"             => "proviso",
  "provisos"              => "proviso",
  "prytan"                => "prytanis",
  "prytanes"              => "prytanis",
  "psammomata"            => "psammoma",
  "pseudopodia"           => "pseudopodium",
  "pseudostomata"         => "pseudostoma",
  "psychos"               => "psycho",
  "psydracia"             => "psydracium",
  "pteromata"             => "pteroma",
  "pteropi"               => "pteropus",
  "pterylae"              => "pteryla",
  "pueblos"               => "pueblo",
  "puirt a beul"          => "port a beul",
  "puirt-a-beul"          => "port-a-beul",
  "puli"                  => "pul",
  "pulli"                 => "pullus",
  "pulmonaria"            => "pulmonarium",
  "puls"                  => "pul",
  "pulsella"              => "pulsellum",
  "pulveratrices"         => "pulveratrix",
  "puncta"                => "punctum",
  "punti blanchi"         => "punto blanco",
  "puntos blancos"        => "punto blanco",
  "pupae"                 => "pupa",
  "purlieus"              => "purlieu",
  "purlieux"              => "purlieu",
  "purum"                 => "purum",
  "Purum"                 => "Purum",
  "Purums"                => "Purum",
  "purums"                => "purum",
  "putti"                 => "putto",
  "puttonys"              => "puttony",
  "pycnia"                => "pycnium",
  "pycnides"              => "pycnis",
  "pycnidia"              => "pycnidium",
  "pyjamas"               => "pyjamas",
  "pylae"                 => "pyla",
  "pyralides"             => "pyralis",
  "pyramidia"             => "pyramidion",
  "pyramidions"           => "pyramidion",
  "pyrexiae"              => "pyrexia",
  "pyritae"               => "pyrites",
  "pyrophori"             => "pyrophorus",
  "pyxidia"               => "pyxidium",
  "quadratrices"          => "quadratrix",
  "quaesita"              => "quaesitum",
  "quanta"                => "quantum",
  "quantums"              => "quantum",
  "quartos"               => "quarto",
  "quartzes"              => "quartz",
  "quid"                  => "quid",
  "quinarii"              => "quinarius",
  "quinquennia"           => "quinquennium",
  "Quitos"                => "Quito",
  "rabies"                => "rabies",
  "rad"                   => "rad",
  "radialia"              => "radiale",
  "radices"               => "radix",
  "radii"                 => "radius",
  "radiuses"              => "radius",
  "radixes"               => "radix",
  "rads"                  => "rad",
  "ragazze"               => "ragazza",
  "ragazzi"               => "ragazzo",
  "raggare"               => "raggare",
  "raggares"              => "raggare",
  "rami"                  => "ramus",
  "ramuli"                => "ramulus",
  "ranunculi"             => "ranunculus",
  "ranunculuses"          => "ranunculus",
  "rara avises"           => "rara avis",
  "rarae aves"            => "rara avis",
  "razzes"                => "razz",
  "recti"                 => "rectus",
  "rediae"                => "redia",
  "reductiones"           => "reductio",
  "referenda"             => "referendum",
  "referendums"           => "referendum",
  "refugia"               => "refugium",
  "regidores"             => "regidor",
  "regidors"              => "regidor",
  "regmata"               => "regma",
  "reguli"                => "regulus",
  "reiche"                => "reich",
  "rejoneadores"          => "rejoneador",
  "rejones"               => "rejon",
  "relata"                => "relatum",
  "rem"                   => "rem",
  "remexes"               => "remex",
  "remiges"               => "remex",
  "remou"                 => "remous",
  "remous"                => "remous",
  "rems"                  => "rem",
  "repla"                 => "replum",
  "representamens"        => "representamen",
  "representamina"        => "representamen",
  "res"                   => "res",
  "residua"               => "residuum",
  "residuums"             => "residuum",
  "responsa"              => "responsum",
  "retia"                 => "rete",
  "retinacula"            => "retinaculum",
  "retinulae"             => "retinula",
  "rezidentsii"           => "rezidentsia",
  "rezidenty"             => "rezident",
  "rhinoceros"            => "rhinoceros",
  "rhinoceroses"          => "rhinoceros",
  "rhinophymas"           => "rhinophyma",
  "rhinophymata"          => "rhinophyma",
  "rhinos"                => "rhino",
  "rhizomas"              => "rhizoma",
  "rhizomata"             => "rhizoma",
  "rhododendra"           => "rhododendron",
  "rhododendrons"         => "rhododendron",
  "rhombohedra"           => "rhombohedron",
  "rhombohedrons"         => "rhombohedron",
  "rhomboidei"            => "rhomboideus",
  "rhopalia"              => "rhopalium",
  "rhynchodaea"           => "rhynchodaeum",
  "rhythmi"               => "rhythmus",
  "ri"                    => "ri",
  "ricercari"             => "ricercar",
  "ricercars"             => "ricercar",
  "ricercate"             => "ricercata",
  "ricordi"               => "ricordo",
  "rideaus"               => "rideau",
  "rideaux"               => "rideau",
  "rilievos"              => "rilievo",
  "rimmonim"              => "rimon",
  "rimonim"               => "rimon",
  "rioni"                 => "rione",
  "risottos"              => "risotto",
  "ritardandi"            => "ritardando",
  "ritardandos"           => "ritardando",
  "rites de passage"      => "rite de passage",
  "rococos"               => "rococo",
  "roe"                   => "roe",
  "roes"                  => "roe",
  "Roma"                  => "Rom",
  "Romagnese"             => "Romagnese",
  "Romanese"              => "Romanese",
  "Romanies"              => "Romany",
  "Romans"                => "Roman",
  "romanzen"              => "romanze",
  "roms"                  => "rom",
  "rond de jambes"        => "rond de jambe",
  "rondeaus"              => "rondeau",
  "rondeaux"              => "rondeau",
  "rondos"                => "rondo",
  "ronds de jambes"       => "rond de jambe",
  "rostra"                => "rostrum",
  "rostrums"              => "rostrum",
  "rotulae"               => "rotula",
  "routes nationales"     => "route nationale",
  "rubashkas"             => "rubashka",
  "rubashki"              => "rubashka",
  "rugae"                 => "ruga",
  "ruses de guerre"       => "ruse de guerre",
  "ryper"                 => "rype",
  "sabertooths"           => "sabertooth",
  "sacculi"               => "sacculus",
  "sacella"               => "sacellum",
  "sachverhalte"          => "sachverhalt",
  "sacra"                 => "sacrum",
  "Sacramentos"           => "Sacramento",
  "sacraria"              => "sacrarium",
  "sacrums"               => "sacrum",
  "saddos"                => "saddo",
  "saffi"                 => "saffo",
  "saga"                  => "sagum",
  "sagos"                 => "sago",
  "salitas"               => "salita",
  "salite"                => "salita",
  "salivaria"             => "salivarium",
  "salmon"                => "salmon",
  "salpae"                => "salpa",
  "salpas"                => "salpa",
  "salvos"                => "salvo",
  "samboes"               => "sambo",
  "sambos"                => "sambo",
  "samurai"               => "samurai",
  "sanatoria"             => "sanatorium",
  "sanatoriums"           => "sanatorium",
  "sancta sanctorum"      => "sanctum sanctorum",
  "sandr"                 => "sandr",
  "sandrs"                => "sandr",
  "Sangirese"             => "Sangirese",
  "Santiagos"             => "Santiago",
  "Sapporos"              => "Sapporo",
  "Sarajevos"             => "Sarajevo",
  "Sarawakese"            => "Sarawakese",
  "sarcinae"              => "sarcina",
  "sarcomas"              => "sarcoma",
  "sarcomata"             => "sarcoma",
  "sarcophagi"            => "sarcophagus",
  "sarissae"              => "sarissa",
  "sassafrases"           => "sassafras",
  "satellites"            => "satelles",
  "saxicavae"             => "saxicava",
  "sbirri"                => "sbirro",
  "scaleni"               => "scalenus",
  "scandala magnatum"     => "scandalum magnatum",
  "scapi"                 => "scapus",
  "scapulae"              => "scapula",
  "scapulas"              => "scapula",
  "scarabaei"             => "scarabaeus",
  "scari"                 => "scarus",
  "scazons"               => "scazon",
  "scazontes"             => "scazon",
  "sceattas"              => "sceat",
  "schemas"               => "schema",
  "schemata"              => "schema",
  "scherzandos"           => "scherzando",
  "scherzos"              => "scherzo",
  "schismata"             => "schisma",
  "schistosomula"         => "schistosomulum",
  "schizostylis"          => "schizostylis",
  "scholia"               => "scholium",
  "scioli"                => "sciolus",
  "scirrhi"               => "scirrhus",
  "scirrhusses"           => "scirrhus",
  "scissors"              => "scissors",
  "scoleces"              => "scolex",
  "scolopidia"            => "scolopidium",
  "scombri"               => "scomber",
  "scoriae"               => "scoria",
  "scorias"               => "scoria",
  "scotomas"              => "scotoma",
  "scotomata"             => "scotoma",
  "scriptoria"            => "scriptorium",
  "scriptoriums"          => "scriptorium",
  "scudi"                 => "scudo",
  "scungilli"             => "scungille",
  "scuole"                => "scuola",
  "scuta"                 => "scutum",
  "scutella"              => "scutellum",
  "scutula"               => "scutulum",
  "scyphi"                => "scyphus",
  "seaquaria"             => "seaquarium",
  "secantes"              => "secans",
  "secreta"               => "secretum",
  "secundagravidae"       => "secundagravida",
  "secundagravidas"       => "secundagravida",
  "secundigravidae"       => "secundigravida",
  "secundigravidas"       => "secundigravida",
  "secundiparae"          => "secundipara",
  "secundiparas"          => "secundipara",
  "sedes"                 => "sedes",
  "sedilia"               => "sedile",
  "seecatchie"            => "seecatch",
  "seed"                  => "seed",
  "seeds"                 => "seed",
  "Selmans"               => "Selman",
  "semas"                 => "sema",
  "semata"                => "sema",
  "seminia"               => "seminium",
  "semunciae"             => "semuncia",
  "senarii"               => "senarius",
  "Senegalese"            => "Senegalese",
  "senes"                 => "senex",
  "sensa"                 => "sensum",
  "sensedata"             => "sensedatum",
  "sensilla"              => "sensillum",
  "sensoriola"            => "sensoriolum",
  "sententiae"            => "sententia",
  "separatrices"          => "separatrix",
  "sephardim"             => "sephardi",
  "sephardin"             => "sephardi",
  "septa"                 => "septum",
  "septaria"              => "septarium",
  "septemviri"            => "septemvir",
  "septenarii"            => "septenarius",
  "sequelae"              => "sequela",
  "sequestra"             => "sequestrum",
  "sera"                  => "serum",
  "seraphim"              => "seraph",
  "seraphs"               => "seraph",
  "sericteria"            => "sericterium",
  "series"                => "series",
  "serir"                 => "serir",
  "serirs"                => "serir",
  "serpigines"            => "serpigo",
  "serpigoes"             => "serpigo",
  "serpulae"              => "serpula",
  "serrae"                => "serra",
  "sertulariae"           => "sertularia",
  "sertularias"           => "sertularia",
  "serums"                => "serum",
  "ses"                   => "sis",
  "sestertia"             => "sestertium",
  "sestieri"              => "sestiere",
  "set offs"              => "set off",
  "set outs"              => "set out",
  "set tos"               => "set to",
  "set-offs"              => "set-off",
  "set-outs"              => "set-out",
  "set-tos"               => "set-to",
  "setae"                 => "seta",
  "sets off"              => "set off",
  "sets out"              => "set out",
  "sets to"               => "set to",
  "sets-off"              => "set-off",
  "sets-out"              => "set-out",
  "sets-to"               => "set-to",
  "sezessionen"           => "sezession",
  "sforzati"              => "sforzato",
  "sforzatos"             => "sforzato",
  "sgraffiati"            => "sgraffiato",
  "shad"                  => "shad",
  "shads"                 => "shad",
  "shamans"               => "shaman",
  "shauries"              => "shauri",
  "shauris"               => "shauri",
  "Shavese"               => "Shavese",
  "shawabtis"             => "shawabti",
  "shawabtiu"             => "shawabti",
  "Shawanese"             => "Shawanese",
  "shears"                => "shears",
  "sheep"                 => "sheep",
  "shelves"               => "shelf",
  "shifta"                => "shifta",
  "shiftas"               => "shifta",
  "shochetim"             => "shochet",
  "shomrim"               => "shomer",
  "shorts"                => "shorts",
  "Siamese"               => "Siamese",
  "siemens"               => "siemens",
  "Sienese"               => "Sienese",
  "sigli"                 => "siglos",
  "sigloi"                => "siglos",
  "signa"                 => "signum",
  "Sikkimese"             => "Sikkimese",
  "silbadores"            => "silbador",
  "silbadors"             => "silbador",
  "sileni"                => "silenus",
  "silices"               => "silex",
  "siliquae"              => "siliqua",
  "silos"                 => "silo",
  "Siluri"                => "Silurus",
  "simiae"                => "simia",
  "simplexes"             => "simplex",
  "simplices"             => "simplex",
  "simpula"               => "simpulum",
  "simulacra"             => "simulacrum",
  "simulacrums"           => "simulacrum",
  "sinfonias"             => "sinfonia",
  "sinfonie"              => "sinfonia",
  "Singhalese"            => "Singhalese",
  "Sinhalese"             => "Sinhalese",
  "sinus"                 => "sinus",
  "sinuses"               => "sinus",
  "siphunculi"            => "siphunculus",
  "sipunculi"             => "sipunculus",
  "siroccos"              => "sirocco",
  "sistra"                => "sistrum",
  "sistrums"              => "sistrum",
  "situlae"               => "situla",
  "situlas"               => "situla",
  "six star generals"     => "six star general",
  "six-star generals"     => "six-star general",
  "sizzes"                => "sizz",
  "skis"                  => "ski",
  "snekkjur"              => "snekkja",
  "snipe"                 => "snipe",
  "snipes"                => "snipe",
  "snoozes"               => "snooze",
  "soes"                  => "so",
  "Sogdianese"            => "Sogdianese",
  "solaria"               => "solarium",
  "soldi"                 => "soldo",
  "solenia"               => "solenium",
  "soles"                 => "sol",
  "solfeggi"              => "solfeggio",
  "solfeggios"            => "solfeggio",
  "soli"                  => "solo",
  "solidi"                => "solidus",
  "solidos"               => "solidus",
  "solos"                 => "solo",
  "solstitia"             => "solstitium",
  "solvi"                 => "solvus",
  "somas"                 => "soma",
  "somata"                => "soma",
  "somatenes"             => "somaten",
  "sombreros"             => "sombrero",
  "some"                  => "one",
  "Sonamans"              => "Sonaman",
  "soprani"               => "soprano",
  "sopranos"              => "soprano",
  "soralia"               => "soralium",
  "soredia"               => "soredium",
  "sori"                  => "sorus",
  "soshi"                 => "soshi",
  "sotches"               => "sotch",
  "sotchs"                => "sotch",
  "souvlakia"             => "souvlaki",
  "souvlakis"             => "souvlaki",
  "spadices"              => "spadix",
  "spadixes"              => "spadix",
  "Spaetlesen"            => "Spaetlese",
  "spari"                 => "sparus",
  "spasmi"                => "spasmus",
  "spathae"               => "spatha",
  "species"               => "species",
  "spectra"               => "spectrum",
  "spectrums"             => "spectrum",
  "specula"               => "speculum",
  "speculums"             => "speculum",
  "spermaria"             => "spermarium",
  "spermata"              => "sperma",
  "spermathecae"          => "spermatheca",
  "spermatia"             => "spermatium",
  "spermatoa"             => "spermatoon",
  "spermogonia"           => "spermogonium",
  "sphaerideum"           => "sphaeridium",
  "sphaeridia"            => "sphaeridium",
  "sphagna"               => "sphagnum",
  "sphagnums"             => "sphagnum",
  "spheges"               => "sphex",
  "sphinges"              => "sphinx",
  "sphinxes"              => "sphinx",
  "spicula"               => "spiculum",
  "spiracula"             => "spiraculum",
  "spirilla"              => "spirillum",
  "spondyli"              => "spondylus",
  "sporodochia"           => "sporodochium",
  "sputa"                 => "sputum",
  "squadre"               => "squadra",
  "squadristi"            => "squadrist",
  "squadrists"            => "squadrist",
  "squali"                => "squalus",
  "squamae"               => "squama",
  "squillae"              => "squilla",
  "stabilimenta"          => "stabilimentum",
  "staccatos"             => "staccato",
  "stadia"                => "stadium",
  "stadiums"              => "stadium",
  "stalactitae"           => "stalactite",
  "stalactites"           => "stalactite",
  "stamen"                => "stamen",
  "stamina"               => "stamen",
  "staminidia"            => "staminidium",
  "staphylococci"         => "staphylococcus",
  "star fish"             => "star fish",
  "star fishes"           => "star fish",
  "star-fish"             => "star-fish",
  "star-fishes"           => "star-fish",
  "starfish"              => "starfish",
  "starfishes"            => "starfish",
  "starosti"              => "starosta",
  "starovers"             => "starover",
  "starovery"             => "starover",
  "startsy"               => "starets",
  "startzy"               => "staretz",
  "stasima"               => "stasimon",
  "stasimons"             => "stasimon",
  "staterae"              => "statera",
  "statuae"               => "statua",
  "statuas"               => "statua",
  "status"                => "status",
  "statuses"              => "status",
  "stelae"                => "stela",
  "stelas"                => "stela",
  "stellae"               => "stella",
  "stemmata"              => "stemma",
  "stephania"             => "stephanion",
  "stephanions"           => "stephanion",
  "sterigmata"            => "sterigma",
  "sterna"                => "sternum",
  "sternebrae"            => "sternebra",
  "sternos"               => "sterno",
  "sternums"              => "sternum",
  "stichidia"             => "stichidium",
  "stichoi"               => "stichos",
  "stigmariae"            => "stigmaria",
  "stigmas"               => "stigma",
  "stigmata"              => "stigma",
  "stilettoes"            => "stiletto",
  "stillicidia"           => "stillicidium",
  "stimuli"               => "stimulus",
  "stipites"              => "stipes",
  "stipulae"              => "stipula",
  "stipulas"              => "stipula",
  "stirpes"               => "stirps",
  "stoai"                 => "stoa",
  "stoas"                 => "stoa",
  "stolones"              => "stolo",
  "stomachs"              => "stomach",
  "stomas"                => "stoma",
  "stomata"               => "stoma",
  "stomatia"              => "stomatium",
  "stomia"                => "stomion",
  "stomodaea"             => "stomodaeum",
  "stomodea"              => "stomodaeum",
  "storeys"               => "storey",
  "stornelli"             => "stornello",
  "strambotti"            => "strambotto",
  "strata"                => "stratum",
  "strategi"              => "strategus",
  "strategoi"             => "strategos",
  "stratums"              => "stratum",
  "streptococci"          => "streptococcus",
  "streptothrices"        => "streptothrix",
  "striae"                => "stria",
  "striata"               => "striatum",
  "strigae"               => "striga",
  "striolae"              => "striola",
  "strobilae"             => "strobila",
  "strobili"              => "strobilus",
  "stromata"              => "stroma",
  "stromodaea"            => "stromodeum",
  "stromodea"             => "stromodeum",
  "strumae"               => "struma",
  "stryddae"              => "stryddag",
  "stuccos"               => "stucco",
  "studia generali"       => "studium generale",
  "styli"                 => "stylus",
  "stylopodia"            => "stylopodium",
  "stylos"                => "stylo",
  "styluses"              => "stylus",
  "subbotniki"            => "subbotnik",
  "subbotniks"            => "subbotnik",
  "subsellia"             => "subsellium",
  "subsidia"              => "subsidium",
  "substrata"             => "substratum",
  "substratums"           => "substratum",
  "succi"                 => "succus",
  "succineae"             => "succinea",
  "succineas"             => "succinea",
  "succubi"               => "succubus",
  "succubuses"            => "succubus",
  "Sudanese"              => "Sudanese",
  "suffrutices"           => "suffrutex",
  "suggesta"              => "suggestum",
  "suggestiones falsi"    => "suggestio falsi",
  "suggestums"            => "suggestum",
  "sulci"                 => "sulcus",
  "sum totals"            => "sum total",
  "sum-totals"            => "sum-total",
  "summa bona"            => "summum bonum",
  "summa genera"          => "summum genus",
  "summae"                => "summa",
  "sumos"                 => "sumo",
  "sums total"            => "sum total",
  "sums-total"            => "sum-total",
  "Sundanese"             => "Sundanese",
  "supercilia"            => "supercilium",
  "superficies"           => "superficies",
  "supernovae"            => "supernova",
  "supernovas"            => "supernova",
  "superstrata"           => "superstratum",
  "supposita"             => "suppositum",
  "supracleithra"         => "supracleithrum",
  "suprascapulae"         => "suprascapula",
  "surculi"               => "surculus",
  "surimonos"             => "surimono",
  "sustentacula"          => "sustentaculum",
  "Swahilese"             => "Swahilese",
  "swine"                 => "swine",
  "swines"                => "swine",
  "switchfoots"           => "switchfoot",
  "syllabaria"            => "syllabarium",
  "syllabi"               => "syllabus",
  "syllabuses"            => "syllabus",
  "symplasmata"           => "symplasma",
  "sympodia"              => "sympodium",
  "symposia"              => "symposium",
  "symposiums"            => "symposium",
  "synaesthesiae"         => "synaesthesia",
  "synangia"              => "synangium",
  "synapticulae"          => "synapticula",
  "synapticulas"          => "synapticula",
  "synaxaria"             => "synaxarium",
  "synaxes"               => "synaxis",
  "syncelli"              => "syncellus",
  "syncytia"              => "syncytium",
  "syndendria"            => "syndendrium",
  "synechiae"             => "synechia",
  "synedria"              => "synedrium",
  "synesthesiae"          => "synesthesia",
  "syntagmas"             => "syntagma",
  "syntagmata"            => "syntagma",
  "syntaxes"              => "syntaxis",
  "synthroni"             => "synthronus",
  "synusiae"              => "synusia",
  "syphilomata"           => "syphiloma",
  "syringes"              => "syringe",
  "syrinxes"              => "syrinx",
  "syrphi"                => "syrphus",
  "syrtes"                => "syrtis",
  "tabellae"              => "tabella",
  "tableaus"              => "tableau",
  "tableaux"              => "tableau",
  "tablina"               => "tablinum",
  "tabulae"               => "tabula",
  "Tacomans"              => "Tacoman",
  "taeniae"               => "taenia",
  "taenias"               => "taenia",
  "tagmata"               => "tagma",
  "Taikos"                => "Taiko",
  "taleae"                => "talea",
  "tali"                  => "talus",
  "talismans"             => "talisman",
  "talouses"              => "talouse",
  "tangoes"               => "tango",
  "tangos"                => "tango",
  "tarantate"             => "tarantata",
  "tarantati"             => "tarantato",
  "tarsi"                 => "tarsus",
  "taxa"                  => "taxon",
  "taxes"                 => "taxis",
  "tazze"                 => "tazza",
  "teal"                  => "teal",
  "teals"                 => "teal",
  "technos"               => "techno",
  "teeth"                 => "tooth",
  "tegmenta"              => "tegmentum",
  "tegmina"               => "tegmen",
  "tegulae"               => "tegula",
  "telamones"             => "telamon",
  "telia"                 => "telium",
  "temblores"             => "temblor",
  "tempi"                 => "tempo",
  "tempietti"             => "tempietto",
  "tempos"                => "tempo",
  "tenacula"              => "tenaculum",
  "tenderfoots"           => "tenderfoot",
  "Tenggerese"            => "Tenggerese",
  "teniae"                => "tenia",
  "tenias"                => "tenia",
  "tenorini"              => "tenorino",
  "tentacula"             => "tentaculum",
  "tentamina"             => "tentamen",
  "tenues"                => "tenuis",
  "tepidaria"             => "tepidarium",
  "teratomata"            => "teratoma",
  "terebella"             => "terebellum",
  "terebratulae"          => "terebratula",
  "terebratulas"          => "terebratula",
  "teredines"             => "teredo",
  "teredos"               => "teredo",
  "terga"                 => "tergum",
  "termini"               => "terminus",
  "terminuses"            => "terminus",
  "termites"              => "termes",
  "terpen"                => "terp",
  "terps"                 => "terp",
  "terrae filii"          => "terrae filius",
  "terraria"              => "terrarium",
  "terrariums"            => "terrarium",
  "terrazzos"             => "terrazzo",
  "terremare"             => "terramara",
  "territoria"            => "territorium",
  "terzetti"              => "terzetto",
  "tessellae"             => "tessella",
  "tessellas"             => "tessella",
  "tesserae"              => "tessera",
  "testes"                => "testes",
  "testudos"              => "testudo",
  "tetanother"            => "tetanothrum",
  "tetanothra"            => "tetanothrum",
  "tete a tetes"          => "tete a tete",
  "tete-a-tetes"          => "tete-a-tete",
  "tetracola"             => "tetracolon",
  "tetragrammata"         => "tetragrammaton",
  "tetrahedra"            => "tetrahedron",
  "tetrahedrons"          => "tetrahedron",
  "tetrapleura"           => "tetrapleuron",
  "tetrapleurons"         => "tetrapleuron",
  "tetrasporangia"        => "tetrasporangium",
  "thalami"               => "thalamus",
  "thalamoi"              => "thalamos",
  "thanatoria"            => "thanatorium",
  "thaumaturgi"           => "thaumaturgus",
  "thebe"                 => "thebe",
  "thecae"                => "theca",
  "theirs"                => "its",
  "thelyca"               => "thelycum",
  "them"                  => "it",
  "themata"               => "thema",
  "themselves"            => "themselves",
  "theologoumena"         => "theologoumenon",
  "thesauri"              => "thesaurus",
  "thesauruses"           => "thesaurus",
  "these"                 => "this",
  "they"                  => "it",
  "thieves"               => "thief",
  "thoes"                 => "thos",
  "tholi"                 => "tholus",
  "tholoi"                => "tholos",
  "thoraces"              => "thorax",
  "thoraxes"              => "thorax",
  "those"                 => "that",
  "thrasoes"              => "thraso",
  "thrasones"             => "thraso",
  "three star generals"   => "three star general",
  "three-star generals"   => "three-star general",
  "thymi"                 => "thymus",
  "thymiateria"           => "thymiaterion",
  "thyridia"              => "thyridium",
  "thyrsi"                => "thyrsus",
  "tibiae"                => "tibia",
  "Timorese"              => "Timorese",
  "timpanos"              => "timpano",
  "tintinnabula"          => "tintinnabulum",
  "tipulae"               => "tipula",
  "Tirolese"              => "Tirolese",
  "tiros"                 => "tiro",
  "tobaccos"              => "tobacco",
  "Tocharese"             => "Tocharese",
  "toes"                  => "toe",
  "Togos"                 => "Togo",
  "Tokyos"                => "Tokyo",
  "tolkachi"              => "tolkach",
  "tomatoes"              => "tomato",
  "tombaroli"             => "tombarolo",
  "tomia"                 => "tomium",
  "tondi"                 => "tondo",
  "tongs"                 => "tongs",
  "Tonkinese"             => "Tonkinese",
  "tonneaus"              => "tonneau",
  "tonneaux"              => "tonneau",
  "topazes"               => "topaz",
  "topoi"                 => "topos",
  "toreros"               => "torero",
  "tori"                  => "torus",
  "toriles"               => "toril",
  "Torinese"              => "Torinese",
  "Torinos"               => "Torino",
  "torma"                 => "torma",
  "tormas"                => "torma",
  "Tornesi"               => "Tornese",
  "torni"                 => "tornus",
  "Torontos"              => "Toronto",
  "torsos"                => "torso",
  "tortillas espanolas"   => "tortilla espanola",
  "tortrices"             => "tortrix",
  "torulae"               => "torula",
  "toruli"                => "torulus",
  "toruses"               => "torus",
  "tours de force"        => "tour de force",
  "toxica"                => "toxicum",
  "toxii"                 => "toxius",
  "toxoplasmata"          => "toxoplasma",
  "trabeae"               => "trabea",
  "trabeculae"            => "trabecula",
  "tracheae"              => "trachea",
  "tractatrices"          => "tractatrix",
  "tractella"             => "tractellum",
  "tractrices"            => "tractrix",
  "tragi"                 => "tragus",
  "trapezia"              => "trapezium",
  "trapezii"              => "trapezius",
  "trapeziums"            => "trapezium",
  "trapezohedra"          => "trapezohedron",
  "trapezohedrons"        => "trapezohedron",
  "trattorias"            => "trattoria",
  "trattorie"             => "trattoria",
  "traumas"               => "trauma",
  "traumata"              => "trauma",
  "trellises"             => "trellis",
  "tremolos"              => "tremolo",
  "treponemata"           => "treponema",
  "trichidia"             => "trichidium",
  "trichinae"             => "trichina",
  "trichine"              => "trichina",
  "trichomata"            => "trichoma",
  "triclinia"             => "triclinium",
  "trientes"              => "triens",
  "triforia"              => "triforium",
  "trilbys"               => "trilby",
  "tripla"                => "triplum",
  "triradii"              => "triradius",
  "triumviri"             => "triumvir",
  "triumvirs"             => "triumvir",
  "trochi"                => "trochus",
  "trochuses"             => "trochus",
  "trockenbeerenauslesen" => "trockenbeerenauslese",
  "tropaeola"             => "tropaeolum",
  "tropaeolums"           => "tropaeolum",
  "troparia"              => "troparion",
  "tropides"              => "tropis",
  "trousers"              => "trousers",
  "trousseaus"            => "trousseau",
  "trousseaux"            => "trousseau",
  "trout"                 => "trout",
  "trulli"                => "trullo",
  "trumeaux"              => "trumeau",
  "tsuba"                 => "tsuba",
  "tsubas"                => "tsuba",
  "tsubo"                 => "tsubo",
  "tsubos"                => "tsubo",
  "tubercula"             => "tuberculum",
  "tuberculomas"          => "tuberculoma",
  "tuberculomata"         => "tuberculoma",
  "tuberes"               => "tuber",
  "tubuli"                => "tubulus",
  "tumuli"                => "tumulus",
  "tuna"                  => "tuna",
  "turbot"                => "turbot",
  "turbots"               => "turbot",
  "turfs"                 => "turf",
  "turrones"              => "turron",
  "turrons"               => "turron",
  "turves"                => "turf",
  "two star generals"     => "two star general",
  "two-star generals"     => "two-star general",
  "tympana"               => "tympanum",
  "typos"                 => "typo",
  "Tyrolese"              => "Tyrolese",
  "tyros"                 => "tyro",
  "udarniki"              => "udarnik",
  "ulpanim"               => "ulpan",
  "ultimata"              => "ultimatum",
  "ultimatums"            => "ultimatum",
  "umbilici"              => "umbilicus",
  "umbilicuses"           => "umbilicus",
  "umbones"               => "umbo",
  "umbos"                 => "umbo",
  "umbrae"                => "umbra",
  "umbras"                => "umbra",
  "umwelten"              => "umwelt",
  "unci"                  => "uncus",
  "unciae"                => "uncia",
  "uncini"                => "uncinus",
  "ungues"                => "unguis",
  "uniones"               => "unio",
  "unios"                 => "unio",
  "uomini"                => "uomo",
  "uomini universali"     => "uomo universale",
  "uraei"                 => "uraeus",
  "uredia"                => "uredium",
  "uredinia"              => "uredinium",
  "uredosori"             => "uredosorus",
  "uri"                   => "urus",
  "urodaea"               => "urodaeum",
  "urodea"                => "urodeum",
  "uruses"                => "urus",
  "us"                    => "me",
  "usneae"                => "usnea",
  "usneas"                => "usnea",
  "ustilagines"           => "ustilago",
  "uteri"                 => "uterus",
  "uteruses"              => "uterus",
  "utriculariae"          => "utricularia",
  "uvae"                  => "uva",
  "vaalpens"              => "vaalpens",
  "vaalpensen"            => "vaalpens",
  "vacua"                 => "vacuum",
  "vacuums"               => "vacuum",
  "vagi"                  => "vagus",
  "vaginae"               => "vagina",
  "vaginas"               => "vagina",
  "vaginulae"             => "vaginula",
  "valleculae"            => "vallecula",
  "valute"                => "valuta",
  "valuten"               => "valuta",
  "valvulae"              => "valvula",
  "vaporetti"             => "vaporetto",
  "vaporettos"            => "vaporetto",
  "vaqueros"              => "vaquero",
  "varellaes"             => "varella",
  "varely"                => "varella",
  "variae lectiones"      => "varia lectio",
  "varices"               => "varix",
  "vasa"                  => "vas",
  "vascula"               => "vasculum",
  "vasculitides"          => "vasculitis",
  "vasculitises"          => "vasculitis",
  "vasculums"             => "vasculum",
  "vedutas"               => "veduta",
  "vedute"                => "veduta",
  "veg"                   => "veg",
  "veges"                 => "veg",
  "vehicula"              => "vehiculum",
  "vela"                  => "velum",
  "velamina"              => "velamen",
  "velaria"               => "velarium",
  "velums"                => "velum",
  "venae"                 => "vena",
  "veneres"               => "venus",
  "venuses"               => "venus",
  "vermicellos"           => "vermicello",
  "vermiculi"             => "vermiculus",
  "Vermontese"            => "Vermontese",
  "Veronese"              => "Veronese",
  "verrucae"              => "verruca",
  "vers libres"           => "vers libre",
  "versiculi"             => "versiculus",
  "versos"                => "verso",
  "vertebrae"             => "vertebra",
  "vertexes"              => "vertex",
  "vertices"              => "vertex",
  "verticilli"            => "verticillus",
  "vesiculae"             => "vesicula",
  "vestigia"              => "vestigium",
  "vetturini"             => "vetturino",
  "viali"                 => "viale",
  "viatica"               => "viaticum",
  "vibices"               => "vibex",
  "vibracula"             => "vibraculum",
  "vibratos"              => "vibrato",
  "vibriones"             => "vibrio",
  "vibrios"               => "vibrio",
  "Viennese"              => "Viennese",
  "Vietnamese"            => "Vietnamese",
  "vilas"                 => "vila",
  "vile"                  => "vila",
  "villanelle"            => "villanella",
  "villi"                 => "villus",
  "villini"               => "villino",
  "vincula"               => "vinculum",
  "violette"              => "violetta",
  "violoncellos"          => "violoncello",
  "vires"                 => "vis",
  "virgae"                => "virga",
  "Virgos"                => "Virgo",
  "viri"                  => "virus",
  "virii"                 => "virus",
  "virtuosi"              => "virtuoso",
  "virtuosos"             => "virtuoso",
  "viruses"               => "virus",
  "viscera"               => "viscus",
  "vitellaria"            => "vitellarium",
  "vittae"                => "vitta",
  "vivaria"               => "vivarium",
  "vivariums"             => "vivarium",
  "vlakten"               => "vlakte",
  "vlaktes"               => "vlakte",
  "voeux"                 => "voeu",
  "volcanelli"            => "volcanello",
  "volcanoes"             => "volcano",
  "volcanos"              => "volcano",
  "vomicae"               => "vomica",
  "vomicas"               => "vomica",
  "vomitoria"             => "vomitorium",
  "vomitoriums"           => "vomitorium",
  "voorbokke"             => "voorbok",
  "vorspiele"             => "vorspiel",
  "vorstellungen"         => "vorstellung",
  "vortexes"              => "vortex",
  "vortices"              => "vortex",
  "wadies"                => "wadi",
  "wadis"                 => "wadi",
  "wadys"                 => "wady",
  "waldoes"               => "waldo",
  "waldos"                => "waldo",
  "waltzes"               => "waltz",
  "wanderjahre"           => "wanderjahr",
  "wandervogel"           => "wandervogel",
  "washers up"            => "washer up",
  "washers-up"            => "washer-up",
  "we"                    => "I",
  "weirdos"               => "weirdo",
  "Wenchowese"            => "Wenchowese",
  "wharfs"                => "wharf",
  "wharves"               => "wharf",
  "what"                  => "what",
  "whatever"              => "whatever",
  "whatsoever"            => "whatsoever",
  "white staves"          => "white staff",
  "whiting"               => "whiting",
  "Whitmanese"            => "Whitmanese",
  "who"                   => "who",
  "whoever"               => "whoever",
  "whom"                  => "whom",
  "whomever"              => "whomever",
  "whomsoever"            => "whomsoever",
  "whose"                 => "whose",
  "whosesoever"           => "whosesoever",
  "whosever"              => "whosever",
  "whosoever"             => "whosoever",
  "wildebeest"            => "wildebeest",
  "wildebeests"           => "wildebeest",
  "wives"                 => "wife",
  "wolves"                => "wolf",
  "women children"        => "woman child",
  "women servants"        => "woman servant",
  "women-children"        => "woman-child",
  "women-servants"        => "woman-servant",
  "womenchildren"         => "womanchild",
  "wreaths"               => "wreath",
  "xanthomas"             => "xanthoma",
  "xanthomata"            => "xanthoma",
  "xiphiplastra"          => "xiphiplastron",
  "xiphopagi"             => "xiphopagus",
  "xiphoplastra"          => "xiphoplastron",
  "xoana"                 => "xoanon",
  "xysti"                 => "xystus",
  "Yakimans"              => "Yakiman",
  "Yamoussoukros"         => "Yamoussoukro",
  "yarramans"             => "yarraman",
  "yarramen"              => "yarraman",
  "Yengeese"              => "Yengeese",
  "yeses"                 => "yes",
  "yo yos"                => "yo yo",
  "yo-yos"                => "yo-yo",
  "yoes"                  => "yo",
  "Yokohamans"            => "Yokohaman",
  "you"                   => "you",
  "yours"                 => "yours",
  "yourselves"            => "yourself",
  "Yumans"                => "Yuman",
  "Yunnanese"             => "Yunnanese",
  "yuon"                  => "yuo",
  "zadrugas"              => "zadruga",
  "zadruge"               => "zadruga",
  "zeitgebers"            => "zeitgeber",
  "zemirot"               => "zemirah",
  "zemiroth"              => "zemirah",
  "zeppoli"               => "zeppole",
  "zeros"                 => "zero",
  "Zibos"                 => "Zibo",
  "zingani"               => "zingano",
  "zite"                  => "zita",
  "zitelle"               => "zitella",
  "ziti"                  => "zita",
  "zizzes"                => "zizz",
  "zloty"                 => "zloty",
  "zlotys"                => "zloty",
  "zoa"                   => "zoon",
  "zoaeae"                => "zoaea",
  "zoaria"                => "zoarium",
  "zoeae"                 => "zoea",
  "zoeas"                 => "zoea",
  "zooeae"                => "zooea",
  "zooecia"               => "zooecium",
  "zoophori"              => "zoophorus",
  "zoosporangia"          => "zoosporangium",
  "zophori"               => "zophorus",
  "zucche"                => "zucca",
  "zucchini"              => "zucchini",
  "zucchinis"             => "zucchini",
  "zuppe"                 => "zuppa",
  "zuzim"                 => "zuz",
  "zuzzes"                => "zuz",
  "zyga"                  => "zygon",
  "zygantra"              => "zygantrum",
  "zygomas"               => "zygoma",
  "zygomata"              => "zygoma",
};

my $is_plural = {}; @{$is_plural}{values %{$modern_plural_of} } = ();
                    @{$is_plural}{values %{$classical_plural_of} } = ();
                    @{$is_plural}{keys %{$singular_of} } = ();

my $is_singular = {}; @{$is_singular}{values %{$singular_of} } = ();
                      @{$is_singular}{keys %{$modern_plural_of} } = ();
                      @{$is_singular}{keys %{$classical_plural_of} } = ();

my $PREP_PAT = qr{ about | above | across | after | among | around | athwart | at | before |
    behind | below | beneath | besides? | between | betwixt | beyond | but | by | during | except |
    for | from | into | in | near | off | of | onto | on | out | over | since | till | to | under | until | unto | upon | with }xms;

sub prep_pat { $PREP_PAT }

sub tc {my($text)=@_; $text=~s{(\A|\s)(\S)|(\S)}{defined($3)?lc($3):$1.uc($2)}egxms; $text; };
sub convert_to_modern_plural {
    my ($word) = @_;
    return $modern_plural_of->{$word}     if exists $modern_plural_of->{$word};
    return $modern_plural_of->{lc $word}  if exists $modern_plural_of->{lc $word};
    return $modern_plural_of->{tc $word}  if exists $modern_plural_of->{tc $word};
    return $word                     if is_plural($word) && !is_singular($word);
    for ($word) {
        if (m{\A.*'s?$}i) { return "${\(Lingua::EN::Inflexion::adj($word)->plural)}"; }
        if (m{\A(.*?)-general$}i) { return "${is_singular($1) ? \convert_to_modern_plural($1) : \$1}-general"; }
        if (m{\A(.*?) general$}i) { return "${is_singular($1) ? \convert_to_modern_plural($1) : \$1} general"; }
        if (m{\A($PREP_PAT) it$}i) { return "$1 them"; }
        if (m{\Ason-of-a-(.*?)$}i) { return "sons-of-${is_singular($1) ? \convert_to_modern_plural($1) : \$1}"; }
        if (m{\Ason of a (.*?)$}i) { return "sons of ${is_singular($1) ? \convert_to_modern_plural($1) : \$1}"; }
        if (m{\A(.*?)-($PREP_PAT)-(.*?)$}i) { return "${is_singular($1) ? \convert_to_modern_plural($1) : \$1}-$2-$3"; }
        if (m{\A(.*?) ($PREP_PAT) (.*?)$}i) { return "${is_singular($1) ? \convert_to_modern_plural($1) : \$1} $2 $3"; }
        if (m{\A($PREP_PAT)-(.*?)$}i) { return "$1-${is_singular($2) ? \convert_to_modern_plural($2) : \$2}"; }
        if (m{\A($PREP_PAT) (.*?)$}i) { return "$1 ${is_singular($2) ? \convert_to_modern_plural($2) : \$2}"; }
        if (m{\A(.*?)-errant$}i) { return "${is_singular($1) ? \convert_to_modern_plural($1) : \$1}-errant"; }
        if (m{\A(.*?) errant$}i) { return "${is_singular($1) ? \convert_to_modern_plural($1) : \$1} errant"; }
        if (m{\A(.*?)-($PREP_PAT)$}i) { return "${is_singular($1) ? \convert_to_modern_plural($1) : \$1}-$2"; }
        if (m{\A(.*?) ($PREP_PAT)$}i) { return "${is_singular($1) ? \convert_to_modern_plural($1) : \$1} $2"; }
        if (m{\A(.*)stave$}i) { return "${1}staves"; }
        if (m{\A(.*)staff$}i) { return "${1}staffs"; }
        if (m{\A(.*)genus$}i) { return "${1}genera"; }
        if (m{\A(.*)person$}i) { return "${1}people"; }
        if (m{\A(.*)hertz$}i) { return "${1}hertz"; }
        if (m{\A(.*)lux$}i) { return "${1}lux"; }
        if (m{\A(.*)siemens$}i) { return "${1}siemens"; }
        if (m{\A(.*)brother$}i) { return "${1}brothers"; }
        if (m{\A(.*)child$}i) { return "${1}children"; }
        if (m{\A(.*)cow$}i) { return "${1}cows"; }
        if (m{\A(.+)-ox$}i) { return "${1}-oxen"; }
        if (m{\A(.*)mensch$}i) { return "${1}menschen"; }
        if (m{\A(.*)elf$}i) { return "${1}elves"; }
        if (m{\A(.*)hoof$}i) { return "${1}hoofs"; }
        if (m{\A(.*)knife$}i) { return "${1}knives"; }
        if (m{\A(.*)leaf$}i) { return "${1}leaves"; }
        if (m{\A(.*)life$}i) { return "${1}lives"; }
        if (m{\A(.*)loaf$}i) { return "${1}loaves"; }
        if (m{\A(.*)shelf$}i) { return "${1}shelves"; }
        if (m{\A(.*)thief$}i) { return "${1}thieves"; }
        if (m{\A(.*)wife$}i) { return "${1}wives"; }
        if (m{\A(.*)wolf$}i) { return "${1}wolves"; }
        if (m{\A(.*)human$}i) { return "${1}humans"; }
        if (m{\A(.*)foot$}i) { return "${1}feet"; }
        if (m{\A(.*)goose$}i) { return "${1}geese"; }
        if (m{\A(.*)louse$}i) { return "${1}lice"; }
        if (m{\A(.*)man$}i) { return "${1}men"; }
        if (m{\A(.*)mouse$}i) { return "${1}mice"; }
        if (m{\A(.*)tooth$}i) { return "${1}teeth"; }
        if (m{\A(.*)buzz$}i) { return "${1}buzzes"; }
        if (m{\A(.*)fizz$}i) { return "${1}fizzes"; }
        if (m{\A(.*)frizz$}i) { return "${1}frizzes"; }
        if (m{\A(.*)fuzz$}i) { return "${1}fuzzes"; }
        if (m{\A(.*)jazz$}i) { return "${1}jazzes"; }
        if (m{\A(.*)proboscis$}i) { return "${1}proboscises"; }
        if (m{\A(.*)bema$}i) { return "${1}bemas"; }
        if (m{\A(.*)drama$}i) { return "${1}dramas"; }
        if (m{\A(.*)edema$}i) { return "${1}edemas"; }
        if (m{\A(.*)lemma$}i) { return "${1}lemmas"; }
        if (m{\A(.*)sarcoma$}i) { return "${1}sarcomas"; }
        if (m{\A(.*)stoma$}i) { return "${1}stomas"; }
        if (m{\A(.*)nova$}i) { return "${1}novas"; }
        if (m{\A(.*)umbra$}i) { return "${1}umbras"; }
        if (m{\A(.*)lumen$}i) { return "${1}lumens"; }
        if (m{\A(.*)datum$}i) { return "${1}data"; }
        if (m{\A(.*)stratum$}i) { return "${1}stratums"; }
        if (m{\A(.*)bacillus$}i) { return "${1}bacilli"; }
        if (m{\A(.*)nucleus$}i) { return "${1}nuclei"; }
        if (m{\A(.*)hedron$}i) { return "${1}hedrons"; }
        if (m{\A(.*)helion$}i) { return "${1}helions"; }
        if (m{\A(.*)legomenon$}i) { return "${1}legomena"; }
        if (m{\A(.*)phenomenon$}i) { return "${1}phenomena"; }
        if (m{\A(.*)helix$}i) { return "${1}helices"; }
        if (m{\A(.*)measles$}i) { return "${1}measles"; }
        if (m{\A(.*)pox$}i) { return "${1}pox"; }
        if (m{\A(.*)bass$}i) { return "${1}basses"; }
        if (m{\A(.*)deer$}i) { return "${1}deer"; }
        if (m{\A(.*)fish$}i) { return "${1}fish"; }
        if (m{\A(.*)fowl$}i) { return "${1}fowls"; }
        if (m{\A(.*)sheep$}i) { return "${1}sheep"; }
        if (m{\A(.*)wildebeest$}i) { return "${1}wildebeests"; }
        if (m{\A(.*)craft$}i) { return "${1}craft"; }
        if (m{\A(.*)gas$}i) { return "${1}gases"; }
        if (m{\A(.*)glottis$}i) { return "${1}glottises"; }
        if (m{\A(.+[aeiou])o$}i) { return "${1}os"; }
        if (m{\A(.+[aeo])lf$}i) { return "${1}lves"; }
        if (m{\A(.+[aiy])nx$}i) { return "${1}nxes"; }
        if (m{\A(.+)arf$}i) { return "${1}arves"; }
        if (m{\A(.+)ceps$}i) { return "${1}ceps"; }
        if (m{\A(.+[cs])h$}i) { return "${1}hes"; }
        if (m{\A(.+)eaf$}i) { return "${1}eaves"; }
        if (m{\A(.+)eau$}i) { return "${1}eaus"; }
        if (m{\A(.+)ieu$}i) { return "${1}ieus"; }
        if (m{\A(.+)nife$}i) { return "${1}nives"; }
        if (m{\A(.+)oe$}i) { return "${1}oes"; }
        if (m{\A(.+)o$}i) { return "${1}oes"; }
        if (m{\A(.+)quy$}i) { return "${1}quies"; }
        if (m{\A(.+[aeiou])y$}i) { return "${1}ys"; }
        if (m{\A(.+)ss$}i) { return "${1}sses"; }
        if (m{\A(.+)orse$}i) { return "${1}orses"; }
        if (m{\A(.+[au])orse$}i) { return "${1}orses"; }
        if (m{\A(.+)nse$}i) { return "${1}nses"; }
        if (m{\A(.+[^ns])sis$}i) { return "${1}ses"; }
        if (m{\A(.+)trix$}i) { return "${1}trixes"; }
        if (m{\A(.+)us$}i) { return "${1}uses"; }
        if (m{\A(.+)x$}i) { return "${1}xes"; }
        if (m{\A(.+)y$}i) { return "${1}ies"; }
        if (m{\A(.+)z$}i) { return "${1}zzes"; }
        if (m{\A(.+)zoon$}i) { return "${1}zoa"; }
        if (m{\A(.+)s$}i) { return "${1}ses"; }
        if (m{\A(.+)$}i) { return "${1}s"; }
        default { return $_; }
    }
}

sub convert_to_classical_plural {
    my ($word) = @_;
    return $classical_plural_of->{$word}     if exists $classical_plural_of->{$word};
    return $classical_plural_of->{lc $word}  if exists $classical_plural_of->{lc $word};
    return $classical_plural_of->{tc $word}  if exists $classical_plural_of->{tc $word};
    return $word                     if is_plural($word) && !is_singular($word);
    for ($word) {
        if (m{\A.*'s?$}i) { return "${\(Lingua::EN::Inflexion::adj($word)->classical->plural)}"; }
        if (m{\A(.*?)-general$}i) { return "${is_singular($1) ? \convert_to_classical_plural($1) : \$1}-general"; }
        if (m{\A(.*?) general$}i) { return "${is_singular($1) ? \convert_to_classical_plural($1) : \$1} general"; }
        if (m{\A($PREP_PAT) it$}i) { return "$1 them"; }
        if (m{\Ason-of-a-(.*?)$}i) { return "sons-of-${is_singular($1) ? \convert_to_classical_plural($1) : \$1}"; }
        if (m{\Ason of a (.*?)$}i) { return "sons of ${is_singular($1) ? \convert_to_classical_plural($1) : \$1}"; }
        if (m{\A(.*?)-($PREP_PAT)-(.*?)$}i) { return "${is_singular($1) ? \convert_to_classical_plural($1) : \$1}-$2-$3"; }
        if (m{\A(.*?) ($PREP_PAT) (.*?)$}i) { return "${is_singular($1) ? \convert_to_classical_plural($1) : \$1} $2 $3"; }
        if (m{\A($PREP_PAT)-(.*?)$}i) { return "$1-${is_singular($2) ? \convert_to_classical_plural($2) : \$2}"; }
        if (m{\A($PREP_PAT) (.*?)$}i) { return "$1 ${is_singular($2) ? \convert_to_classical_plural($2) : \$2}"; }
        if (m{\A(.*?)-errant$}i) { return "${is_singular($1) ? \convert_to_classical_plural($1) : \$1}-errant"; }
        if (m{\A(.*?) errant$}i) { return "${is_singular($1) ? \convert_to_classical_plural($1) : \$1} errant"; }
        if (m{\A(.*?)-($PREP_PAT)$}i) { return "${is_singular($1) ? \convert_to_classical_plural($1) : \$1}-$2"; }
        if (m{\A(.*?) ($PREP_PAT)$}i) { return "${is_singular($1) ? \convert_to_classical_plural($1) : \$1} $2"; }
        if (m{\A(.*)stave$}i) { return "${1}staves"; }
        if (m{\A(.*)staff$}i) { return "${1}staves"; }
        if (m{\A(.*)genus$}i) { return "${1}genera"; }
        if (m{\A(.*)person$}i) { return "${1}persons"; }
        if (m{\A(.*)hertz$}i) { return "${1}hertz"; }
        if (m{\A(.*)lux$}i) { return "${1}lux"; }
        if (m{\A(.*)siemens$}i) { return "${1}siemens"; }
        if (m{\A(.*)brother$}i) { return "${1}brethren"; }
        if (m{\A(.*)child$}i) { return "${1}children"; }
        if (m{\A(.*)cow$}i) { return "${1}kine"; }
        if (m{\A(.+)-ox$}i) { return "${1}-oxen"; }
        if (m{\A(.*)mensch$}i) { return "${1}menschen"; }
        if (m{\A(.*)elf$}i) { return "${1}elves"; }
        if (m{\A(.*)hoof$}i) { return "${1}hooves"; }
        if (m{\A(.*)knife$}i) { return "${1}knives"; }
        if (m{\A(.*)leaf$}i) { return "${1}leaves"; }
        if (m{\A(.*)life$}i) { return "${1}lives"; }
        if (m{\A(.*)loaf$}i) { return "${1}loaves"; }
        if (m{\A(.*)shelf$}i) { return "${1}shelves"; }
        if (m{\A(.*)thief$}i) { return "${1}thieves"; }
        if (m{\A(.*)wife$}i) { return "${1}wives"; }
        if (m{\A(.*)wolf$}i) { return "${1}wolves"; }
        if (m{\A(.*)human$}i) { return "${1}humans"; }
        if (m{\A(.*)foot$}i) { return "${1}feet"; }
        if (m{\A(.*)goose$}i) { return "${1}geese"; }
        if (m{\A(.*)louse$}i) { return "${1}lice"; }
        if (m{\A(.*)man$}i) { return "${1}men"; }
        if (m{\A(.*)mouse$}i) { return "${1}mice"; }
        if (m{\A(.*)tooth$}i) { return "${1}teeth"; }
        if (m{\A(.*)buzz$}i) { return "${1}buzzes"; }
        if (m{\A(.*)fizz$}i) { return "${1}fizzes"; }
        if (m{\A(.*)frizz$}i) { return "${1}frizzes"; }
        if (m{\A(.*)fuzz$}i) { return "${1}fuzzes"; }
        if (m{\A(.*)jazz$}i) { return "${1}jazzes"; }
        if (m{\A(.*)proboscis$}i) { return "${1}proboscides"; }
        if (m{\A(.*)bema$}i) { return "${1}bemata"; }
        if (m{\A(.*)drama$}i) { return "${1}dramas"; }
        if (m{\A(.*)edema$}i) { return "${1}edemata"; }
        if (m{\A(.*)lemma$}i) { return "${1}lemmata"; }
        if (m{\A(.*)sarcoma$}i) { return "${1}sarcomata"; }
        if (m{\A(.*)stoma$}i) { return "${1}stomata"; }
        if (m{\A(.*)nova$}i) { return "${1}novae"; }
        if (m{\A(.*)umbra$}i) { return "${1}umbrae"; }
        if (m{\A(.*)lumen$}i) { return "${1}lumina"; }
        if (m{\A(.*)datum$}i) { return "${1}data"; }
        if (m{\A(.*)stratum$}i) { return "${1}strata"; }
        if (m{\A(.*)bacillus$}i) { return "${1}bacilli"; }
        if (m{\A(.*)nucleus$}i) { return "${1}nuclei"; }
        if (m{\A(.*)hedron$}i) { return "${1}hedra"; }
        if (m{\A(.*)helion$}i) { return "${1}helia"; }
        if (m{\A(.*)legomenon$}i) { return "${1}legomena"; }
        if (m{\A(.*)phenomenon$}i) { return "${1}phenomena"; }
        if (m{\A(.*)helix$}i) { return "${1}helices"; }
        if (m{\A(.*)measles$}i) { return "${1}measles"; }
        if (m{\A(.*)pox$}i) { return "${1}pox"; }
        if (m{\A(.*)bass$}i) { return "${1}bass"; }
        if (m{\A(.*)deer$}i) { return "${1}deer"; }
        if (m{\A(.*)fish$}i) { return "${1}fish"; }
        if (m{\A(.*)fowl$}i) { return "${1}fowl"; }
        if (m{\A(.*)sheep$}i) { return "${1}sheep"; }
        if (m{\A(.*)wildebeest$}i) { return "${1}wildebeest"; }
        if (m{\A(.*)craft$}i) { return "${1}craft"; }
        if (m{\A(.*)gas$}i) { return "${1}gases"; }
        if (m{\A(.*)glottis$}i) { return "${1}glottises"; }
        if (m{\A(.+[aeiou])o$}i) { return "${1}os"; }
        if (m{\A(.+[aeo])lf$}i) { return "${1}lves"; }
        if (m{\A(.+[aiy])nx$}i) { return "${1}nges"; }
        if (m{\A(.+)arf$}i) { return "${1}arves"; }
        if (m{\A(.+)ceps$}i) { return "${1}ceps"; }
        if (m{\A(.+[cs])h$}i) { return "${1}hes"; }
        if (m{\A(.+)eaf$}i) { return "${1}eaves"; }
        if (m{\A(.+)eau$}i) { return "${1}eaux"; }
        if (m{\A(.+)ieu$}i) { return "${1}ieux"; }
        if (m{\A(.+)nife$}i) { return "${1}nives"; }
        if (m{\A(.+)oe$}i) { return "${1}oes"; }
        if (m{\A(.+)o$}i) { return "${1}oes"; }
        if (m{\A(.+)quy$}i) { return "${1}quies"; }
        if (m{\A(.+[aeiou])y$}i) { return "${1}ys"; }
        if (m{\A(.+)ss$}i) { return "${1}sses"; }
        if (m{\A(.+)orse$}i) { return "${1}orses"; }
        if (m{\A(.+[au])orse$}i) { return "${1}orses"; }
        if (m{\A(.+)nse$}i) { return "${1}nses"; }
        if (m{\A(.+[^ns])sis$}i) { return "${1}ses"; }
        if (m{\A(.+)trix$}i) { return "${1}trices"; }
        if (m{\A(.+)us$}i) { return "${1}uses"; }
        if (m{\A(.+)x$}i) { return "${1}xes"; }
        if (m{\A(.+)y$}i) { return "${1}ies"; }
        if (m{\A(.+)z$}i) { return "${1}zzes"; }
        if (m{\A(.+)zoon$}i) { return "${1}zoa"; }
        if (m{\A(.+)s$}i) { return "${1}ses"; }
        if (m{\A(.+)$}i) { return "${1}s"; }
        default { return $_; }
    }
}

sub convert_to_singular {
    my ($word) = @_;
    return $singular_of->{$word}     if exists $singular_of->{$word};
    return $singular_of->{lc $word}  if exists $singular_of->{lc $word};
    return $singular_of->{tc $word}  if exists $singular_of->{tc $word};
    return $word                     if is_singular($word);
    for ($word) {
        if (m{\A.*'s?$}i) { return "${\(Lingua::EN::Inflexion::adj($word)->singular)}"; }
        if (m{\A(.*?)-general$}i) { return "${is_plural($1) ? \convert_to_singular($1) : \$1}-general"; }
        if (m{\A(.*?) general$}i) { return "${is_plural($1) ? \convert_to_singular($1) : \$1} general"; }
        if (m{\A($PREP_PAT) them$}i) { return "$1 it"; }
        if (m{\Asons-of-(.*?)$}i) { return "son-of-a-${is_plural($1) ? \convert_to_singular($1) : \$1}"; }
        if (m{\Asons of (.*?)$}i) { return "son of a ${is_plural($1) ? \convert_to_singular($1) : \$1}"; }
        if (m{\A(.*?)-($PREP_PAT)-(.*?)$}i) { return "${is_plural($1) ? \convert_to_singular($1) : \$1}-$2-$3"; }
        if (m{\A(.*?) ($PREP_PAT) (.*?)$}i) { return "${is_plural($1) ? \convert_to_singular($1) : \$1} $2 $3"; }
        if (m{\A($PREP_PAT)-(.*?)$}i) { return "$1-${is_plural($2) ? \convert_to_singular($2) : \$2}"; }
        if (m{\A($PREP_PAT) (.*?)$}i) { return "$1 ${is_plural($2) ? \convert_to_singular($2) : \$2}"; }
        if (m{\A(.*?)-errant$}i) { return "${is_plural($1) ? \convert_to_singular($1) : \$1}-errant"; }
        if (m{\A(.*?) errant$}i) { return "${is_plural($1) ? \convert_to_singular($1) : \$1} errant"; }
        if (m{\A(.*?)-($PREP_PAT)$}i) { return "${is_plural($1) ? \convert_to_singular($1) : \$1}-$2"; }
        if (m{\A(.*?) ($PREP_PAT)$}i) { return "${is_plural($1) ? \convert_to_singular($1) : \$1} $2"; }
        if (m{\A(.*)staves$}i) { return "${1}stave"; }
        if (m{\A(.*)staffs$}i) { return "${1}staff"; }
        if (m{\A(.*)staves$}i) { return "${1}staff"; }
        if (m{\A(.*)genera$}i) { return "${1}genus"; }
        if (m{\A(.*)people$}i) { return "${1}person"; }
        if (m{\A(.*)persons$}i) { return "${1}person"; }
        if (m{\A(.*)hertz$}i) { return "${1}hertz"; }
        if (m{\A(.*)lux$}i) { return "${1}lux"; }
        if (m{\A(.*)siemens$}i) { return "${1}siemens"; }
        if (m{\A(.*)brothers$}i) { return "${1}brother"; }
        if (m{\A(.*)brethren$}i) { return "${1}brother"; }
        if (m{\A(.*)children$}i) { return "${1}child"; }
        if (m{\A(.*)cows$}i) { return "${1}cow"; }
        if (m{\A(.*)kine$}i) { return "${1}cow"; }
        if (m{\A(.+)-oxen$}i) { return "${1}-ox"; }
        if (m{\A(.*)menschen$}i) { return "${1}mensch"; }
        if (m{\A(.*)elves$}i) { return "${1}elf"; }
        if (m{\A(.*)hoofs$}i) { return "${1}hoof"; }
        if (m{\A(.*)hooves$}i) { return "${1}hoof"; }
        if (m{\A(.*)knives$}i) { return "${1}knife"; }
        if (m{\A(.*)leaves$}i) { return "${1}leaf"; }
        if (m{\A(.*)lives$}i) { return "${1}life"; }
        if (m{\A(.*)loaves$}i) { return "${1}loaf"; }
        if (m{\A(.*)shelves$}i) { return "${1}shelf"; }
        if (m{\A(.*)thieves$}i) { return "${1}thief"; }
        if (m{\A(.*)wives$}i) { return "${1}wife"; }
        if (m{\A(.*)wolves$}i) { return "${1}wolf"; }
        if (m{\A(.*)humans$}i) { return "${1}human"; }
        if (m{\A(.*)feet$}i) { return "${1}foot"; }
        if (m{\A(.*)geese$}i) { return "${1}goose"; }
        if (m{\A(.*)lice$}i) { return "${1}louse"; }
        if (m{\A(.*)men$}i) { return "${1}man"; }
        if (m{\A(.*)mice$}i) { return "${1}mouse"; }
        if (m{\A(.*)teeth$}i) { return "${1}tooth"; }
        if (m{\A(.*)buzzes$}i) { return "${1}buzz"; }
        if (m{\A(.*)fizzes$}i) { return "${1}fizz"; }
        if (m{\A(.*)frizzes$}i) { return "${1}frizz"; }
        if (m{\A(.*)fuzzes$}i) { return "${1}fuzz"; }
        if (m{\A(.*)jazzes$}i) { return "${1}jazz"; }
        if (m{\A(.*)proboscises$}i) { return "${1}proboscis"; }
        if (m{\A(.*)proboscides$}i) { return "${1}proboscis"; }
        if (m{\A(.*)bemas$}i) { return "${1}bema"; }
        if (m{\A(.*)bemata$}i) { return "${1}bema"; }
        if (m{\A(.*)dramas$}i) { return "${1}drama"; }
        if (m{\A(.*)edemas$}i) { return "${1}edema"; }
        if (m{\A(.*)edemata$}i) { return "${1}edema"; }
        if (m{\A(.*)lemmas$}i) { return "${1}lemma"; }
        if (m{\A(.*)lemmata$}i) { return "${1}lemma"; }
        if (m{\A(.*)sarcomas$}i) { return "${1}sarcoma"; }
        if (m{\A(.*)sarcomata$}i) { return "${1}sarcoma"; }
        if (m{\A(.*)stomas$}i) { return "${1}stoma"; }
        if (m{\A(.*)stomata$}i) { return "${1}stoma"; }
        if (m{\A(.*)novas$}i) { return "${1}nova"; }
        if (m{\A(.*)novae$}i) { return "${1}nova"; }
        if (m{\A(.*)umbras$}i) { return "${1}umbra"; }
        if (m{\A(.*)umbrae$}i) { return "${1}umbra"; }
        if (m{\A(.*)lumens$}i) { return "${1}lumen"; }
        if (m{\A(.*)lumina$}i) { return "${1}lumen"; }
        if (m{\A(.*)data$}i) { return "${1}datum"; }
        if (m{\A(.*)stratums$}i) { return "${1}stratum"; }
        if (m{\A(.*)strata$}i) { return "${1}stratum"; }
        if (m{\A(.*)bacilli$}i) { return "${1}bacillus"; }
        if (m{\A(.*)nuclei$}i) { return "${1}nucleus"; }
        if (m{\A(.*)hedrons$}i) { return "${1}hedron"; }
        if (m{\A(.*)hedra$}i) { return "${1}hedron"; }
        if (m{\A(.*)helions$}i) { return "${1}helion"; }
        if (m{\A(.*)helia$}i) { return "${1}helion"; }
        if (m{\A(.*)legomena$}i) { return "${1}legomenon"; }
        if (m{\A(.*)phenomena$}i) { return "${1}phenomenon"; }
        if (m{\A(.*)helices$}i) { return "${1}helix"; }
        if (m{\A(.*)measles$}i) { return "${1}measles"; }
        if (m{\A(.*)pox$}i) { return "${1}pox"; }
        if (m{\A(.*)basses$}i) { return "${1}bass"; }
        if (m{\A(.*)bass$}i) { return "${1}bass"; }
        if (m{\A(.*)deer$}i) { return "${1}deer"; }
        if (m{\A(.*)fish$}i) { return "${1}fish"; }
        if (m{\A(.*)fowls$}i) { return "${1}fowl"; }
        if (m{\A(.*)fowl$}i) { return "${1}fowl"; }
        if (m{\A(.*)sheep$}i) { return "${1}sheep"; }
        if (m{\A(.*)wildebeests$}i) { return "${1}wildebeest"; }
        if (m{\A(.*)wildebeest$}i) { return "${1}wildebeest"; }
        if (m{\A(.*)craft$}i) { return "${1}craft"; }
        if (m{\A(.*)gases$}i) { return "${1}gas"; }
        if (m{\A(.*)glottises$}i) { return "${1}glottis"; }
        if (m{\A(.+[aeiou])os$}i) { return "${1}o"; }
        if (m{\A(.+[aeo])lves$}i) { return "${1}lf"; }
        if (m{\A(.+[aiy])nxes$}i) { return "${1}nx"; }
        if (m{\A(.+[aiy])nges$}i) { return "${1}nx"; }
        if (m{\A(.+)arves$}i) { return "${1}arf"; }
        if (m{\A(.+)ceps$}i) { return "${1}ceps"; }
        if (m{\A(.+[cs])hes$}i) { return "${1}h"; }
        if (m{\A(.+)eaves$}i) { return "${1}eaf"; }
        if (m{\A(.+)eaus$}i) { return "${1}eau"; }
        if (m{\A(.+)eaux$}i) { return "${1}eau"; }
        if (m{\A(.+)ieus$}i) { return "${1}ieu"; }
        if (m{\A(.+)ieux$}i) { return "${1}ieu"; }
        if (m{\A(.+)nives$}i) { return "${1}nife"; }
        if (m{\A(.+)oes$}i) { return "${1}oe"; }
        if (m{\A(.+)oes$}i) { return "${1}o"; }
        if (m{\A(.+)quies$}i) { return "${1}quy"; }
        if (m{\A(.+[aeiou])ys$}i) { return "${1}y"; }
        if (m{\A(.+)sses$}i) { return "${1}ss"; }
        if (m{\A(.+)orses$}i) { return "${1}orse"; }
        if (m{\A(.+[au])orses$}i) { return "${1}orse"; }
        if (m{\A(.+)nses$}i) { return "${1}nse"; }
        if (m{\A(.+[^ns])ses$}i) { return "${1}sis"; }
        if (m{\A(.+)trixes$}i) { return "${1}trix"; }
        if (m{\A(.+)trices$}i) { return "${1}trix"; }
        if (m{\A(.+)uses$}i) { return "${1}us"; }
        if (m{\A(.+)xes$}i) { return "${1}x"; }
        if (m{\A(.+)ies$}i) { return "${1}y"; }
        if (m{\A(.+)zzes$}i) { return "${1}z"; }
        if (m{\A(.+)zoa$}i) { return "${1}zoon"; }
        if (m{\A(.+)ses$}i) { return "${1}s"; }
        if (m{\A(.+)s$}i) { return "${1}"; }
        default { return $_; }
    }
}

sub is_plural {
    my ($word) = @_;
    return 1 if exists $is_plural->{$word};
    return 1 if exists $is_plural->{lc $word};
    return 1 if exists $is_plural->{tc $word};
    return 0 if exists $is_singular->{$word};
    return 0 if exists $is_singular->{lc $word};
    return 0 if exists $is_singular->{tc $word};
    for ($word) {
        if (m{'$})  { return 1 }
        if (m{'s$}) { return is_plural(substr($word,0,-2)) }
        if (m{\A.*'s?$}i) { return 1 }
        if (m{\A(.*?)-general$}i) { return is_plural($1);return 1 }
        if (m{\A(.*?) general$}i) { return is_plural($1);return 1 }
        if (m{\A($PREP_PAT) them$}i) { return 1 }
        if (m{\Asons-of-(.*?)$}i) { return is_plural($1);return 1 }
        if (m{\Asons of (.*?)$}i) { return is_plural($1);return 1 }
        if (m{\A(.*?)-($PREP_PAT)-(.*?)$}i) { return is_plural($1);return 1 }
        if (m{\A(.*?) ($PREP_PAT) (.*?)$}i) { return is_plural($1);return 1 }
        if (m{\A($PREP_PAT)-(.*?)$}i) { return is_plural($2);return 1 }
        if (m{\A($PREP_PAT) (.*?)$}i) { return is_plural($2);return 1 }
        if (m{\A(.*?)-errant$}i) { return is_plural($1);return 1 }
        if (m{\A(.*?) errant$}i) { return is_plural($1);return 1 }
        if (m{\A(.*?)-($PREP_PAT)$}i) { return is_plural($1);return 1 }
        if (m{\A(.*?) ($PREP_PAT)$}i) { return is_plural($1);return 1 }
        if (m{\A(.*)staves$}i) { return 1 }
        if (m{\A(.*)staffs$}i) { return 1 }
        if (m{\A(.*)genera$}i) { return 1 }
        if (m{\A(.*)people$}i) { return 1 }
        if (m{\A(.*)persons$}i) { return 1 }
        if (m{\A(.*)hertz$}i) { return 1 }
        if (m{\A(.*)lux$}i) { return 1 }
        if (m{\A(.*)siemens$}i) { return 1 }
        if (m{\A(.*)brothers$}i) { return 1 }
        if (m{\A(.*)brethren$}i) { return 1 }
        if (m{\A(.*)children$}i) { return 1 }
        if (m{\A(.*)cows$}i) { return 1 }
        if (m{\A(.*)kine$}i) { return 1 }
        if (m{\A(.+)-oxen$}i) { return 1 }
        if (m{\A(.*)menschen$}i) { return 1 }
        if (m{\A(.*)elves$}i) { return 1 }
        if (m{\A(.*)hoofs$}i) { return 1 }
        if (m{\A(.*)hooves$}i) { return 1 }
        if (m{\A(.*)knives$}i) { return 1 }
        if (m{\A(.*)leaves$}i) { return 1 }
        if (m{\A(.*)lives$}i) { return 1 }
        if (m{\A(.*)loaves$}i) { return 1 }
        if (m{\A(.*)shelves$}i) { return 1 }
        if (m{\A(.*)thieves$}i) { return 1 }
        if (m{\A(.*)wives$}i) { return 1 }
        if (m{\A(.*)wolves$}i) { return 1 }
        if (m{\A(.*)humans$}i) { return 1 }
        if (m{\A(.*)feet$}i) { return 1 }
        if (m{\A(.*)geese$}i) { return 1 }
        if (m{\A(.*)lice$}i) { return 1 }
        if (m{\A(.*)men$}i) { return 1 }
        if (m{\A(.*)mice$}i) { return 1 }
        if (m{\A(.*)teeth$}i) { return 1 }
        if (m{\A(.*)buzzes$}i) { return 1 }
        if (m{\A(.*)fizzes$}i) { return 1 }
        if (m{\A(.*)frizzes$}i) { return 1 }
        if (m{\A(.*)fuzzes$}i) { return 1 }
        if (m{\A(.*)jazzes$}i) { return 1 }
        if (m{\A(.*)proboscises$}i) { return 1 }
        if (m{\A(.*)proboscides$}i) { return 1 }
        if (m{\A(.*)bemas$}i) { return 1 }
        if (m{\A(.*)bemata$}i) { return 1 }
        if (m{\A(.*)dramas$}i) { return 1 }
        if (m{\A(.*)edemas$}i) { return 1 }
        if (m{\A(.*)edemata$}i) { return 1 }
        if (m{\A(.*)lemmas$}i) { return 1 }
        if (m{\A(.*)lemmata$}i) { return 1 }
        if (m{\A(.*)sarcomas$}i) { return 1 }
        if (m{\A(.*)sarcomata$}i) { return 1 }
        if (m{\A(.*)stomas$}i) { return 1 }
        if (m{\A(.*)stomata$}i) { return 1 }
        if (m{\A(.*)novas$}i) { return 1 }
        if (m{\A(.*)novae$}i) { return 1 }
        if (m{\A(.*)umbras$}i) { return 1 }
        if (m{\A(.*)umbrae$}i) { return 1 }
        if (m{\A(.*)lumens$}i) { return 1 }
        if (m{\A(.*)lumina$}i) { return 1 }
        if (m{\A(.*)data$}i) { return 1 }
        if (m{\A(.*)stratums$}i) { return 1 }
        if (m{\A(.*)strata$}i) { return 1 }
        if (m{\A(.*)bacilli$}i) { return 1 }
        if (m{\A(.*)nuclei$}i) { return 1 }
        if (m{\A(.*)hedrons$}i) { return 1 }
        if (m{\A(.*)hedra$}i) { return 1 }
        if (m{\A(.*)helions$}i) { return 1 }
        if (m{\A(.*)helia$}i) { return 1 }
        if (m{\A(.*)legomena$}i) { return 1 }
        if (m{\A(.*)phenomena$}i) { return 1 }
        if (m{\A(.*)helices$}i) { return 1 }
        if (m{\A(.*)measles$}i) { return 1 }
        if (m{\A(.*)pox$}i) { return 1 }
        if (m{\A(.*)basses$}i) { return 1 }
        if (m{\A(.*)bass$}i) { return 1 }
        if (m{\A(.*)deer$}i) { return 1 }
        if (m{\A(.*)fish$}i) { return 1 }
        if (m{\A(.*)fowls$}i) { return 1 }
        if (m{\A(.*)fowl$}i) { return 1 }
        if (m{\A(.*)sheep$}i) { return 1 }
        if (m{\A(.*)wildebeests$}i) { return 1 }
        if (m{\A(.*)wildebeest$}i) { return 1 }
        if (m{\A(.*)craft$}i) { return 1 }
        if (m{\A(.*)gases$}i) { return 1 }
        if (m{\A(.*)glottises$}i) { return 1 }
        if (m{\A(.+[aeiou])os$}i) { return 1 }
        if (m{\A(.+[aeo])lves$}i) { return 1 }
        if (m{\A(.+[aiy])nxes$}i) { return 1 }
        if (m{\A(.+[aiy])nges$}i) { return 1 }
        if (m{\A(.+)arves$}i) { return 1 }
        if (m{\A(.+)ceps$}i) { return 1 }
        if (m{\A(.+[cs])hes$}i) { return 1 }
        if (m{\A(.+)eaves$}i) { return 1 }
        if (m{\A(.+)eaus$}i) { return 1 }
        if (m{\A(.+)eaux$}i) { return 1 }
        if (m{\A(.+)ieus$}i) { return 1 }
        if (m{\A(.+)ieux$}i) { return 1 }
        if (m{\A(.+)nives$}i) { return 1 }
        if (m{\A(.+)oes$}i) { return 1 }
        if (m{\A(.+)quies$}i) { return 1 }
        if (m{\A(.+[aeiou])ys$}i) { return 1 }
        if (m{\A(.+)sses$}i) { return 1 }
        if (m{\A(.+)orses$}i) { return 1 }
        if (m{\A(.+[au])orses$}i) { return 1 }
        if (m{\A(.+)nses$}i) { return 1 }
        if (m{\A(.+[^ns])ses$}i) { return 1 }
        if (m{\A(.+)trixes$}i) { return 1 }
        if (m{\A(.+)trices$}i) { return 1 }
        if (m{\A(.+)uses$}i) { return 1 }
        if (m{\A(.+)xes$}i) { return 1 }
        if (m{\A(.+)ies$}i) { return 1 }
        if (m{\A(.+)zzes$}i) { return 1 }
        if (m{\A(.+)zoa$}i) { return 1 }
        default { return $word =~ m{ s \Z }ixms; }
    }
}

sub is_singular {
    my ($word) = @_;
    return 1 if exists $is_singular->{$word};
    return 1 if exists $is_singular->{lc $word};
    return 1 if exists $is_singular->{tc $word};
    return 0 if exists $is_plural->{$word};
    return 0 if exists $is_plural->{lc $word};
    return 0 if exists $is_plural->{tc $word};
    for ($word) {
        if (m{'$})  { return 0 }
        if (m{'s$}) { return is_singular(substr($word,0,-2)) }
        if (m{\A.*'s?$}i) { return 1 }
        if (m{\A(.*?)-general$}i) { return is_singular($1);return 1 }
        if (m{\A(.*?) general$}i) { return is_singular($1);return 1 }
        if (m{\A($PREP_PAT) it$}i) { return 1 }
        if (m{\Ason-of-a-(.*?)$}i) { return is_singular($1);return 1 }
        if (m{\Ason of a (.*?)$}i) { return is_singular($1);return 1 }
        if (m{\A(.*?)-($PREP_PAT)-(.*?)$}i) { return is_singular($1);return 1 }
        if (m{\A(.*?) ($PREP_PAT) (.*?)$}i) { return is_singular($1);return 1 }
        if (m{\A($PREP_PAT)-(.*?)$}i) { return is_singular($2);return 1 }
        if (m{\A($PREP_PAT) (.*?)$}i) { return is_singular($2);return 1 }
        if (m{\A(.*?)-errant$}i) { return is_singular($1);return 1 }
        if (m{\A(.*?) errant$}i) { return is_singular($1);return 1 }
        if (m{\A(.*?)-($PREP_PAT)$}i) { return is_singular($1);return 1 }
        if (m{\A(.*?) ($PREP_PAT)$}i) { return is_singular($1);return 1 }
        if (m{\A(.*)stave$}i) { return 1 }
        if (m{\A(.*)staff$}i) { return 1 }
        if (m{\A(.*)genus$}i) { return 1 }
        if (m{\A(.*)person$}i) { return 1 }
        if (m{\A(.*)hertz$}i) { return 1 }
        if (m{\A(.*)lux$}i) { return 1 }
        if (m{\A(.*)siemens$}i) { return 1 }
        if (m{\A(.*)brother$}i) { return 1 }
        if (m{\A(.*)child$}i) { return 1 }
        if (m{\A(.*)cow$}i) { return 1 }
        if (m{\A(.+)-ox$}i) { return 1 }
        if (m{\A(.*)mensch$}i) { return 1 }
        if (m{\A(.*)elf$}i) { return 1 }
        if (m{\A(.*)hoof$}i) { return 1 }
        if (m{\A(.*)knife$}i) { return 1 }
        if (m{\A(.*)leaf$}i) { return 1 }
        if (m{\A(.*)life$}i) { return 1 }
        if (m{\A(.*)loaf$}i) { return 1 }
        if (m{\A(.*)shelf$}i) { return 1 }
        if (m{\A(.*)thief$}i) { return 1 }
        if (m{\A(.*)wife$}i) { return 1 }
        if (m{\A(.*)wolf$}i) { return 1 }
        if (m{\A(.*)human$}i) { return 1 }
        if (m{\A(.*)foot$}i) { return 1 }
        if (m{\A(.*)goose$}i) { return 1 }
        if (m{\A(.*)louse$}i) { return 1 }
        if (m{\A(.*)man$}i) { return 1 }
        if (m{\A(.*)mouse$}i) { return 1 }
        if (m{\A(.*)tooth$}i) { return 1 }
        if (m{\A(.*)buzz$}i) { return 1 }
        if (m{\A(.*)fizz$}i) { return 1 }
        if (m{\A(.*)frizz$}i) { return 1 }
        if (m{\A(.*)fuzz$}i) { return 1 }
        if (m{\A(.*)jazz$}i) { return 1 }
        if (m{\A(.*)proboscis$}i) { return 1 }
        if (m{\A(.*)bema$}i) { return 1 }
        if (m{\A(.*)drama$}i) { return 1 }
        if (m{\A(.*)edema$}i) { return 1 }
        if (m{\A(.*)lemma$}i) { return 1 }
        if (m{\A(.*)sarcoma$}i) { return 1 }
        if (m{\A(.*)stoma$}i) { return 1 }
        if (m{\A(.*)nova$}i) { return 1 }
        if (m{\A(.*)umbra$}i) { return 1 }
        if (m{\A(.*)lumen$}i) { return 1 }
        if (m{\A(.*)datum$}i) { return 1 }
        if (m{\A(.*)stratum$}i) { return 1 }
        if (m{\A(.*)bacillus$}i) { return 1 }
        if (m{\A(.*)nucleus$}i) { return 1 }
        if (m{\A(.*)hedron$}i) { return 1 }
        if (m{\A(.*)helion$}i) { return 1 }
        if (m{\A(.*)legomenon$}i) { return 1 }
        if (m{\A(.*)phenomenon$}i) { return 1 }
        if (m{\A(.*)helix$}i) { return 1 }
        if (m{\A(.*)measles$}i) { return 1 }
        if (m{\A(.*)pox$}i) { return 1 }
        if (m{\A(.*)bass$}i) { return 1 }
        if (m{\A(.*)deer$}i) { return 1 }
        if (m{\A(.*)fish$}i) { return 1 }
        if (m{\A(.*)fowl$}i) { return 1 }
        if (m{\A(.*)sheep$}i) { return 1 }
        if (m{\A(.*)wildebeest$}i) { return 1 }
        if (m{\A(.*)craft$}i) { return 1 }
        if (m{\A(.*)gas$}i) { return 1 }
        if (m{\A(.*)glottis$}i) { return 1 }
        if (m{\A(.+[aeiou])o$}i) { return 1 }
        if (m{\A(.+[aeo])lf$}i) { return 1 }
        if (m{\A(.+[aiy])nx$}i) { return 1 }
        if (m{\A(.+)arf$}i) { return 1 }
        if (m{\A(.+)ceps$}i) { return 1 }
        if (m{\A(.+[cs])h$}i) { return 1 }
        if (m{\A(.+)eaf$}i) { return 1 }
        if (m{\A(.+)eau$}i) { return 1 }
        if (m{\A(.+)ieu$}i) { return 1 }
        if (m{\A(.+)nife$}i) { return 1 }
        if (m{\A(.+)oe$}i) { return 1 }
        if (m{\A(.+)o$}i) { return 1 }
        if (m{\A(.+)quy$}i) { return 1 }
        if (m{\A(.+[aeiou])y$}i) { return 1 }
        if (m{\A(.+)ss$}i) { return 1 }
        if (m{\A(.+)orse$}i) { return 1 }
        if (m{\A(.+[au])orse$}i) { return 1 }
        if (m{\A(.+)nse$}i) { return 1 }
        if (m{\A(.+[^ns])sis$}i) { return 1 }
        if (m{\A(.+)trix$}i) { return 1 }
        if (m{\A(.+)us$}i) { return 1 }
        if (m{\A(.+)x$}i) { return 1 }
        if (m{\A(.+)y$}i) { return 1 }
        if (m{\A(.+)z$}i) { return 1 }
        if (m{\A(.+)zoon$}i) { return 1 }
        default { return !is_plural($word); }
    }
}

1;
