use Test::More;
use Lingua::EN::Inflexion;

is noun(q{wady})->plural,   q{wadies}  => q{plural: 'wady' --> 'wadies'};
is noun(q{wadies})->plural, q{wadies}  => q{plural: 'wadies' --> 'wadies'};
is noun(q{pietra})->plural,   q{pietre}  => q{plural: 'pietra' --> 'pietre'};
is noun(q{pietre})->plural, q{pietre}  => q{plural: 'pietre' --> 'pietre'};
is noun(q{vlakte})->plural,   q{vlaktes}  => q{plural: 'vlakte' --> 'vlaktes'};
is noun(q{vlaktes})->plural, q{vlaktes}  => q{plural: 'vlaktes' --> 'vlaktes'};
is noun(q{silenus})->plural,   q{sileni}  => q{plural: 'silenus' --> 'sileni'};
is noun(q{sileni})->plural, q{sileni}  => q{plural: 'sileni' --> 'sileni'};
is noun(q{frenum})->plural,   q{frena}  => q{plural: 'frenum' --> 'frena'};
is noun(q{frena})->plural, q{frena}  => q{plural: 'frena' --> 'frena'};
is noun(q{paranucleus})->plural,   q{paranuclei}  => q{plural: 'paranucleus' --> 'paranuclei'};
is noun(q{paranuclei})->plural, q{paranuclei}  => q{plural: 'paranuclei' --> 'paranuclei'};
is noun(q{Norman})->plural,   q{Normans}  => q{plural: 'Norman' --> 'Normans'};
is noun(q{Normans})->plural, q{Normans}  => q{plural: 'Normans' --> 'Normans'};
is noun(q{chromonema})->plural,   q{chromonemata}  => q{plural: 'chromonema' --> 'chromonemata'};
is noun(q{chromonemata})->plural, q{chromonemata}  => q{plural: 'chromonemata' --> 'chromonemata'};
is noun(q{ispravnik})->plural,   q{ispravniks}  => q{plural: 'ispravnik' --> 'ispravniks'};
is noun(q{ispravniks})->plural, q{ispravniks}  => q{plural: 'ispravniks' --> 'ispravniks'};
is noun(q{osteoma})->plural,   q{osteomata}  => q{plural: 'osteoma' --> 'osteomata'};
is noun(q{osteomata})->plural, q{osteomata}  => q{plural: 'osteomata' --> 'osteomata'};
is noun(q{kantharos})->plural,   q{kantharoi}  => q{plural: 'kantharos' --> 'kantharoi'};
is noun(q{kantharoi})->plural, q{kantharoi}  => q{plural: 'kantharoi' --> 'kantharoi'};
is noun(q{contadino})->plural,   q{contadini}  => q{plural: 'contadino' --> 'contadini'};
is noun(q{contadini})->plural, q{contadini}  => q{plural: 'contadini' --> 'contadini'};
is noun(q{soralium})->plural,   q{soralia}  => q{plural: 'soralium' --> 'soralia'};
is noun(q{soralia})->plural, q{soralia}  => q{plural: 'soralia' --> 'soralia'};
is noun(q{penny})->plural,   q{pennies}  => q{plural: 'penny' --> 'pennies'};
is noun(q{pennies})->plural, q{pennies}  => q{plural: 'pennies' --> 'pennies'};
is noun(q{rondo})->plural,   q{rondos}  => q{plural: 'rondo' --> 'rondos'};
is noun(q{rondos})->plural, q{rondos}  => q{plural: 'rondos' --> 'rondos'};
is noun(q{interregnum})->plural,   q{interregnums}  => q{plural: 'interregnum' --> 'interregnums'};
is noun(q{interregnums})->plural, q{interregnums}  => q{plural: 'interregnums' --> 'interregnums'};
is noun(q{planula})->plural,   q{planulae}  => q{plural: 'planula' --> 'planulae'};
is noun(q{planulae})->plural, q{planulae}  => q{plural: 'planulae' --> 'planulae'};
is noun(q{kioko})->plural,   q{kiokos}  => q{plural: 'kioko' --> 'kiokos'};
is noun(q{kiokos})->plural, q{kiokos}  => q{plural: 'kiokos' --> 'kiokos'};
is noun(q{haddock})->plural,   q{haddocks}  => q{plural: 'haddock' --> 'haddocks'};
is noun(q{haddocks})->plural, q{haddocks}  => q{plural: 'haddocks' --> 'haddocks'};
is noun(q{hernia})->plural,   q{hernias}  => q{plural: 'hernia' --> 'hernias'};
is noun(q{hernias})->plural, q{hernias}  => q{plural: 'hernias' --> 'hernias'};
is noun(q{Lorrainese})->plural,   q{Lorrainese}  => q{plural: 'Lorrainese' --> 'Lorrainese'};
is noun(q{mezzo-rilievo})->plural,   q{mezzo-rilievos}  => q{plural: 'mezzo-rilievo' --> 'mezzo-rilievos'};
is noun(q{mezzo-rilievos})->plural, q{mezzo-rilievos}  => q{plural: 'mezzo-rilievos' --> 'mezzo-rilievos'};
is noun(q{fasciculus})->plural,   q{fasciculi}  => q{plural: 'fasciculus' --> 'fasciculi'};
is noun(q{fasciculi})->plural, q{fasciculi}  => q{plural: 'fasciculi' --> 'fasciculi'};
is noun(q{scotoma})->plural,   q{scotomas}  => q{plural: 'scotoma' --> 'scotomas'};
is noun(q{scotomas})->plural, q{scotomas}  => q{plural: 'scotomas' --> 'scotomas'};
is noun(q{thraso})->plural,   q{thrasoes}  => q{plural: 'thraso' --> 'thrasoes'};
is noun(q{thrasoes})->plural, q{thrasoes}  => q{plural: 'thrasoes' --> 'thrasoes'};
is noun(q{teratoma})->plural,   q{teratomata}  => q{plural: 'teratoma' --> 'teratomata'};
is noun(q{teratomata})->plural, q{teratomata}  => q{plural: 'teratomata' --> 'teratomata'};
is noun(q{set-to})->plural,   q{set-tos}  => q{plural: 'set-to' --> 'set-tos'};
is noun(q{set-tos})->plural, q{set-tos}  => q{plural: 'set-tos' --> 'set-tos'};
is noun(q{proseucha})->plural,   q{proseuchae}  => q{plural: 'proseucha' --> 'proseuchae'};
is noun(q{proseuchae})->plural, q{proseuchae}  => q{plural: 'proseuchae' --> 'proseuchae'};
is noun(q{caffe ristretto})->plural,   q{caffe ristrettos}  => q{plural: 'caffe ristretto' --> 'caffe ristrettos'};
is noun(q{caffe ristrettos})->plural, q{caffe ristrettos}  => q{plural: 'caffe ristrettos' --> 'caffe ristrettos'};
is noun(q{Barquisimeto})->plural,   q{Barquisimetos}  => q{plural: 'Barquisimeto' --> 'Barquisimetos'};
is noun(q{Barquisimetos})->plural, q{Barquisimetos}  => q{plural: 'Barquisimetos' --> 'Barquisimetos'};
is noun(q{gluteus})->plural,   q{glutei}  => q{plural: 'gluteus' --> 'glutei'};
is noun(q{glutei})->plural, q{glutei}  => q{plural: 'glutei' --> 'glutei'};
is noun(q{scyphus})->plural,   q{scyphi}  => q{plural: 'scyphus' --> 'scyphi'};
is noun(q{scyphi})->plural, q{scyphi}  => q{plural: 'scyphi' --> 'scyphi'};
is noun(q{programma})->plural,   q{programmata}  => q{plural: 'programma' --> 'programmata'};
is noun(q{programmata})->plural, q{programmata}  => q{plural: 'programmata' --> 'programmata'};
is noun(q{franc-archer})->plural,   q{franc-archers}  => q{plural: 'franc-archer' --> 'franc-archers'};
is noun(q{franc-archers})->plural, q{franc-archers}  => q{plural: 'franc-archers' --> 'franc-archers'};
is noun(q{varix})->plural,   q{varices}  => q{plural: 'varix' --> 'varices'};
is noun(q{varices})->plural, q{varices}  => q{plural: 'varices' --> 'varices'};
is noun(q{bel-esprit})->plural,   q{beaux esprits}  => q{plural: 'bel-esprit' --> 'beaux esprits'};
is noun(q{beaux esprits})->plural, q{beaux esprits}  => q{plural: 'beaux esprits' --> 'beaux esprits'};
is noun(q{ballista})->plural,   q{ballistas}  => q{plural: 'ballista' --> 'ballistas'};
is noun(q{ballistas})->plural, q{ballistas}  => q{plural: 'ballistas' --> 'ballistas'};
is noun(q{regma})->plural,   q{regmata}  => q{plural: 'regma' --> 'regmata'};
is noun(q{regmata})->plural, q{regmata}  => q{plural: 'regmata' --> 'regmata'};
is noun(q{contretemps})->plural,   q{contretemps}  => q{plural: 'contretemps' --> 'contretemps'};
is noun(q{responsum})->plural,   q{responsa}  => q{plural: 'responsum' --> 'responsa'};
is noun(q{responsa})->plural, q{responsa}  => q{plural: 'responsa' --> 'responsa'};
is noun(q{epilimnion})->plural,   q{epilimnia}  => q{plural: 'epilimnion' --> 'epilimnia'};
is noun(q{epilimnia})->plural, q{epilimnia}  => q{plural: 'epilimnia' --> 'epilimnia'};
is noun(q{genie})->plural,   q{genies}  => q{plural: 'genie' --> 'genies'};
is noun(q{genies})->plural, q{genies}  => q{plural: 'genies' --> 'genies'};
is noun(q{likuta})->plural,   q{makuta}  => q{plural: 'likuta' --> 'makuta'};
is noun(q{makuta})->plural, q{makuta}  => q{plural: 'makuta' --> 'makuta'};
is noun(q{arcosolium})->plural,   q{arcosolia}  => q{plural: 'arcosolium' --> 'arcosolia'};
is noun(q{arcosolia})->plural, q{arcosolia}  => q{plural: 'arcosolia' --> 'arcosolia'};
is noun(q{Cassinese})->plural,   q{Cassinese}  => q{plural: 'Cassinese' --> 'Cassinese'};
is noun(q{falx})->plural,   q{falces}  => q{plural: 'falx' --> 'falces'};
is noun(q{falces})->plural, q{falces}  => q{plural: 'falces' --> 'falces'};
is noun(q{plica})->plural,   q{plicae}  => q{plural: 'plica' --> 'plicae'};
is noun(q{plicae})->plural, q{plicae}  => q{plural: 'plicae' --> 'plicae'};
is noun(q{intervallum})->plural,   q{intervallums}  => q{plural: 'intervallum' --> 'intervallums'};
is noun(q{intervallums})->plural, q{intervallums}  => q{plural: 'intervallums' --> 'intervallums'};
is noun(q{ala})->plural,   q{alae}  => q{plural: 'ala' --> 'alae'};
is noun(q{alae})->plural, q{alae}  => q{plural: 'alae' --> 'alae'};
is noun(q{niello})->plural,   q{niellos}  => q{plural: 'niello' --> 'niellos'};
is noun(q{niellos})->plural, q{niellos}  => q{plural: 'niellos' --> 'niellos'};
is noun(q{villanella})->plural,   q{villanelle}  => q{plural: 'villanella' --> 'villanelle'};
is noun(q{villanelle})->plural, q{villanelle}  => q{plural: 'villanelle' --> 'villanelle'};
is noun(q{faveolus})->plural,   q{faveoli}  => q{plural: 'faveolus' --> 'faveoli'};
is noun(q{faveoli})->plural, q{faveoli}  => q{plural: 'faveoli' --> 'faveoli'};
is noun(q{ramulus})->plural,   q{ramuli}  => q{plural: 'ramulus' --> 'ramuli'};
is noun(q{ramuli})->plural, q{ramuli}  => q{plural: 'ramuli' --> 'ramuli'};
is noun(q{giuncus})->plural,   q{giunchi}  => q{plural: 'giuncus' --> 'giunchi'};
is noun(q{giunchi})->plural, q{giunchi}  => q{plural: 'giunchi' --> 'giunchi'};
is noun(q{money})->plural,   q{monies}  => q{plural: 'money' --> 'monies'};
is noun(q{monies})->plural, q{monies}  => q{plural: 'monies' --> 'monies'};
is noun(q{Gestapo})->plural,   q{Gestapos}  => q{plural: 'Gestapo' --> 'Gestapos'};
is noun(q{Gestapos})->plural, q{Gestapos}  => q{plural: 'Gestapos' --> 'Gestapos'};
is noun(q{batz})->plural,   q{batzes}  => q{plural: 'batz' --> 'batzes'};
is noun(q{batzes})->plural, q{batzes}  => q{plural: 'batzes' --> 'batzes'};
is noun(q{hippocampus})->plural,   q{hippocampi}  => q{plural: 'hippocampus' --> 'hippocampi'};
is noun(q{hippocampi})->plural, q{hippocampi}  => q{plural: 'hippocampi' --> 'hippocampi'};
is noun(q{pueblo})->plural,   q{pueblos}  => q{plural: 'pueblo' --> 'pueblos'};
is noun(q{pueblos})->plural, q{pueblos}  => q{plural: 'pueblos' --> 'pueblos'};
is noun(q{condo})->plural,   q{condos}  => q{plural: 'condo' --> 'condos'};
is noun(q{condos})->plural, q{condos}  => q{plural: 'condos' --> 'condos'};
is noun(q{abortorium})->plural,   q{abortoria}  => q{plural: 'abortorium' --> 'abortoria'};
is noun(q{abortoria})->plural, q{abortoria}  => q{plural: 'abortoria' --> 'abortoria'};
is noun(q{zucchini})->plural,   q{zucchinis}  => q{plural: 'zucchini' --> 'zucchinis'};
is noun(q{zucchinis})->plural, q{zucchinis}  => q{plural: 'zucchinis' --> 'zucchinis'};
is noun(q{aficionado})->plural,   q{aficionados}  => q{plural: 'aficionado' --> 'aficionados'};
is noun(q{aficionados})->plural, q{aficionados}  => q{plural: 'aficionados' --> 'aficionados'};
is noun(q{postulatum})->plural,   q{postulata}  => q{plural: 'postulatum' --> 'postulata'};
is noun(q{postulata})->plural, q{postulata}  => q{plural: 'postulata' --> 'postulata'};
is noun(q{soprano})->plural,   q{sopranos}  => q{plural: 'soprano' --> 'sopranos'};
is noun(q{sopranos})->plural, q{sopranos}  => q{plural: 'sopranos' --> 'sopranos'};
is noun(q{series})->plural,   q{series}  => q{plural: 'series' --> 'series'};
is noun(q{rite de passage})->plural,   q{rites de passage}  => q{plural: 'rite de passage' --> 'rites de passage'};
is noun(q{rites de passage})->plural, q{rites de passage}  => q{plural: 'rites de passage' --> 'rites de passage'};
is noun(q{viale})->plural,   q{viali}  => q{plural: 'viale' --> 'viali'};
is noun(q{viali})->plural, q{viali}  => q{plural: 'viali' --> 'viali'};
is noun(q{tango})->plural,   q{tangos}  => q{plural: 'tango' --> 'tangos'};
is noun(q{tangos})->plural, q{tangos}  => q{plural: 'tangos' --> 'tangos'};
is noun(q{rejon})->plural,   q{rejones}  => q{plural: 'rejon' --> 'rejones'};
is noun(q{rejones})->plural, q{rejones}  => q{plural: 'rejones' --> 'rejones'};
is noun(q{equinoctium})->plural,   q{equinoctiums}  => q{plural: 'equinoctium' --> 'equinoctiums'};
is noun(q{equinoctiums})->plural, q{equinoctiums}  => q{plural: 'equinoctiums' --> 'equinoctiums'};
is noun(q{usnea})->plural,   q{usneas}  => q{plural: 'usnea' --> 'usneas'};
is noun(q{usneas})->plural, q{usneas}  => q{plural: 'usneas' --> 'usneas'};
is noun(q{leptospira})->plural,   q{leptospirae}  => q{plural: 'leptospira' --> 'leptospirae'};
is noun(q{leptospirae})->plural, q{leptospirae}  => q{plural: 'leptospirae' --> 'leptospirae'};
is noun(q{louse})->plural,   q{lice}  => q{plural: 'louse' --> 'lice'};
is noun(q{lice})->plural, q{lice}  => q{plural: 'lice' --> 'lice'};
is noun(q{stroma})->plural,   q{stromata}  => q{plural: 'stroma' --> 'stromata'};
is noun(q{stromata})->plural, q{stromata}  => q{plural: 'stromata' --> 'stromata'};
is noun(q{intaglio})->plural,   q{intaglios}  => q{plural: 'intaglio' --> 'intaglios'};
is noun(q{intaglios})->plural, q{intaglios}  => q{plural: 'intaglios' --> 'intaglios'};
is noun(q{microcephalus})->plural,   q{microcephali}  => q{plural: 'microcephalus' --> 'microcephali'};
is noun(q{microcephali})->plural, q{microcephali}  => q{plural: 'microcephali' --> 'microcephali'};
is noun(q{stoma})->plural,   q{stomas}  => q{plural: 'stoma' --> 'stomas'};
is noun(q{stomas})->plural, q{stomas}  => q{plural: 'stomas' --> 'stomas'};
is noun(q{septenarius})->plural,   q{septenarii}  => q{plural: 'septenarius' --> 'septenarii'};
is noun(q{septenarii})->plural, q{septenarii}  => q{plural: 'septenarii' --> 'septenarii'};
is noun(q{retinaculum})->plural,   q{retinacula}  => q{plural: 'retinaculum' --> 'retinacula'};
is noun(q{retinacula})->plural, q{retinacula}  => q{plural: 'retinacula' --> 'retinacula'};
is noun(q{tour de force})->plural,   q{tours de force}  => q{plural: 'tour de force' --> 'tours de force'};
is noun(q{tours de force})->plural, q{tours de force}  => q{plural: 'tours de force' --> 'tours de force'};
is noun(q{Cantonese})->plural,   q{Cantonese}  => q{plural: 'Cantonese' --> 'Cantonese'};
is noun(q{panorpa})->plural,   q{panorpae}  => q{plural: 'panorpa' --> 'panorpae'};
is noun(q{panorpae})->plural, q{panorpae}  => q{plural: 'panorpae' --> 'panorpae'};
is noun(q{simpulum})->plural,   q{simpula}  => q{plural: 'simpulum' --> 'simpula'};
is noun(q{simpula})->plural, q{simpula}  => q{plural: 'simpula' --> 'simpula'};
is noun(q{mustachio})->plural,   q{mustachios}  => q{plural: 'mustachio' --> 'mustachios'};
is noun(q{mustachios})->plural, q{mustachios}  => q{plural: 'mustachios' --> 'mustachios'};
is noun(q{edema})->plural,   q{edemas}  => q{plural: 'edema' --> 'edemas'};
is noun(q{edemas})->plural, q{edemas}  => q{plural: 'edemas' --> 'edemas'};
is noun(q{marquis})->plural,   q{marquises}  => q{plural: 'marquis' --> 'marquises'};
is noun(q{marquises})->plural, q{marquises}  => q{plural: 'marquises' --> 'marquises'};
is noun(q{noctiluca})->plural,   q{noctilucae}  => q{plural: 'noctiluca' --> 'noctilucae'};
is noun(q{noctilucae})->plural, q{noctilucae}  => q{plural: 'noctilucae' --> 'noctilucae'};
is noun(q{enteron})->plural,   q{entera}  => q{plural: 'enteron' --> 'entera'};
is noun(q{entera})->plural, q{entera}  => q{plural: 'entera' --> 'entera'};
is noun(q{symplasma})->plural,   q{symplasmata}  => q{plural: 'symplasma' --> 'symplasmata'};
is noun(q{symplasmata})->plural, q{symplasmata}  => q{plural: 'symplasmata' --> 'symplasmata'};
is noun(q{epiphenomenon})->plural,   q{epiphenomena}  => q{plural: 'epiphenomenon' --> 'epiphenomena'};
is noun(q{epiphenomena})->plural, q{epiphenomena}  => q{plural: 'epiphenomena' --> 'epiphenomena'};
is noun(q{tempietto})->plural,   q{tempietti}  => q{plural: 'tempietto' --> 'tempietti'};
is noun(q{tempietti})->plural, q{tempietti}  => q{plural: 'tempietti' --> 'tempietti'};
is noun(q{legionella})->plural,   q{legionellae}  => q{plural: 'legionella' --> 'legionellae'};
is noun(q{legionellae})->plural, q{legionellae}  => q{plural: 'legionellae' --> 'legionellae'};
is noun(q{logodaedalus})->plural,   q{logodaedali}  => q{plural: 'logodaedalus' --> 'logodaedali'};
is noun(q{logodaedali})->plural, q{logodaedali}  => q{plural: 'logodaedali' --> 'logodaedali'};
is noun(q{4 star general})->plural,   q{4 star generals}  => q{plural: '4 star general' --> '4 star generals'};
is noun(q{4 star generals})->plural, q{4 star generals}  => q{plural: '4 star generals' --> '4 star generals'};
is noun(q{septum})->plural,   q{septa}  => q{plural: 'septum' --> 'septa'};
is noun(q{septa})->plural, q{septa}  => q{plural: 'septa' --> 'septa'};
is noun(q{follis})->plural,   q{folles}  => q{plural: 'follis' --> 'folles'};
is noun(q{folles})->plural, q{folles}  => q{plural: 'folles' --> 'folles'};
is noun(q{menage a trois})->plural,   q{menages a trois}  => q{plural: 'menage a trois' --> 'menages a trois'};
is noun(q{menages a trois})->plural, q{menages a trois}  => q{plural: 'menages a trois' --> 'menages a trois'};
is noun(q{phalanx})->plural,   q{phalanxes}  => q{plural: 'phalanx' --> 'phalanxes'};
is noun(q{phalanxes})->plural, q{phalanxes}  => q{plural: 'phalanxes' --> 'phalanxes'};
is noun(q{locus})->plural,   q{loci}  => q{plural: 'locus' --> 'loci'};
is noun(q{loci})->plural, q{loci}  => q{plural: 'loci' --> 'loci'};
is noun(q{staphylococcus})->plural,   q{staphylococci}  => q{plural: 'staphylococcus' --> 'staphylococci'};
is noun(q{staphylococci})->plural, q{staphylococci}  => q{plural: 'staphylococci' --> 'staphylococci'};
is noun(q{verticillus})->plural,   q{verticilli}  => q{plural: 'verticillus' --> 'verticilli'};
is noun(q{verticilli})->plural, q{verticilli}  => q{plural: 'verticilli' --> 'verticilli'};
is noun(q{seecatch})->plural,   q{seecatchie}  => q{plural: 'seecatch' --> 'seecatchie'};
is noun(q{seecatchie})->plural, q{seecatchie}  => q{plural: 'seecatchie' --> 'seecatchie'};
is noun(q{Esperanto})->plural,   q{Esperantos}  => q{plural: 'Esperanto' --> 'Esperantos'};
is noun(q{Esperantos})->plural, q{Esperantos}  => q{plural: 'Esperantos' --> 'Esperantos'};
is noun(q{urus})->plural,   q{uruses}  => q{plural: 'urus' --> 'uruses'};
is noun(q{uruses})->plural, q{uruses}  => q{plural: 'uruses' --> 'uruses'};
is noun(q{indicium})->plural,   q{indicia}  => q{plural: 'indicium' --> 'indicia'};
is noun(q{indicia})->plural, q{indicia}  => q{plural: 'indicia' --> 'indicia'};
is noun(q{penis})->plural,   q{penises}  => q{plural: 'penis' --> 'penises'};
is noun(q{penises})->plural, q{penises}  => q{plural: 'penises' --> 'penises'};
is noun(q{waldo})->plural,   q{waldos}  => q{plural: 'waldo' --> 'waldos'};
is noun(q{waldos})->plural, q{waldos}  => q{plural: 'waldos' --> 'waldos'};
is noun(q{bregma})->plural,   q{bregmata}  => q{plural: 'bregma' --> 'bregmata'};
is noun(q{bregmata})->plural, q{bregmata}  => q{plural: 'bregmata' --> 'bregmata'};
is noun(q{woman servant})->plural,   q{women servants}  => q{plural: 'woman servant' --> 'women servants'};
is noun(q{women servants})->plural, q{women servants}  => q{plural: 'women servants' --> 'women servants'};
is noun(q{stimulus})->plural,   q{stimuli}  => q{plural: 'stimulus' --> 'stimuli'};
is noun(q{stimuli})->plural, q{stimuli}  => q{plural: 'stimuli' --> 'stimuli'};
is noun(q{ruga})->plural,   q{rugae}  => q{plural: 'ruga' --> 'rugae'};
is noun(q{rugae})->plural, q{rugae}  => q{plural: 'rugae' --> 'rugae'};
is noun(q{res})->plural,   q{res}  => q{plural: 'res' --> 'res'};
is noun(q{Majuro})->plural,   q{Majuros}  => q{plural: 'Majuro' --> 'Majuros'};
is noun(q{Majuros})->plural, q{Majuros}  => q{plural: 'Majuros' --> 'Majuros'};
is noun(q{glochidium})->plural,   q{glochidia}  => q{plural: 'glochidium' --> 'glochidia'};
is noun(q{glochidia})->plural, q{glochidia}  => q{plural: 'glochidia' --> 'glochidia'};
is noun(q{alveolus})->plural,   q{alveoli}  => q{plural: 'alveolus' --> 'alveoli'};
is noun(q{alveoli})->plural, q{alveoli}  => q{plural: 'alveoli' --> 'alveoli'};
is noun(q{profluvium})->plural,   q{profluvia}  => q{plural: 'profluvium' --> 'profluvia'};
is noun(q{profluvia})->plural, q{profluvia}  => q{plural: 'profluvia' --> 'profluvia'};
is noun(q{indusium})->plural,   q{indusia}  => q{plural: 'indusium' --> 'indusia'};
is noun(q{indusia})->plural, q{indusia}  => q{plural: 'indusia' --> 'indusia'};
is noun(q{calamistrum})->plural,   q{calamistra}  => q{plural: 'calamistrum' --> 'calamistra'};
is noun(q{calamistra})->plural, q{calamistra}  => q{plural: 'calamistra' --> 'calamistra'};
is noun(q{man-child})->plural,   q{men-children}  => q{plural: 'man-child' --> 'men-children'};
is noun(q{men-children})->plural, q{men-children}  => q{plural: 'men-children' --> 'men-children'};
is noun(q{trousers})->plural,   q{trousers}  => q{plural: 'trousers' --> 'trousers'};
is noun(q{octohedron})->plural,   q{octohedrons}  => q{plural: 'octohedron' --> 'octohedrons'};
is noun(q{octohedrons})->plural, q{octohedrons}  => q{plural: 'octohedrons' --> 'octohedrons'};
is noun(q{whosever})->plural,   q{whosever}  => q{plural: 'whosever' --> 'whosever'};
is noun(q{parador})->plural,   q{paradors}  => q{plural: 'parador' --> 'paradors'};
is noun(q{paradors})->plural, q{paradors}  => q{plural: 'paradors' --> 'paradors'};
is noun(q{melastoma})->plural,   q{melastomas}  => q{plural: 'melastoma' --> 'melastomas'};
is noun(q{melastomas})->plural, q{melastomas}  => q{plural: 'melastomas' --> 'melastomas'};
is noun(q{ragazza})->plural,   q{ragazze}  => q{plural: 'ragazza' --> 'ragazze'};
is noun(q{ragazze})->plural, q{ragazze}  => q{plural: 'ragazze' --> 'ragazze'};
is noun(q{inoculum})->plural,   q{inocula}  => q{plural: 'inoculum' --> 'inocula'};
is noun(q{inocula})->plural, q{inocula}  => q{plural: 'inocula' --> 'inocula'};
is noun(q{minutia})->plural,   q{minutias}  => q{plural: 'minutia' --> 'minutias'};
is noun(q{minutias})->plural, q{minutias}  => q{plural: 'minutias' --> 'minutias'};
is noun(q{torma})->plural,   q{tormas}  => q{plural: 'torma' --> 'tormas'};
is noun(q{tormas})->plural, q{tormas}  => q{plural: 'tormas' --> 'tormas'};
is noun(q{helix})->plural,   q{helices}  => q{plural: 'helix' --> 'helices'};
is noun(q{helices})->plural, q{helices}  => q{plural: 'helices' --> 'helices'};
is noun(q{suppositum})->plural,   q{supposita}  => q{plural: 'suppositum' --> 'supposita'};
is noun(q{supposita})->plural, q{supposita}  => q{plural: 'supposita' --> 'supposita'};
is noun(q{phyllobranchia})->plural,   q{phyllobranchiae}  => q{plural: 'phyllobranchia' --> 'phyllobranchiae'};
is noun(q{phyllobranchiae})->plural, q{phyllobranchiae}  => q{plural: 'phyllobranchiae' --> 'phyllobranchiae'};
is noun(q{osteoclastoma})->plural,   q{osteoclastomas}  => q{plural: 'osteoclastoma' --> 'osteoclastomas'};
is noun(q{osteoclastomas})->plural, q{osteoclastomas}  => q{plural: 'osteoclastomas' --> 'osteoclastomas'};
is noun(q{sterigma})->plural,   q{sterigmata}  => q{plural: 'sterigma' --> 'sterigmata'};
is noun(q{sterigmata})->plural, q{sterigmata}  => q{plural: 'sterigmata' --> 'sterigmata'};
is noun(q{verso})->plural,   q{versos}  => q{plural: 'verso' --> 'versos'};
is noun(q{versos})->plural, q{versos}  => q{plural: 'versos' --> 'versos'};
is noun(q{acarus})->plural,   q{acari}  => q{plural: 'acarus' --> 'acari'};
is noun(q{acari})->plural, q{acari}  => q{plural: 'acari' --> 'acari'};
is noun(q{scolex})->plural,   q{scoleces}  => q{plural: 'scolex' --> 'scoleces'};
is noun(q{scoleces})->plural, q{scoleces}  => q{plural: 'scoleces' --> 'scoleces'};
is noun(q{Purum})->plural,   q{Purums}  => q{plural: 'Purum' --> 'Purums'};
is noun(q{Purums})->plural, q{Purums}  => q{plural: 'Purums' --> 'Purums'};
is noun(q{protarsus})->plural,   q{protarsi}  => q{plural: 'protarsus' --> 'protarsi'};
is noun(q{protarsi})->plural, q{protarsi}  => q{plural: 'protarsi' --> 'protarsi'};
is noun(q{Ningbo})->plural,   q{Ningbos}  => q{plural: 'Ningbo' --> 'Ningbos'};
is noun(q{Ningbos})->plural, q{Ningbos}  => q{plural: 'Ningbos' --> 'Ningbos'};
is noun(q{fedai})->plural,   q{fedais}  => q{plural: 'fedai' --> 'fedais'};
is noun(q{fedais})->plural, q{fedais}  => q{plural: 'fedais' --> 'fedais'};
is noun(q{allegro})->plural,   q{allegros}  => q{plural: 'allegro' --> 'allegros'};
is noun(q{allegros})->plural, q{allegros}  => q{plural: 'allegros' --> 'allegros'};
is noun(q{vertebra})->plural,   q{vertebrae}  => q{plural: 'vertebra' --> 'vertebrae'};
is noun(q{vertebrae})->plural, q{vertebrae}  => q{plural: 'vertebrae' --> 'vertebrae'};
is noun(q{paraganglioma})->plural,   q{paragangliomas}  => q{plural: 'paraganglioma' --> 'paragangliomas'};
is noun(q{paragangliomas})->plural, q{paragangliomas}  => q{plural: 'paragangliomas' --> 'paragangliomas'};
is noun(q{salivarium})->plural,   q{salivaria}  => q{plural: 'salivarium' --> 'salivaria'};
is noun(q{salivaria})->plural, q{salivaria}  => q{plural: 'salivaria' --> 'salivaria'};
is noun(q{sciolus})->plural,   q{scioli}  => q{plural: 'sciolus' --> 'scioli'};
is noun(q{scioli})->plural, q{scioli}  => q{plural: 'scioli' --> 'scioli'};
is noun(q{calathus})->plural,   q{calathi}  => q{plural: 'calathus' --> 'calathi'};
is noun(q{calathi})->plural, q{calathi}  => q{plural: 'calathi' --> 'calathi'};
is noun(q{Malabarese})->plural,   q{Malabarese}  => q{plural: 'Malabarese' --> 'Malabarese'};
is noun(q{Pardusco})->plural,   q{Parduscos}  => q{plural: 'Pardusco' --> 'Parduscos'};
is noun(q{Parduscos})->plural, q{Parduscos}  => q{plural: 'Parduscos' --> 'Parduscos'};
is noun(q{loa})->plural,   q{loas}  => q{plural: 'loa' --> 'loas'};
is noun(q{loas})->plural, q{loas}  => q{plural: 'loas' --> 'loas'};
is noun(q{tegmentum})->plural,   q{tegmenta}  => q{plural: 'tegmentum' --> 'tegmenta'};
is noun(q{tegmenta})->plural, q{tegmenta}  => q{plural: 'tegmenta' --> 'tegmenta'};
is noun(q{stylopodium})->plural,   q{stylopodia}  => q{plural: 'stylopodium' --> 'stylopodia'};
is noun(q{stylopodia})->plural, q{stylopodia}  => q{plural: 'stylopodia' --> 'stylopodia'};
is noun(q{zitella})->plural,   q{zitelle}  => q{plural: 'zitella' --> 'zitelle'};
is noun(q{zitelle})->plural, q{zitelle}  => q{plural: 'zitelle' --> 'zitelle'};
is noun(q{quinarius})->plural,   q{quinarii}  => q{plural: 'quinarius' --> 'quinarii'};
is noun(q{quinarii})->plural, q{quinarii}  => q{plural: 'quinarii' --> 'quinarii'};
is noun(q{sericterium})->plural,   q{sericteria}  => q{plural: 'sericterium' --> 'sericteria'};
is noun(q{sericteria})->plural, q{sericteria}  => q{plural: 'sericteria' --> 'sericteria'};
is noun(q{elf})->plural,   q{elves}  => q{plural: 'elf' --> 'elves'};
is noun(q{elves})->plural, q{elves}  => q{plural: 'elves' --> 'elves'};
is noun(q{uomo universale})->plural,   q{uomini universali}  => q{plural: 'uomo universale' --> 'uomini universali'};
is noun(q{uomini universali})->plural, q{uomini universali}  => q{plural: 'uomini universali' --> 'uomini universali'};
is noun(q{acropolis})->plural,   q{acropolises}  => q{plural: 'acropolis' --> 'acropolises'};
is noun(q{acropolises})->plural, q{acropolises}  => q{plural: 'acropolises' --> 'acropolises'};
is noun(q{summum bonum})->plural,   q{summa bona}  => q{plural: 'summum bonum' --> 'summa bona'};
is noun(q{summa bona})->plural, q{summa bona}  => q{plural: 'summa bona' --> 'summa bona'};
is noun(q{casus belli})->plural,   q{casus belli}  => q{plural: 'casus belli' --> 'casus belli'};
is noun(q{jerry})->plural,   q{jerries}  => q{plural: 'jerry' --> 'jerries'};
is noun(q{jerries})->plural, q{jerries}  => q{plural: 'jerries' --> 'jerries'};
is noun(q{terrae filius})->plural,   q{terrae filii}  => q{plural: 'terrae filius' --> 'terrae filii'};
is noun(q{terrae filii})->plural, q{terrae filii}  => q{plural: 'terrae filii' --> 'terrae filii'};
is noun(q{denarius})->plural,   q{denarii}  => q{plural: 'denarius' --> 'denarii'};
is noun(q{denarii})->plural, q{denarii}  => q{plural: 'denarii' --> 'denarii'};
is noun(q{metropolis})->plural,   q{metropolises}  => q{plural: 'metropolis' --> 'metropolises'};
is noun(q{metropolises})->plural, q{metropolises}  => q{plural: 'metropolises' --> 'metropolises'};
is noun(q{mesothelium})->plural,   q{mesothelia}  => q{plural: 'mesothelium' --> 'mesothelia'};
is noun(q{mesothelia})->plural, q{mesothelia}  => q{plural: 'mesothelia' --> 'mesothelia'};
is noun(q{meatus})->plural,   q{meatuses}  => q{plural: 'meatus' --> 'meatuses'};
is noun(q{meatuses})->plural, q{meatuses}  => q{plural: 'meatuses' --> 'meatuses'};
is noun(q{zizz})->plural,   q{zizzes}  => q{plural: 'zizz' --> 'zizzes'};
is noun(q{zizzes})->plural, q{zizzes}  => q{plural: 'zizzes' --> 'zizzes'};
is noun(q{diplococcus})->plural,   q{diplococci}  => q{plural: 'diplococcus' --> 'diplococci'};
is noun(q{diplococci})->plural, q{diplococci}  => q{plural: 'diplococci' --> 'diplococci'};
is noun(q{yo yo})->plural,   q{yo yos}  => q{plural: 'yo yo' --> 'yo yos'};
is noun(q{yo yos})->plural, q{yo yos}  => q{plural: 'yo yos' --> 'yo yos'};
is noun(q{pseudopodium})->plural,   q{pseudopodia}  => q{plural: 'pseudopodium' --> 'pseudopodia'};
is noun(q{pseudopodia})->plural, q{pseudopodia}  => q{plural: 'pseudopodia' --> 'pseudopodia'};
is noun(q{talouse})->plural,   q{talouses}  => q{plural: 'talouse' --> 'talouses'};
is noun(q{talouses})->plural, q{talouses}  => q{plural: 'talouses' --> 'talouses'};
is noun(q{vagus})->plural,   q{vagi}  => q{plural: 'vagus' --> 'vagi'};
is noun(q{vagi})->plural, q{vagi}  => q{plural: 'vagi' --> 'vagi'};
is noun(q{1-star general})->plural,   q{1-star generals}  => q{plural: '1-star general' --> '1-star generals'};
is noun(q{1-star generals})->plural, q{1-star generals}  => q{plural: '1-star generals' --> '1-star generals'};
is noun(q{pedicellaria})->plural,   q{pedicellariae}  => q{plural: 'pedicellaria' --> 'pedicellariae'};
is noun(q{pedicellariae})->plural, q{pedicellariae}  => q{plural: 'pedicellariae' --> 'pedicellariae'};
is noun(q{ipse dixit})->plural,   q{ipse dixits}  => q{plural: 'ipse dixit' --> 'ipse dixits'};
is noun(q{ipse dixits})->plural, q{ipse dixits}  => q{plural: 'ipse dixits' --> 'ipse dixits'};
is noun(q{logo})->plural,   q{logos}  => q{plural: 'logo' --> 'logos'};
is noun(q{logos})->plural, q{logos}  => q{plural: 'logos' --> 'logos'};
is noun(q{secans})->plural,   q{secantes}  => q{plural: 'secans' --> 'secantes'};
is noun(q{secantes})->plural, q{secantes}  => q{plural: 'secantes' --> 'secantes'};
is noun(q{Alfurese})->plural,   q{Alfurese}  => q{plural: 'Alfurese' --> 'Alfurese'};
is noun(q{Lyonese})->plural,   q{Lyonese}  => q{plural: 'Lyonese' --> 'Lyonese'};
is noun(q{Sundanese})->plural,   q{Sundanese}  => q{plural: 'Sundanese' --> 'Sundanese'};
is noun(q{washer-up})->plural,   q{washers-up}  => q{plural: 'washer-up' --> 'washers-up'};
is noun(q{washers-up})->plural, q{washers-up}  => q{plural: 'washers-up' --> 'washers-up'};
is noun(q{desma})->plural,   q{desmas}  => q{plural: 'desma' --> 'desmas'};
is noun(q{desmas})->plural, q{desmas}  => q{plural: 'desmas' --> 'desmas'};
is noun(q{filaria})->plural,   q{filarias}  => q{plural: 'filaria' --> 'filarias'};
is noun(q{filarias})->plural, q{filarias}  => q{plural: 'filarias' --> 'filarias'};
is noun(q{nodus})->plural,   q{nodi}  => q{plural: 'nodus' --> 'nodi'};
is noun(q{nodi})->plural, q{nodi}  => q{plural: 'nodi' --> 'nodi'};
is noun(q{she})->plural,   q{they}  => q{plural: 'she' --> 'they'};
is noun(q{moscardino})->plural,   q{moscardini}  => q{plural: 'moscardino' --> 'moscardini'};
is noun(q{moscardini})->plural, q{moscardini}  => q{plural: 'moscardini' --> 'moscardini'};
is noun(q{I})->plural,   q{we}  => q{plural: 'I' --> 'we'};
is noun(q{we})->plural, q{we}  => q{plural: 'we' --> 'we'};
is noun(q{coma})->plural,   q{comae}  => q{plural: 'coma' --> 'comae'};
is noun(q{comae})->plural, q{comae}  => q{plural: 'comae' --> 'comae'};
is noun(q{protypon})->plural,   q{protypa}  => q{plural: 'protypon' --> 'protypa'};
is noun(q{protypa})->plural, q{protypa}  => q{plural: 'protypa' --> 'protypa'};
is noun(q{ploshchadka})->plural,   q{ploshchadki}  => q{plural: 'ploshchadka' --> 'ploshchadki'};
is noun(q{ploshchadki})->plural, q{ploshchadki}  => q{plural: 'ploshchadki' --> 'ploshchadki'};
is noun(q{furioso})->plural,   q{furiosos}  => q{plural: 'furioso' --> 'furiosos'};
is noun(q{furiosos})->plural, q{furiosos}  => q{plural: 'furiosos' --> 'furiosos'};
is noun(q{chateau})->plural,   q{chateaux}  => q{plural: 'chateau' --> 'chateaux'};
is noun(q{chateaux})->plural, q{chateaux}  => q{plural: 'chateaux' --> 'chateaux'};
is noun(q{itself})->plural,   q{themselves}  => q{plural: 'itself' --> 'themselves'};
is noun(q{alguacil})->plural,   q{alguacils}  => q{plural: 'alguacil' --> 'alguacils'};
is noun(q{alguacils})->plural, q{alguacils}  => q{plural: 'alguacils' --> 'alguacils'};
is noun(q{pingo})->plural,   q{pingos}  => q{plural: 'pingo' --> 'pingos'};
is noun(q{pingos})->plural, q{pingos}  => q{plural: 'pingos' --> 'pingos'};
is noun(q{maximum})->plural,   q{maximums}  => q{plural: 'maximum' --> 'maximums'};
is noun(q{maximums})->plural, q{maximums}  => q{plural: 'maximums' --> 'maximums'};
is noun(q{Greensboro})->plural,   q{Greensboros}  => q{plural: 'Greensboro' --> 'Greensboros'};
is noun(q{Greensboros})->plural, q{Greensboros}  => q{plural: 'Greensboros' --> 'Greensboros'};
is noun(q{heroon})->plural,   q{heroa}  => q{plural: 'heroon' --> 'heroa'};
is noun(q{heroa})->plural, q{heroa}  => q{plural: 'heroa' --> 'heroa'};
is noun(q{aculeus})->plural,   q{aculei}  => q{plural: 'aculeus' --> 'aculei'};
is noun(q{aculei})->plural, q{aculei}  => q{plural: 'aculei' --> 'aculei'};
is noun(q{Annamese})->plural,   q{Annamese}  => q{plural: 'Annamese' --> 'Annamese'};
is noun(q{livedo})->plural,   q{livedos}  => q{plural: 'livedo' --> 'livedos'};
is noun(q{livedos})->plural, q{livedos}  => q{plural: 'livedos' --> 'livedos'};
is noun(q{epididymis})->plural,   q{epididymises}  => q{plural: 'epididymis' --> 'epididymises'};
is noun(q{epididymises})->plural, q{epididymises}  => q{plural: 'epididymises' --> 'epididymises'};
is noun(q{molimen})->plural,   q{molimina}  => q{plural: 'molimen' --> 'molimina'};
is noun(q{molimina})->plural, q{molimina}  => q{plural: 'molimina' --> 'molimina'};
is noun(q{lux})->plural,   q{lux}  => q{plural: 'lux' --> 'lux'};
is noun(q{portico})->plural,   q{porticos}  => q{plural: 'portico' --> 'porticos'};
is noun(q{porticos})->plural, q{porticos}  => q{plural: 'porticos' --> 'porticos'};
is noun(q{pneumothorax})->plural,   q{pneumothoraxes}  => q{plural: 'pneumothorax' --> 'pneumothoraxes'};
is noun(q{pneumothoraxes})->plural, q{pneumothoraxes}  => q{plural: 'pneumothoraxes' --> 'pneumothoraxes'};
is noun(q{mine})->plural,   q{ours}  => q{plural: 'mine' --> 'ours'};
is noun(q{ours})->plural, q{ours}  => q{plural: 'ours' --> 'ours'};
is noun(q{bilbo})->plural,   q{bilboes}  => q{plural: 'bilbo' --> 'bilboes'};
is noun(q{bilboes})->plural, q{bilboes}  => q{plural: 'bilboes' --> 'bilboes'};
is noun(q{syncellus})->plural,   q{syncelli}  => q{plural: 'syncellus' --> 'syncelli'};
is noun(q{syncelli})->plural, q{syncelli}  => q{plural: 'syncelli' --> 'syncelli'};
is noun(q{pleura})->plural,   q{pleura}  => q{plural: 'pleura' --> 'pleura'};
is noun(q{coz})->plural,   q{cozes}  => q{plural: 'coz' --> 'cozes'};
is noun(q{cozes})->plural, q{cozes}  => q{plural: 'cozes' --> 'cozes'};
is noun(q{mare})->plural,   q{mares}  => q{plural: 'mare' --> 'mares'};
is noun(q{mares})->plural, q{mares}  => q{plural: 'mares' --> 'mares'};
is noun(q{alias})->plural,   q{aliases}  => q{plural: 'alias' --> 'aliases'};
is noun(q{aliases})->plural, q{aliases}  => q{plural: 'aliases' --> 'aliases'};
is noun(q{sago})->plural,   q{sagos}  => q{plural: 'sago' --> 'sagos'};
is noun(q{sagos})->plural, q{sagos}  => q{plural: 'sagos' --> 'sagos'};
is noun(q{avocado})->plural,   q{avocados}  => q{plural: 'avocado' --> 'avocados'};
is noun(q{avocados})->plural, q{avocados}  => q{plural: 'avocados' --> 'avocados'};
is noun(q{fidei defensor})->plural,   q{fidei defensores}  => q{plural: 'fidei defensor' --> 'fidei defensores'};
is noun(q{fidei defensores})->plural, q{fidei defensores}  => q{plural: 'fidei defensores' --> 'fidei defensores'};
is noun(q{fioritura})->plural,   q{fioriture}  => q{plural: 'fioritura' --> 'fioriture'};
is noun(q{fioriture})->plural, q{fioriture}  => q{plural: 'fioriture' --> 'fioriture'};
is noun(q{port de bras})->plural,   q{ports de bras}  => q{plural: 'port de bras' --> 'ports de bras'};
is noun(q{ports de bras})->plural, q{ports de bras}  => q{plural: 'ports de bras' --> 'ports de bras'};
is noun(q{generalissimo})->plural,   q{generalissimos}  => q{plural: 'generalissimo' --> 'generalissimos'};
is noun(q{generalissimos})->plural, q{generalissimos}  => q{plural: 'generalissimos' --> 'generalissimos'};
is noun(q{man-servant})->plural,   q{men-servants}  => q{plural: 'man-servant' --> 'men-servants'};
is noun(q{men-servants})->plural, q{men-servants}  => q{plural: 'men-servants' --> 'men-servants'};
is noun(q{honorarium})->plural,   q{honorariums}  => q{plural: 'honorarium' --> 'honorariums'};
is noun(q{honorariums})->plural, q{honorariums}  => q{plural: 'honorariums' --> 'honorariums'};
is noun(q{loaf})->plural,   q{loaves}  => q{plural: 'loaf' --> 'loaves'};
is noun(q{loaves})->plural, q{loaves}  => q{plural: 'loaves' --> 'loaves'};
is noun(q{phenomenon})->plural,   q{phenomena}  => q{plural: 'phenomenon' --> 'phenomena'};
is noun(q{phenomena})->plural, q{phenomena}  => q{plural: 'phenomena' --> 'phenomena'};
is noun(q{fabella})->plural,   q{fabellae}  => q{plural: 'fabella' --> 'fabellae'};
is noun(q{fabellae})->plural, q{fabellae}  => q{plural: 'fabellae' --> 'fabellae'};
is noun(q{paries})->plural,   q{parietes}  => q{plural: 'paries' --> 'parietes'};
is noun(q{parietes})->plural, q{parietes}  => q{plural: 'parietes' --> 'parietes'};
is noun(q{guglio})->plural,   q{guglios}  => q{plural: 'guglio' --> 'guglios'};
is noun(q{guglios})->plural, q{guglios}  => q{plural: 'guglios' --> 'guglios'};
is noun(q{sambo})->plural,   q{sambos}  => q{plural: 'sambo' --> 'sambos'};
is noun(q{sambos})->plural, q{sambos}  => q{plural: 'sambos' --> 'sambos'};
is noun(q{Macanese})->plural,   q{Macanese}  => q{plural: 'Macanese' --> 'Macanese'};
is noun(q{perithecium})->plural,   q{perithecia}  => q{plural: 'perithecium' --> 'perithecia'};
is noun(q{perithecia})->plural, q{perithecia}  => q{plural: 'perithecia' --> 'perithecia'};
is noun(q{stephanion})->plural,   q{stephanions}  => q{plural: 'stephanion' --> 'stephanions'};
is noun(q{stephanions})->plural, q{stephanions}  => q{plural: 'stephanions' --> 'stephanions'};
is noun(q{nauplius})->plural,   q{nauplii}  => q{plural: 'nauplius' --> 'nauplii'};
is noun(q{nauplii})->plural, q{nauplii}  => q{plural: 'nauplii' --> 'nauplii'};
is noun(q{neuma})->plural,   q{neumas}  => q{plural: 'neuma' --> 'neumas'};
is noun(q{neumas})->plural, q{neumas}  => q{plural: 'neumas' --> 'neumas'};
is noun(q{diastema})->plural,   q{diastemata}  => q{plural: 'diastema' --> 'diastemata'};
is noun(q{diastemata})->plural, q{diastemata}  => q{plural: 'diastemata' --> 'diastemata'};
is noun(q{ranunculus})->plural,   q{ranunculuses}  => q{plural: 'ranunculus' --> 'ranunculuses'};
is noun(q{ranunculuses})->plural, q{ranunculuses}  => q{plural: 'ranunculuses' --> 'ranunculuses'};
is noun(q{tarantato})->plural,   q{tarantati}  => q{plural: 'tarantato' --> 'tarantati'};
is noun(q{tarantati})->plural, q{tarantati}  => q{plural: 'tarantati' --> 'tarantati'};
is noun(q{hinaki})->plural,   q{hinaki}  => q{plural: 'hinaki' --> 'hinaki'};
is noun(q{monorchis})->plural,   q{monorchides}  => q{plural: 'monorchis' --> 'monorchides'};
is noun(q{monorchides})->plural, q{monorchides}  => q{plural: 'monorchides' --> 'monorchides'};
is noun(q{pincer})->plural,   q{pincers}  => q{plural: 'pincer' --> 'pincers'};
is noun(q{fungus})->plural,   q{funguses}  => q{plural: 'fungus' --> 'funguses'};
is noun(q{funguses})->plural, q{funguses}  => q{plural: 'funguses' --> 'funguses'};
is noun(q{osculum})->plural,   q{oscula}  => q{plural: 'osculum' --> 'oscula'};
is noun(q{oscula})->plural, q{oscula}  => q{plural: 'oscula' --> 'oscula'};
is noun(q{mezuzah})->plural,   q{mezuzoth}  => q{plural: 'mezuzah' --> 'mezuzoth'};
is noun(q{mezuzoth})->plural, q{mezuzoth}  => q{plural: 'mezuzoth' --> 'mezuzoth'};
is noun(q{designatum})->plural,   q{designata}  => q{plural: 'designatum' --> 'designata'};
is noun(q{designata})->plural, q{designata}  => q{plural: 'designata' --> 'designata'};
is noun(q{brother german})->plural,   q{brothers german}  => q{plural: 'brother german' --> 'brothers german'};
is noun(q{brothers german})->plural, q{brothers german}  => q{plural: 'brothers german' --> 'brothers german'};
is noun(q{gumma})->plural,   q{gummas}  => q{plural: 'gumma' --> 'gummas'};
is noun(q{gummas})->plural, q{gummas}  => q{plural: 'gummas' --> 'gummas'};
is noun(q{amentum})->plural,   q{amenta}  => q{plural: 'amentum' --> 'amenta'};
is noun(q{amenta})->plural, q{amenta}  => q{plural: 'amenta' --> 'amenta'};
is noun(q{pleuron})->plural,   q{pleura}  => q{plural: 'pleuron' --> 'pleura'};
is noun(q{ruse de guerre})->plural,   q{ruses de guerre}  => q{plural: 'ruse de guerre' --> 'ruses de guerre'};
is noun(q{ruses de guerre})->plural, q{ruses de guerre}  => q{plural: 'ruses de guerre' --> 'ruses de guerre'};
is noun(q{germarium})->plural,   q{germaria}  => q{plural: 'germarium' --> 'germaria'};
is noun(q{germaria})->plural, q{germaria}  => q{plural: 'germaria' --> 'germaria'};
is noun(q{Sogdianese})->plural,   q{Sogdianese}  => q{plural: 'Sogdianese' --> 'Sogdianese'};
is noun(q{glass})->plural,   q{glasses}  => q{plural: 'glass' --> 'glasses'};
is noun(q{plasmalemma})->plural,   q{plasmalemmas}  => q{plural: 'plasmalemma' --> 'plasmalemmas'};
is noun(q{plasmalemmas})->plural, q{plasmalemmas}  => q{plural: 'plasmalemmas' --> 'plasmalemmas'};
is noun(q{pala})->plural,   q{palae}  => q{plural: 'pala' --> 'palae'};
is noun(q{palae})->plural, q{palae}  => q{plural: 'palae' --> 'palae'};
is noun(q{porcino})->plural,   q{porcini}  => q{plural: 'porcino' --> 'porcini'};
is noun(q{porcini})->plural, q{porcini}  => q{plural: 'porcini' --> 'porcini'};
is noun(q{Tyrolese})->plural,   q{Tyrolese}  => q{plural: 'Tyrolese' --> 'Tyrolese'};
is noun(q{diabetes})->plural,   q{diabetes}  => q{plural: 'diabetes' --> 'diabetes'};
is noun(q{monstre sacre})->plural,   q{monstres sacres}  => q{plural: 'monstre sacre' --> 'monstres sacres'};
is noun(q{monstres sacres})->plural, q{monstres sacres}  => q{plural: 'monstres sacres' --> 'monstres sacres'};
is noun(q{concetto})->plural,   q{concetti}  => q{plural: 'concetto' --> 'concetti'};
is noun(q{concetti})->plural, q{concetti}  => q{plural: 'concetti' --> 'concetti'};
is noun(q{caddis})->plural,   q{caddises}  => q{plural: 'caddis' --> 'caddises'};
is noun(q{caddises})->plural, q{caddises}  => q{plural: 'caddises' --> 'caddises'};
is noun(q{scolopidium})->plural,   q{scolopidia}  => q{plural: 'scolopidium' --> 'scolopidia'};
is noun(q{scolopidia})->plural, q{scolopidia}  => q{plural: 'scolopidia' --> 'scolopidia'};
is noun(q{Singhalese})->plural,   q{Singhalese}  => q{plural: 'Singhalese' --> 'Singhalese'};
is noun(q{pomme de terre})->plural,   q{pommes de terre}  => q{plural: 'pomme de terre' --> 'pommes de terre'};
is noun(q{pommes de terre})->plural, q{pommes de terre}  => q{plural: 'pommes de terre' --> 'pommes de terre'};
is noun(q{yarraman})->plural,   q{yarramen}  => q{plural: 'yarraman' --> 'yarramen'};
is noun(q{yarramen})->plural, q{yarramen}  => q{plural: 'yarramen' --> 'yarramen'};
is noun(q{nymphaeum})->plural,   q{nymphea}  => q{plural: 'nymphaeum' --> 'nymphea'};
is noun(q{nymphea})->plural, q{nymphea}  => q{plural: 'nymphea' --> 'nymphea'};
is noun(q{limo})->plural,   q{limos}  => q{plural: 'limo' --> 'limos'};
is noun(q{limos})->plural, q{limos}  => q{plural: 'limos' --> 'limos'};
is noun(q{propylon})->plural,   q{propylons}  => q{plural: 'propylon' --> 'propylons'};
is noun(q{propylons})->plural, q{propylons}  => q{plural: 'propylons' --> 'propylons'};
is noun(q{triforium})->plural,   q{triforia}  => q{plural: 'triforium' --> 'triforia'};
is noun(q{triforia})->plural, q{triforia}  => q{plural: 'triforia' --> 'triforia'};
is noun(q{woman child})->plural,   q{women children}  => q{plural: 'woman child' --> 'women children'};
is noun(q{women children})->plural, q{women children}  => q{plural: 'women children' --> 'women children'};
is noun(q{aide-de-camp})->plural,   q{aides-de-camp}  => q{plural: 'aide-de-camp' --> 'aides-de-camp'};
is noun(q{aides-de-camp})->plural, q{aides-de-camp}  => q{plural: 'aides-de-camp' --> 'aides-de-camp'};
is noun(q{Avignonese})->plural,   q{Avignonese}  => q{plural: 'Avignonese' --> 'Avignonese'};
is noun(q{tremolo})->plural,   q{tremolos}  => q{plural: 'tremolo' --> 'tremolos'};
is noun(q{tremolos})->plural, q{tremolos}  => q{plural: 'tremolos' --> 'tremolos'};
is noun(q{metatarsus})->plural,   q{metatarsi}  => q{plural: 'metatarsus' --> 'metatarsi'};
is noun(q{metatarsi})->plural, q{metatarsi}  => q{plural: 'metatarsi' --> 'metatarsi'};
is noun(q{pedion})->plural,   q{pedia}  => q{plural: 'pedion' --> 'pedia'};
is noun(q{pedia})->plural, q{pedia}  => q{plural: 'pedia' --> 'pedia'};
is noun(q{scudo})->plural,   q{scudi}  => q{plural: 'scudo' --> 'scudi'};
is noun(q{scudi})->plural, q{scudi}  => q{plural: 'scudi' --> 'scudi'};
is noun(q{larynx})->plural,   q{larynges}  => q{plural: 'larynx' --> 'larynges'};
is noun(q{larynges})->plural, q{larynges}  => q{plural: 'larynges' --> 'larynges'};
is noun(q{scuola})->plural,   q{scuole}  => q{plural: 'scuola' --> 'scuole'};
is noun(q{scuole})->plural, q{scuole}  => q{plural: 'scuole' --> 'scuole'};
is noun(q{index})->plural,   q{indexes}  => q{plural: 'index' --> 'indexes'};
is noun(q{indexes})->plural, q{indexes}  => q{plural: 'indexes' --> 'indexes'};
is noun(q{suggestio falsi})->plural,   q{suggestiones falsi}  => q{plural: 'suggestio falsi' --> 'suggestiones falsi'};
is noun(q{suggestiones falsi})->plural, q{suggestiones falsi}  => q{plural: 'suggestiones falsi' --> 'suggestiones falsi'};
is noun(q{fabliau})->plural,   q{fabliaux}  => q{plural: 'fabliau' --> 'fabliaux'};
is noun(q{fabliaux})->plural, q{fabliaux}  => q{plural: 'fabliaux' --> 'fabliaux'};
is noun(q{bursch})->plural,   q{burschen}  => q{plural: 'bursch' --> 'burschen'};
is noun(q{burschen})->plural, q{burschen}  => q{plural: 'burschen' --> 'burschen'};
is noun(q{Andamanese})->plural,   q{Andamanese}  => q{plural: 'Andamanese' --> 'Andamanese'};
is noun(q{interaxis})->plural,   q{interaxes}  => q{plural: 'interaxis' --> 'interaxes'};
is noun(q{interaxes})->plural, q{interaxes}  => q{plural: 'interaxes' --> 'interaxes'};
is noun(q{zadruga})->plural,   q{zadrugas}  => q{plural: 'zadruga' --> 'zadrugas'};
is noun(q{zadrugas})->plural, q{zadrugas}  => q{plural: 'zadrugas' --> 'zadrugas'};
is noun(q{rimon})->plural,   q{rimonim}  => q{plural: 'rimon' --> 'rimonim'};
is noun(q{rimonim})->plural, q{rimonim}  => q{plural: 'rimonim' --> 'rimonim'};
is noun(q{tholos})->plural,   q{tholoi}  => q{plural: 'tholos' --> 'tholoi'};
is noun(q{tholoi})->plural, q{tholoi}  => q{plural: 'tholoi' --> 'tholoi'};
is noun(q{Angolese})->plural,   q{Angolese}  => q{plural: 'Angolese' --> 'Angolese'};
is noun(q{syrphus})->plural,   q{syrphi}  => q{plural: 'syrphus' --> 'syrphi'};
is noun(q{syrphi})->plural, q{syrphi}  => q{plural: 'syrphi' --> 'syrphi'};
is noun(q{valvula})->plural,   q{valvulae}  => q{plural: 'valvula' --> 'valvulae'};
is noun(q{valvulae})->plural, q{valvulae}  => q{plural: 'valvulae' --> 'valvulae'};
is noun(q{Ferrarese})->plural,   q{Ferrarese}  => q{plural: 'Ferrarese' --> 'Ferrarese'};
is noun(q{Torino})->plural,   q{Torinos}  => q{plural: 'Torino' --> 'Torinos'};
is noun(q{Torinos})->plural, q{Torinos}  => q{plural: 'Torinos' --> 'Torinos'};
is noun(q{jalapeno})->plural,   q{jalapenos}  => q{plural: 'jalapeno' --> 'jalapenos'};
is noun(q{jalapenos})->plural, q{jalapenos}  => q{plural: 'jalapenos' --> 'jalapenos'};
is noun(q{tipula})->plural,   q{tipulae}  => q{plural: 'tipula' --> 'tipulae'};
is noun(q{tipulae})->plural, q{tipulae}  => q{plural: 'tipulae' --> 'tipulae'};
is noun(q{hetaira})->plural,   q{hetaerae}  => q{plural: 'hetaira' --> 'hetaerae'};
is noun(q{hetaerae})->plural, q{hetaerae}  => q{plural: 'hetaerae' --> 'hetaerae'};
is noun(q{zoosporangium})->plural,   q{zoosporangia}  => q{plural: 'zoosporangium' --> 'zoosporangia'};
is noun(q{zoosporangia})->plural, q{zoosporangia}  => q{plural: 'zoosporangia' --> 'zoosporangia'};
is noun(q{Polonese})->plural,   q{Polonese}  => q{plural: 'Polonese' --> 'Polonese'};
is noun(q{substratum})->plural,   q{substratums}  => q{plural: 'substratum' --> 'substratums'};
is noun(q{substratums})->plural, q{substratums}  => q{plural: 'substratums' --> 'substratums'};
is noun(q{that})->plural,   q{those}  => q{plural: 'that' --> 'those'};
is noun(q{those})->plural, q{those}  => q{plural: 'those' --> 'those'};
is noun(q{lorum})->plural,   q{lora}  => q{plural: 'lorum' --> 'lora'};
is noun(q{lora})->plural, q{lora}  => q{plural: 'lora' --> 'lora'};
is noun(q{tractatrix})->plural,   q{tractatrices}  => q{plural: 'tractatrix' --> 'tractatrices'};
is noun(q{tractatrices})->plural, q{tractatrices}  => q{plural: 'tractatrices' --> 'tractatrices'};
is noun(q{hemangioma})->plural,   q{hemangiomas}  => q{plural: 'hemangioma' --> 'hemangiomas'};
is noun(q{hemangiomas})->plural, q{hemangiomas}  => q{plural: 'hemangiomas' --> 'hemangiomas'};
is noun(q{utricularia})->plural,   q{utriculariae}  => q{plural: 'utricularia' --> 'utriculariae'};
is noun(q{utriculariae})->plural, q{utriculariae}  => q{plural: 'utriculariae' --> 'utriculariae'};
is noun(q{aureus})->plural,   q{aurei}  => q{plural: 'aureus' --> 'aurei'};
is noun(q{aurei})->plural, q{aurei}  => q{plural: 'aurei' --> 'aurei'};
is noun(q{heft})->plural,   q{hefte}  => q{plural: 'heft' --> 'hefte'};
is noun(q{hefte})->plural, q{hefte}  => q{plural: 'hefte' --> 'hefte'};
is noun(q{timpano})->plural,   q{timpanos}  => q{plural: 'timpano' --> 'timpanos'};
is noun(q{timpanos})->plural, q{timpanos}  => q{plural: 'timpanos' --> 'timpanos'};
is noun(q{rotula})->plural,   q{rotulae}  => q{plural: 'rotula' --> 'rotulae'};
is noun(q{rotulae})->plural, q{rotulae}  => q{plural: 'rotulae' --> 'rotulae'};
is noun(q{rem})->plural,   q{rems}  => q{plural: 'rem' --> 'rems'};
is noun(q{rems})->plural, q{rems}  => q{plural: 'rems' --> 'rems'};
is noun(q{archipelago})->plural,   q{archipelagos}  => q{plural: 'archipelago' --> 'archipelagos'};
is noun(q{archipelagos})->plural, q{archipelagos}  => q{plural: 'archipelagos' --> 'archipelagos'};
is noun(q{appressorium})->plural,   q{appressoria}  => q{plural: 'appressorium' --> 'appressoria'};
is noun(q{appressoria})->plural, q{appressoria}  => q{plural: 'appressoria' --> 'appressoria'};
is noun(q{tomato})->plural,   q{tomatoes}  => q{plural: 'tomato' --> 'tomatoes'};
is noun(q{tomatoes})->plural, q{tomatoes}  => q{plural: 'tomatoes' --> 'tomatoes'};
is noun(q{messa di voce})->plural,   q{messe di voce}  => q{plural: 'messa di voce' --> 'messe di voce'};
is noun(q{messe di voce})->plural, q{messe di voce}  => q{plural: 'messe di voce' --> 'messe di voce'};
is noun(q{amphora})->plural,   q{amphorae}  => q{plural: 'amphora' --> 'amphorae'};
is noun(q{amphorae})->plural, q{amphorae}  => q{plural: 'amphorae' --> 'amphorae'};
is noun(q{nemathecium})->plural,   q{nemathecia}  => q{plural: 'nemathecium' --> 'nemathecia'};
is noun(q{nemathecia})->plural, q{nemathecia}  => q{plural: 'nemathecia' --> 'nemathecia'};
is noun(q{colonel general})->plural,   q{colonel generals}  => q{plural: 'colonel general' --> 'colonel generals'};
is noun(q{colonel generals})->plural, q{colonel generals}  => q{plural: 'colonel generals' --> 'colonel generals'};
is noun(q{Bamako})->plural,   q{Bamakos}  => q{plural: 'Bamako' --> 'Bamakos'};
is noun(q{Bamakos})->plural, q{Bamakos}  => q{plural: 'Bamakos' --> 'Bamakos'};
is noun(q{prothallium})->plural,   q{prothallia}  => q{plural: 'prothallium' --> 'prothallia'};
is noun(q{prothallia})->plural, q{prothallia}  => q{plural: 'prothallia' --> 'prothallia'};
is noun(q{louis})->plural,   q{louis}  => q{plural: 'louis' --> 'louis'};
is noun(q{velamen})->plural,   q{velamina}  => q{plural: 'velamen' --> 'velamina'};
is noun(q{velamina})->plural, q{velamina}  => q{plural: 'velamina' --> 'velamina'};
is noun(q{beef})->plural,   q{beefs}  => q{plural: 'beef' --> 'beefs'};
is noun(q{beefs})->plural, q{beefs}  => q{plural: 'beefs' --> 'beefs'};
is noun(q{pragma})->plural,   q{pragmas}  => q{plural: 'pragma' --> 'pragmas'};
is noun(q{pragmas})->plural, q{pragmas}  => q{plural: 'pragmas' --> 'pragmas'};
is noun(q{gyrus})->plural,   q{gyri}  => q{plural: 'gyrus' --> 'gyri'};
is noun(q{gyri})->plural, q{gyri}  => q{plural: 'gyri' --> 'gyri'};
is noun(q{iter})->plural,   q{iters}  => q{plural: 'iter' --> 'iters'};
is noun(q{iters})->plural, q{iters}  => q{plural: 'iters' --> 'iters'};
is noun(q{agent provocateur})->plural,   q{agents provocateurs}  => q{plural: 'agent provocateur' --> 'agents provocateurs'};
is noun(q{agents provocateurs})->plural, q{agents provocateurs}  => q{plural: 'agents provocateurs' --> 'agents provocateurs'};
is noun(q{idolum})->plural,   q{idola}  => q{plural: 'idolum' --> 'idola'};
is noun(q{idola})->plural, q{idola}  => q{plural: 'idola' --> 'idola'};
is noun(q{summa})->plural,   q{summae}  => q{plural: 'summa' --> 'summae'};
is noun(q{summae})->plural, q{summae}  => q{plural: 'summae' --> 'summae'};
is noun(q{hoti})->plural,   q{hoties}  => q{plural: 'hoti' --> 'hoties'};
is noun(q{hoties})->plural, q{hoties}  => q{plural: 'hoties' --> 'hoties'};
is noun(q{musee imaginaire})->plural,   q{musees imaginaires}  => q{plural: 'musee imaginaire' --> 'musees imaginaires'};
is noun(q{musees imaginaires})->plural, q{musees imaginaires}  => q{plural: 'musees imaginaires' --> 'musees imaginaires'};
is noun(q{lomentum})->plural,   q{lomenta}  => q{plural: 'lomentum' --> 'lomenta'};
is noun(q{lomenta})->plural, q{lomenta}  => q{plural: 'lomenta' --> 'lomenta'};
is noun(q{Milanese})->plural,   q{Milanese}  => q{plural: 'Milanese' --> 'Milanese'};
is noun(q{terp})->plural,   q{terps}  => q{plural: 'terp' --> 'terps'};
is noun(q{terps})->plural, q{terps}  => q{plural: 'terps' --> 'terps'};
is noun(q{blastema})->plural,   q{blastemata}  => q{plural: 'blastema' --> 'blastemata'};
is noun(q{blastemata})->plural, q{blastemata}  => q{plural: 'blastemata' --> 'blastemata'};
is noun(q{Messinese})->plural,   q{Messinese}  => q{plural: 'Messinese' --> 'Messinese'};
is noun(q{fizz})->plural,   q{fizzes}  => q{plural: 'fizz' --> 'fizzes'};
is noun(q{fizzes})->plural, q{fizzes}  => q{plural: 'fizzes' --> 'fizzes'};
is noun(q{whom})->plural,   q{whom}  => q{plural: 'whom' --> 'whom'};
is noun(q{maxilla})->plural,   q{maxillae}  => q{plural: 'maxilla' --> 'maxillae'};
is noun(q{maxillae})->plural, q{maxillae}  => q{plural: 'maxillae' --> 'maxillae'};
is noun(q{arista})->plural,   q{aristae}  => q{plural: 'arista' --> 'aristae'};
is noun(q{aristae})->plural, q{aristae}  => q{plural: 'aristae' --> 'aristae'};
is noun(q{abortus})->plural,   q{abortuses}  => q{plural: 'abortus' --> 'abortuses'};
is noun(q{abortuses})->plural, q{abortuses}  => q{plural: 'abortuses' --> 'abortuses'};
is noun(q{cul de lampe})->plural,   q{culs de lampe}  => q{plural: 'cul de lampe' --> 'culs de lampe'};
is noun(q{culs de lampe})->plural, q{culs de lampe}  => q{plural: 'culs de lampe' --> 'culs de lampe'};
is noun(q{zuppa})->plural,   q{zuppe}  => q{plural: 'zuppa' --> 'zuppe'};
is noun(q{zuppe})->plural, q{zuppe}  => q{plural: 'zuppe' --> 'zuppe'};
is noun(q{Otomi})->plural,   q{Otomies}  => q{plural: 'Otomi' --> 'Otomies'};
is noun(q{Otomies})->plural, q{Otomies}  => q{plural: 'Otomies' --> 'Otomies'};
is noun(q{rhino})->plural,   q{rhinos}  => q{plural: 'rhino' --> 'rhinos'};
is noun(q{rhinos})->plural, q{rhinos}  => q{plural: 'rhinos' --> 'rhinos'};
is noun(q{prosecutrix})->plural,   q{prosecutrices}  => q{plural: 'prosecutrix' --> 'prosecutrices'};
is noun(q{prosecutrices})->plural, q{prosecutrices}  => q{plural: 'prosecutrices' --> 'prosecutrices'};
is noun(q{Tenggerese})->plural,   q{Tenggerese}  => q{plural: 'Tenggerese' --> 'Tenggerese'};
is noun(q{uncia})->plural,   q{unciae}  => q{plural: 'uncia' --> 'unciae'};
is noun(q{unciae})->plural, q{unciae}  => q{plural: 'unciae' --> 'unciae'};
is noun(q{glissando})->plural,   q{glissandos}  => q{plural: 'glissando' --> 'glissandos'};
is noun(q{glissandos})->plural, q{glissandos}  => q{plural: 'glissandos' --> 'glissandos'};
is noun(q{callus})->plural,   q{calluses}  => q{plural: 'callus' --> 'calluses'};
is noun(q{calluses})->plural, q{calluses}  => q{plural: 'calluses' --> 'calluses'};
is noun(q{diverticulum})->plural,   q{diverticula}  => q{plural: 'diverticulum' --> 'diverticula'};
is noun(q{diverticula})->plural, q{diverticula}  => q{plural: 'diverticula' --> 'diverticula'};
is noun(q{Kosovo})->plural,   q{Kosovos}  => q{plural: 'Kosovo' --> 'Kosovos'};
is noun(q{Kosovos})->plural, q{Kosovos}  => q{plural: 'Kosovos' --> 'Kosovos'};
is noun(q{vaginula})->plural,   q{vaginulae}  => q{plural: 'vaginula' --> 'vaginulae'};
is noun(q{vaginulae})->plural, q{vaginulae}  => q{plural: 'vaginulae' --> 'vaginulae'};
is noun(q{atlas})->plural,   q{atlases}  => q{plural: 'atlas' --> 'atlases'};
is noun(q{atlases})->plural, q{atlases}  => q{plural: 'atlases' --> 'atlases'};
is noun(q{agora})->plural,   q{agorae}  => q{plural: 'agora' --> 'agorae'};
is noun(q{agorae})->plural, q{agorae}  => q{plural: 'agorae' --> 'agorae'};
is noun(q{techno})->plural,   q{technos}  => q{plural: 'techno' --> 'technos'};
is noun(q{technos})->plural, q{technos}  => q{plural: 'technos' --> 'technos'};
is noun(q{interstitium})->plural,   q{interstitiums}  => q{plural: 'interstitium' --> 'interstitiums'};
is noun(q{interstitiums})->plural, q{interstitiums}  => q{plural: 'interstitiums' --> 'interstitiums'};
is noun(q{eyas})->plural,   q{eyases}  => q{plural: 'eyas' --> 'eyases'};
is noun(q{eyases})->plural, q{eyases}  => q{plural: 'eyases' --> 'eyases'};
is noun(q{strobila})->plural,   q{strobilae}  => q{plural: 'strobila' --> 'strobilae'};
is noun(q{strobilae})->plural, q{strobilae}  => q{plural: 'strobilae' --> 'strobilae'};
is noun(q{fibula})->plural,   q{fibulas}  => q{plural: 'fibula' --> 'fibulas'};
is noun(q{fibulas})->plural, q{fibulas}  => q{plural: 'fibulas' --> 'fibulas'};
is noun(q{hymnarium})->plural,   q{hymnaria}  => q{plural: 'hymnarium' --> 'hymnaria'};
is noun(q{hymnaria})->plural, q{hymnaria}  => q{plural: 'hymnaria' --> 'hymnaria'};
is noun(q{three-star general})->plural,   q{three-star generals}  => q{plural: 'three-star general' --> 'three-star generals'};
is noun(q{three-star generals})->plural, q{three-star generals}  => q{plural: 'three-star generals' --> 'three-star generals'};
is noun(q{papyrus})->plural,   q{papyruses}  => q{plural: 'papyrus' --> 'papyruses'};
is noun(q{papyruses})->plural, q{papyruses}  => q{plural: 'papyruses' --> 'papyruses'};
is noun(q{one})->plural,   q{some}  => q{plural: 'one' --> 'some'};
is noun(q{some})->plural, q{some}  => q{plural: 'some' --> 'some'};
is noun(q{monoxylon})->plural,   q{monoxyla}  => q{plural: 'monoxylon' --> 'monoxyla'};
is noun(q{monoxyla})->plural, q{monoxyla}  => q{plural: 'monoxyla' --> 'monoxyla'};
is noun(q{arboretum})->plural,   q{arboreta}  => q{plural: 'arboretum' --> 'arboreta'};
is noun(q{arboreta})->plural, q{arboreta}  => q{plural: 'arboreta' --> 'arboreta'};
is noun(q{alluvium})->plural,   q{alluviums}  => q{plural: 'alluvium' --> 'alluviums'};
is noun(q{alluviums})->plural, q{alluviums}  => q{plural: 'alluviums' --> 'alluviums'};
is noun(q{thebe})->plural,   q{thebe}  => q{plural: 'thebe' --> 'thebe'};
is noun(q{Santiago})->plural,   q{Santiagos}  => q{plural: 'Santiago' --> 'Santiagos'};
is noun(q{Santiagos})->plural, q{Santiagos}  => q{plural: 'Santiagos' --> 'Santiagos'};
is noun(q{trapezius})->plural,   q{trapezii}  => q{plural: 'trapezius' --> 'trapezii'};
is noun(q{trapezii})->plural, q{trapezii}  => q{plural: 'trapezii' --> 'trapezii'};
is noun(q{parenchyma})->plural,   q{parenchymata}  => q{plural: 'parenchyma' --> 'parenchymata'};
is noun(q{parenchymata})->plural, q{parenchymata}  => q{plural: 'parenchymata' --> 'parenchymata'};
is noun(q{moaks})->plural,   q{moakses}  => q{plural: 'moaks' --> 'moakses'};
is noun(q{moakses})->plural, q{moakses}  => q{plural: 'moakses' --> 'moakses'};
is noun(q{tetragrammaton})->plural,   q{tetragrammata}  => q{plural: 'tetragrammaton' --> 'tetragrammata'};
is noun(q{tetragrammata})->plural, q{tetragrammata}  => q{plural: 'tetragrammata' --> 'tetragrammata'};
is noun(q{tetracolon})->plural,   q{tetracola}  => q{plural: 'tetracolon' --> 'tetracola'};
is noun(q{tetracola})->plural, q{tetracola}  => q{plural: 'tetracola' --> 'tetracola'};
is noun(q{schema})->plural,   q{schemas}  => q{plural: 'schema' --> 'schemas'};
is noun(q{schemas})->plural, q{schemas}  => q{plural: 'schemas' --> 'schemas'};
is noun(q{pastorale})->plural,   q{pastorales}  => q{plural: 'pastorale' --> 'pastorales'};
is noun(q{pastorales})->plural, q{pastorales}  => q{plural: 'pastorales' --> 'pastorales'};
is noun(q{dreikanter})->plural,   q{dreikanters}  => q{plural: 'dreikanter' --> 'dreikanters'};
is noun(q{dreikanters})->plural, q{dreikanters}  => q{plural: 'dreikanters' --> 'dreikanters'};
is noun(q{favella})->plural,   q{favellae}  => q{plural: 'favella' --> 'favellae'};
is noun(q{favellae})->plural, q{favellae}  => q{plural: 'favellae' --> 'favellae'};
is noun(q{sedes})->plural,   q{sedes}  => q{plural: 'sedes' --> 'sedes'};
is noun(q{finger-end})->plural,   q{finger-ends}  => q{plural: 'finger-end' --> 'finger-ends'};
is noun(q{finger-ends})->plural, q{finger-ends}  => q{plural: 'finger-ends' --> 'finger-ends'};
is noun(q{venus})->plural,   q{venuses}  => q{plural: 'venus' --> 'venuses'};
is noun(q{venuses})->plural, q{venuses}  => q{plural: 'venuses' --> 'venuses'};
is noun(q{stria})->plural,   q{striae}  => q{plural: 'stria' --> 'striae'};
is noun(q{striae})->plural, q{striae}  => q{plural: 'striae' --> 'striae'};
is noun(q{pollinium})->plural,   q{pollinia}  => q{plural: 'pollinium' --> 'pollinia'};
is noun(q{pollinia})->plural, q{pollinia}  => q{plural: 'pollinia' --> 'pollinia'};
is noun(q{Monaco})->plural,   q{Monacos}  => q{plural: 'Monaco' --> 'Monacos'};
is noun(q{Monacos})->plural, q{Monacos}  => q{plural: 'Monacos' --> 'Monacos'};
is noun(q{cuspis})->plural,   q{cuspides}  => q{plural: 'cuspis' --> 'cuspides'};
is noun(q{cuspides})->plural, q{cuspides}  => q{plural: 'cuspides' --> 'cuspides'};
is noun(q{streptothrix})->plural,   q{streptothrices}  => q{plural: 'streptothrix' --> 'streptothrices'};
is noun(q{streptothrices})->plural, q{streptothrices}  => q{plural: 'streptothrices' --> 'streptothrices'};
is noun(q{sustentaculum})->plural,   q{sustentacula}  => q{plural: 'sustentaculum' --> 'sustentacula'};
is noun(q{sustentacula})->plural, q{sustentacula}  => q{plural: 'sustentacula' --> 'sustentacula'};
is noun(q{torus})->plural,   q{toruses}  => q{plural: 'torus' --> 'toruses'};
is noun(q{toruses})->plural, q{toruses}  => q{plural: 'toruses' --> 'toruses'};
is noun(q{lixivium})->plural,   q{lixivia}  => q{plural: 'lixivium' --> 'lixivia'};
is noun(q{lixivia})->plural, q{lixivia}  => q{plural: 'lixivia' --> 'lixivia'};
is noun(q{miasma})->plural,   q{miasmas}  => q{plural: 'miasma' --> 'miasmas'};
is noun(q{miasmas})->plural, q{miasmas}  => q{plural: 'miasmas' --> 'miasmas'};
is noun(q{ballata})->plural,   q{ballate}  => q{plural: 'ballata' --> 'ballate'};
is noun(q{ballate})->plural, q{ballate}  => q{plural: 'ballate' --> 'ballate'};
is noun(q{praecognitum})->plural,   q{praecognita}  => q{plural: 'praecognitum' --> 'praecognita'};
is noun(q{praecognita})->plural, q{praecognita}  => q{plural: 'praecognita' --> 'praecognita'};
is noun(q{veduta})->plural,   q{vedutas}  => q{plural: 'veduta' --> 'vedutas'};
is noun(q{vedutas})->plural, q{vedutas}  => q{plural: 'vedutas' --> 'vedutas'};
is noun(q{yuo})->plural,   q{yuon}  => q{plural: 'yuo' --> 'yuon'};
is noun(q{yuon})->plural, q{yuon}  => q{plural: 'yuon' --> 'yuon'};
is noun(q{triplum})->plural,   q{tripla}  => q{plural: 'triplum' --> 'tripla'};
is noun(q{tripla})->plural, q{tripla}  => q{plural: 'tripla' --> 'tripla'};
is noun(q{vitellarium})->plural,   q{vitellaria}  => q{plural: 'vitellarium' --> 'vitellaria'};
is noun(q{vitellaria})->plural, q{vitellaria}  => q{plural: 'vitellaria' --> 'vitellaria'};
is noun(q{hsien})->plural,   q{heen}  => q{plural: 'hsien' --> 'heen'};
is noun(q{heen})->plural, q{heen}  => q{plural: 'heen' --> 'heen'};
is noun(q{talus})->plural,   q{tali}  => q{plural: 'talus' --> 'tali'};
is noun(q{tali})->plural, q{tali}  => q{plural: 'tali' --> 'tali'};
is noun(q{patera})->plural,   q{paterae}  => q{plural: 'patera' --> 'paterae'};
is noun(q{paterae})->plural, q{paterae}  => q{plural: 'paterae' --> 'paterae'};
is noun(q{opus magnum})->plural,   q{opera magna}  => q{plural: 'opus magnum' --> 'opera magna'};
is noun(q{opera magna})->plural, q{opera magna}  => q{plural: 'opera magna' --> 'opera magna'};
is noun(q{pajamas})->plural,   q{pajamas}  => q{plural: 'pajamas' --> 'pajamas'};
is noun(q{stigma})->plural,   q{stigmas}  => q{plural: 'stigma' --> 'stigmas'};
is noun(q{stigmas})->plural, q{stigmas}  => q{plural: 'stigmas' --> 'stigmas'};
is noun(q{bodegon})->plural,   q{bodegones}  => q{plural: 'bodegon' --> 'bodegones'};
is noun(q{bodegones})->plural, q{bodegones}  => q{plural: 'bodegones' --> 'bodegones'};
is noun(q{volcanello})->plural,   q{volcanelli}  => q{plural: 'volcanello' --> 'volcanelli'};
is noun(q{volcanelli})->plural, q{volcanelli}  => q{plural: 'volcanelli' --> 'volcanelli'};
is noun(q{pizza})->plural,   q{pizzas}  => q{plural: 'pizza' --> 'pizzas'};
is noun(q{pizzas})->plural, q{pizzas}  => q{plural: 'pizzas' --> 'pizzas'};
is noun(q{Spaetlese})->plural,   q{Spaetlesen}  => q{plural: 'Spaetlese' --> 'Spaetlesen'};
is noun(q{Spaetlesen})->plural, q{Spaetlesen}  => q{plural: 'Spaetlesen' --> 'Spaetlesen'};
is noun(q{hydraulicon})->plural,   q{hydraulica}  => q{plural: 'hydraulicon' --> 'hydraulica'};
is noun(q{hydraulica})->plural, q{hydraulica}  => q{plural: 'hydraulica' --> 'hydraulica'};
is noun(q{Azerbaijanese})->plural,   q{Azerbaijanese}  => q{plural: 'Azerbaijanese' --> 'Azerbaijanese'};
is noun(q{nebenkern})->plural,   q{nebenkerne}  => q{plural: 'nebenkern' --> 'nebenkerne'};
is noun(q{nebenkerne})->plural, q{nebenkerne}  => q{plural: 'nebenkerne' --> 'nebenkerne'};
is noun(q{set out})->plural,   q{set outs}  => q{plural: 'set out' --> 'set outs'};
is noun(q{set outs})->plural, q{set outs}  => q{plural: 'set outs' --> 'set outs'};
is noun(q{bubo})->plural,   q{buboes}  => q{plural: 'bubo' --> 'buboes'};
is noun(q{buboes})->plural, q{buboes}  => q{plural: 'buboes' --> 'buboes'};
is noun(q{manchild})->plural,   q{menchildren}  => q{plural: 'manchild' --> 'menchildren'};
is noun(q{menchildren})->plural, q{menchildren}  => q{plural: 'menchildren' --> 'menchildren'};
is noun(q{fermata})->plural,   q{fermatas}  => q{plural: 'fermata' --> 'fermatas'};
is noun(q{fermatas})->plural, q{fermatas}  => q{plural: 'fermatas' --> 'fermatas'};
is noun(q{samurai})->plural,   q{samurai}  => q{plural: 'samurai' --> 'samurai'};
is noun(q{salmon})->plural,   q{salmon}  => q{plural: 'salmon' --> 'salmon'};
is noun(q{leprosarium})->plural,   q{leprosaria}  => q{plural: 'leprosarium' --> 'leprosaria'};
is noun(q{leprosaria})->plural, q{leprosaria}  => q{plural: 'leprosaria' --> 'leprosaria'};
is noun(q{criterion})->plural,   q{criteria}  => q{plural: 'criterion' --> 'criteria'};
is noun(q{criteria})->plural, q{criteria}  => q{plural: 'criteria' --> 'criteria'};
is noun(q{ricercata})->plural,   q{ricercate}  => q{plural: 'ricercata' --> 'ricercate'};
is noun(q{ricercate})->plural, q{ricercate}  => q{plural: 'ricercate' --> 'ricercate'};
is noun(q{libero})->plural,   q{liberos}  => q{plural: 'libero' --> 'liberos'};
is noun(q{liberos})->plural, q{liberos}  => q{plural: 'liberos' --> 'liberos'};
is noun(q{lochus})->plural,   q{lochi}  => q{plural: 'lochus' --> 'lochi'};
is noun(q{lochi})->plural, q{lochi}  => q{plural: 'lochi' --> 'lochi'};
is noun(q{shad})->plural,   q{shads}  => q{plural: 'shad' --> 'shads'};
is noun(q{shads})->plural, q{shads}  => q{plural: 'shads' --> 'shads'};
is noun(q{sema})->plural,   q{semas}  => q{plural: 'sema' --> 'semas'};
is noun(q{semas})->plural, q{semas}  => q{plural: 'semas' --> 'semas'};
is noun(q{saffo})->plural,   q{saffi}  => q{plural: 'saffo' --> 'saffi'};
is noun(q{saffi})->plural, q{saffi}  => q{plural: 'saffi' --> 'saffi'};
is noun(q{fish})->plural,   q{fish}  => q{plural: 'fish' --> 'fish'};
is noun(q{scherzando})->plural,   q{scherzandos}  => q{plural: 'scherzando' --> 'scherzandos'};
is noun(q{scherzandos})->plural, q{scherzandos}  => q{plural: 'scherzandos' --> 'scherzandos'};
is noun(q{stipes})->plural,   q{stipites}  => q{plural: 'stipes' --> 'stipites'};
is noun(q{stipites})->plural, q{stipites}  => q{plural: 'stipites' --> 'stipites'};
is noun(q{sarissa})->plural,   q{sarissae}  => q{plural: 'sarissa' --> 'sarissae'};
is noun(q{sarissae})->plural, q{sarissae}  => q{plural: 'sarissae' --> 'sarissae'};
is noun(q{lord-lieutenant})->plural,   q{lord-lieutenants}  => q{plural: 'lord-lieutenant' --> 'lord-lieutenants'};
is noun(q{lord-lieutenants})->plural, q{lord-lieutenants}  => q{plural: 'lord-lieutenants' --> 'lord-lieutenants'};
is noun(q{souvlaki})->plural,   q{souvlakis}  => q{plural: 'souvlaki' --> 'souvlakis'};
is noun(q{souvlakis})->plural, q{souvlakis}  => q{plural: 'souvlakis' --> 'souvlakis'};
is noun(q{phoca})->plural,   q{phocas}  => q{plural: 'phoca' --> 'phocas'};
is noun(q{phocas})->plural, q{phocas}  => q{plural: 'phocas' --> 'phocas'};
is noun(q{lowlife})->plural,   q{lowlifes}  => q{plural: 'lowlife' --> 'lowlifes'};
is noun(q{lowlifes})->plural, q{lowlifes}  => q{plural: 'lowlifes' --> 'lowlifes'};
is noun(q{Lesotho})->plural,   q{Lesothos}  => q{plural: 'Lesotho' --> 'Lesothos'};
is noun(q{Lesothos})->plural, q{Lesothos}  => q{plural: 'Lesothos' --> 'Lesothos'};
is noun(q{fascia})->plural,   q{fascias}  => q{plural: 'fascia' --> 'fascias'};
is noun(q{fascias})->plural, q{fascias}  => q{plural: 'fascias' --> 'fascias'};
is noun(q{tessella})->plural,   q{tessellas}  => q{plural: 'tessella' --> 'tessellas'};
is noun(q{tessellas})->plural, q{tessellas}  => q{plural: 'tessellas' --> 'tessellas'};
is noun(q{tenorino})->plural,   q{tenorini}  => q{plural: 'tenorino' --> 'tenorini'};
is noun(q{tenorini})->plural, q{tenorini}  => q{plural: 'tenorini' --> 'tenorini'};
is noun(q{plectrum})->plural,   q{plectra}  => q{plural: 'plectrum' --> 'plectra'};
is noun(q{plectra})->plural, q{plectra}  => q{plural: 'plectra' --> 'plectra'};
is noun(q{Nipponese})->plural,   q{Nipponese}  => q{plural: 'Nipponese' --> 'Nipponese'};
is noun(q{aecidium})->plural,   q{aecidia}  => q{plural: 'aecidium' --> 'aecidia'};
is noun(q{aecidia})->plural, q{aecidia}  => q{plural: 'aecidia' --> 'aecidia'};
is noun(q{tabula})->plural,   q{tabulae}  => q{plural: 'tabula' --> 'tabulae'};
is noun(q{tabulae})->plural, q{tabulae}  => q{plural: 'tabulae' --> 'tabulae'};
is noun(q{plethron})->plural,   q{plethra}  => q{plural: 'plethron' --> 'plethra'};
is noun(q{plethra})->plural, q{plethra}  => q{plural: 'plethra' --> 'plethra'};
is noun(q{ambo})->plural,   q{ambos}  => q{plural: 'ambo' --> 'ambos'};
is noun(q{ambos})->plural, q{ambos}  => q{plural: 'ambos' --> 'ambos'};
is noun(q{octopus})->plural,   q{octopuses}  => q{plural: 'octopus' --> 'octopuses'};
is noun(q{octopuses})->plural, q{octopuses}  => q{plural: 'octopuses' --> 'octopuses'};
is noun(q{halteridium})->plural,   q{halteridia}  => q{plural: 'halteridium' --> 'halteridia'};
is noun(q{halteridia})->plural, q{halteridia}  => q{plural: 'halteridia' --> 'halteridia'};
is noun(q{Japanese})->plural,   q{Japanese}  => q{plural: 'Japanese' --> 'Japanese'};
is noun(q{paxilla})->plural,   q{paxillae}  => q{plural: 'paxilla' --> 'paxillae'};
is noun(q{paxillae})->plural, q{paxillae}  => q{plural: 'paxillae' --> 'paxillae'};
is noun(q{thymus})->plural,   q{thymi}  => q{plural: 'thymus' --> 'thymi'};
is noun(q{thymi})->plural, q{thymi}  => q{plural: 'thymi' --> 'thymi'};
is noun(q{proferens})->plural,   q{proferentes}  => q{plural: 'proferens' --> 'proferentes'};
is noun(q{proferentes})->plural, q{proferentes}  => q{plural: 'proferentes' --> 'proferentes'};
is noun(q{Chicago})->plural,   q{Chicagos}  => q{plural: 'Chicago' --> 'Chicagos'};
is noun(q{Chicagos})->plural, q{Chicagos}  => q{plural: 'Chicagos' --> 'Chicagos'};
is noun(q{nectocalyx})->plural,   q{nectocalyces}  => q{plural: 'nectocalyx' --> 'nectocalyces'};
is noun(q{nectocalyces})->plural, q{nectocalyces}  => q{plural: 'nectocalyces' --> 'nectocalyces'};
is noun(q{termes})->plural,   q{termites}  => q{plural: 'termes' --> 'termites'};
is noun(q{termites})->plural, q{termites}  => q{plural: 'termites' --> 'termites'};
is noun(q{Draco})->plural,   q{Dracos}  => q{plural: 'Draco' --> 'Dracos'};
is noun(q{Dracos})->plural, q{Dracos}  => q{plural: 'Dracos' --> 'Dracos'};
is noun(q{pilus})->plural,   q{pili}  => q{plural: 'pilus' --> 'pili'};
is noun(q{pili})->plural, q{pili}  => q{plural: 'pili' --> 'pili'};
is noun(q{nucleus})->plural,   q{nuclei}  => q{plural: 'nucleus' --> 'nuclei'};
is noun(q{nuclei})->plural, q{nuclei}  => q{plural: 'nuclei' --> 'nuclei'};
is noun(q{metapleuron})->plural,   q{metapleura}  => q{plural: 'metapleuron' --> 'metapleura'};
is noun(q{metapleura})->plural, q{metapleura}  => q{plural: 'metapleura' --> 'metapleura'};
is noun(q{aggro})->plural,   q{aggros}  => q{plural: 'aggro' --> 'aggros'};
is noun(q{aggros})->plural, q{aggros}  => q{plural: 'aggros' --> 'aggros'};
is noun(q{tazza})->plural,   q{tazze}  => q{plural: 'tazza' --> 'tazze'};
is noun(q{tazze})->plural, q{tazze}  => q{plural: 'tazze' --> 'tazze'};
is noun(q{quantum})->plural,   q{quantums}  => q{plural: 'quantum' --> 'quantums'};
is noun(q{quantums})->plural, q{quantums}  => q{plural: 'quantums' --> 'quantums'};
is noun(q{starfish})->plural,   q{starfishes}  => q{plural: 'starfish' --> 'starfishes'};
is noun(q{starfishes})->plural, q{starfishes}  => q{plural: 'starfishes' --> 'starfishes'};
is noun(q{syringe})->plural,   q{syringes}  => q{plural: 'syringe' --> 'syringes'};
is noun(q{syringes})->plural, q{syringes}  => q{plural: 'syringes' --> 'syringes'};
is noun(q{mary})->plural,   q{maries}  => q{plural: 'mary' --> 'maries'};
is noun(q{maries})->plural, q{maries}  => q{plural: 'maries' --> 'maries'};
is noun(q{pleco})->plural,   q{plecos}  => q{plural: 'pleco' --> 'plecos'};
is noun(q{plecos})->plural, q{plecos}  => q{plural: 'plecos' --> 'plecos'};
is noun(q{ditto})->plural,   q{dittos}  => q{plural: 'ditto' --> 'dittos'};
is noun(q{dittos})->plural, q{dittos}  => q{plural: 'dittos' --> 'dittos'};
is noun(q{podetium})->plural,   q{podetia}  => q{plural: 'podetium' --> 'podetia'};
is noun(q{podetia})->plural, q{podetia}  => q{plural: 'podetia' --> 'podetia'};
is noun(q{prosa})->plural,   q{prosae}  => q{plural: 'prosa' --> 'prosae'};
is noun(q{prosae})->plural, q{prosae}  => q{plural: 'prosae' --> 'prosae'};
is noun(q{magnifico})->plural,   q{magnificos}  => q{plural: 'magnifico' --> 'magnificos'};
is noun(q{magnificos})->plural, q{magnificos}  => q{plural: 'magnificos' --> 'magnificos'};
is noun(q{hypha})->plural,   q{hyphae}  => q{plural: 'hypha' --> 'hyphae'};
is noun(q{hyphae})->plural, q{hyphae}  => q{plural: 'hyphae' --> 'hyphae'};
is noun(q{man-midwife})->plural,   q{men-midwives}  => q{plural: 'man-midwife' --> 'men-midwives'};
is noun(q{men-midwives})->plural, q{men-midwives}  => q{plural: 'men-midwives' --> 'men-midwives'};
is noun(q{chapplis})->plural,   q{chapplies}  => q{plural: 'chapplis' --> 'chapplies'};
is noun(q{chapplies})->plural, q{chapplies}  => q{plural: 'chapplies' --> 'chapplies'};
is noun(q{secundigravida})->plural,   q{secundigravidas}  => q{plural: 'secundigravida' --> 'secundigravidas'};
is noun(q{secundigravidas})->plural, q{secundigravidas}  => q{plural: 'secundigravidas' --> 'secundigravidas'};
is noun(q{Pangasinan})->plural,   q{Pangasinans}  => q{plural: 'Pangasinan' --> 'Pangasinans'};
is noun(q{Pangasinans})->plural, q{Pangasinans}  => q{plural: 'Pangasinans' --> 'Pangasinans'};
is noun(q{coxendix})->plural,   q{coxendices}  => q{plural: 'coxendix' --> 'coxendices'};
is noun(q{coxendices})->plural, q{coxendices}  => q{plural: 'coxendices' --> 'coxendices'};
is noun(q{frate})->plural,   q{frati}  => q{plural: 'frate' --> 'frati'};
is noun(q{frati})->plural, q{frati}  => q{plural: 'frati' --> 'frati'};
is noun(q{trellis})->plural,   q{trellises}  => q{plural: 'trellis' --> 'trellises'};
is noun(q{trellises})->plural, q{trellises}  => q{plural: 'trellises' --> 'trellises'};
is noun(q{fowl})->plural,   q{fowls}  => q{plural: 'fowl' --> 'fowls'};
is noun(q{fowls})->plural, q{fowls}  => q{plural: 'fowls' --> 'fowls'};
is noun(q{progymnasium})->plural,   q{progymnasia}  => q{plural: 'progymnasium' --> 'progymnasia'};
is noun(q{progymnasia})->plural, q{progymnasia}  => q{plural: 'progymnasia' --> 'progymnasia'};
is noun(q{aptychus})->plural,   q{aptychi}  => q{plural: 'aptychus' --> 'aptychi'};
is noun(q{aptychi})->plural, q{aptychi}  => q{plural: 'aptychi' --> 'aptychi'};
is noun(q{cello})->plural,   q{cellos}  => q{plural: 'cello' --> 'cellos'};
is noun(q{cellos})->plural, q{cellos}  => q{plural: 'cellos' --> 'cellos'};
is noun(q{Jerry})->plural,   q{Jerrys}  => q{plural: 'Jerry' --> 'Jerrys'};
is noun(q{Jerrys})->plural, q{Jerrys}  => q{plural: 'Jerrys' --> 'Jerrys'};
is noun(q{Vietnamese})->plural,   q{Vietnamese}  => q{plural: 'Vietnamese' --> 'Vietnamese'};
is noun(q{mews})->plural,   q{mews}  => q{plural: 'mews' --> 'mews'};
is noun(q{tenuis})->plural,   q{tenues}  => q{plural: 'tenuis' --> 'tenues'};
is noun(q{tenues})->plural, q{tenues}  => q{plural: 'tenues' --> 'tenues'};
is noun(q{Antananarivo})->plural,   q{Antananarivos}  => q{plural: 'Antananarivo' --> 'Antananarivos'};
is noun(q{Antananarivos})->plural, q{Antananarivos}  => q{plural: 'Antananarivos' --> 'Antananarivos'};
is noun(q{referendum})->plural,   q{referendums}  => q{plural: 'referendum' --> 'referendums'};
is noun(q{referendums})->plural, q{referendums}  => q{plural: 'referendums' --> 'referendums'};
is noun(q{hippo})->plural,   q{hippos}  => q{plural: 'hippo' --> 'hippos'};
is noun(q{hippos})->plural, q{hippos}  => q{plural: 'hippos' --> 'hippos'};
is noun(q{scazon})->plural,   q{scazontes}  => q{plural: 'scazon' --> 'scazontes'};
is noun(q{scazontes})->plural, q{scazontes}  => q{plural: 'scazontes' --> 'scazontes'};
is noun(q{taenia})->plural,   q{taenias}  => q{plural: 'taenia' --> 'taenias'};
is noun(q{taenias})->plural, q{taenias}  => q{plural: 'taenias' --> 'taenias'};
is noun(q{lf})->plural,   q{lves}  => q{plural: 'lf' --> 'lves'};
is noun(q{lves})->plural, q{lves}  => q{plural: 'lves' --> 'lves'};
is noun(q{Quito})->plural,   q{Quitos}  => q{plural: 'Quito' --> 'Quitos'};
is noun(q{Quitos})->plural, q{Quitos}  => q{plural: 'Quitos' --> 'Quitos'};
is noun(q{buffalo})->plural,   q{buffalos}  => q{plural: 'buffalo' --> 'buffalos'};
is noun(q{buffalos})->plural, q{buffalos}  => q{plural: 'buffalos' --> 'buffalos'};
is noun(q{maestro})->plural,   q{maestros}  => q{plural: 'maestro' --> 'maestros'};
is noun(q{maestros})->plural, q{maestros}  => q{plural: 'maestros' --> 'maestros'};
is noun(q{wharf})->plural,   q{wharfs}  => q{plural: 'wharf' --> 'wharfs'};
is noun(q{wharfs})->plural, q{wharfs}  => q{plural: 'wharfs' --> 'wharfs'};
is noun(q{stromodeum})->plural,   q{stromodea}  => q{plural: 'stromodeum' --> 'stromodea'};
is noun(q{stromodea})->plural, q{stromodea}  => q{plural: 'stromodea' --> 'stromodea'};
is noun(q{remex})->plural,   q{remexes}  => q{plural: 'remex' --> 'remexes'};
is noun(q{remexes})->plural, q{remexes}  => q{plural: 'remexes' --> 'remexes'};
is noun(q{shauri})->plural,   q{shauris}  => q{plural: 'shauri' --> 'shauris'};
is noun(q{shauris})->plural, q{shauris}  => q{plural: 'shauris' --> 'shauris'};
is noun(q{striga})->plural,   q{strigae}  => q{plural: 'striga' --> 'strigae'};
is noun(q{strigae})->plural, q{strigae}  => q{plural: 'strigae' --> 'strigae'};
is noun(q{belle epoque})->plural,   q{belle epoques}  => q{plural: 'belle epoque' --> 'belle epoques'};
is noun(q{belle epoques})->plural, q{belle epoques}  => q{plural: 'belle epoques' --> 'belle epoques'};
is noun(q{nympha})->plural,   q{nymphae}  => q{plural: 'nympha' --> 'nymphae'};
is noun(q{nymphae})->plural, q{nymphae}  => q{plural: 'nymphae' --> 'nymphae'};
is noun(q{tetrahedron})->plural,   q{tetrahedrons}  => q{plural: 'tetrahedron' --> 'tetrahedrons'};
is noun(q{tetrahedrons})->plural, q{tetrahedrons}  => q{plural: 'tetrahedrons' --> 'tetrahedrons'};
is noun(q{chrysalis})->plural,   q{chrysalises}  => q{plural: 'chrysalis' --> 'chrysalises'};
is noun(q{chrysalises})->plural, q{chrysalises}  => q{plural: 'chrysalises' --> 'chrysalises'};
is noun(q{agend})->plural,   q{agends}  => q{plural: 'agend' --> 'agends'};
is noun(q{agends})->plural, q{agends}  => q{plural: 'agends' --> 'agends'};
is noun(q{strategos})->plural,   q{strategoi}  => q{plural: 'strategos' --> 'strategoi'};
is noun(q{strategoi})->plural, q{strategoi}  => q{plural: 'strategoi' --> 'strategoi'};
is noun(q{entrochus})->plural,   q{entrochi}  => q{plural: 'entrochus' --> 'entrochi'};
is noun(q{entrochi})->plural, q{entrochi}  => q{plural: 'entrochi' --> 'entrochi'};
is noun(q{nuntius})->plural,   q{nuntii}  => q{plural: 'nuntius' --> 'nuntii'};
is noun(q{nuntii})->plural, q{nuntii}  => q{plural: 'nuntii' --> 'nuntii'};
is noun(q{parc ferme})->plural,   q{parcs fermes}  => q{plural: 'parc ferme' --> 'parcs fermes'};
is noun(q{parcs fermes})->plural, q{parcs fermes}  => q{plural: 'parcs fermes' --> 'parcs fermes'};
is noun(q{trabea})->plural,   q{trabeae}  => q{plural: 'trabea' --> 'trabeae'};
is noun(q{trabeae})->plural, q{trabeae}  => q{plural: 'trabeae' --> 'trabeae'};
is noun(q{felo-de-se})->plural,   q{felos-de-se}  => q{plural: 'felo-de-se' --> 'felos-de-se'};
is noun(q{felos-de-se})->plural, q{felos-de-se}  => q{plural: 'felos-de-se' --> 'felos-de-se'};
is noun(q{faciendum})->plural,   q{facienda}  => q{plural: 'faciendum' --> 'facienda'};
is noun(q{facienda})->plural, q{facienda}  => q{plural: 'facienda' --> 'facienda'};
is noun(q{white staff})->plural,   q{white staves}  => q{plural: 'white staff' --> 'white staves'};
is noun(q{white staves})->plural, q{white staves}  => q{plural: 'white staves' --> 'white staves'};
is noun(q{Nakayaman})->plural,   q{Nakayamans}  => q{plural: 'Nakayaman' --> 'Nakayamans'};
is noun(q{Nakayamans})->plural, q{Nakayamans}  => q{plural: 'Nakayamans' --> 'Nakayamans'};
is noun(q{interambulacrum})->plural,   q{interambulacra}  => q{plural: 'interambulacrum' --> 'interambulacra'};
is noun(q{interambulacra})->plural, q{interambulacra}  => q{plural: 'interambulacra' --> 'interambulacra'};
is noun(q{synaxis})->plural,   q{synaxes}  => q{plural: 'synaxis' --> 'synaxes'};
is noun(q{synaxes})->plural, q{synaxes}  => q{plural: 'synaxes' --> 'synaxes'};
is noun(q{biscotto})->plural,   q{biscotti}  => q{plural: 'biscotto' --> 'biscotti'};
is noun(q{biscotti})->plural, q{biscotti}  => q{plural: 'biscotti' --> 'biscotti'};
is noun(q{tenaculum})->plural,   q{tenacula}  => q{plural: 'tenaculum' --> 'tenacula'};
is noun(q{tenacula})->plural, q{tenacula}  => q{plural: 'tenacula' --> 'tenacula'};
is noun(q{six-star general})->plural,   q{six-star generals}  => q{plural: 'six-star general' --> 'six-star generals'};
is noun(q{six-star generals})->plural, q{six-star generals}  => q{plural: 'six-star generals' --> 'six-star generals'};
is noun(q{Hararese})->plural,   q{Hararese}  => q{plural: 'Hararese' --> 'Hararese'};
is noun(q{flamenco})->plural,   q{flamencos}  => q{plural: 'flamenco' --> 'flamencos'};
is noun(q{flamencos})->plural, q{flamencos}  => q{plural: 'flamencos' --> 'flamencos'};
is noun(q{bimbo})->plural,   q{bimbos}  => q{plural: 'bimbo' --> 'bimbos'};
is noun(q{bimbos})->plural, q{bimbos}  => q{plural: 'bimbos' --> 'bimbos'};
is noun(q{mater lectionis})->plural,   q{matres lectionis}  => q{plural: 'mater lectionis' --> 'matres lectionis'};
is noun(q{matres lectionis})->plural, q{matres lectionis}  => q{plural: 'matres lectionis' --> 'matres lectionis'};
is noun(q{Yokohaman})->plural,   q{Yokohamans}  => q{plural: 'Yokohaman' --> 'Yokohamans'};
is noun(q{Yokohamans})->plural, q{Yokohamans}  => q{plural: 'Yokohamans' --> 'Yokohamans'};
is noun(q{Morocco})->plural,   q{Moroccos}  => q{plural: 'Morocco' --> 'Moroccos'};
is noun(q{Moroccos})->plural, q{Moroccos}  => q{plural: 'Moroccos' --> 'Moroccos'};
is noun(q{fuzz})->plural,   q{fuzzes}  => q{plural: 'fuzz' --> 'fuzzes'};
is noun(q{fuzzes})->plural, q{fuzzes}  => q{plural: 'fuzzes' --> 'fuzzes'};
is noun(q{fibroma})->plural,   q{fibromata}  => q{plural: 'fibroma' --> 'fibromata'};
is noun(q{fibromata})->plural, q{fibromata}  => q{plural: 'fibromata' --> 'fibromata'};
is noun(q{vinculum})->plural,   q{vincula}  => q{plural: 'vinculum' --> 'vincula'};
is noun(q{vincula})->plural, q{vincula}  => q{plural: 'vincula' --> 'vincula'};
is noun(q{pensiero})->plural,   q{pensieri}  => q{plural: 'pensiero' --> 'pensieri'};
is noun(q{pensieri})->plural, q{pensieri}  => q{plural: 'pensieri' --> 'pensieri'};
is noun(q{serum})->plural,   q{serums}  => q{plural: 'serum' --> 'serums'};
is noun(q{serums})->plural, q{serums}  => q{plural: 'serums' --> 'serums'};
is noun(q{rostrum})->plural,   q{rostrums}  => q{plural: 'rostrum' --> 'rostrums'};
is noun(q{rostrums})->plural, q{rostrums}  => q{plural: 'rostrums' --> 'rostrums'};
is noun(q{cosmos})->plural,   q{cosmoses}  => q{plural: 'cosmos' --> 'cosmoses'};
is noun(q{cosmoses})->plural, q{cosmoses}  => q{plural: 'cosmoses' --> 'cosmoses'};
is noun(q{collegium musicum})->plural,   q{collegia musica}  => q{plural: 'collegium musicum' --> 'collegia musica'};
is noun(q{collegia musica})->plural, q{collegia musica}  => q{plural: 'collegia musica' --> 'collegia musica'};
is noun(q{muzz})->plural,   q{muzzes}  => q{plural: 'muzz' --> 'muzzes'};
is noun(q{muzzes})->plural, q{muzzes}  => q{plural: 'muzzes' --> 'muzzes'};
is noun(q{vers libre})->plural,   q{vers libres}  => q{plural: 'vers libre' --> 'vers libres'};
is noun(q{vers libres})->plural, q{vers libres}  => q{plural: 'vers libres' --> 'vers libres'};
is noun(q{dynamo})->plural,   q{dynamos}  => q{plural: 'dynamo' --> 'dynamos'};
is noun(q{dynamos})->plural, q{dynamos}  => q{plural: 'dynamos' --> 'dynamos'};
is noun(q{3 star general})->plural,   q{3 star generals}  => q{plural: '3 star general' --> '3 star generals'};
is noun(q{3 star generals})->plural, q{3 star generals}  => q{plural: '3 star generals' --> '3 star generals'};
is noun(q{statua})->plural,   q{statuas}  => q{plural: 'statua' --> 'statuas'};
is noun(q{statuas})->plural, q{statuas}  => q{plural: 'statuas' --> 'statuas'};
is noun(q{cardophagus})->plural,   q{cardophagi}  => q{plural: 'cardophagus' --> 'cardophagi'};
is noun(q{cardophagi})->plural, q{cardophagi}  => q{plural: 'cardophagi' --> 'cardophagi'};
is noun(q{proboscis})->plural,   q{proboscises}  => q{plural: 'proboscis' --> 'proboscises'};
is noun(q{proboscises})->plural, q{proboscises}  => q{plural: 'proboscises' --> 'proboscises'};
is noun(q{caryopsis})->plural,   q{caryopsides}  => q{plural: 'caryopsis' --> 'caryopsides'};
is noun(q{caryopsides})->plural, q{caryopsides}  => q{plural: 'caryopsides' --> 'caryopsides'};
is noun(q{Modenese})->plural,   q{Modenese}  => q{plural: 'Modenese' --> 'Modenese'};
is noun(q{simulacrum})->plural,   q{simulacrums}  => q{plural: 'simulacrum' --> 'simulacrums'};
is noun(q{simulacrums})->plural, q{simulacrums}  => q{plural: 'simulacrums' --> 'simulacrums'};
is noun(q{virus})->plural,   q{viruses}  => q{plural: 'virus' --> 'viruses'};
is noun(q{viruses})->plural, q{viruses}  => q{plural: 'viruses' --> 'viruses'};
is noun(q{pyramidion})->plural,   q{pyramidions}  => q{plural: 'pyramidion' --> 'pyramidions'};
is noun(q{pyramidions})->plural, q{pyramidions}  => q{plural: 'pyramidions' --> 'pyramidions'};
is noun(q{macho})->plural,   q{machos}  => q{plural: 'macho' --> 'machos'};
is noun(q{machos})->plural, q{machos}  => q{plural: 'machos' --> 'machos'};
is noun(q{shears})->plural,   q{shears}  => q{plural: 'shears' --> 'shears'};
is noun(q{Timorese})->plural,   q{Timorese}  => q{plural: 'Timorese' --> 'Timorese'};
is noun(q{nenets})->plural,   q{nentsi}  => q{plural: 'nenets' --> 'nentsi'};
is noun(q{nentsi})->plural, q{nentsi}  => q{plural: 'nentsi' --> 'nentsi'};
is noun(q{anacoluthon})->plural,   q{anacoluthons}  => q{plural: 'anacoluthon' --> 'anacoluthons'};
is noun(q{anacoluthons})->plural, q{anacoluthons}  => q{plural: 'anacoluthons' --> 'anacoluthons'};
is noun(q{oedema})->plural,   q{oedemas}  => q{plural: 'oedema' --> 'oedemas'};
is noun(q{oedemas})->plural, q{oedemas}  => q{plural: 'oedemas' --> 'oedemas'};
is noun(q{hapax legomenon})->plural,   q{hapax legomenons}  => q{plural: 'hapax legomenon' --> 'hapax legomenons'};
is noun(q{hapax legomenons})->plural, q{hapax legomenons}  => q{plural: 'hapax legomenons' --> 'hapax legomenons'};
is noun(q{concertino})->plural,   q{concertinos}  => q{plural: 'concertino' --> 'concertinos'};
is noun(q{concertinos})->plural, q{concertinos}  => q{plural: 'concertinos' --> 'concertinos'};
is noun(q{her})->plural,   q{them}  => q{plural: 'her' --> 'them'};
is noun(q{bronchus})->plural,   q{bronchi}  => q{plural: 'bronchus' --> 'bronchi'};
is noun(q{bronchi})->plural, q{bronchi}  => q{plural: 'bronchi' --> 'bronchi'};
is noun(q{bel homme})->plural,   q{beaux hommes}  => q{plural: 'bel homme' --> 'beaux hommes'};
is noun(q{beaux hommes})->plural, q{beaux hommes}  => q{plural: 'beaux hommes' --> 'beaux hommes'};
is noun(q{stabilimentum})->plural,   q{stabilimenta}  => q{plural: 'stabilimentum' --> 'stabilimenta'};
is noun(q{stabilimenta})->plural, q{stabilimenta}  => q{plural: 'stabilimenta' --> 'stabilimenta'};
is noun(q{Iquico})->plural,   q{Iquicos}  => q{plural: 'Iquico' --> 'Iquicos'};
is noun(q{Iquicos})->plural, q{Iquicos}  => q{plural: 'Iquicos' --> 'Iquicos'};
is noun(q{loma})->plural,   q{lomata}  => q{plural: 'loma' --> 'lomata'};
is noun(q{lomata})->plural, q{lomata}  => q{plural: 'lomata' --> 'lomata'};
is noun(q{hertz})->plural,   q{hertz}  => q{plural: 'hertz' --> 'hertz'};
is noun(q{epicardium})->plural,   q{epicardia}  => q{plural: 'epicardium' --> 'epicardia'};
is noun(q{epicardia})->plural, q{epicardia}  => q{plural: 'epicardia' --> 'epicardia'};
is noun(q{cochito})->plural,   q{cochitos}  => q{plural: 'cochito' --> 'cochitos'};
is noun(q{cochitos})->plural, q{cochitos}  => q{plural: 'cochitos' --> 'cochitos'};
is noun(q{tegula})->plural,   q{tegulae}  => q{plural: 'tegula' --> 'tegulae'};
is noun(q{tegulae})->plural, q{tegulae}  => q{plural: 'tegulae' --> 'tegulae'};
is noun(q{oxybaphon})->plural,   q{oxybapha}  => q{plural: 'oxybaphon' --> 'oxybapha'};
is noun(q{oxybapha})->plural, q{oxybapha}  => q{plural: 'oxybapha' --> 'oxybapha'};
is noun(q{papula})->plural,   q{papulae}  => q{plural: 'papula' --> 'papulae'};
is noun(q{papulae})->plural, q{papulae}  => q{plural: 'papulae' --> 'papulae'};
is noun(q{turron})->plural,   q{turrons}  => q{plural: 'turron' --> 'turrons'};
is noun(q{turrons})->plural, q{turrons}  => q{plural: 'turrons' --> 'turrons'};
is noun(q{photo})->plural,   q{photos}  => q{plural: 'photo' --> 'photos'};
is noun(q{photos})->plural, q{photos}  => q{plural: 'photos' --> 'photos'};
is noun(q{bateau})->plural,   q{bateaux}  => q{plural: 'bateau' --> 'bateaux'};
is noun(q{bateaux})->plural, q{bateaux}  => q{plural: 'bateaux' --> 'bateaux'};
is noun(q{Arakanese})->plural,   q{Arakanese}  => q{plural: 'Arakanese' --> 'Arakanese'};
is noun(q{mediastinum})->plural,   q{mediastina}  => q{plural: 'mediastinum' --> 'mediastina'};
is noun(q{mediastina})->plural, q{mediastina}  => q{plural: 'mediastina' --> 'mediastina'};
is noun(q{sarcina})->plural,   q{sarcinae}  => q{plural: 'sarcina' --> 'sarcinae'};
is noun(q{sarcinae})->plural, q{sarcinae}  => q{plural: 'sarcinae' --> 'sarcinae'};
is noun(q{sol})->plural,   q{soles}  => q{plural: 'sol' --> 'soles'};
is noun(q{soles})->plural, q{soles}  => q{plural: 'soles' --> 'soles'};
is noun(q{intercalarium})->plural,   q{intercalaria}  => q{plural: 'intercalarium' --> 'intercalaria'};
is noun(q{intercalaria})->plural, q{intercalaria}  => q{plural: 'intercalaria' --> 'intercalaria'};
is noun(q{supernova})->plural,   q{supernovas}  => q{plural: 'supernova' --> 'supernovas'};
is noun(q{supernovas})->plural, q{supernovas}  => q{plural: 'supernovas' --> 'supernovas'};
is noun(q{vivarium})->plural,   q{vivariums}  => q{plural: 'vivarium' --> 'vivariums'};
is noun(q{vivariums})->plural, q{vivariums}  => q{plural: 'vivariums' --> 'vivariums'};
is noun(q{secundipara})->plural,   q{secundiparas}  => q{plural: 'secundipara' --> 'secundiparas'};
is noun(q{secundiparas})->plural, q{secundiparas}  => q{plural: 'secundiparas' --> 'secundiparas'};
is noun(q{poblador})->plural,   q{pobladores}  => q{plural: 'poblador' --> 'pobladores'};
is noun(q{pobladores})->plural, q{pobladores}  => q{plural: 'pobladores' --> 'pobladores'};
is noun(q{ignoramus})->plural,   q{ignoramuses}  => q{plural: 'ignoramus' --> 'ignoramuses'};
is noun(q{ignoramuses})->plural, q{ignoramuses}  => q{plural: 'ignoramuses' --> 'ignoramuses'};
is noun(q{sizz})->plural,   q{sizzes}  => q{plural: 'sizz' --> 'sizzes'};
is noun(q{sizzes})->plural, q{sizzes}  => q{plural: 'sizzes' --> 'sizzes'};
is noun(q{brigadier general})->plural,   q{brigadier generals}  => q{plural: 'brigadier general' --> 'brigadier generals'};
is noun(q{brigadier generals})->plural, q{brigadier generals}  => q{plural: 'brigadier generals' --> 'brigadier generals'};
is noun(q{succinea})->plural,   q{succineas}  => q{plural: 'succinea' --> 'succineas'};
is noun(q{succineas})->plural, q{succineas}  => q{plural: 'succineas' --> 'succineas'};
is noun(q{velum})->plural,   q{velums}  => q{plural: 'velum' --> 'velums'};
is noun(q{velums})->plural, q{velums}  => q{plural: 'velums' --> 'velums'};
is noun(q{army-corps general})->plural,   q{army-corps generals}  => q{plural: 'army-corps general' --> 'army-corps generals'};
is noun(q{army-corps generals})->plural, q{army-corps generals}  => q{plural: 'army-corps generals' --> 'army-corps generals'};
is noun(q{pinto})->plural,   q{pintos}  => q{plural: 'pinto' --> 'pintos'};
is noun(q{pintos})->plural, q{pintos}  => q{plural: 'pintos' --> 'pintos'};
is noun(q{conductus})->plural,   q{conducti}  => q{plural: 'conductus' --> 'conducti'};
is noun(q{conducti})->plural, q{conducti}  => q{plural: 'conducti' --> 'conducti'};
is noun(q{modernus})->plural,   q{moderni}  => q{plural: 'modernus' --> 'moderni'};
is noun(q{moderni})->plural, q{moderni}  => q{plural: 'moderni' --> 'moderni'};
is noun(q{turf})->plural,   q{turfs}  => q{plural: 'turf' --> 'turfs'};
is noun(q{turfs})->plural, q{turfs}  => q{plural: 'turfs' --> 'turfs'};
is noun(q{flabellum})->plural,   q{flabella}  => q{plural: 'flabellum' --> 'flabella'};
is noun(q{flabella})->plural, q{flabella}  => q{plural: 'flabella' --> 'flabella'};
is noun(q{unguis})->plural,   q{ungues}  => q{plural: 'unguis' --> 'ungues'};
is noun(q{ungues})->plural, q{ungues}  => q{plural: 'ungues' --> 'ungues'};
is noun(q{extremum})->plural,   q{extremums}  => q{plural: 'extremum' --> 'extremums'};
is noun(q{extremums})->plural, q{extremums}  => q{plural: 'extremums' --> 'extremums'};
is noun(q{pluteus})->plural,   q{plutei}  => q{plural: 'pluteus' --> 'plutei'};
is noun(q{plutei})->plural, q{plutei}  => q{plural: 'plutei' --> 'plutei'};
is noun(q{autobahn})->plural,   q{autobahns}  => q{plural: 'autobahn' --> 'autobahns'};
is noun(q{autobahns})->plural, q{autobahns}  => q{plural: 'autobahns' --> 'autobahns'};
is noun(q{seed})->plural,   q{seeds}  => q{plural: 'seed' --> 'seeds'};
is noun(q{seeds})->plural, q{seeds}  => q{plural: 'seeds' --> 'seeds'};
is noun(q{vas})->plural,   q{vasa}  => q{plural: 'vas' --> 'vasa'};
is noun(q{vasa})->plural, q{vasa}  => q{plural: 'vasa' --> 'vasa'};
is noun(q{zygoma})->plural,   q{zygomas}  => q{plural: 'zygoma' --> 'zygomas'};
is noun(q{zygomas})->plural, q{zygomas}  => q{plural: 'zygomas' --> 'zygomas'};
is noun(q{trousseau})->plural,   q{trousseaus}  => q{plural: 'trousseau' --> 'trousseaus'};
is noun(q{trousseaus})->plural, q{trousseaus}  => q{plural: 'trousseaus' --> 'trousseaus'};
is noun(q{depositum})->plural,   q{depositums}  => q{plural: 'depositum' --> 'depositums'};
is noun(q{depositums})->plural, q{depositums}  => q{plural: 'depositums' --> 'depositums'};
is noun(q{vetturino})->plural,   q{vetturini}  => q{plural: 'vetturino' --> 'vetturini'};
is noun(q{vetturini})->plural, q{vetturini}  => q{plural: 'vetturini' --> 'vetturini'};
is noun(q{Mexico})->plural,   q{Mexicos}  => q{plural: 'Mexico' --> 'Mexicos'};
is noun(q{Mexicos})->plural, q{Mexicos}  => q{plural: 'Mexicos' --> 'Mexicos'};
is noun(q{vis})->plural,   q{vires}  => q{plural: 'vis' --> 'vires'};
is noun(q{vires})->plural, q{vires}  => q{plural: 'vires' --> 'vires'};
is noun(q{sympodium})->plural,   q{sympodia}  => q{plural: 'sympodium' --> 'sympodia'};
is noun(q{sympodia})->plural, q{sympodia}  => q{plural: 'sympodia' --> 'sympodia'};
is noun(q{axis})->plural,   q{axes}  => q{plural: 'axis' --> 'axes'};
is noun(q{axes})->plural, q{axes}  => q{plural: 'axes' --> 'axes'};
is noun(q{deer})->plural,   q{deer}  => q{plural: 'deer' --> 'deer'};
is noun(q{Guianese})->plural,   q{Guianese}  => q{plural: 'Guianese' --> 'Guianese'};
is noun(q{Bhutanese})->plural,   q{Bhutanese}  => q{plural: 'Bhutanese' --> 'Bhutanese'};
is noun(q{Pistoiese})->plural,   q{Pistoiese}  => q{plural: 'Pistoiese' --> 'Pistoiese'};
is noun(q{megalosaurus})->plural,   q{megalosauri}  => q{plural: 'megalosaurus' --> 'megalosauri'};
is noun(q{megalosauri})->plural, q{megalosauri}  => q{plural: 'megalosauri' --> 'megalosauri'};
is noun(q{mukim})->plural,   q{mukims}  => q{plural: 'mukim' --> 'mukims'};
is noun(q{mukims})->plural, q{mukims}  => q{plural: 'mukims' --> 'mukims'};
is noun(q{fibra})->plural,   q{fibrae}  => q{plural: 'fibra' --> 'fibrae'};
is noun(q{fibrae})->plural, q{fibrae}  => q{plural: 'fibrae' --> 'fibrae'};
is noun(q{blitz})->plural,   q{blitzes}  => q{plural: 'blitz' --> 'blitzes'};
is noun(q{blitzes})->plural, q{blitzes}  => q{plural: 'blitzes' --> 'blitzes'};
is noun(q{monseigneur})->plural,   q{monsiegneurs}  => q{plural: 'monseigneur' --> 'monsiegneurs'};
is noun(q{monsiegneurs})->plural, q{monsiegneurs}  => q{plural: 'monsiegneurs' --> 'monsiegneurs'};
is noun(q{tintinnabulum})->plural,   q{tintinnabula}  => q{plural: 'tintinnabulum' --> 'tintinnabula'};
is noun(q{tintinnabula})->plural, q{tintinnabula}  => q{plural: 'tintinnabula' --> 'tintinnabula'};
is noun(q{mafioso})->plural,   q{mafiosi}  => q{plural: 'mafioso' --> 'mafiosi'};
is noun(q{mafiosi})->plural, q{mafiosi}  => q{plural: 'mafiosi' --> 'mafiosi'};
is noun(q{prospectus})->plural,   q{prospectuses}  => q{plural: 'prospectus' --> 'prospectuses'};
is noun(q{prospectuses})->plural, q{prospectuses}  => q{plural: 'prospectuses' --> 'prospectuses'};
is noun(q{senex})->plural,   q{senes}  => q{plural: 'senex' --> 'senes'};
is noun(q{senes})->plural, q{senes}  => q{plural: 'senes' --> 'senes'};
is noun(q{spermogonium})->plural,   q{spermogonia}  => q{plural: 'spermogonium' --> 'spermogonia'};
is noun(q{spermogonia})->plural, q{spermogonia}  => q{plural: 'spermogonia' --> 'spermogonia'};
is noun(q{Carlylese})->plural,   q{Carlylese}  => q{plural: 'Carlylese' --> 'Carlylese'};
is noun(q{bravo})->plural,   q{bravos}  => q{plural: 'bravo' --> 'bravos'};
is noun(q{bravos})->plural, q{bravos}  => q{plural: 'bravos' --> 'bravos'};
is noun(q{matinee musicale})->plural,   q{matinees musicales}  => q{plural: 'matinee musicale' --> 'matinees musicales'};
is noun(q{matinees musicales})->plural, q{matinees musicales}  => q{plural: 'matinees musicales' --> 'matinees musicales'};
is noun(q{tetanothrum})->plural,   q{tetanothra}  => q{plural: 'tetanothrum' --> 'tetanothra'};
is noun(q{tetanothra})->plural, q{tetanothra}  => q{plural: 'tetanothra' --> 'tetanothra'};
is noun(q{terzetto})->plural,   q{terzetti}  => q{plural: 'terzetto' --> 'terzetti'};
is noun(q{terzetti})->plural, q{terzetti}  => q{plural: 'terzetti' --> 'terzetti'};
is noun(q{aphelion})->plural,   q{aphelia}  => q{plural: 'aphelion' --> 'aphelia'};
is noun(q{aphelia})->plural, q{aphelia}  => q{plural: 'aphelia' --> 'aphelia'};
is noun(q{trapezium})->plural,   q{trapeziums}  => q{plural: 'trapezium' --> 'trapeziums'};
is noun(q{trapeziums})->plural, q{trapeziums}  => q{plural: 'trapeziums' --> 'trapeziums'};
is noun(q{rectus})->plural,   q{recti}  => q{plural: 'rectus' --> 'recti'};
is noun(q{recti})->plural, q{recti}  => q{plural: 'recti' --> 'recti'};
is noun(q{roe})->plural,   q{roes}  => q{plural: 'roe' --> 'roes'};
is noun(q{roes})->plural, q{roes}  => q{plural: 'roes' --> 'roes'};
is noun(q{kar})->plural,   q{kars}  => q{plural: 'kar' --> 'kars'};
is noun(q{kars})->plural, q{kars}  => q{plural: 'kars' --> 'kars'};
is noun(q{drama})->plural,   q{dramas}  => q{plural: 'drama' --> 'dramas'};
is noun(q{dramas})->plural, q{dramas}  => q{plural: 'dramas' --> 'dramas'};
is noun(q{olfactorium})->plural,   q{olfactoria}  => q{plural: 'olfactorium' --> 'olfactoria'};
is noun(q{olfactoria})->plural, q{olfactoria}  => q{plural: 'olfactoria' --> 'olfactoria'};
is noun(q{vortex})->plural,   q{vortexes}  => q{plural: 'vortex' --> 'vortexes'};
is noun(q{vortexes})->plural, q{vortexes}  => q{plural: 'vortexes' --> 'vortexes'};
is noun(q{hero})->plural,   q{heroes}  => q{plural: 'hero' --> 'heroes'};
is noun(q{heroes})->plural, q{heroes}  => q{plural: 'heroes' --> 'heroes'};
is noun(q{Cairo})->plural,   q{Cairos}  => q{plural: 'Cairo' --> 'Cairos'};
is noun(q{Cairos})->plural, q{Cairos}  => q{plural: 'Cairos' --> 'Cairos'};
is noun(q{Mary})->plural,   q{Marys}  => q{plural: 'Mary' --> 'Marys'};
is noun(q{Marys})->plural, q{Marys}  => q{plural: 'Marys' --> 'Marys'};
is noun(q{triumvir})->plural,   q{triumvirs}  => q{plural: 'triumvir' --> 'triumvirs'};
is noun(q{triumvirs})->plural, q{triumvirs}  => q{plural: 'triumvirs' --> 'triumvirs'};
is noun(q{valuta})->plural,   q{valute}  => q{plural: 'valuta' --> 'valute'};
is noun(q{valute})->plural, q{valute}  => q{plural: 'valute' --> 'valute'};
is noun(q{panto})->plural,   q{pantos}  => q{plural: 'panto' --> 'pantos'};
is noun(q{pantos})->plural, q{pantos}  => q{plural: 'pantos' --> 'pantos'};
is noun(q{brachiopod})->plural,   q{brachiopods}  => q{plural: 'brachiopod' --> 'brachiopods'};
is noun(q{brachiopods})->plural, q{brachiopods}  => q{plural: 'brachiopods' --> 'brachiopods'};
is noun(q{bureau})->plural,   q{bureaus}  => q{plural: 'bureau' --> 'bureaus'};
is noun(q{bureaus})->plural, q{bureaus}  => q{plural: 'bureaus' --> 'bureaus'};
is noun(q{putto})->plural,   q{putti}  => q{plural: 'putto' --> 'putti'};
is noun(q{putti})->plural, q{putti}  => q{plural: 'putti' --> 'putti'};
is noun(q{alumna})->plural,   q{alumnae}  => q{plural: 'alumna' --> 'alumnae'};
is noun(q{alumnae})->plural, q{alumnae}  => q{plural: 'alumnae' --> 'alumnae'};
is noun(q{alto})->plural,   q{altos}  => q{plural: 'alto' --> 'altos'};
is noun(q{altos})->plural, q{altos}  => q{plural: 'altos' --> 'altos'};
is noun(q{bifolium})->plural,   q{bifolia}  => q{plural: 'bifolium' --> 'bifolia'};
is noun(q{bifolia})->plural, q{bifolia}  => q{plural: 'bifolia' --> 'bifolia'};
is noun(q{kletterschuh})->plural,   q{kletterschuhe}  => q{plural: 'kletterschuh' --> 'kletterschuhe'};
is noun(q{kletterschuhe})->plural, q{kletterschuhe}  => q{plural: 'kletterschuhe' --> 'kletterschuhe'};
is noun(q{ataman})->plural,   q{atamans}  => q{plural: 'ataman' --> 'atamans'};
is noun(q{atamans})->plural, q{atamans}  => q{plural: 'atamans' --> 'atamans'};
is noun(q{euro})->plural,   q{euros}  => q{plural: 'euro' --> 'euros'};
is noun(q{euros})->plural, q{euros}  => q{plural: 'euros' --> 'euros'};
is noun(q{spiraculum})->plural,   q{spiracula}  => q{plural: 'spiraculum' --> 'spiracula'};
is noun(q{spiracula})->plural, q{spiracula}  => q{plural: 'spiracula' --> 'spiracula'};
is noun(q{jambeau})->plural,   q{jambeaus}  => q{plural: 'jambeau' --> 'jambeaus'};
is noun(q{jambeaus})->plural, q{jambeaus}  => q{plural: 'jambeaus' --> 'jambeaus'};
is noun(q{coe})->plural,   q{coes}  => q{plural: 'coe' --> 'coes'};
is noun(q{coes})->plural, q{coes}  => q{plural: 'coes' --> 'coes'};
is noun(q{prototypon})->plural,   q{prototypons}  => q{plural: 'prototypon' --> 'prototypons'};
is noun(q{prototypons})->plural, q{prototypons}  => q{plural: 'prototypons' --> 'prototypons'};
is noun(q{oregano})->plural,   q{oreganos}  => q{plural: 'oregano' --> 'oreganos'};
is noun(q{oreganos})->plural, q{oreganos}  => q{plural: 'oreganos' --> 'oreganos'};
is noun(q{apothecium})->plural,   q{apothecia}  => q{plural: 'apothecium' --> 'apothecia'};
is noun(q{apothecia})->plural, q{apothecia}  => q{plural: 'apothecia' --> 'apothecia'};
is noun(q{fulcrum})->plural,   q{fulcra}  => q{plural: 'fulcrum' --> 'fulcra'};
is noun(q{fulcra})->plural, q{fulcra}  => q{plural: 'fulcra' --> 'fulcra'};
is noun(q{xiphopagus})->plural,   q{xiphopagi}  => q{plural: 'xiphopagus' --> 'xiphopagi'};
is noun(q{xiphopagi})->plural, q{xiphopagi}  => q{plural: 'xiphopagi' --> 'xiphopagi'};
is noun(q{perradius})->plural,   q{perradii}  => q{plural: 'perradius' --> 'perradii'};
is noun(q{perradii})->plural, q{perradii}  => q{plural: 'perradii' --> 'perradii'};
is noun(q{crescendo})->plural,   q{crescendos}  => q{plural: 'crescendo' --> 'crescendos'};
is noun(q{crescendos})->plural, q{crescendos}  => q{plural: 'crescendos' --> 'crescendos'};
is noun(q{Veronese})->plural,   q{Veronese}  => q{plural: 'Veronese' --> 'Veronese'};
is noun(q{solo})->plural,   q{solos}  => q{plural: 'solo' --> 'solos'};
is noun(q{solos})->plural, q{solos}  => q{plural: 'solos' --> 'solos'};
is noun(q{oculus})->plural,   q{oculi}  => q{plural: 'oculus' --> 'oculi'};
is noun(q{oculi})->plural, q{oculi}  => q{plural: 'oculi' --> 'oculi'};
is noun(q{ultimatum})->plural,   q{ultimatums}  => q{plural: 'ultimatum' --> 'ultimatums'};
is noun(q{ultimatums})->plural, q{ultimatums}  => q{plural: 'ultimatums' --> 'ultimatums'};
is noun(q{zeppole})->plural,   q{zeppoli}  => q{plural: 'zeppole' --> 'zeppoli'};
is noun(q{zeppoli})->plural, q{zeppoli}  => q{plural: 'zeppoli' --> 'zeppoli'};
is noun(q{anthemion})->plural,   q{anthemia}  => q{plural: 'anthemion' --> 'anthemia'};
is noun(q{anthemia})->plural, q{anthemia}  => q{plural: 'anthemia' --> 'anthemia'};
is noun(q{lido})->plural,   q{lidos}  => q{plural: 'lido' --> 'lidos'};
is noun(q{lidos})->plural, q{lidos}  => q{plural: 'lidos' --> 'lidos'};
is noun(q{zygantrum})->plural,   q{zygantra}  => q{plural: 'zygantrum' --> 'zygantra'};
is noun(q{zygantra})->plural, q{zygantra}  => q{plural: 'zygantra' --> 'zygantra'};
is noun(q{Romany})->plural,   q{Romanies}  => q{plural: 'Romany' --> 'Romanies'};
is noun(q{Romanies})->plural, q{Romanies}  => q{plural: 'Romanies' --> 'Romanies'};
is noun(q{spasmus})->plural,   q{spasmi}  => q{plural: 'spasmus' --> 'spasmi'};
is noun(q{spasmi})->plural, q{spasmi}  => q{plural: 'spasmi' --> 'spasmi'};
is noun(q{osmaterium})->plural,   q{osmateria}  => q{plural: 'osmaterium' --> 'osmateria'};
is noun(q{osmateria})->plural, q{osmateria}  => q{plural: 'osmateria' --> 'osmateria'};
is noun(q{judas})->plural,   q{judases}  => q{plural: 'judas' --> 'judases'};
is noun(q{judases})->plural, q{judases}  => q{plural: 'judases' --> 'judases'};
is noun(q{intichiuma})->plural,   q{intichiuma}  => q{plural: 'intichiuma' --> 'intichiuma'};
is noun(q{aegis})->plural,   q{aegises}  => q{plural: 'aegis' --> 'aegises'};
is noun(q{aegises})->plural, q{aegises}  => q{plural: 'aegises' --> 'aegises'};
is noun(q{Malabo})->plural,   q{Malabos}  => q{plural: 'Malabo' --> 'Malabos'};
is noun(q{Malabos})->plural, q{Malabos}  => q{plural: 'Malabos' --> 'Malabos'};
is noun(q{struma})->plural,   q{strumae}  => q{plural: 'struma' --> 'strumae'};
is noun(q{strumae})->plural, q{strumae}  => q{plural: 'strumae' --> 'strumae'};
is noun(q{polo})->plural,   q{polos}  => q{plural: 'polo' --> 'polos'};
is noun(q{polos})->plural, q{polos}  => q{plural: 'polos' --> 'polos'};
is noun(q{Sarawakese})->plural,   q{Sarawakese}  => q{plural: 'Sarawakese' --> 'Sarawakese'};
is noun(q{stryddag})->plural,   q{stryddae}  => q{plural: 'stryddag' --> 'stryddae'};
is noun(q{stryddae})->plural, q{stryddae}  => q{plural: 'stryddae' --> 'stryddae'};
is noun(q{plasmolyticum})->plural,   q{plasmolytica}  => q{plural: 'plasmolyticum' --> 'plasmolytica'};
is noun(q{plasmolytica})->plural, q{plasmolytica}  => q{plural: 'plasmolytica' --> 'plasmolytica'};
is noun(q{topos})->plural,   q{topoi}  => q{plural: 'topos' --> 'topoi'};
is noun(q{topoi})->plural, q{topoi}  => q{plural: 'topoi' --> 'topoi'};
is noun(q{duumvir})->plural,   q{duumvirs}  => q{plural: 'duumvir' --> 'duumvirs'};
is noun(q{duumvirs})->plural, q{duumvirs}  => q{plural: 'duumvirs' --> 'duumvirs'};
is noun(q{castrato})->plural,   q{castrati}  => q{plural: 'castrato' --> 'castrati'};
is noun(q{castrati})->plural, q{castrati}  => q{plural: 'castrati' --> 'castrati'};
is noun(q{bingo})->plural,   q{bingos}  => q{plural: 'bingo' --> 'bingos'};
is noun(q{bingos})->plural, q{bingos}  => q{plural: 'bingos' --> 'bingos'};
is noun(q{directrix})->plural,   q{directrices}  => q{plural: 'directrix' --> 'directrices'};
is noun(q{directrices})->plural, q{directrices}  => q{plural: 'directrices' --> 'directrices'};
is noun(q{lis})->plural,   q{lisses}  => q{plural: 'lis' --> 'lisses'};
is noun(q{lisses})->plural, q{lisses}  => q{plural: 'lisses' --> 'lisses'};
is noun(q{tepidarium})->plural,   q{tepidaria}  => q{plural: 'tepidarium' --> 'tepidaria'};
is noun(q{tepidaria})->plural, q{tepidaria}  => q{plural: 'tepidaria' --> 'tepidaria'};
is noun(q{haggis})->plural,   q{haggis}  => q{plural: 'haggis' --> 'haggis'};
is noun(q{trullo})->plural,   q{trulli}  => q{plural: 'trullo' --> 'trulli'};
is noun(q{trulli})->plural, q{trulli}  => q{plural: 'trulli' --> 'trulli'};
is noun(q{palpebra})->plural,   q{palpebrae}  => q{plural: 'palpebra' --> 'palpebrae'};
is noun(q{palpebrae})->plural, q{palpebrae}  => q{plural: 'palpebrae' --> 'palpebrae'};
is noun(q{ascidium})->plural,   q{ascidia}  => q{plural: 'ascidium' --> 'ascidia'};
is noun(q{ascidia})->plural, q{ascidia}  => q{plural: 'ascidia' --> 'ascidia'};
is noun(q{rejoneador})->plural,   q{rejoneadores}  => q{plural: 'rejoneador' --> 'rejoneadores'};
is noun(q{rejoneadores})->plural, q{rejoneadores}  => q{plural: 'rejoneadores' --> 'rejoneadores'};
is noun(q{diporpa})->plural,   q{diporpae}  => q{plural: 'diporpa' --> 'diporpae'};
is noun(q{diporpae})->plural, q{diporpae}  => q{plural: 'diporpae' --> 'diporpae'};
is noun(q{urodeum})->plural,   q{urodea}  => q{plural: 'urodeum' --> 'urodea'};
is noun(q{urodea})->plural, q{urodea}  => q{plural: 'urodea' --> 'urodea'};
is noun(q{basso})->plural,   q{bassos}  => q{plural: 'basso' --> 'bassos'};
is noun(q{bassos})->plural, q{bassos}  => q{plural: 'bassos' --> 'bassos'};
is noun(q{spectrum})->plural,   q{spectrums}  => q{plural: 'spectrum' --> 'spectrums'};
is noun(q{spectrums})->plural, q{spectrums}  => q{plural: 'spectrums' --> 'spectrums'};
is noun(q{frottola})->plural,   q{frottole}  => q{plural: 'frottola' --> 'frottole'};
is noun(q{frottole})->plural, q{frottole}  => q{plural: 'frottole' --> 'frottole'};
is noun(q{spirillum})->plural,   q{spirilla}  => q{plural: 'spirillum' --> 'spirilla'};
is noun(q{spirilla})->plural, q{spirilla}  => q{plural: 'spirilla' --> 'spirilla'};
is noun(q{coitus})->plural,   q{coituses}  => q{plural: 'coitus' --> 'coituses'};
is noun(q{coituses})->plural, q{coituses}  => q{plural: 'coituses' --> 'coituses'};
is noun(q{ancona})->plural,   q{ancone}  => q{plural: 'ancona' --> 'ancone'};
is noun(q{ancone})->plural, q{ancone}  => q{plural: 'ancone' --> 'ancone'};
is noun(q{whomever})->plural,   q{whomever}  => q{plural: 'whomever' --> 'whomever'};
is noun(q{subsellium})->plural,   q{subsellia}  => q{plural: 'subsellium' --> 'subsellia'};
is noun(q{subsellia})->plural, q{subsellia}  => q{plural: 'subsellia' --> 'subsellia'};
is noun(q{simplex})->plural,   q{simplexes}  => q{plural: 'simplex' --> 'simplexes'};
is noun(q{simplexes})->plural, q{simplexes}  => q{plural: 'simplexes' --> 'simplexes'};
is noun(q{woman-child})->plural,   q{women-children}  => q{plural: 'woman-child' --> 'women-children'};
is noun(q{women-children})->plural, q{women-children}  => q{plural: 'women-children' --> 'women-children'};
is noun(q{gumbo})->plural,   q{gumbos}  => q{plural: 'gumbo' --> 'gumbos'};
is noun(q{gumbos})->plural, q{gumbos}  => q{plural: 'gumbos' --> 'gumbos'};
is noun(q{Orlando})->plural,   q{Orlandos}  => q{plural: 'Orlando' --> 'Orlandos'};
is noun(q{Orlandos})->plural, q{Orlandos}  => q{plural: 'Orlandos' --> 'Orlandos'};
is noun(q{bylina})->plural,   q{bylinas}  => q{plural: 'bylina' --> 'bylinas'};
is noun(q{bylinas})->plural, q{bylinas}  => q{plural: 'bylinas' --> 'bylinas'};
is noun(q{hydra})->plural,   q{hydras}  => q{plural: 'hydra' --> 'hydras'};
is noun(q{hydras})->plural, q{hydras}  => q{plural: 'hydras' --> 'hydras'};
is noun(q{equisetum})->plural,   q{equisetums}  => q{plural: 'equisetum' --> 'equisetums'};
is noun(q{equisetums})->plural, q{equisetums}  => q{plural: 'equisetums' --> 'equisetums'};
is noun(q{sorus})->plural,   q{sori}  => q{plural: 'sorus' --> 'sori'};
is noun(q{sori})->plural, q{sori}  => q{plural: 'sori' --> 'sori'};
is noun(q{pina colada})->plural,   q{pina coladas}  => q{plural: 'pina colada' --> 'pina coladas'};
is noun(q{pina coladas})->plural, q{pina coladas}  => q{plural: 'pina coladas' --> 'pina coladas'};
is noun(q{opusculum})->plural,   q{opuscula}  => q{plural: 'opusculum' --> 'opuscula'};
is noun(q{opuscula})->plural, q{opuscula}  => q{plural: 'opuscula' --> 'opuscula'};
is noun(q{mitochondrion})->plural,   q{mitochondria}  => q{plural: 'mitochondrion' --> 'mitochondria'};
is noun(q{mitochondria})->plural, q{mitochondria}  => q{plural: 'mitochondria' --> 'mitochondria'};
is noun(q{purum})->plural,   q{purums}  => q{plural: 'purum' --> 'purums'};
is noun(q{purums})->plural, q{purums}  => q{plural: 'purums' --> 'purums'};
is noun(q{innings})->plural,   q{innings}  => q{plural: 'innings' --> 'innings'};
is noun(q{snekkja})->plural,   q{snekkjur}  => q{plural: 'snekkja' --> 'snekkjur'};
is noun(q{snekkjur})->plural, q{snekkjur}  => q{plural: 'snekkjur' --> 'snekkjur'};
is noun(q{thesaurus})->plural,   q{thesauruses}  => q{plural: 'thesaurus' --> 'thesauruses'};
is noun(q{thesauruses})->plural, q{thesauruses}  => q{plural: 'thesauruses' --> 'thesauruses'};
is noun(q{Oklahoman})->plural,   q{Oklahomans}  => q{plural: 'Oklahoman' --> 'Oklahomans'};
is noun(q{Oklahomans})->plural, q{Oklahomans}  => q{plural: 'Oklahomans' --> 'Oklahomans'};
is noun(q{Liman})->plural,   q{Limans}  => q{plural: 'Liman' --> 'Limans'};
is noun(q{Limans})->plural, q{Limans}  => q{plural: 'Limans' --> 'Limans'};
is noun(q{interleaf})->plural,   q{leaves}  => q{plural: 'interleaf' --> 'leaves'};
is noun(q{leaves})->plural, q{leaves}  => q{plural: 'leaves' --> 'leaves'};
is noun(q{clepsydra})->plural,   q{clepsydras}  => q{plural: 'clepsydra' --> 'clepsydras'};
is noun(q{clepsydras})->plural, q{clepsydras}  => q{plural: 'clepsydras' --> 'clepsydras'};
is noun(q{Pluto})->plural,   q{Plutos}  => q{plural: 'Pluto' --> 'Plutos'};
is noun(q{Plutos})->plural, q{Plutos}  => q{plural: 'Plutos' --> 'Plutos'};
is noun(q{set-out})->plural,   q{set-outs}  => q{plural: 'set-out' --> 'set-outs'};
is noun(q{set-outs})->plural, q{set-outs}  => q{plural: 'set-outs' --> 'set-outs'};
is noun(q{addendum})->plural,   q{addendums}  => q{plural: 'addendum' --> 'addendums'};
is noun(q{addendums})->plural, q{addendums}  => q{plural: 'addendums' --> 'addendums'};
is noun(q{tornus})->plural,   q{torni}  => q{plural: 'tornus' --> 'torni'};
is noun(q{torni})->plural, q{torni}  => q{plural: 'torni' --> 'torni'};
is noun(q{stipula})->plural,   q{stipulas}  => q{plural: 'stipula' --> 'stipulas'};
is noun(q{stipulas})->plural, q{stipulas}  => q{plural: 'stipulas' --> 'stipulas'};
is noun(q{mumps})->plural,   q{mumps}  => q{plural: 'mumps' --> 'mumps'};
is noun(q{symposium})->plural,   q{symposiums}  => q{plural: 'symposium' --> 'symposiums'};
is noun(q{symposiums})->plural, q{symposiums}  => q{plural: 'symposiums' --> 'symposiums'};
is noun(q{rara avis})->plural,   q{rara avises}  => q{plural: 'rara avis' --> 'rara avises'};
is noun(q{rara avises})->plural, q{rara avises}  => q{plural: 'rara avises' --> 'rara avises'};
is noun(q{entente cordiale})->plural,   q{ententes cordiales}  => q{plural: 'entente cordiale' --> 'ententes cordiales'};
is noun(q{ententes cordiales})->plural, q{ententes cordiales}  => q{plural: 'ententes cordiales' --> 'ententes cordiales'};
is noun(q{lipoma})->plural,   q{lipomata}  => q{plural: 'lipoma' --> 'lipomata'};
is noun(q{lipomata})->plural, q{lipomata}  => q{plural: 'lipomata' --> 'lipomata'};
is noun(q{ephelis})->plural,   q{ephelides}  => q{plural: 'ephelis' --> 'ephelides'};
is noun(q{ephelides})->plural, q{ephelides}  => q{plural: 'ephelides' --> 'ephelides'};
is noun(q{unio})->plural,   q{unios}  => q{plural: 'unio' --> 'unios'};
is noun(q{unios})->plural, q{unios}  => q{plural: 'unios' --> 'unios'};
is noun(q{scarabaeus})->plural,   q{scarabaei}  => q{plural: 'scarabaeus' --> 'scarabaei'};
is noun(q{scarabaei})->plural, q{scarabaei}  => q{plural: 'scarabaei' --> 'scarabaei'};
is noun(q{German})->plural,   q{Germans}  => q{plural: 'German' --> 'Germans'};
is noun(q{Germans})->plural, q{Germans}  => q{plural: 'Germans' --> 'Germans'};
is noun(q{zoophorus})->plural,   q{zoophori}  => q{plural: 'zoophorus' --> 'zoophori'};
is noun(q{zoophori})->plural, q{zoophori}  => q{plural: 'zoophori' --> 'zoophori'};
is noun(q{Roman})->plural,   q{Romans}  => q{plural: 'Roman' --> 'Romans'};
is noun(q{Romans})->plural, q{Romans}  => q{plural: 'Romans' --> 'Romans'};
is noun(q{lapith})->plural,   q{lapiths}  => q{plural: 'lapith' --> 'lapiths'};
is noun(q{lapiths})->plural, q{lapiths}  => q{plural: 'lapiths' --> 'lapiths'};
is noun(q{dichasium})->plural,   q{dichasia}  => q{plural: 'dichasium' --> 'dichasia'};
is noun(q{dichasia})->plural, q{dichasia}  => q{plural: 'dichasia' --> 'dichasia'};
is noun(q{improperium})->plural,   q{improperia}  => q{plural: 'improperium' --> 'improperia'};
is noun(q{improperia})->plural, q{improperia}  => q{plural: 'improperia' --> 'improperia'};
is noun(q{Bostonese})->plural,   q{Bostonese}  => q{plural: 'Bostonese' --> 'Bostonese'};
is noun(q{grotto})->plural,   q{grottos}  => q{plural: 'grotto' --> 'grottos'};
is noun(q{grottos})->plural, q{grottos}  => q{plural: 'grottos' --> 'grottos'};
is noun(q{tablinum})->plural,   q{tablina}  => q{plural: 'tablinum' --> 'tablina'};
is noun(q{tablina})->plural, q{tablina}  => q{plural: 'tablina' --> 'tablina'};
is noun(q{mortarium})->plural,   q{mortaria}  => q{plural: 'mortarium' --> 'mortaria'};
is noun(q{mortaria})->plural, q{mortaria}  => q{plural: 'mortaria' --> 'mortaria'};
is noun(q{pecten})->plural,   q{pectens}  => q{plural: 'pecten' --> 'pectens'};
is noun(q{pectens})->plural, q{pectens}  => q{plural: 'pectens' --> 'pectens'};
is noun(q{sforzato})->plural,   q{sforzatos}  => q{plural: 'sforzato' --> 'sforzatos'};
is noun(q{sforzatos})->plural, q{sforzatos}  => q{plural: 'sforzatos' --> 'sforzatos'};
is noun(q{Auslese})->plural,   q{Auslesen}  => q{plural: 'Auslese' --> 'Auslesen'};
is noun(q{Auslesen})->plural, q{Auslesen}  => q{plural: 'Auslesen' --> 'Auslesen'};
is noun(q{zooecium})->plural,   q{zooecia}  => q{plural: 'zooecium' --> 'zooecia'};
is noun(q{zooecia})->plural, q{zooecia}  => q{plural: 'zooecia' --> 'zooecia'};
is noun(q{credo})->plural,   q{credos}  => q{plural: 'credo' --> 'credos'};
is noun(q{credos})->plural, q{credos}  => q{plural: 'credos' --> 'credos'};
is noun(q{denotatum})->plural,   q{denotata}  => q{plural: 'denotatum' --> 'denotata'};
is noun(q{denotata})->plural, q{denotata}  => q{plural: 'denotata' --> 'denotata'};
is noun(q{neurula})->plural,   q{neurulae}  => q{plural: 'neurula' --> 'neurulae'};
is noun(q{neurulae})->plural, q{neurulae}  => q{plural: 'neurulae' --> 'neurulae'};
is noun(q{quid})->plural,   q{quid}  => q{plural: 'quid' --> 'quid'};
is noun(q{autochthon})->plural,   q{autochthons}  => q{plural: 'autochthon' --> 'autochthons'};
is noun(q{autochthons})->plural, q{autochthons}  => q{plural: 'autochthons' --> 'autochthons'};
is noun(q{mantis})->plural,   q{mantises}  => q{plural: 'mantis' --> 'mantises'};
is noun(q{mantises})->plural, q{mantises}  => q{plural: 'mantises' --> 'mantises'};
is noun(q{hypnum})->plural,   q{hypnums}  => q{plural: 'hypnum' --> 'hypnums'};
is noun(q{hypnums})->plural, q{hypnums}  => q{plural: 'hypnums' --> 'hypnums'};
is noun(q{trout})->plural,   q{trout}  => q{plural: 'trout' --> 'trout'};
is noun(q{palus})->plural,   q{pali}  => q{plural: 'palus' --> 'pali'};
is noun(q{pali})->plural, q{pali}  => q{plural: 'pali' --> 'pali'};
is noun(q{eros})->plural,   q{eroses}  => q{plural: 'eros' --> 'eroses'};
is noun(q{eroses})->plural, q{eroses}  => q{plural: 'eroses' --> 'eroses'};
is noun(q{enconium})->plural,   q{enconiums}  => q{plural: 'enconium' --> 'enconiums'};
is noun(q{enconiums})->plural, q{enconiums}  => q{plural: 'enconiums' --> 'enconiums'};
is noun(q{malum in se})->plural,   q{mala in se}  => q{plural: 'malum in se' --> 'mala in se'};
is noun(q{mala in se})->plural, q{mala in se}  => q{plural: 'mala in se' --> 'mala in se'};
is noun(q{carte-de-visite})->plural,   q{cartes-de-visite}  => q{plural: 'carte-de-visite' --> 'cartes-de-visite'};
is noun(q{cartes-de-visite})->plural, q{cartes-de-visite}  => q{plural: 'cartes-de-visite' --> 'cartes-de-visite'};
is noun(q{abacus})->plural,   q{abacuses}  => q{plural: 'abacus' --> 'abacuses'};
is noun(q{abacuses})->plural, q{abacuses}  => q{plural: 'abacuses' --> 'abacuses'};
is noun(q{pyrexia})->plural,   q{pyrexiae}  => q{plural: 'pyrexia' --> 'pyrexiae'};
is noun(q{pyrexiae})->plural, q{pyrexiae}  => q{plural: 'pyrexiae' --> 'pyrexiae'};
is noun(q{corpus})->plural,   q{corpuses}  => q{plural: 'corpus' --> 'corpuses'};
is noun(q{corpuses})->plural, q{corpuses}  => q{plural: 'corpuses' --> 'corpuses'};
is noun(q{franc archer})->plural,   q{franc archers}  => q{plural: 'franc archer' --> 'franc archers'};
is noun(q{franc archers})->plural, q{franc archers}  => q{plural: 'franc archers' --> 'franc archers'};
is noun(q{nerita})->plural,   q{neritas}  => q{plural: 'nerita' --> 'neritas'};
is noun(q{neritas})->plural, q{neritas}  => q{plural: 'neritas' --> 'neritas'};
is noun(q{strategus})->plural,   q{strategi}  => q{plural: 'strategus' --> 'strategi'};
is noun(q{strategi})->plural, q{strategi}  => q{plural: 'strategi' --> 'strategi'};
is noun(q{euporiston})->plural,   q{euporista}  => q{plural: 'euporiston' --> 'euporista'};
is noun(q{euporista})->plural, q{euporista}  => q{plural: 'euporista' --> 'euporista'};
is noun(q{relatum})->plural,   q{relata}  => q{plural: 'relatum' --> 'relata'};
is noun(q{relata})->plural, q{relata}  => q{plural: 'relata' --> 'relata'};
is noun(q{rideau})->plural,   q{rideaus}  => q{plural: 'rideau' --> 'rideaus'};
is noun(q{rideaus})->plural, q{rideaus}  => q{plural: 'rideaus' --> 'rideaus'};
is noun(q{cul-de-four})->plural,   q{culs-de-four}  => q{plural: 'cul-de-four' --> 'culs-de-four'};
is noun(q{culs-de-four})->plural, q{culs-de-four}  => q{plural: 'culs-de-four' --> 'culs-de-four'};
is noun(q{apterium})->plural,   q{apteria}  => q{plural: 'apterium' --> 'apteria'};
is noun(q{apteria})->plural, q{apteria}  => q{plural: 'apteria' --> 'apteria'};
is noun(q{star-fish})->plural,   q{star-fishes}  => q{plural: 'star-fish' --> 'star-fishes'};
is noun(q{star-fishes})->plural, q{star-fishes}  => q{plural: 'star-fishes' --> 'star-fishes'};
is noun(q{limulus})->plural,   q{limuli}  => q{plural: 'limulus' --> 'limuli'};
is noun(q{limuli})->plural, q{limuli}  => q{plural: 'limuli' --> 'limuli'};
is noun(q{pasteurella})->plural,   q{pasteurellas}  => q{plural: 'pasteurella' --> 'pasteurellas'};
is noun(q{pasteurellas})->plural, q{pasteurellas}  => q{plural: 'pasteurellas' --> 'pasteurellas'};
is noun(q{antefix})->plural,   q{antifixes}  => q{plural: 'antefix' --> 'antifixes'};
is noun(q{antifixes})->plural, q{antifixes}  => q{plural: 'antifixes' --> 'antifixes'};
is noun(q{columbarium})->plural,   q{columbaria}  => q{plural: 'columbarium' --> 'columbaria'};
is noun(q{columbaria})->plural, q{columbaria}  => q{plural: 'columbaria' --> 'columbaria'};
is noun(q{crafts child})->plural,   q{crafts childer}  => q{plural: 'crafts child' --> 'crafts childer'};
is noun(q{crafts childer})->plural, q{crafts childer}  => q{plural: 'crafts childer' --> 'crafts childer'};
is noun(q{ballabile})->plural,   q{ballabili}  => q{plural: 'ballabile' --> 'ballabili'};
is noun(q{ballabili})->plural, q{ballabili}  => q{plural: 'ballabili' --> 'ballabili'};
is noun(q{testes})->plural,   q{testes}  => q{plural: 'testes' --> 'testes'};
is noun(q{nucleolus})->plural,   q{nucleoluses}  => q{plural: 'nucleolus' --> 'nucleoluses'};
is noun(q{nucleoluses})->plural, q{nucleoluses}  => q{plural: 'nucleoluses' --> 'nucleoluses'};
is noun(q{staccato})->plural,   q{staccatos}  => q{plural: 'staccato' --> 'staccatos'};
is noun(q{staccatos})->plural, q{staccatos}  => q{plural: 'staccatos' --> 'staccatos'};
is noun(q{capataz})->plural,   q{capataces}  => q{plural: 'capataz' --> 'capataces'};
is noun(q{capataces})->plural, q{capataces}  => q{plural: 'capataces' --> 'capataces'};
is noun(q{digitalis})->plural,   q{digitalises}  => q{plural: 'digitalis' --> 'digitalises'};
is noun(q{digitalises})->plural, q{digitalises}  => q{plural: 'digitalises' --> 'digitalises'};
is noun(q{lens})->plural,   q{lenses}  => q{plural: 'lens' --> 'lenses'};
is noun(q{lenses})->plural, q{lenses}  => q{plural: 'lenses' --> 'lenses'};
is noun(q{fenestra})->plural,   q{fenestrae}  => q{plural: 'fenestra' --> 'fenestrae'};
is noun(q{fenestrae})->plural, q{fenestrae}  => q{plural: 'fenestrae' --> 'fenestrae'};
is noun(q{obelus})->plural,   q{obeli}  => q{plural: 'obelus' --> 'obeli'};
is noun(q{obeli})->plural, q{obeli}  => q{plural: 'obeli' --> 'obeli'};
is noun(q{siliqua})->plural,   q{siliquae}  => q{plural: 'siliqua' --> 'siliquae'};
is noun(q{siliquae})->plural, q{siliquae}  => q{plural: 'siliquae' --> 'siliquae'};
is noun(q{contralto})->plural,   q{contraltos}  => q{plural: 'contralto' --> 'contraltos'};
is noun(q{contraltos})->plural, q{contraltos}  => q{plural: 'contraltos' --> 'contraltos'};
is noun(q{Guaiabero})->plural,   q{Guaiaberos}  => q{plural: 'Guaiabero' --> 'Guaiaberos'};
is noun(q{Guaiaberos})->plural, q{Guaiaberos}  => q{plural: 'Guaiaberos' --> 'Guaiaberos'};
is noun(q{man})->plural,   q{men}  => q{plural: 'man' --> 'men'};
is noun(q{men})->plural, q{men}  => q{plural: 'men' --> 'men'};
is noun(q{Wenchowese})->plural,   q{Wenchowese}  => q{plural: 'Wenchowese' --> 'Wenchowese'};
is noun(q{Torinese})->plural,   q{Torinese}  => q{plural: 'Torinese' --> 'Torinese'};
is noun(q{stillicidium})->plural,   q{stillicidia}  => q{plural: 'stillicidium' --> 'stillicidia'};
is noun(q{stillicidia})->plural, q{stillicidia}  => q{plural: 'stillicidia' --> 'stillicidia'};
is noun(q{pelvis})->plural,   q{pelvises}  => q{plural: 'pelvis' --> 'pelvises'};
is noun(q{pelvises})->plural, q{pelvises}  => q{plural: 'pelvises' --> 'pelvises'};
is noun(q{djinn})->plural,   q{djinns}  => q{plural: 'djinn' --> 'djinns'};
is noun(q{djinns})->plural, q{djinns}  => q{plural: 'djinns' --> 'djinns'};
is noun(q{violetta})->plural,   q{violette}  => q{plural: 'violetta' --> 'violette'};
is noun(q{violette})->plural, q{violette}  => q{plural: 'violette' --> 'violette'};
is noun(q{monimolimnion})->plural,   q{monimolimnia}  => q{plural: 'monimolimnion' --> 'monimolimnia'};
is noun(q{monimolimnia})->plural, q{monimolimnia}  => q{plural: 'monimolimnia' --> 'monimolimnia'};
is noun(q{siphunculus})->plural,   q{siphunculi}  => q{plural: 'siphunculus' --> 'siphunculi'};
is noun(q{siphunculi})->plural, q{siphunculi}  => q{plural: 'siphunculi' --> 'siphunculi'};
is noun(q{man midwife})->plural,   q{men midwives}  => q{plural: 'man midwife' --> 'men midwives'};
is noun(q{men midwives})->plural, q{men midwives}  => q{plural: 'men midwives' --> 'men midwives'};
is noun(q{impetigo})->plural,   q{impetigos}  => q{plural: 'impetigo' --> 'impetigos'};
is noun(q{impetigos})->plural, q{impetigos}  => q{plural: 'impetigos' --> 'impetigos'};
is noun(q{grouse})->plural,   q{grouses}  => q{plural: 'grouse' --> 'grouses'};
is noun(q{grouses})->plural, q{grouses}  => q{plural: 'grouses' --> 'grouses'};
is noun(q{retinula})->plural,   q{retinulae}  => q{plural: 'retinula' --> 'retinulae'};
is noun(q{retinulae})->plural, q{retinulae}  => q{plural: 'retinulae' --> 'retinulae'};
is noun(q{serpigo})->plural,   q{serpigoes}  => q{plural: 'serpigo' --> 'serpigoes'};
is noun(q{serpigoes})->plural, q{serpigoes}  => q{plural: 'serpigoes' --> 'serpigoes'};
is noun(q{mons})->plural,   q{montes}  => q{plural: 'mons' --> 'montes'};
is noun(q{montes})->plural, q{montes}  => q{plural: 'montes' --> 'montes'};
is noun(q{tubulus})->plural,   q{tubuli}  => q{plural: 'tubulus' --> 'tubuli'};
is noun(q{tubuli})->plural, q{tubuli}  => q{plural: 'tubuli' --> 'tubuli'};
is noun(q{alumnus})->plural,   q{alumni}  => q{plural: 'alumnus' --> 'alumni'};
is noun(q{alumni})->plural, q{alumni}  => q{plural: 'alumni' --> 'alumni'};
is noun(q{falsetto})->plural,   q{falsettos}  => q{plural: 'falsetto' --> 'falsettos'};
is noun(q{falsettos})->plural, q{falsettos}  => q{plural: 'falsettos' --> 'falsettos'};
is noun(q{arrha})->plural,   q{arrhae}  => q{plural: 'arrha' --> 'arrhae'};
is noun(q{arrhae})->plural, q{arrhae}  => q{plural: 'arrhae' --> 'arrhae'};
is noun(q{puttony})->plural,   q{puttonys}  => q{plural: 'puttony' --> 'puttonys'};
is noun(q{puttonys})->plural, q{puttonys}  => q{plural: 'puttonys' --> 'puttonys'};
is noun(q{co})->plural,   q{coes}  => q{plural: 'co' --> 'coes'};
is noun(q{coes})->plural, q{coes}  => q{plural: 'coes' --> 'coes'};
is noun(q{moroso})->plural,   q{morosi}  => q{plural: 'moroso' --> 'morosi'};
is noun(q{morosi})->plural, q{morosi}  => q{plural: 'morosi' --> 'morosi'};
is noun(q{zoon})->plural,   q{zoa}  => q{plural: 'zoon' --> 'zoa'};
is noun(q{zoa})->plural, q{zoa}  => q{plural: 'zoa' --> 'zoa'};
is noun(q{gubernaculum})->plural,   q{gubernacula}  => q{plural: 'gubernaculum' --> 'gubernacula'};
is noun(q{gubernacula})->plural, q{gubernacula}  => q{plural: 'gubernacula' --> 'gubernacula'};
is noun(q{amoretto})->plural,   q{amoretti}  => q{plural: 'amoretto' --> 'amoretti'};
is noun(q{amoretti})->plural, q{amoretti}  => q{plural: 'amoretti' --> 'amoretti'};
is noun(q{ellipsis})->plural,   q{ellipses}  => q{plural: 'ellipsis' --> 'ellipses'};
is noun(q{ellipses})->plural, q{ellipses}  => q{plural: 'ellipses' --> 'ellipses'};
is noun(q{cassone})->plural,   q{cassones}  => q{plural: 'cassone' --> 'cassones'};
is noun(q{cassones})->plural, q{cassones}  => q{plural: 'cassones' --> 'cassones'};
is noun(q{tegmen})->plural,   q{tegmina}  => q{plural: 'tegmen' --> 'tegmina'};
is noun(q{tegmina})->plural, q{tegmina}  => q{plural: 'tegmina' --> 'tegmina'};
is noun(q{Chimango})->plural,   q{Chimangos}  => q{plural: 'Chimango' --> 'Chimangos'};
is noun(q{Chimangos})->plural, q{Chimangos}  => q{plural: 'Chimangos' --> 'Chimangos'};
is noun(q{voeu})->plural,   q{voeux}  => q{plural: 'voeu' --> 'voeux'};
is noun(q{voeux})->plural, q{voeux}  => q{plural: 'voeux' --> 'voeux'};
is noun(q{thanatorium})->plural,   q{thanatoria}  => q{plural: 'thanatorium' --> 'thanatoria'};
is noun(q{thanatoria})->plural, q{thanatoria}  => q{plural: 'thanatoria' --> 'thanatoria'};
is noun(q{soldo})->plural,   q{soldi}  => q{plural: 'soldo' --> 'soldi'};
is noun(q{soldi})->plural, q{soldi}  => q{plural: 'soldi' --> 'soldi'};
is noun(q{favissa})->plural,   q{favissae}  => q{plural: 'favissa' --> 'favissae'};
is noun(q{favissae})->plural, q{favissae}  => q{plural: 'favissae' --> 'favissae'};
is noun(q{phyogemmarium})->plural,   q{phyogemmaria}  => q{plural: 'phyogemmarium' --> 'phyogemmaria'};
is noun(q{phyogemmaria})->plural, q{phyogemmaria}  => q{plural: 'phyogemmaria' --> 'phyogemmaria'};
is noun(q{mausoleum})->plural,   q{mausoleums}  => q{plural: 'mausoleum' --> 'mausoleums'};
is noun(q{mausoleums})->plural, q{mausoleums}  => q{plural: 'mausoleums' --> 'mausoleums'};
is noun(q{hippopotamus})->plural,   q{hippopotamuses}  => q{plural: 'hippopotamus' --> 'hippopotamuses'};
is noun(q{hippopotamuses})->plural, q{hippopotamuses}  => q{plural: 'hippopotamuses' --> 'hippopotamuses'};
is noun(q{geisteswissenschaft})->plural,   q{geisteswissenschaften}  => q{plural: 'geisteswissenschaft' --> 'geisteswissenschaften'};
is noun(q{geisteswissenschaften})->plural, q{geisteswissenschaften}  => q{plural: 'geisteswissenschaften' --> 'geisteswissenschaften'};
is noun(q{paparrazo})->plural,   q{paparrazi}  => q{plural: 'paparrazo' --> 'paparrazi'};
is noun(q{paparrazi})->plural, q{paparrazi}  => q{plural: 'paparrazi' --> 'paparrazi'};
is noun(q{cactus})->plural,   q{cactuses}  => q{plural: 'cactus' --> 'cactuses'};
is noun(q{cactuses})->plural, q{cactuses}  => q{plural: 'cactuses' --> 'cactuses'};
is noun(q{morceau})->plural,   q{morceaux}  => q{plural: 'morceau' --> 'morceaux'};
is noun(q{morceaux})->plural, q{morceaux}  => q{plural: 'morceaux' --> 'morceaux'};
is noun(q{felo de se})->plural,   q{felos de se}  => q{plural: 'felo de se' --> 'felos de se'};
is noun(q{felos de se})->plural, q{felos de se}  => q{plural: 'felos de se' --> 'felos de se'};
is noun(q{prothallus})->plural,   q{prothalli}  => q{plural: 'prothallus' --> 'prothalli'};
is noun(q{prothalli})->plural, q{prothalli}  => q{plural: 'prothalli' --> 'prothalli'};
is noun(q{allargando})->plural,   q{allargandi}  => q{plural: 'allargando' --> 'allargandi'};
is noun(q{allargandi})->plural, q{allargandi}  => q{plural: 'allargandi' --> 'allargandi'};
is noun(q{primigravida})->plural,   q{primigravidae}  => q{plural: 'primigravida' --> 'primigravidae'};
is noun(q{primigravidae})->plural, q{primigravidae}  => q{plural: 'primigravidae' --> 'primigravidae'};
is noun(q{shifta})->plural,   q{shiftas}  => q{plural: 'shifta' --> 'shiftas'};
is noun(q{shiftas})->plural, q{shiftas}  => q{plural: 'shiftas' --> 'shiftas'};
is noun(q{rhombohedron})->plural,   q{rhombohedrons}  => q{plural: 'rhombohedron' --> 'rhombohedrons'};
is noun(q{rhombohedrons})->plural, q{rhombohedrons}  => q{plural: 'rhombohedrons' --> 'rhombohedrons'};
is noun(q{mezzo rilievo})->plural,   q{mezzo rilievos}  => q{plural: 'mezzo rilievo' --> 'mezzo rilievos'};
is noun(q{mezzo rilievos})->plural, q{mezzo rilievos}  => q{plural: 'mezzo rilievos' --> 'mezzo rilievos'};
is noun(q{six star general})->plural,   q{six star generals}  => q{plural: 'six star general' --> 'six star generals'};
is noun(q{six star generals})->plural, q{six star generals}  => q{plural: 'six star generals' --> 'six star generals'};
is noun(q{sgraffiato})->plural,   q{sgraffiati}  => q{plural: 'sgraffiato' --> 'sgraffiati'};
is noun(q{sgraffiati})->plural, q{sgraffiati}  => q{plural: 'sgraffiati' --> 'sgraffiati'};
is noun(q{Milano})->plural,   q{Milanos}  => q{plural: 'Milano' --> 'Milanos'};
is noun(q{Milanos})->plural, q{Milanos}  => q{plural: 'Milanos' --> 'Milanos'};
is noun(q{pinon})->plural,   q{pinons}  => q{plural: 'pinon' --> 'pinons'};
is noun(q{pinons})->plural, q{pinons}  => q{plural: 'pinons' --> 'pinons'};
is noun(q{human})->plural,   q{humans}  => q{plural: 'human' --> 'humans'};
is noun(q{humans})->plural, q{humans}  => q{plural: 'humans' --> 'humans'};
is noun(q{Indochinese})->plural,   q{Indochinese}  => q{plural: 'Indochinese' --> 'Indochinese'};
is noun(q{murex})->plural,   q{murexes}  => q{plural: 'murex' --> 'murexes'};
is noun(q{murexes})->plural, q{murexes}  => q{plural: 'murexes' --> 'murexes'};
is noun(q{phyle})->plural,   q{phylae}  => q{plural: 'phyle' --> 'phylae'};
is noun(q{phylae})->plural, q{phylae}  => q{plural: 'phylae' --> 'phylae'};
is noun(q{chapeau})->plural,   q{chapeaux}  => q{plural: 'chapeau' --> 'chapeaux'};
is noun(q{chapeaux})->plural, q{chapeaux}  => q{plural: 'chapeaux' --> 'chapeaux'};
is noun(q{cinclis})->plural,   q{cinclides}  => q{plural: 'cinclis' --> 'cinclides'};
is noun(q{cinclides})->plural, q{cinclides}  => q{plural: 'cinclides' --> 'cinclides'};
is noun(q{proscenium})->plural,   q{proscenia}  => q{plural: 'proscenium' --> 'proscenia'};
is noun(q{proscenia})->plural, q{proscenia}  => q{plural: 'proscenia' --> 'proscenia'};
is noun(q{bream})->plural,   q{bream}  => q{plural: 'bream' --> 'bream'};
is noun(q{datum})->plural,   q{data}  => q{plural: 'datum' --> 'data'};
is noun(q{data})->plural, q{data}  => q{plural: 'data' --> 'data'};
is noun(q{indumentum})->plural,   q{indumenta}  => q{plural: 'indumentum' --> 'indumenta'};
is noun(q{indumenta})->plural, q{indumenta}  => q{plural: 'indumenta' --> 'indumenta'};
is noun(q{woman-servant})->plural,   q{women-servants}  => q{plural: 'woman-servant' --> 'women-servants'};
is noun(q{women-servants})->plural, q{women-servants}  => q{plural: 'women-servants' --> 'women-servants'};
is noun(q{lumen})->plural,   q{lumens}  => q{plural: 'lumen' --> 'lumens'};
is noun(q{lumens})->plural, q{lumens}  => q{plural: 'lumens' --> 'lumens'};
is noun(q{Biro})->plural,   q{Biros}  => q{plural: 'Biro' --> 'Biros'};
is noun(q{Biros})->plural, q{Biros}  => q{plural: 'Biros' --> 'Biros'};
is noun(q{primordium})->plural,   q{primordia}  => q{plural: 'primordium' --> 'primordia'};
is noun(q{primordia})->plural, q{primordia}  => q{plural: 'primordia' --> 'primordia'};
is noun(q{lieutenant general})->plural,   q{lieutenant generals}  => q{plural: 'lieutenant general' --> 'lieutenant generals'};
is noun(q{lieutenant generals})->plural, q{lieutenant generals}  => q{plural: 'lieutenant generals' --> 'lieutenant generals'};
is noun(q{grano})->plural,   q{grani}  => q{plural: 'grano' --> 'grani'};
is noun(q{grani})->plural, q{grani}  => q{plural: 'grani' --> 'grani'};
is noun(q{Lapponese})->plural,   q{Lapponese}  => q{plural: 'Lapponese' --> 'Lapponese'};
is noun(q{baal})->plural,   q{baals}  => q{plural: 'baal' --> 'baals'};
is noun(q{baals})->plural, q{baals}  => q{plural: 'baals' --> 'baals'};
is noun(q{grissino})->plural,   q{grissini}  => q{plural: 'grissino' --> 'grissini'};
is noun(q{grissini})->plural, q{grissini}  => q{plural: 'grissini' --> 'grissini'};
is noun(q{Kongolese})->plural,   q{Kongolese}  => q{plural: 'Kongolese' --> 'Kongolese'};
is noun(q{Sapporo})->plural,   q{Sapporos}  => q{plural: 'Sapporo' --> 'Sapporos'};
is noun(q{Sapporos})->plural, q{Sapporos}  => q{plural: 'Sapporos' --> 'Sapporos'};
is noun(q{offspring})->plural,   q{offspring}  => q{plural: 'offspring' --> 'offspring'};
is noun(q{pontifex})->plural,   q{pontifexes}  => q{plural: 'pontifex' --> 'pontifexes'};
is noun(q{pontifexes})->plural, q{pontifexes}  => q{plural: 'pontifexes' --> 'pontifexes'};
is noun(q{zophorus})->plural,   q{zophori}  => q{plural: 'zophorus' --> 'zophori'};
is noun(q{zophori})->plural, q{zophori}  => q{plural: 'zophori' --> 'zophori'};
is noun(q{abscissa})->plural,   q{abscissas}  => q{plural: 'abscissa' --> 'abscissas'};
is noun(q{abscissas})->plural, q{abscissas}  => q{plural: 'abscissas' --> 'abscissas'};
is noun(q{novus homo})->plural,   q{novi homines}  => q{plural: 'novus homo' --> 'novi homines'};
is noun(q{novi homines})->plural, q{novi homines}  => q{plural: 'novi homines' --> 'novi homines'};
is noun(q{lobulus})->plural,   q{lobuli}  => q{plural: 'lobulus' --> 'lobuli'};
is noun(q{lobuli})->plural, q{lobuli}  => q{plural: 'lobuli' --> 'lobuli'};
is noun(q{gonidium})->plural,   q{gonidia}  => q{plural: 'gonidium' --> 'gonidia'};
is noun(q{gonidia})->plural, q{gonidia}  => q{plural: 'gonidia' --> 'gonidia'};
is noun(q{sarcoma})->plural,   q{sarcomas}  => q{plural: 'sarcoma' --> 'sarcomas'};
is noun(q{sarcomas})->plural, q{sarcomas}  => q{plural: 'sarcomas' --> 'sarcomas'};
is noun(q{metro})->plural,   q{metros}  => q{plural: 'metro' --> 'metros'};
is noun(q{metros})->plural, q{metros}  => q{plural: 'metros' --> 'metros'};
is noun(q{Sudanese})->plural,   q{Sudanese}  => q{plural: 'Sudanese' --> 'Sudanese'};
is noun(q{uncus})->plural,   q{unci}  => q{plural: 'uncus' --> 'unci'};
is noun(q{unci})->plural, q{unci}  => q{plural: 'unci' --> 'unci'};
is noun(q{axon})->plural,   q{axons}  => q{plural: 'axon' --> 'axons'};
is noun(q{axons})->plural, q{axons}  => q{plural: 'axons' --> 'axons'};
is noun(q{dogma})->plural,   q{dogmas}  => q{plural: 'dogma' --> 'dogmas'};
is noun(q{dogmas})->plural, q{dogmas}  => q{plural: 'dogmas' --> 'dogmas'};
is noun(q{familia})->plural,   q{familiae}  => q{plural: 'familia' --> 'familiae'};
is noun(q{familiae})->plural, q{familiae}  => q{plural: 'familiae' --> 'familiae'};
is noun(q{insula})->plural,   q{insulae}  => q{plural: 'insula' --> 'insulae'};
is noun(q{insulae})->plural, q{insulae}  => q{plural: 'insulae' --> 'insulae'};
is noun(q{phallos})->plural,   q{phalloi}  => q{plural: 'phallos' --> 'phalloi'};
is noun(q{phalloi})->plural, q{phalloi}  => q{plural: 'phalloi' --> 'phalloi'};
is noun(q{differentia})->plural,   q{differentiae}  => q{plural: 'differentia' --> 'differentiae'};
is noun(q{differentiae})->plural, q{differentiae}  => q{plural: 'differentiae' --> 'differentiae'};
is noun(q{magneto})->plural,   q{magnetos}  => q{plural: 'magneto' --> 'magnetos'};
is noun(q{magnetos})->plural, q{magnetos}  => q{plural: 'magnetos' --> 'magnetos'};
is noun(q{salvo})->plural,   q{salvos}  => q{plural: 'salvo' --> 'salvos'};
is noun(q{salvos})->plural, q{salvos}  => q{plural: 'salvos' --> 'salvos'};
is noun(q{phragma})->plural,   q{phragmata}  => q{plural: 'phragma' --> 'phragmata'};
is noun(q{phragmata})->plural, q{phragmata}  => q{plural: 'phragmata' --> 'phragmata'};
is noun(q{cargador})->plural,   q{cargadores}  => q{plural: 'cargador' --> 'cargadores'};
is noun(q{cargadores})->plural, q{cargadores}  => q{plural: 'cargadores' --> 'cargadores'};
is noun(q{idolon})->plural,   q{idola}  => q{plural: 'idolon' --> 'idola'};
is noun(q{idola})->plural, q{idola}  => q{plural: 'idola' --> 'idola'};
is noun(q{gorgonia})->plural,   q{gorgonias}  => q{plural: 'gorgonia' --> 'gorgonias'};
is noun(q{gorgonias})->plural, q{gorgonias}  => q{plural: 'gorgonias' --> 'gorgonias'};
is noun(q{tetrasporangium})->plural,   q{tetrasporangia}  => q{plural: 'tetrasporangium' --> 'tetrasporangia'};
is noun(q{tetrasporangia})->plural, q{tetrasporangia}  => q{plural: 'tetrasporangia' --> 'tetrasporangia'};
is noun(q{scapus})->plural,   q{scapi}  => q{plural: 'scapus' --> 'scapi'};
is noun(q{scapi})->plural, q{scapi}  => q{plural: 'scapi' --> 'scapi'};
is noun(q{tiro})->plural,   q{tiros}  => q{plural: 'tiro' --> 'tiros'};
is noun(q{tiros})->plural, q{tiros}  => q{plural: 'tiros' --> 'tiros'};
is noun(q{umbo})->plural,   q{umbos}  => q{plural: 'umbo' --> 'umbos'};
is noun(q{umbos})->plural, q{umbos}  => q{plural: 'umbos' --> 'umbos'};
is noun(q{succubus})->plural,   q{succubuses}  => q{plural: 'succubus' --> 'succubuses'};
is noun(q{succubuses})->plural, q{succubuses}  => q{plural: 'succubuses' --> 'succubuses'};
is noun(q{line out})->plural,   q{line outs}  => q{plural: 'line out' --> 'line outs'};
is noun(q{line outs})->plural, q{line outs}  => q{plural: 'line outs' --> 'line outs'};
is noun(q{claustrum})->plural,   q{claustra}  => q{plural: 'claustrum' --> 'claustra'};
is noun(q{claustra})->plural, q{claustra}  => q{plural: 'claustra' --> 'claustra'};
is noun(q{municipium})->plural,   q{municipia}  => q{plural: 'municipium' --> 'municipia'};
is noun(q{municipia})->plural, q{municipia}  => q{plural: 'municipia' --> 'municipia'};
is noun(q{amphipneust})->plural,   q{amphipneusts}  => q{plural: 'amphipneust' --> 'amphipneusts'};
is noun(q{amphipneusts})->plural, q{amphipneusts}  => q{plural: 'amphipneusts' --> 'amphipneusts'};
is noun(q{minyan})->plural,   q{minyanim}  => q{plural: 'minyan' --> 'minyanim'};
is noun(q{minyanim})->plural, q{minyanim}  => q{plural: 'minyanim' --> 'minyanim'};
is noun(q{ballerina})->plural,   q{ballerinas}  => q{plural: 'ballerina' --> 'ballerinas'};
is noun(q{ballerinas})->plural, q{ballerinas}  => q{plural: 'ballerinas' --> 'ballerinas'};
is noun(q{procoelia})->plural,   q{procoeliae}  => q{plural: 'procoelia' --> 'procoeliae'};
is noun(q{procoeliae})->plural, q{procoeliae}  => q{plural: 'procoeliae' --> 'procoeliae'};
is noun(q{progymnasma})->plural,   q{progymnasmata}  => q{plural: 'progymnasma' --> 'progymnasmata'};
is noun(q{progymnasmata})->plural, q{progymnasmata}  => q{plural: 'progymnasmata' --> 'progymnasmata'};
is noun(q{lacinia})->plural,   q{laciniae}  => q{plural: 'lacinia' --> 'laciniae'};
is noun(q{laciniae})->plural, q{laciniae}  => q{plural: 'laciniae' --> 'laciniae'};
is noun(q{pipkrake})->plural,   q{pipkrakes}  => q{plural: 'pipkrake' --> 'pipkrakes'};
is noun(q{pipkrakes})->plural, q{pipkrakes}  => q{plural: 'pipkrakes' --> 'pipkrakes'};
is noun(q{sestiere})->plural,   q{sestieri}  => q{plural: 'sestiere' --> 'sestieri'};
is noun(q{sestieri})->plural, q{sestieri}  => q{plural: 'sestieri' --> 'sestieri'};
is noun(q{vasculitis})->plural,   q{vasculitises}  => q{plural: 'vasculitis' --> 'vasculitises'};
is noun(q{vasculitises})->plural, q{vasculitises}  => q{plural: 'vasculitises' --> 'vasculitises'};
is noun(q{cimex})->plural,   q{cimices}  => q{plural: 'cimex' --> 'cimices'};
is noun(q{cimices})->plural, q{cimices}  => q{plural: 'cimices' --> 'cimices'};
is noun(q{ligamentum})->plural,   q{ligamenta}  => q{plural: 'ligamentum' --> 'ligamenta'};
is noun(q{ligamenta})->plural, q{ligamenta}  => q{plural: 'ligamenta' --> 'ligamenta'};
is noun(q{beau geste})->plural,   q{beau gestes}  => q{plural: 'beau geste' --> 'beau gestes'};
is noun(q{beau gestes})->plural, q{beau gestes}  => q{plural: 'beau gestes' --> 'beau gestes'};
is noun(q{Virgo})->plural,   q{Virgos}  => q{plural: 'Virgo' --> 'Virgos'};
is noun(q{Virgos})->plural, q{Virgos}  => q{plural: 'Virgos' --> 'Virgos'};
is noun(q{rhopalium})->plural,   q{rhopalia}  => q{plural: 'rhopalium' --> 'rhopalia'};
is noun(q{rhopalia})->plural, q{rhopalia}  => q{plural: 'rhopalia' --> 'rhopalia'};
is noun(q{lex humana})->plural,   q{leges humanae}  => q{plural: 'lex humana' --> 'leges humanae'};
is noun(q{leges humanae})->plural, q{leges humanae}  => q{plural: 'leges humanae' --> 'leges humanae'};
is noun(q{parnass})->plural,   q{parnassim}  => q{plural: 'parnass' --> 'parnassim'};
is noun(q{parnassim})->plural, q{parnassim}  => q{plural: 'parnassim' --> 'parnassim'};
is noun(q{maar})->plural,   q{maars}  => q{plural: 'maar' --> 'maars'};
is noun(q{maars})->plural, q{maars}  => q{plural: 'maars' --> 'maars'};
is noun(q{Shawanese})->plural,   q{Shawanese}  => q{plural: 'Shawanese' --> 'Shawanese'};
is noun(q{violoncello})->plural,   q{violoncellos}  => q{plural: 'violoncello' --> 'violoncellos'};
is noun(q{violoncellos})->plural, q{violoncellos}  => q{plural: 'violoncellos' --> 'violoncellos'};
is noun(q{rype})->plural,   q{ryper}  => q{plural: 'rype' --> 'ryper'};
is noun(q{ryper})->plural, q{ryper}  => q{plural: 'ryper' --> 'ryper'};
is noun(q{melanoma})->plural,   q{melanomas}  => q{plural: 'melanoma' --> 'melanomas'};
is noun(q{melanomas})->plural, q{melanomas}  => q{plural: 'melanomas' --> 'melanomas'};
is noun(q{auto})->plural,   q{autos}  => q{plural: 'auto' --> 'autos'};
is noun(q{autos})->plural, q{autos}  => q{plural: 'autos' --> 'autos'};
is noun(q{Piedmontese})->plural,   q{Piedmontese}  => q{plural: 'Piedmontese' --> 'Piedmontese'};
is noun(q{bechuana})->plural,   q{bechuanas}  => q{plural: 'bechuana' --> 'bechuanas'};
is noun(q{bechuanas})->plural, q{bechuanas}  => q{plural: 'bechuanas' --> 'bechuanas'};
is noun(q{cathisma})->plural,   q{cathismata}  => q{plural: 'cathisma' --> 'cathismata'};
is noun(q{cathismata})->plural, q{cathismata}  => q{plural: 'cathismata' --> 'cathismata'};
is noun(q{antenna})->plural,   q{antennas}  => q{plural: 'antenna' --> 'antennas'};
is noun(q{antennas})->plural, q{antennas}  => q{plural: 'antennas' --> 'antennas'};
is noun(q{Nepalese})->plural,   q{Nepalese}  => q{plural: 'Nepalese' --> 'Nepalese'};
is noun(q{interrex})->plural,   q{interreges}  => q{plural: 'interrex' --> 'interreges'};
is noun(q{interreges})->plural, q{interreges}  => q{plural: 'interreges' --> 'interreges'};
is noun(q{divisional general})->plural,   q{divisional generals}  => q{plural: 'divisional general' --> 'divisional generals'};
is noun(q{divisional generals})->plural, q{divisional generals}  => q{plural: 'divisional generals' --> 'divisional generals'};
is noun(q{Madurese})->plural,   q{Madurese}  => q{plural: 'Madurese' --> 'Madurese'};
is noun(q{tergum})->plural,   q{terga}  => q{plural: 'tergum' --> 'terga'};
is noun(q{terga})->plural, q{terga}  => q{plural: 'terga' --> 'terga'};
is noun(q{trochus})->plural,   q{trochuses}  => q{plural: 'trochus' --> 'trochuses'};
is noun(q{trochuses})->plural, q{trochuses}  => q{plural: 'trochuses' --> 'trochuses'};
is noun(q{solfeggio})->plural,   q{solfeggios}  => q{plural: 'solfeggio' --> 'solfeggios'};
is noun(q{solfeggios})->plural, q{solfeggios}  => q{plural: 'solfeggios' --> 'solfeggios'};
is noun(q{caryatid})->plural,   q{caryatids}  => q{plural: 'caryatid' --> 'caryatids'};
is noun(q{caryatids})->plural, q{caryatids}  => q{plural: 'caryatids' --> 'caryatids'};
is noun(q{wildebeest})->plural,   q{wildebeests}  => q{plural: 'wildebeest' --> 'wildebeests'};
is noun(q{wildebeests})->plural, q{wildebeests}  => q{plural: 'wildebeests' --> 'wildebeests'};
is noun(q{starover})->plural,   q{starovers}  => q{plural: 'starover' --> 'starovers'};
is noun(q{starovers})->plural, q{starovers}  => q{plural: 'starovers' --> 'starovers'};
is noun(q{tabella})->plural,   q{tabellae}  => q{plural: 'tabella' --> 'tabellae'};
is noun(q{tabellae})->plural, q{tabellae}  => q{plural: 'tabellae' --> 'tabellae'};
is noun(q{-ox})->plural,   q{-oxen}  => q{plural: '-ox' --> '-oxen'};
is noun(q{-oxen})->plural, q{-oxen}  => q{plural: '-oxen' --> '-oxen'};
is noun(q{representamen})->plural,   q{representamens}  => q{plural: 'representamen' --> 'representamens'};
is noun(q{representamens})->plural, q{representamens}  => q{plural: 'representamens' --> 'representamens'};
is noun(q{terramara})->plural,   q{terremare}  => q{plural: 'terramara' --> 'terremare'};
is noun(q{terremare})->plural, q{terremare}  => q{plural: 'terremare' --> 'terremare'};
is noun(q{beau})->plural,   q{beaus}  => q{plural: 'beau' --> 'beaus'};
is noun(q{beaus})->plural, q{beaus}  => q{plural: 'beaus' --> 'beaus'};
is noun(q{Congolese})->plural,   q{Congolese}  => q{plural: 'Congolese' --> 'Congolese'};
is noun(q{lithophyton})->plural,   q{lithophyta}  => q{plural: 'lithophyton' --> 'lithophyta'};
is noun(q{lithophyta})->plural, q{lithophyta}  => q{plural: 'lithophyta' --> 'lithophyta'};
is noun(q{menage a quatre})->plural,   q{menages a quatre}  => q{plural: 'menage a quatre' --> 'menages a quatre'};
is noun(q{menages a quatre})->plural, q{menages a quatre}  => q{plural: 'menages a quatre' --> 'menages a quatre'};
is noun(q{bona fides})->plural,   q{bonis fidebus}  => q{plural: 'bona fides' --> 'bonis fidebus'};
is noun(q{bonis fidebus})->plural, q{bonis fidebus}  => q{plural: 'bonis fidebus' --> 'bonis fidebus'};
is noun(q{chlamydia})->plural,   q{chlamydias}  => q{plural: 'chlamydia' --> 'chlamydias'};
is noun(q{chlamydias})->plural, q{chlamydias}  => q{plural: 'chlamydias' --> 'chlamydias'};
is noun(q{cheval de bataille})->plural,   q{chevaux de bataille}  => q{plural: 'cheval de bataille' --> 'chevaux de bataille'};
is noun(q{chevaux de bataille})->plural, q{chevaux de bataille}  => q{plural: 'chevaux de bataille' --> 'chevaux de bataille'};
is noun(q{alula})->plural,   q{alulae}  => q{plural: 'alula' --> 'alulae'};
is noun(q{alulae})->plural, q{alulae}  => q{plural: 'alulae' --> 'alulae'};
is noun(q{caiman})->plural,   q{caimans}  => q{plural: 'caiman' --> 'caimans'};
is noun(q{caimans})->plural, q{caimans}  => q{plural: 'caimans' --> 'caimans'};
is noun(q{four star general})->plural,   q{four star generals}  => q{plural: 'four star general' --> 'four star generals'};
is noun(q{four star generals})->plural, q{four star generals}  => q{plural: 'four star generals' --> 'four star generals'};
is noun(q{calypso})->plural,   q{calypsos}  => q{plural: 'calypso' --> 'calypsos'};
is noun(q{calypsos})->plural, q{calypsos}  => q{plural: 'calypsos' --> 'calypsos'};
is noun(q{set to})->plural,   q{set tos}  => q{plural: 'set to' --> 'set tos'};
is noun(q{set tos})->plural, q{set tos}  => q{plural: 'set tos' --> 'set tos'};
is noun(q{contrafactum})->plural,   q{contrafacta}  => q{plural: 'contrafactum' --> 'contrafacta'};
is noun(q{contrafacta})->plural, q{contrafacta}  => q{plural: 'contrafacta' --> 'contrafacta'};
is noun(q{millennium})->plural,   q{millenniums}  => q{plural: 'millennium' --> 'millenniums'};
is noun(q{millenniums})->plural, q{millenniums}  => q{plural: 'millenniums' --> 'millenniums'};
is noun(q{bass})->plural,   q{basses}  => q{plural: 'bass' --> 'basses'};
is noun(q{basses})->plural, q{basses}  => q{plural: 'basses' --> 'basses'};
is noun(q{femur})->plural,   q{femurs}  => q{plural: 'femur' --> 'femurs'};
is noun(q{femurs})->plural, q{femurs}  => q{plural: 'femurs' --> 'femurs'};
is noun(q{supercilium})->plural,   q{supercilia}  => q{plural: 'supercilium' --> 'supercilia'};
is noun(q{supercilia})->plural, q{supercilia}  => q{plural: 'supercilia' --> 'supercilia'};
is noun(q{perikaryon})->plural,   q{perikarya}  => q{plural: 'perikaryon' --> 'perikarya'};
is noun(q{perikarya})->plural, q{perikarya}  => q{plural: 'perikarya' --> 'perikarya'};
is noun(q{yours})->plural,   q{yours}  => q{plural: 'yours' --> 'yours'};
is noun(q{separatrix})->plural,   q{separatrices}  => q{plural: 'separatrix' --> 'separatrices'};
is noun(q{separatrices})->plural, q{separatrices}  => q{plural: 'separatrices' --> 'separatrices'};
is noun(q{pulveratrix})->plural,   q{pulveratrices}  => q{plural: 'pulveratrix' --> 'pulveratrices'};
is noun(q{pulveratrices})->plural, q{pulveratrices}  => q{plural: 'pulveratrices' --> 'pulveratrices'};
is noun(q{zoea})->plural,   q{zoeas}  => q{plural: 'zoea' --> 'zoeas'};
is noun(q{zoeas})->plural, q{zoeas}  => q{plural: 'zoeas' --> 'zoeas'};
is noun(q{haemangioma})->plural,   q{haemangiomas}  => q{plural: 'haemangioma' --> 'haemangiomas'};
is noun(q{haemangiomas})->plural, q{haemangiomas}  => q{plural: 'haemangiomas' --> 'haemangiomas'};
is noun(q{captain general})->plural,   q{captain generals}  => q{plural: 'captain general' --> 'captain generals'};
is noun(q{captain generals})->plural, q{captain generals}  => q{plural: 'captain generals' --> 'captain generals'};
is noun(q{bajocco})->plural,   q{bajocchi}  => q{plural: 'bajocco' --> 'bajocchi'};
is noun(q{bajocchi})->plural, q{bajocchi}  => q{plural: 'bajocchi' --> 'bajocchi'};
is noun(q{pecia})->plural,   q{pecias}  => q{plural: 'pecia' --> 'pecias'};
is noun(q{pecias})->plural, q{pecias}  => q{plural: 'pecias' --> 'pecias'};
is noun(q{cysticercus})->plural,   q{cysticerci}  => q{plural: 'cysticercus' --> 'cysticerci'};
is noun(q{cysticerci})->plural, q{cysticerci}  => q{plural: 'cysticerci' --> 'cysticerci'};
is noun(q{sternebra})->plural,   q{sternebrae}  => q{plural: 'sternebra' --> 'sternebrae'};
is noun(q{sternebrae})->plural, q{sternebrae}  => q{plural: 'sternebrae' --> 'sternebrae'};
is noun(q{theca})->plural,   q{thecae}  => q{plural: 'theca' --> 'thecae'};
is noun(q{thecae})->plural, q{thecae}  => q{plural: 'thecae' --> 'thecae'};
is noun(q{sabertooth})->plural,   q{sabertooths}  => q{plural: 'sabertooth' --> 'sabertooths'};
is noun(q{sabertooths})->plural, q{sabertooths}  => q{plural: 'sabertooths' --> 'sabertooths'};
is noun(q{theirs})->plural,   q{theirs}  => q{plural: 'theirs' --> 'theirs'};
is noun(q{emporium})->plural,   q{emporiums}  => q{plural: 'emporium' --> 'emporiums'};
is noun(q{emporiums})->plural, q{emporiums}  => q{plural: 'emporiums' --> 'emporiums'};
is noun(q{ibis})->plural,   q{ibises}  => q{plural: 'ibis' --> 'ibises'};
is noun(q{ibises})->plural, q{ibises}  => q{plural: 'ibises' --> 'ibises'};
is noun(q{torero})->plural,   q{toreros}  => q{plural: 'torero' --> 'toreros'};
is noun(q{toreros})->plural, q{toreros}  => q{plural: 'toreros' --> 'toreros'};
is noun(q{Swahilese})->plural,   q{Swahilese}  => q{plural: 'Swahilese' --> 'Swahilese'};
is noun(q{blue})->plural,   q{blues}  => q{plural: 'blue' --> 'blues'};
is noun(q{surculus})->plural,   q{surculi}  => q{plural: 'surculus' --> 'surculi'};
is noun(q{surculi})->plural, q{surculi}  => q{plural: 'surculi' --> 'surculi'};
is noun(q{lingula})->plural,   q{lingulae}  => q{plural: 'lingula' --> 'lingulae'};
is noun(q{lingulae})->plural, q{lingulae}  => q{plural: 'lingulae' --> 'lingulae'};
is noun(q{epyllion})->plural,   q{epyllia}  => q{plural: 'epyllion' --> 'epyllia'};
is noun(q{epyllia})->plural, q{epyllia}  => q{plural: 'epyllia' --> 'epyllia'};
is noun(q{waltz})->plural,   q{waltzes}  => q{plural: 'waltz' --> 'waltzes'};
is noun(q{waltzes})->plural, q{waltzes}  => q{plural: 'waltzes' --> 'waltzes'};
is noun(q{dilettante})->plural,   q{dilettantes}  => q{plural: 'dilettante' --> 'dilettantes'};
is noun(q{dilettantes})->plural, q{dilettantes}  => q{plural: 'dilettantes' --> 'dilettantes'};
is noun(q{tongs})->plural,   q{tongs}  => q{plural: 'tongs' --> 'tongs'};
is noun(q{6-star general})->plural,   q{6-star generals}  => q{plural: '6-star general' --> '6-star generals'};
is noun(q{6-star generals})->plural, q{6-star generals}  => q{plural: '6-star generals' --> '6-star generals'};
is noun(q{troparion})->plural,   q{troparia}  => q{plural: 'troparion' --> 'troparia'};
is noun(q{troparia})->plural, q{troparia}  => q{plural: 'troparia' --> 'troparia'};
is noun(q{scalenus})->plural,   q{scaleni}  => q{plural: 'scalenus' --> 'scaleni'};
is noun(q{scaleni})->plural, q{scaleni}  => q{plural: 'scaleni' --> 'scaleni'};
is noun(q{ski})->plural,   q{skis}  => q{plural: 'ski' --> 'skis'};
is noun(q{skis})->plural, q{skis}  => q{plural: 'skis' --> 'skis'};
is noun(q{bel esprit})->plural,   q{beaux esprits}  => q{plural: 'bel esprit' --> 'beaux esprits'};
is noun(q{beaux esprits})->plural, q{beaux esprits}  => q{plural: 'beaux esprits' --> 'beaux esprits'};
is noun(q{actinia})->plural,   q{actinias}  => q{plural: 'actinia' --> 'actinias'};
is noun(q{actinias})->plural, q{actinias}  => q{plural: 'actinias' --> 'actinias'};
is noun(q{Balinese})->plural,   q{Balinese}  => q{plural: 'Balinese' --> 'Balinese'};
is noun(q{gemma})->plural,   q{gemmae}  => q{plural: 'gemma' --> 'gemmae'};
is noun(q{gemmae})->plural, q{gemmae}  => q{plural: 'gemmae' --> 'gemmae'};
is noun(q{cortex})->plural,   q{cortexes}  => q{plural: 'cortex' --> 'cortexes'};
is noun(q{cortexes})->plural, q{cortexes}  => q{plural: 'cortexes' --> 'cortexes'};
is noun(q{child})->plural,   q{children}  => q{plural: 'child' --> 'children'};
is noun(q{children})->plural, q{children}  => q{plural: 'children' --> 'children'};
is noun(q{delirium})->plural,   q{deliriums}  => q{plural: 'delirium' --> 'deliriums'};
is noun(q{deliriums})->plural, q{deliriums}  => q{plural: 'deliriums' --> 'deliriums'};
is noun(q{meris})->plural,   q{merides}  => q{plural: 'meris' --> 'merides'};
is noun(q{merides})->plural, q{merides}  => q{plural: 'merides' --> 'merides'};
is noun(q{meshummad})->plural,   q{meshummadim}  => q{plural: 'meshummad' --> 'meshummadim'};
is noun(q{meshummadim})->plural, q{meshummadim}  => q{plural: 'meshummadim' --> 'meshummadim'};
is noun(q{nagaika})->plural,   q{nagaikas}  => q{plural: 'nagaika' --> 'nagaikas'};
is noun(q{nagaikas})->plural, q{nagaikas}  => q{plural: 'nagaikas' --> 'nagaikas'};
is noun(q{exemplum})->plural,   q{exempla}  => q{plural: 'exemplum' --> 'exempla'};
is noun(q{exempla})->plural, q{exempla}  => q{plural: 'exempla' --> 'exempla'};
is noun(q{whatsoever})->plural,   q{whatsoever}  => q{plural: 'whatsoever' --> 'whatsoever'};
is noun(q{summum genus})->plural,   q{summa genera}  => q{plural: 'summum genus' --> 'summa genera'};
is noun(q{summa genera})->plural, q{summa genera}  => q{plural: 'summa genera' --> 'summa genera'};
is noun(q{penicillus})->plural,   q{penicilli}  => q{plural: 'penicillus' --> 'penicilli'};
is noun(q{penicilli})->plural, q{penicilli}  => q{plural: 'penicilli' --> 'penicilli'};
is noun(q{tessera})->plural,   q{tesserae}  => q{plural: 'tessera' --> 'tesserae'};
is noun(q{tesserae})->plural, q{tesserae}  => q{plural: 'tesserae' --> 'tesserae'};
is noun(q{flora})->plural,   q{floras}  => q{plural: 'flora' --> 'floras'};
is noun(q{floras})->plural, q{floras}  => q{plural: 'floras' --> 'floras'};
is noun(q{joe})->plural,   q{joes}  => q{plural: 'joe' --> 'joes'};
is noun(q{joes})->plural, q{joes}  => q{plural: 'joes' --> 'joes'};
is noun(q{wandervogel})->plural,   q{wandervogel}  => q{plural: 'wandervogel' --> 'wandervogel'};
is noun(q{otomi})->plural,   q{otomies}  => q{plural: 'otomi' --> 'otomies'};
is noun(q{otomies})->plural, q{otomies}  => q{plural: 'otomies' --> 'otomies'};
is noun(q{terminus})->plural,   q{terminuses}  => q{plural: 'terminus' --> 'terminuses'};
is noun(q{terminuses})->plural, q{terminuses}  => q{plural: 'terminuses' --> 'terminuses'};
is noun(q{serra})->plural,   q{serrae}  => q{plural: 'serra' --> 'serrae'};
is noun(q{serrae})->plural, q{serrae}  => q{plural: 'serrae' --> 'serrae'};
is noun(q{herr})->plural,   q{herren}  => q{plural: 'herr' --> 'herren'};
is noun(q{herren})->plural, q{herren}  => q{plural: 'herren' --> 'herren'};
is noun(q{modulus})->plural,   q{moduluses}  => q{plural: 'modulus' --> 'moduluses'};
is noun(q{moduluses})->plural, q{moduluses}  => q{plural: 'moduluses' --> 'moduluses'};
is noun(q{prosodiencephalon})->plural,   q{prosodiencephala}  => q{plural: 'prosodiencephalon' --> 'prosodiencephala'};
is noun(q{prosodiencephala})->plural, q{prosodiencephala}  => q{plural: 'prosodiencephala' --> 'prosodiencephala'};
is noun(q{polis})->plural,   q{polises}  => q{plural: 'polis' --> 'polises'};
is noun(q{polises})->plural, q{polises}  => q{plural: 'polises' --> 'polises'};
is noun(q{salita})->plural,   q{salitas}  => q{plural: 'salita' --> 'salitas'};
is noun(q{salitas})->plural, q{salitas}  => q{plural: 'salitas' --> 'salitas'};
is noun(q{viscus})->plural,   q{viscera}  => q{plural: 'viscus' --> 'viscera'};
is noun(q{viscera})->plural, q{viscera}  => q{plural: 'viscera' --> 'viscera'};
is noun(q{aviso})->plural,   q{avisos}  => q{plural: 'aviso' --> 'avisos'};
is noun(q{avisos})->plural, q{avisos}  => q{plural: 'avisos' --> 'avisos'};
is noun(q{stirps})->plural,   q{stirpes}  => q{plural: 'stirps' --> 'stirpes'};
is noun(q{stirpes})->plural, q{stirpes}  => q{plural: 'stirpes' --> 'stirpes'};
is noun(q{whosoever})->plural,   q{whosoever}  => q{plural: 'whosoever' --> 'whosoever'};
is noun(q{2-star general})->plural,   q{2-star generals}  => q{plural: '2-star general' --> '2-star generals'};
is noun(q{2-star generals})->plural, q{2-star generals}  => q{plural: '2-star generals' --> '2-star generals'};
is noun(q{hemi-elytrum})->plural,   q{hemi-elytra}  => q{plural: 'hemi-elytrum' --> 'hemi-elytra'};
is noun(q{hemi-elytra})->plural, q{hemi-elytra}  => q{plural: 'hemi-elytra' --> 'hemi-elytra'};
is noun(q{proavis})->plural,   q{proaves}  => q{plural: 'proavis' --> 'proaves'};
is noun(q{proaves})->plural, q{proaves}  => q{plural: 'proaves' --> 'proaves'};
is noun(q{it})->plural,   q{they}  => q{plural: 'it' --> 'they'};
is noun(q{desman})->plural,   q{desmans}  => q{plural: 'desman' --> 'desmans'};
is noun(q{desmans})->plural, q{desmans}  => q{plural: 'desmans' --> 'desmans'};
is noun(q{kuvasz})->plural,   q{kuvaszok}  => q{plural: 'kuvasz' --> 'kuvaszok'};
is noun(q{kuvaszok})->plural, q{kuvaszok}  => q{plural: 'kuvaszok' --> 'kuvaszok'};
is noun(q{pant})->plural,   q{pants}  => q{plural: 'pant' --> 'pants'};
is noun(q{ergastulum})->plural,   q{ergastula}  => q{plural: 'ergastulum' --> 'ergastula'};
is noun(q{ergastula})->plural, q{ergastula}  => q{plural: 'ergastula' --> 'ergastula'};
is noun(q{ephemeris})->plural,   q{ephemerises}  => q{plural: 'ephemeris' --> 'ephemerises'};
is noun(q{ephemerises})->plural, q{ephemerises}  => q{plural: 'ephemerises' --> 'ephemerises'};
is noun(q{kovsh})->plural,   q{kovshi}  => q{plural: 'kovsh' --> 'kovshi'};
is noun(q{kovshi})->plural, q{kovshi}  => q{plural: 'kovshi' --> 'kovshi'};
is noun(q{leptomonas})->plural,   q{leptomonas}  => q{plural: 'leptomonas' --> 'leptomonas'};
is noun(q{Bahaman})->plural,   q{Bahamans}  => q{plural: 'Bahaman' --> 'Bahamans'};
is noun(q{Bahamans})->plural, q{Bahamans}  => q{plural: 'Bahamans' --> 'Bahamans'};
is noun(q{corgi})->plural,   q{corgis}  => q{plural: 'corgi' --> 'corgis'};
is noun(q{corgis})->plural, q{corgis}  => q{plural: 'corgis' --> 'corgis'};
is noun(q{port a beul})->plural,   q{puirt a beul}  => q{plural: 'port a beul' --> 'puirt a beul'};
is noun(q{puirt a beul})->plural, q{puirt a beul}  => q{plural: 'puirt a beul' --> 'puirt a beul'};
is noun(q{portmanteau})->plural,   q{portmanteaus}  => q{plural: 'portmanteau' --> 'portmanteaus'};
is noun(q{portmanteaus})->plural, q{portmanteaus}  => q{plural: 'portmanteaus' --> 'portmanteaus'};
is noun(q{plasmodium})->plural,   q{plasmodia}  => q{plural: 'plasmodium' --> 'plasmodia'};
is noun(q{plasmodia})->plural, q{plasmodia}  => q{plural: 'plasmodia' --> 'plasmodia'};
is noun(q{inhalatorium})->plural,   q{inhalatoria}  => q{plural: 'inhalatorium' --> 'inhalatoria'};
is noun(q{inhalatoria})->plural, q{inhalatoria}  => q{plural: 'inhalatoria' --> 'inhalatoria'};
is noun(q{parapleura})->plural,   q{parapleura}  => q{plural: 'parapleura' --> 'parapleura'};
is noun(q{bronchitis})->plural,   q{bronchitises}  => q{plural: 'bronchitis' --> 'bronchitises'};
is noun(q{bronchitises})->plural, q{bronchitises}  => q{plural: 'bronchitises' --> 'bronchitises'};
is noun(q{tholus})->plural,   q{tholi}  => q{plural: 'tholus' --> 'tholi'};
is noun(q{tholi})->plural, q{tholi}  => q{plural: 'tholi' --> 'tholi'};
is noun(q{micronucleus})->plural,   q{micronuclei}  => q{plural: 'micronucleus' --> 'micronuclei'};
is noun(q{micronuclei})->plural, q{micronuclei}  => q{plural: 'micronuclei' --> 'micronuclei'};
is noun(q{shawabti})->plural,   q{shawabtis}  => q{plural: 'shawabti' --> 'shawabtis'};
is noun(q{shawabtis})->plural, q{shawabtis}  => q{plural: 'shawabtis' --> 'shawabtis'};
is noun(q{sassafras})->plural,   q{sassafrases}  => q{plural: 'sassafras' --> 'sassafrases'};
is noun(q{sassafrases})->plural, q{sassafrases}  => q{plural: 'sassafrases' --> 'sassafrases'};
is noun(q{Whitmanese})->plural,   q{Whitmanese}  => q{plural: 'Whitmanese' --> 'Whitmanese'};
is noun(q{they})->plural,   q{they}  => q{plural: 'they' --> 'they'};
is noun(q{propylaeum})->plural,   q{propylaea}  => q{plural: 'propylaeum' --> 'propylaea'};
is noun(q{propylaea})->plural, q{propylaea}  => q{plural: 'propylaea' --> 'propylaea'};
is noun(q{umbra})->plural,   q{umbras}  => q{plural: 'umbra' --> 'umbras'};
is noun(q{umbras})->plural, q{umbras}  => q{plural: 'umbras' --> 'umbras'};
is noun(q{port-a-beul})->plural,   q{puirt-a-beul}  => q{plural: 'port-a-beul' --> 'puirt-a-beul'};
is noun(q{puirt-a-beul})->plural, q{puirt-a-beul}  => q{plural: 'puirt-a-beul' --> 'puirt-a-beul'};
is noun(q{stylo})->plural,   q{stylos}  => q{plural: 'stylo' --> 'stylos'};
is noun(q{stylos})->plural, q{stylos}  => q{plural: 'stylos' --> 'stylos'};
is noun(q{siglos})->plural,   q{sigli}  => q{plural: 'siglos' --> 'sigli'};
is noun(q{sigli})->plural, q{sigli}  => q{plural: 'sigli' --> 'sigli'};
is noun(q{scissors})->plural,   q{scissors}  => q{plural: 'scissors' --> 'scissors'};
is noun(q{musa})->plural,   q{musas}  => q{plural: 'musa' --> 'musas'};
is noun(q{musas})->plural, q{musas}  => q{plural: 'musas' --> 'musas'};
is noun(q{vacuum})->plural,   q{vacuums}  => q{plural: 'vacuum' --> 'vacuums'};
is noun(q{vacuums})->plural, q{vacuums}  => q{plural: 'vacuums' --> 'vacuums'};
is noun(q{portrait parle})->plural,   q{portraits parles}  => q{plural: 'portrait parle' --> 'portraits parles'};
is noun(q{portraits parles})->plural, q{portraits parles}  => q{plural: 'portraits parles' --> 'portraits parles'};
is noun(q{sistrum})->plural,   q{sistrums}  => q{plural: 'sistrum' --> 'sistrums'};
is noun(q{sistrums})->plural, q{sistrums}  => q{plural: 'sistrums' --> 'sistrums'};
is noun(q{plenarium})->plural,   q{plenaria}  => q{plural: 'plenarium' --> 'plenaria'};
is noun(q{plenaria})->plural, q{plenaria}  => q{plural: 'plenaria' --> 'plenaria'};
is noun(q{himself})->plural,   q{themselves}  => q{plural: 'himself' --> 'themselves'};
is noun(q{sputum})->plural,   q{sputa}  => q{plural: 'sputum' --> 'sputa'};
is noun(q{sputa})->plural, q{sputa}  => q{plural: 'sputa' --> 'sputa'};
is noun(q{rad})->plural,   q{rads}  => q{plural: 'rad' --> 'rads'};
is noun(q{rads})->plural, q{rads}  => q{plural: 'rads' --> 'rads'};
is noun(q{judicatum})->plural,   q{judicata}  => q{plural: 'judicatum' --> 'judicata'};
is noun(q{judicata})->plural, q{judicata}  => q{plural: 'judicata' --> 'judicata'};
is noun(q{snooze})->plural,   q{snoozes}  => q{plural: 'snooze' --> 'snoozes'};
is noun(q{snoozes})->plural, q{snoozes}  => q{plural: 'snoozes' --> 'snoozes'};
is noun(q{ellipse})->plural,   q{ellipses}  => q{plural: 'ellipse' --> 'ellipses'};
is noun(q{ellipses})->plural, q{ellipses}  => q{plural: 'ellipses' --> 'ellipses'};
is noun(q{starets})->plural,   q{startsy}  => q{plural: 'starets' --> 'startsy'};
is noun(q{startsy})->plural, q{startsy}  => q{plural: 'startsy' --> 'startsy'};
is noun(q{theologoumenon})->plural,   q{theologoumena}  => q{plural: 'theologoumenon' --> 'theologoumena'};
is noun(q{theologoumena})->plural, q{theologoumena}  => q{plural: 'theologoumena' --> 'theologoumena'};
is noun(q{cumulus})->plural,   q{cumuli}  => q{plural: 'cumulus' --> 'cumuli'};
is noun(q{cumuli})->plural, q{cumuli}  => q{plural: 'cumuli' --> 'cumuli'};
is noun(q{scarus})->plural,   q{scari}  => q{plural: 'scarus' --> 'scari'};
is noun(q{scari})->plural, q{scari}  => q{plural: 'scari' --> 'scari'};
is noun(q{cicatrix})->plural,   q{cicatrices}  => q{plural: 'cicatrix' --> 'cicatrices'};
is noun(q{cicatrices})->plural, q{cicatrices}  => q{plural: 'cicatrices' --> 'cicatrices'};
is noun(q{exanthema})->plural,   q{exanthemata}  => q{plural: 'exanthema' --> 'exanthemata'};
is noun(q{exanthemata})->plural, q{exanthemata}  => q{plural: 'exanthemata' --> 'exanthemata'};
is noun(q{glacis})->plural,   q{glacises}  => q{plural: 'glacis' --> 'glacises'};
is noun(q{glacises})->plural, q{glacises}  => q{plural: 'glacises' --> 'glacises'};
is noun(q{perceptum})->plural,   q{percepta}  => q{plural: 'perceptum' --> 'percepta'};
is noun(q{percepta})->plural, q{percepta}  => q{plural: 'percepta' --> 'percepta'};
is noun(q{testudo})->plural,   q{testudos}  => q{plural: 'testudo' --> 'testudos'};
is noun(q{testudos})->plural, q{testudos}  => q{plural: 'testudos' --> 'testudos'};
is noun(q{paha})->plural,   q{paha}  => q{plural: 'paha' --> 'paha'};
is noun(q{phyma})->plural,   q{phymata}  => q{plural: 'phyma' --> 'phymata'};
is noun(q{phymata})->plural, q{phymata}  => q{plural: 'phymata' --> 'phymata'};
is noun(q{synaesthesia})->plural,   q{synaesthesiae}  => q{plural: 'synaesthesia' --> 'synaesthesiae'};
is noun(q{synaesthesiae})->plural, q{synaesthesiae}  => q{plural: 'synaesthesiae' --> 'synaesthesiae'};
is noun(q{Tokyo})->plural,   q{Tokyos}  => q{plural: 'Tokyo' --> 'Tokyos'};
is noun(q{Tokyos})->plural, q{Tokyos}  => q{plural: 'Tokyos' --> 'Tokyos'};
is noun(q{legumen})->plural,   q{legumens}  => q{plural: 'legumen' --> 'legumens'};
is noun(q{legumens})->plural, q{legumens}  => q{plural: 'legumens' --> 'legumens'};
is noun(q{proceedings})->plural,   q{proceedings}  => q{plural: 'proceedings' --> 'proceedings'};
is noun(q{stylus})->plural,   q{styluses}  => q{plural: 'stylus' --> 'styluses'};
is noun(q{styluses})->plural, q{styluses}  => q{plural: 'styluses' --> 'styluses'};
is noun(q{agrogorod})->plural,   q{agrogoroda}  => q{plural: 'agrogorod' --> 'agrogoroda'};
is noun(q{agrogoroda})->plural, q{agrogoroda}  => q{plural: 'agrogoroda' --> 'agrogoroda'};
is noun(q{heroum})->plural,   q{heroa}  => q{plural: 'heroum' --> 'heroa'};
is noun(q{heroa})->plural, q{heroa}  => q{plural: 'heroa' --> 'heroa'};
is noun(q{rhinoceros})->plural,   q{rhinoceroses}  => q{plural: 'rhinoceros' --> 'rhinoceroses'};
is noun(q{rhinoceroses})->plural, q{rhinoceroses}  => q{plural: 'rhinoceroses' --> 'rhinoceroses'};
is noun(q{motoscafo})->plural,   q{motoscafi}  => q{plural: 'motoscafo' --> 'motoscafi'};
is noun(q{motoscafi})->plural, q{motoscafi}  => q{plural: 'motoscafi' --> 'motoscafi'};
is noun(q{phren})->plural,   q{phrenes}  => q{plural: 'phren' --> 'phrenes'};
is noun(q{phrenes})->plural, q{phrenes}  => q{plural: 'phrenes' --> 'phrenes'};
is noun(q{simia})->plural,   q{simiae}  => q{plural: 'simia' --> 'simiae'};
is noun(q{simiae})->plural, q{simiae}  => q{plural: 'simiae' --> 'simiae'};
is noun(q{naumachia})->plural,   q{naumachias}  => q{plural: 'naumachia' --> 'naumachias'};
is noun(q{naumachias})->plural, q{naumachias}  => q{plural: 'naumachias' --> 'naumachias'};
is noun(q{kibbutz})->plural,   q{kibbutzes}  => q{plural: 'kibbutz' --> 'kibbutzes'};
is noun(q{kibbutzes})->plural, q{kibbutzes}  => q{plural: 'kibbutzes' --> 'kibbutzes'};
is noun(q{synaxarium})->plural,   q{synaxaria}  => q{plural: 'synaxarium' --> 'synaxaria'};
is noun(q{synaxaria})->plural, q{synaxaria}  => q{plural: 'synaxaria' --> 'synaxaria'};
is noun(q{herring})->plural,   q{herrings}  => q{plural: 'herring' --> 'herrings'};
is noun(q{herrings})->plural, q{herrings}  => q{plural: 'herrings' --> 'herrings'};
is noun(q{clippers})->plural,   q{clippers}  => q{plural: 'clippers' --> 'clippers'};
is noun(q{stalactite})->plural,   q{stalactites}  => q{plural: 'stalactite' --> 'stalactites'};
is noun(q{stalactites})->plural, q{stalactites}  => q{plural: 'stalactites' --> 'stalactites'};
is noun(q{residuum})->plural,   q{residuums}  => q{plural: 'residuum' --> 'residuums'};
is noun(q{residuums})->plural, q{residuums}  => q{plural: 'residuums' --> 'residuums'};
is noun(q{quaesitum})->plural,   q{quaesita}  => q{plural: 'quaesitum' --> 'quaesita'};
is noun(q{quaesita})->plural, q{quaesita}  => q{plural: 'quaesita' --> 'quaesita'};
is noun(q{vehiculum})->plural,   q{vehicula}  => q{plural: 'vehiculum' --> 'vehicula'};
is noun(q{vehicula})->plural, q{vehicula}  => q{plural: 'vehicula' --> 'vehicula'};
is noun(q{Aragonese})->plural,   q{Aragonese}  => q{plural: 'Aragonese' --> 'Aragonese'};
is noun(q{man child})->plural,   q{men children}  => q{plural: 'man child' --> 'men children'};
is noun(q{men children})->plural, q{men children}  => q{plural: 'men children' --> 'men children'};
is noun(q{sacrarium})->plural,   q{sacraria}  => q{plural: 'sacrarium' --> 'sacraria'};
is noun(q{sacraria})->plural, q{sacraria}  => q{plural: 'sacraria' --> 'sacraria'};
is noun(q{lamina})->plural,   q{laminae}  => q{plural: 'lamina' --> 'laminae'};
is noun(q{laminae})->plural, q{laminae}  => q{plural: 'laminae' --> 'laminae'};
is noun(q{torso})->plural,   q{torsos}  => q{plural: 'torso' --> 'torsos'};
is noun(q{torsos})->plural, q{torsos}  => q{plural: 'torsos' --> 'torsos'};
is noun(q{sparus})->plural,   q{spari}  => q{plural: 'sparus' --> 'spari'};
is noun(q{spari})->plural, q{spari}  => q{plural: 'spari' --> 'spari'};
is noun(q{die})->plural,   q{dice}  => q{plural: 'die' --> 'dice'};
is noun(q{dice})->plural, q{dice}  => q{plural: 'dice' --> 'dice'};
is noun(q{karakia})->plural,   q{karakias}  => q{plural: 'karakia' --> 'karakias'};
is noun(q{karakias})->plural, q{karakias}  => q{plural: 'karakias' --> 'karakias'};
is noun(q{superstratum})->plural,   q{superstrata}  => q{plural: 'superstratum' --> 'superstrata'};
is noun(q{superstrata})->plural, q{superstrata}  => q{plural: 'superstrata' --> 'superstrata'};
is noun(q{candelabrum})->plural,   q{candelabra}  => q{plural: 'candelabrum' --> 'candelabra'};
is noun(q{candelabra})->plural, q{candelabra}  => q{plural: 'candelabra' --> 'candelabra'};
is noun(q{pyrites})->plural,   q{pyritae}  => q{plural: 'pyrites' --> 'pyritae'};
is noun(q{pyritae})->plural, q{pyritae}  => q{plural: 'pyritae' --> 'pyritae'};
is noun(q{burro})->plural,   q{burros}  => q{plural: 'burro' --> 'burros'};
is noun(q{burros})->plural, q{burros}  => q{plural: 'burros' --> 'burros'};
is noun(q{phototaxis})->plural,   q{phototaxes}  => q{plural: 'phototaxis' --> 'phototaxes'};
is noun(q{phototaxes})->plural, q{phototaxes}  => q{plural: 'phototaxes' --> 'phototaxes'};
is noun(q{asterias})->plural,   q{asteriae}  => q{plural: 'asterias' --> 'asteriae'};
is noun(q{asteriae})->plural, q{asteriae}  => q{plural: 'asteriae' --> 'asteriae'};
is noun(q{phallus})->plural,   q{phalluses}  => q{plural: 'phallus' --> 'phalluses'};
is noun(q{phalluses})->plural, q{phalluses}  => q{plural: 'phalluses' --> 'phalluses'};
is noun(q{conversazione})->plural,   q{conversaziones}  => q{plural: 'conversazione' --> 'conversaziones'};
is noun(q{conversaziones})->plural, q{conversaziones}  => q{plural: 'conversaziones' --> 'conversaziones'};
is noun(q{synthronus})->plural,   q{synthroni}  => q{plural: 'synthronus' --> 'synthroni'};
is noun(q{synthroni})->plural, q{synthroni}  => q{plural: 'synthroni' --> 'synthroni'};
is noun(q{situla})->plural,   q{situlas}  => q{plural: 'situla' --> 'situlas'};
is noun(q{situlas})->plural, q{situlas}  => q{plural: 'situlas' --> 'situlas'};
is noun(q{cony})->plural,   q{conys}  => q{plural: 'cony' --> 'conys'};
is noun(q{conys})->plural, q{conys}  => q{plural: 'conys' --> 'conys'};
is noun(q{swine})->plural,   q{swine}  => q{plural: 'swine' --> 'swine'};
is noun(q{frustulum})->plural,   q{frustula}  => q{plural: 'frustulum' --> 'frustula'};
is noun(q{frustula})->plural, q{frustula}  => q{plural: 'frustula' --> 'frustula'};
is noun(q{porion})->plural,   q{poria}  => q{plural: 'porion' --> 'poria'};
is noun(q{poria})->plural, q{poria}  => q{plural: 'poria' --> 'poria'};
is noun(q{maremma})->plural,   q{maremme}  => q{plural: 'maremma' --> 'maremme'};
is noun(q{maremme})->plural, q{maremme}  => q{plural: 'maremme' --> 'maremme'};
is noun(q{sagum})->plural,   q{saga}  => q{plural: 'sagum' --> 'saga'};
is noun(q{saga})->plural, q{saga}  => q{plural: 'saga' --> 'saga'};
is noun(q{lamella})->plural,   q{lamellae}  => q{plural: 'lamella' --> 'lamellae'};
is noun(q{lamellae})->plural, q{lamellae}  => q{plural: 'lamellae' --> 'lamellae'};
is noun(q{propositus})->plural,   q{propositi}  => q{plural: 'propositus' --> 'propositi'};
is noun(q{propositi})->plural, q{propositi}  => q{plural: 'propositi' --> 'propositi'};
is noun(q{ustilago})->plural,   q{ustilagines}  => q{plural: 'ustilago' --> 'ustilagines'};
is noun(q{ustilagines})->plural, q{ustilagines}  => q{plural: 'ustilagines' --> 'ustilagines'};
is noun(q{aurora})->plural,   q{auroras}  => q{plural: 'aurora' --> 'auroras'};
is noun(q{auroras})->plural, q{auroras}  => q{plural: 'auroras' --> 'auroras'};
is noun(q{squama})->plural,   q{squamae}  => q{plural: 'squama' --> 'squamae'};
is noun(q{squamae})->plural, q{squamae}  => q{plural: 'squamae' --> 'squamae'};
is noun(q{Tornese})->plural,   q{Tornesi}  => q{plural: 'Tornese' --> 'Tornesi'};
is noun(q{Tornesi})->plural, q{Tornesi}  => q{plural: 'Tornesi' --> 'Tornesi'};
is noun(q{Javanese})->plural,   q{Javanese}  => q{plural: 'Javanese' --> 'Javanese'};
is noun(q{carte de visite})->plural,   q{cartes de visite}  => q{plural: 'carte de visite' --> 'cartes de visite'};
is noun(q{cartes de visite})->plural, q{cartes de visite}  => q{plural: 'cartes de visite' --> 'cartes de visite'};
is noun(q{onager})->plural,   q{onagers}  => q{plural: 'onager' --> 'onagers'};
is noun(q{onagers})->plural, q{onagers}  => q{plural: 'onagers' --> 'onagers'};
is noun(q{nasutus})->plural,   q{nasuti}  => q{plural: 'nasutus' --> 'nasuti'};
is noun(q{nasuti})->plural, q{nasuti}  => q{plural: 'nasuti' --> 'nasuti'};
is noun(q{Yunnanese})->plural,   q{Yunnanese}  => q{plural: 'Yunnanese' --> 'Yunnanese'};
is noun(q{placebo})->plural,   q{placebos}  => q{plural: 'placebo' --> 'placebos'};
is noun(q{placebos})->plural, q{placebos}  => q{plural: 'placebos' --> 'placebos'};
is noun(q{tentaculum})->plural,   q{tentacula}  => q{plural: 'tentaculum' --> 'tentacula'};
is noun(q{tentacula})->plural, q{tentacula}  => q{plural: 'tentacula' --> 'tentacula'};
is noun(q{medium})->plural,   q{mediums}  => q{plural: 'medium' --> 'mediums'};
is noun(q{mediums})->plural, q{mediums}  => q{plural: 'mediums' --> 'mediums'};
is noun(q{clausula})->plural,   q{clausulae}  => q{plural: 'clausula' --> 'clausulae'};
is noun(q{clausulae})->plural, q{clausulae}  => q{plural: 'clausulae' --> 'clausulae'};
is noun(q{Taiko})->plural,   q{Taikos}  => q{plural: 'Taiko' --> 'Taikos'};
is noun(q{Taikos})->plural, q{Taikos}  => q{plural: 'Taikos' --> 'Taikos'};
is noun(q{senarius})->plural,   q{senarii}  => q{plural: 'senarius' --> 'senarii'};
is noun(q{senarii})->plural, q{senarii}  => q{plural: 'senarii' --> 'senarii'};
is noun(q{mythos})->plural,   q{mythoi}  => q{plural: 'mythos' --> 'mythoi'};
is noun(q{mythoi})->plural, q{mythoi}  => q{plural: 'mythoi' --> 'mythoi'};
is noun(q{rhododendron})->plural,   q{rhododendrons}  => q{plural: 'rhododendron' --> 'rhododendrons'};
is noun(q{rhododendrons})->plural, q{rhododendrons}  => q{plural: 'rhododendrons' --> 'rhododendrons'};
is noun(q{flag staff})->plural,   q{flag staffs}  => q{plural: 'flag staff' --> 'flag staffs'};
is noun(q{flag staffs})->plural, q{flag staffs}  => q{plural: 'flag staffs' --> 'flag staffs'};
is noun(q{debris})->plural,   q{debris}  => q{plural: 'debris' --> 'debris'};
is noun(q{starosta})->plural,   q{starosti}  => q{plural: 'starosta' --> 'starosti'};
is noun(q{starosti})->plural, q{starosti}  => q{plural: 'starosti' --> 'starosti'};
is noun(q{Sonaman})->plural,   q{Sonamans}  => q{plural: 'Sonaman' --> 'Sonamans'};
is noun(q{Sonamans})->plural, q{Sonamans}  => q{plural: 'Sonamans' --> 'Sonamans'};
is noun(q{lyssa})->plural,   q{lyssae}  => q{plural: 'lyssa' --> 'lyssae'};
is noun(q{lyssae})->plural, q{lyssae}  => q{plural: 'lyssae' --> 'lyssae'};
is noun(q{leishmania})->plural,   q{leishmanias}  => q{plural: 'leishmania' --> 'leishmanias'};
is noun(q{leishmanias})->plural, q{leishmanias}  => q{plural: 'leishmanias' --> 'leishmanias'};
is noun(q{mediatrix})->plural,   q{mediatrices}  => q{plural: 'mediatrix' --> 'mediatrices'};
is noun(q{mediatrices})->plural, q{mediatrices}  => q{plural: 'mediatrices' --> 'mediatrices'};
is noun(q{plurale tantum})->plural,   q{pluralia tantum}  => q{plural: 'plurale tantum' --> 'pluralia tantum'};
is noun(q{pluralia tantum})->plural, q{pluralia tantum}  => q{plural: 'pluralia tantum' --> 'pluralia tantum'};
is noun(q{ricordo})->plural,   q{ricordi}  => q{plural: 'ricordo' --> 'ricordi'};
is noun(q{ricordi})->plural, q{ricordi}  => q{plural: 'ricordi' --> 'ricordi'};
is noun(q{helion})->plural,   q{helions}  => q{plural: 'helion' --> 'helions'};
is noun(q{helions})->plural, q{helions}  => q{plural: 'helions' --> 'helions'};
is noun(q{coup d'etat})->plural,   q{coups d'etat}  => q{plural: 'coup d'etat' --> 'coups d'etat'};
is noun(q{coups d'etat})->plural, q{coups d'etat}  => q{plural: 'coups d'etat' --> 'coups d'etat'};
is noun(q{funambulus})->plural,   q{funambuli}  => q{plural: 'funambulus' --> 'funambuli'};
is noun(q{funambuli})->plural, q{funambuli}  => q{plural: 'funambuli' --> 'funambuli'};
is noun(q{uomo})->plural,   q{uomini}  => q{plural: 'uomo' --> 'uomini'};
is noun(q{uomini})->plural, q{uomini}  => q{plural: 'uomini' --> 'uomini'};
is noun(q{bratwurst})->plural,   q{bratwursts}  => q{plural: 'bratwurst' --> 'bratwursts'};
is noun(q{bratwursts})->plural, q{bratwursts}  => q{plural: 'bratwursts' --> 'bratwursts'};
is noun(q{acroama})->plural,   q{acroamata}  => q{plural: 'acroama' --> 'acroamata'};
is noun(q{acroamata})->plural, q{acroamata}  => q{plural: 'acroamata' --> 'acroamata'};
is noun(q{shear})->plural,   q{shears}  => q{plural: 'shear' --> 'shears'};
is noun(q{serir})->plural,   q{serirs}  => q{plural: 'serir' --> 'serirs'};
is noun(q{serirs})->plural, q{serirs}  => q{plural: 'serirs' --> 'serirs'};
is noun(q{cul de sac})->plural,   q{culs de sac}  => q{plural: 'cul de sac' --> 'culs de sac'};
is noun(q{culs de sac})->plural, q{culs de sac}  => q{plural: 'culs de sac' --> 'culs de sac'};
is noun(q{stichos})->plural,   q{stichoi}  => q{plural: 'stichos' --> 'stichoi'};
is noun(q{stichoi})->plural, q{stichoi}  => q{plural: 'stichoi' --> 'stichoi'};
is noun(q{consortium})->plural,   q{consortiums}  => q{plural: 'consortium' --> 'consortiums'};
is noun(q{consortiums})->plural, q{consortiums}  => q{plural: 'consortiums' --> 'consortiums'};
is noun(q{ixodid})->plural,   q{ixodides}  => q{plural: 'ixodid' --> 'ixodides'};
is noun(q{ixodides})->plural, q{ixodides}  => q{plural: 'ixodides' --> 'ixodides'};
is noun(q{medulloblastoma})->plural,   q{medulloblastomas}  => q{plural: 'medulloblastoma' --> 'medulloblastomas'};
is noun(q{medulloblastomas})->plural, q{medulloblastomas}  => q{plural: 'medulloblastomas' --> 'medulloblastomas'};
is noun(q{corps general})->plural,   q{corps generals}  => q{plural: 'corps general' --> 'corps generals'};
is noun(q{corps generals})->plural, q{corps generals}  => q{plural: 'corps generals' --> 'corps generals'};
is noun(q{topaz})->plural,   q{topazes}  => q{plural: 'topaz' --> 'topazes'};
is noun(q{topazes})->plural, q{topazes}  => q{plural: 'topazes' --> 'topazes'};
is noun(q{konditorei})->plural,   q{konditorei}  => q{plural: 'konditorei' --> 'konditorei'};
is noun(q{menu})->plural,   q{menus}  => q{plural: 'menu' --> 'menus'};
is noun(q{menus})->plural, q{menus}  => q{plural: 'menus' --> 'menus'};
is noun(q{remous})->plural,   q{remous}  => q{plural: 'remous' --> 'remous'};
is noun(q{tympanum})->plural,   q{tympana}  => q{plural: 'tympanum' --> 'tympana'};
is noun(q{tympana})->plural, q{tympana}  => q{plural: 'tympana' --> 'tympana'};
is noun(q{Tocharese})->plural,   q{Tocharese}  => q{plural: 'Tocharese' --> 'Tocharese'};
is noun(q{Selman})->plural,   q{Selmans}  => q{plural: 'Selman' --> 'Selmans'};
is noun(q{Selmans})->plural, q{Selmans}  => q{plural: 'Selmans' --> 'Selmans'};
is noun(q{jo})->plural,   q{joes}  => q{plural: 'jo' --> 'joes'};
is noun(q{joes})->plural, q{joes}  => q{plural: 'joes' --> 'joes'};
is noun(q{pangasinan})->plural,   q{pangasinans}  => q{plural: 'pangasinan' --> 'pangasinans'};
is noun(q{pangasinans})->plural, q{pangasinans}  => q{plural: 'pangasinans' --> 'pangasinans'};
is noun(q{switchfoot})->plural,   q{switchfoots}  => q{plural: 'switchfoot' --> 'switchfoots'};
is noun(q{switchfoots})->plural, q{switchfoots}  => q{plural: 'switchfoots' --> 'switchfoots'};
is noun(q{alto-relievo})->plural,   q{alto-relievos}  => q{plural: 'alto-relievo' --> 'alto-relievos'};
is noun(q{alto-relievos})->plural, q{alto-relievos}  => q{plural: 'alto-relievos' --> 'alto-relievos'};
is noun(q{trauma})->plural,   q{traumas}  => q{plural: 'trauma' --> 'traumas'};
is noun(q{traumas})->plural, q{traumas}  => q{plural: 'traumas' --> 'traumas'};
is noun(q{medico})->plural,   q{medicos}  => q{plural: 'medico' --> 'medicos'};
is noun(q{medicos})->plural, q{medicos}  => q{plural: 'medicos' --> 'medicos'};
is noun(q{syntagma})->plural,   q{syntagmas}  => q{plural: 'syntagma' --> 'syntagmas'};
is noun(q{syntagmas})->plural, q{syntagmas}  => q{plural: 'syntagmas' --> 'syntagmas'};
is noun(q{scutum})->plural,   q{scuta}  => q{plural: 'scutum' --> 'scuta'};
is noun(q{scuta})->plural, q{scuta}  => q{plural: 'scuta' --> 'scuta'};
is noun(q{saxicava})->plural,   q{saxicavae}  => q{plural: 'saxicava' --> 'saxicavae'};
is noun(q{saxicavae})->plural, q{saxicavae}  => q{plural: 'saxicavae' --> 'saxicavae'};
is noun(q{occiput})->plural,   q{occiputs}  => q{plural: 'occiput' --> 'occiputs'};
is noun(q{occiputs})->plural, q{occiputs}  => q{plural: 'occiputs' --> 'occiputs'};
is noun(q{clipper})->plural,   q{clippers}  => q{plural: 'clipper' --> 'clippers'};
is noun(q{tractrix})->plural,   q{tractrices}  => q{plural: 'tractrix' --> 'tractrices'};
is noun(q{tractrices})->plural, q{tractrices}  => q{plural: 'tractrices' --> 'tractrices'};
is noun(q{eucalyptus})->plural,   q{eucalyptuses}  => q{plural: 'eucalyptus' --> 'eucalyptuses'};
is noun(q{eucalyptuses})->plural, q{eucalyptuses}  => q{plural: 'eucalyptuses' --> 'eucalyptuses'};
is noun(q{hubris})->plural,   q{hubrises}  => q{plural: 'hubris' --> 'hubrises'};
is noun(q{hubrises})->plural, q{hubrises}  => q{plural: 'hubrises' --> 'hubrises'};
is noun(q{varia lectio})->plural,   q{variae lectiones}  => q{plural: 'varia lectio' --> 'variae lectiones'};
is noun(q{variae lectiones})->plural, q{variae lectiones}  => q{plural: 'variae lectiones' --> 'variae lectiones'};
is noun(q{pollex})->plural,   q{pollices}  => q{plural: 'pollex' --> 'pollices'};
is noun(q{pollices})->plural, q{pollices}  => q{plural: 'pollices' --> 'pollices'};
is noun(q{5-star general})->plural,   q{5-star generals}  => q{plural: '5-star general' --> '5-star generals'};
is noun(q{5-star generals})->plural, q{5-star generals}  => q{plural: '5-star generals' --> '5-star generals'};
is noun(q{storey})->plural,   q{storeys}  => q{plural: 'storey' --> 'storeys'};
is noun(q{storeys})->plural, q{storeys}  => q{plural: 'storeys' --> 'storeys'};
is noun(q{hyperbola})->plural,   q{hyperbolas}  => q{plural: 'hyperbola' --> 'hyperbolas'};
is noun(q{hyperbolas})->plural, q{hyperbolas}  => q{plural: 'hyperbolas' --> 'hyperbolas'};
is noun(q{vomitorium})->plural,   q{vomitoriums}  => q{plural: 'vomitorium' --> 'vomitoriums'};
is noun(q{vomitoriums})->plural, q{vomitoriums}  => q{plural: 'vomitoriums' --> 'vomitoriums'};
is noun(q{pistillidium})->plural,   q{pistillidia}  => q{plural: 'pistillidium' --> 'pistillidia'};
is noun(q{pistillidia})->plural, q{pistillidia}  => q{plural: 'pistillidia' --> 'pistillidia'};
is noun(q{moratorium})->plural,   q{moratoriums}  => q{plural: 'moratorium' --> 'moratoriums'};
is noun(q{moratoriums})->plural, q{moratoriums}  => q{plural: 'moratoriums' --> 'moratoriums'};
is noun(q{Romanese})->plural,   q{Romanese}  => q{plural: 'Romanese' --> 'Romanese'};
is noun(q{seaquarium})->plural,   q{seaquaria}  => q{plural: 'seaquarium' --> 'seaquaria'};
is noun(q{seaquaria})->plural, q{seaquaria}  => q{plural: 'seaquaria' --> 'seaquaria'};
is noun(q{epimeron})->plural,   q{epimera}  => q{plural: 'epimeron' --> 'epimera'};
is noun(q{epimera})->plural, q{epimera}  => q{plural: 'epimera' --> 'epimera'};
is noun(q{vena})->plural,   q{venae}  => q{plural: 'vena' --> 'venae'};
is noun(q{venae})->plural, q{venae}  => q{plural: 'venae' --> 'venae'};
is noun(q{pengo})->plural,   q{pengo}  => q{plural: 'pengo' --> 'pengo'};
is noun(q{ocellus})->plural,   q{ocelli}  => q{plural: 'ocellus' --> 'ocelli'};
is noun(q{ocelli})->plural, q{ocelli}  => q{plural: 'ocelli' --> 'ocelli'};
is noun(q{Yengeese})->plural,   q{Yengeese}  => q{plural: 'Yengeese' --> 'Yengeese'};
is noun(q{volcano})->plural,   q{volcanos}  => q{plural: 'volcano' --> 'volcanos'};
is noun(q{volcanos})->plural, q{volcanos}  => q{plural: 'volcanos' --> 'volcanos'};
is noun(q{guttus})->plural,   q{gutti}  => q{plural: 'guttus' --> 'gutti'};
is noun(q{gutti})->plural, q{gutti}  => q{plural: 'gutti' --> 'gutti'};
is noun(q{man servant})->plural,   q{men servants}  => q{plural: 'man servant' --> 'men servants'};
is noun(q{men servants})->plural, q{men servants}  => q{plural: 'men servants' --> 'men servants'};
is noun(q{corrigendum})->plural,   q{corrigenda}  => q{plural: 'corrigendum' --> 'corrigenda'};
is noun(q{corrigenda})->plural, q{corrigenda}  => q{plural: 'corrigenda' --> 'corrigenda'};
is noun(q{weirdo})->plural,   q{weirdos}  => q{plural: 'weirdo' --> 'weirdos'};
is noun(q{weirdos})->plural, q{weirdos}  => q{plural: 'weirdos' --> 'weirdos'};
is noun(q{hallux})->plural,   q{halluces}  => q{plural: 'hallux' --> 'halluces'};
is noun(q{halluces})->plural, q{halluces}  => q{plural: 'halluces' --> 'halluces'};
is noun(q{eland})->plural,   q{elands}  => q{plural: 'eland' --> 'elands'};
is noun(q{elands})->plural, q{elands}  => q{plural: 'elands' --> 'elands'};
is noun(q{listerella})->plural,   q{listerellas}  => q{plural: 'listerella' --> 'listerellas'};
is noun(q{listerellas})->plural, q{listerellas}  => q{plural: 'listerellas' --> 'listerellas'};
is noun(q{omentum})->plural,   q{omenta}  => q{plural: 'omentum' --> 'omenta'};
is noun(q{omenta})->plural, q{omenta}  => q{plural: 'omenta' --> 'omenta'};
is noun(q{pholas})->plural,   q{pholades}  => q{plural: 'pholas' --> 'pholades'};
is noun(q{pholades})->plural, q{pholades}  => q{plural: 'pholades' --> 'pholades'};
is noun(q{semuncia})->plural,   q{semunciae}  => q{plural: 'semuncia' --> 'semunciae'};
is noun(q{semunciae})->plural, q{semunciae}  => q{plural: 'semunciae' --> 'semunciae'};
is noun(q{five-star general})->plural,   q{five-star generals}  => q{plural: 'five-star general' --> 'five-star generals'};
is noun(q{five-star generals})->plural, q{five-star generals}  => q{plural: 'five-star generals' --> 'five-star generals'};
is noun(q{me})->plural,   q{us}  => q{plural: 'me' --> 'us'};
is noun(q{us})->plural, q{us}  => q{plural: 'us' --> 'us'};
is noun(q{teal})->plural,   q{teals}  => q{plural: 'teal' --> 'teals'};
is noun(q{teals})->plural, q{teals}  => q{plural: 'teals' --> 'teals'};
is noun(q{hiatus})->plural,   q{hiatuses}  => q{plural: 'hiatus' --> 'hiatuses'};
is noun(q{hiatuses})->plural, q{hiatuses}  => q{plural: 'hiatuses' --> 'hiatuses'};
is noun(q{spermarium})->plural,   q{spermaria}  => q{plural: 'spermarium' --> 'spermaria'};
is noun(q{spermaria})->plural, q{spermaria}  => q{plural: 'spermaria' --> 'spermaria'};
is noun(q{ovum})->plural,   q{ova}  => q{plural: 'ovum' --> 'ova'};
is noun(q{ova})->plural, q{ova}  => q{plural: 'ova' --> 'ova'};
is noun(q{turbot})->plural,   q{turbots}  => q{plural: 'turbot' --> 'turbots'};
is noun(q{turbots})->plural, q{turbots}  => q{plural: 'turbots' --> 'turbots'};
is noun(q{Celanese})->plural,   q{Celanese}  => q{plural: 'Celanese' --> 'Celanese'};
is noun(q{synaxarion})->plural,   q{synaxaria}  => q{plural: 'synaxarion' --> 'synaxaria'};
is noun(q{synaxaria})->plural, q{synaxaria}  => q{plural: 'synaxaria' --> 'synaxaria'};
is noun(q{fucus})->plural,   q{fuci}  => q{plural: 'fucus' --> 'fuci'};
is noun(q{fuci})->plural, q{fuci}  => q{plural: 'fuci' --> 'fuci'};
is noun(q{geisha})->plural,   q{geishas}  => q{plural: 'geisha' --> 'geishas'};
is noun(q{geishas})->plural, q{geishas}  => q{plural: 'geishas' --> 'geishas'};
is noun(q{chaos})->plural,   q{chaoses}  => q{plural: 'chaos' --> 'chaoses'};
is noun(q{chaoses})->plural, q{chaoses}  => q{plural: 'chaoses' --> 'chaoses'};
is noun(q{anti-serum})->plural,   q{anti-serums}  => q{plural: 'anti-serum' --> 'anti-serums'};
is noun(q{anti-serums})->plural, q{anti-serums}  => q{plural: 'anti-serums' --> 'anti-serums'};
is noun(q{chervonetz})->plural,   q{chervontzi}  => q{plural: 'chervonetz' --> 'chervontzi'};
is noun(q{chervontzi})->plural, q{chervontzi}  => q{plural: 'chervontzi' --> 'chervontzi'};
is noun(q{antrum})->plural,   q{antra}  => q{plural: 'antrum' --> 'antra'};
is noun(q{antra})->plural, q{antra}  => q{plural: 'antra' --> 'antra'};
is noun(q{three star general})->plural,   q{three star generals}  => q{plural: 'three star general' --> 'three star generals'};
is noun(q{three star generals})->plural, q{three star generals}  => q{plural: 'three star generals' --> 'three star generals'};
is noun(q{Heavenese})->plural,   q{Heavenese}  => q{plural: 'Heavenese' --> 'Heavenese'};
is noun(q{corpus vile})->plural,   q{corpora vilia}  => q{plural: 'corpus vile' --> 'corpora vilia'};
is noun(q{corpora vilia})->plural, q{corpora vilia}  => q{plural: 'corpora vilia' --> 'corpora vilia'};
is noun(q{pox})->plural,   q{pox}  => q{plural: 'pox' --> 'pox'};
is noun(q{phlegmasia})->plural,   q{phlegmasiae}  => q{plural: 'phlegmasia' --> 'phlegmasiae'};
is noun(q{phlegmasiae})->plural, q{phlegmasiae}  => q{plural: 'phlegmasiae' --> 'phlegmasiae'};
is noun(q{obolus})->plural,   q{oboli}  => q{plural: 'obolus' --> 'oboli'};
is noun(q{oboli})->plural, q{oboli}  => q{plural: 'oboli' --> 'oboli'};
is noun(q{Kanarese})->plural,   q{Kanarese}  => q{plural: 'Kanarese' --> 'Kanarese'};
is noun(q{bema})->plural,   q{bemas}  => q{plural: 'bema' --> 'bemas'};
is noun(q{bemas})->plural, q{bemas}  => q{plural: 'bemas' --> 'bemas'};
is noun(q{canvas})->plural,   q{canvases}  => q{plural: 'canvas' --> 'canvases'};
is noun(q{canvases})->plural, q{canvases}  => q{plural: 'canvases' --> 'canvases'};
is noun(q{tete-a-tete})->plural,   q{tete-a-tetes}  => q{plural: 'tete-a-tete' --> 'tete-a-tetes'};
is noun(q{tete-a-tetes})->plural, q{tete-a-tetes}  => q{plural: 'tete-a-tetes' --> 'tete-a-tetes'};
is noun(q{fundamentum divisionis})->plural,   q{fundamenta divisionis}  => q{plural: 'fundamentum divisionis' --> 'fundamenta divisionis'};
is noun(q{fundamenta divisionis})->plural, q{fundamenta divisionis}  => q{plural: 'fundamenta divisionis' --> 'fundamenta divisionis'};
is noun(q{agendum})->plural,   q{agenda}  => q{plural: 'agendum' --> 'agenda'};
is noun(q{agenda})->plural, q{agenda}  => q{plural: 'agenda' --> 'agenda'};
is noun(q{aide de camp})->plural,   q{aides de camp}  => q{plural: 'aide de camp' --> 'aides de camp'};
is noun(q{aides de camp})->plural, q{aides de camp}  => q{plural: 'aides de camp' --> 'aides de camp'};
is noun(q{desideratum})->plural,   q{desiderata}  => q{plural: 'desideratum' --> 'desiderata'};
is noun(q{desiderata})->plural, q{desiderata}  => q{plural: 'desiderata' --> 'desiderata'};
is noun(q{ceriman})->plural,   q{cerimans}  => q{plural: 'ceriman' --> 'cerimans'};
is noun(q{cerimans})->plural, q{cerimans}  => q{plural: 'cerimans' --> 'cerimans'};
is noun(q{stoa})->plural,   q{stoas}  => q{plural: 'stoa' --> 'stoas'};
is noun(q{stoas})->plural, q{stoas}  => q{plural: 'stoas' --> 'stoas'};
is noun(q{diploma})->plural,   q{diplomas}  => q{plural: 'diploma' --> 'diplomas'};
is noun(q{diplomas})->plural, q{diplomas}  => q{plural: 'diplomas' --> 'diplomas'};
is noun(q{punto blanco})->plural,   q{puntos blancos}  => q{plural: 'punto blanco' --> 'puntos blancos'};
is noun(q{puntos blancos})->plural, q{puntos blancos}  => q{plural: 'puntos blancos' --> 'puntos blancos'};
is noun(q{tete a tete})->plural,   q{tete a tetes}  => q{plural: 'tete a tete' --> 'tete a tetes'};
is noun(q{tete a tetes})->plural, q{tete a tetes}  => q{plural: 'tete a tetes' --> 'tete a tetes'};
is noun(q{mango})->plural,   q{mangos}  => q{plural: 'mango' --> 'mangos'};
is noun(q{mangos})->plural, q{mangos}  => q{plural: 'mangos' --> 'mangos'};
is noun(q{breech})->plural,   q{breeches}  => q{plural: 'breech' --> 'breeches'};
is noun(q{Portuguese})->plural,   q{Portuguese}  => q{plural: 'Portuguese' --> 'Portuguese'};
is noun(q{telium})->plural,   q{telia}  => q{plural: 'telium' --> 'telia'};
is noun(q{telia})->plural, q{telia}  => q{plural: 'telia' --> 'telia'};
is noun(q{Galla})->plural,   q{Gallas}  => q{plural: 'Galla' --> 'Gallas'};
is noun(q{Gallas})->plural, q{Gallas}  => q{plural: 'Gallas' --> 'Gallas'};
is noun(q{flatus})->plural,   q{flatuses}  => q{plural: 'flatus' --> 'flatuses'};
is noun(q{flatuses})->plural, q{flatuses}  => q{plural: 'flatuses' --> 'flatuses'};
is noun(q{goy})->plural,   q{goys}  => q{plural: 'goy' --> 'goys'};
is noun(q{goys})->plural, q{goys}  => q{plural: 'goys' --> 'goys'};
is noun(q{he})->plural,   q{they}  => q{plural: 'he' --> 'they'};
is noun(q{sceat})->plural,   q{sceattas}  => q{plural: 'sceat' --> 'sceattas'};
is noun(q{sceattas})->plural, q{sceattas}  => q{plural: 'sceattas' --> 'sceattas'};
is noun(q{villus})->plural,   q{villi}  => q{plural: 'villus' --> 'villi'};
is noun(q{villi})->plural, q{villi}  => q{plural: 'villi' --> 'villi'};
is noun(q{zero})->plural,   q{zeros}  => q{plural: 'zero' --> 'zeros'};
is noun(q{zeros})->plural, q{zeros}  => q{plural: 'zeros' --> 'zeros'};
is noun(q{adytum})->plural,   q{adyta}  => q{plural: 'adytum' --> 'adyta'};
is noun(q{adyta})->plural, q{adyta}  => q{plural: 'adyta' --> 'adyta'};
is noun(q{numen})->plural,   q{numina}  => q{plural: 'numen' --> 'numina'};
is noun(q{numina})->plural, q{numina}  => q{plural: 'numina' --> 'numina'};
is noun(q{anathema})->plural,   q{anathemas}  => q{plural: 'anathema' --> 'anathemas'};
is noun(q{anathemas})->plural, q{anathemas}  => q{plural: 'anathemas' --> 'anathemas'};
is noun(q{hamadryad})->plural,   q{hamadrayads}  => q{plural: 'hamadryad' --> 'hamadrayads'};
is noun(q{hamadrayads})->plural, q{hamadrayads}  => q{plural: 'hamadrayads' --> 'hamadrayads'};
is noun(q{Sinhalese})->plural,   q{Sinhalese}  => q{plural: 'Sinhalese' --> 'Sinhalese'};
is noun(q{noxa})->plural,   q{noxae}  => q{plural: 'noxa' --> 'noxae'};
is noun(q{noxae})->plural, q{noxae}  => q{plural: 'noxae' --> 'noxae'};
is noun(q{buzz})->plural,   q{buzzes}  => q{plural: 'buzz' --> 'buzzes'};
is noun(q{buzzes})->plural, q{buzzes}  => q{plural: 'buzzes' --> 'buzzes'};
is noun(q{zuz})->plural,   q{zuzzes}  => q{plural: 'zuz' --> 'zuzzes'};
is noun(q{zuzzes})->plural, q{zuzzes}  => q{plural: 'zuzzes' --> 'zuzzes'};
is noun(q{taxon})->plural,   q{taxa}  => q{plural: 'taxon' --> 'taxa'};
is noun(q{taxa})->plural, q{taxa}  => q{plural: 'taxa' --> 'taxa'};
is noun(q{Lucchese})->plural,   q{Lucchese}  => q{plural: 'Lucchese' --> 'Lucchese'};
is noun(q{sperma})->plural,   q{spermata}  => q{plural: 'sperma' --> 'spermata'};
is noun(q{spermata})->plural, q{spermata}  => q{plural: 'spermata' --> 'spermata'};
is noun(q{Hunanese})->plural,   q{Hunanese}  => q{plural: 'Hunanese' --> 'Hunanese'};
is noun(q{premier danseur})->plural,   q{premiers danseurs}  => q{plural: 'premier danseur' --> 'premiers danseurs'};
is noun(q{premiers danseurs})->plural, q{premiers danseurs}  => q{plural: 'premiers danseurs' --> 'premiers danseurs'};
is noun(q{tortilla espanola})->plural,   q{tortillas espanolas}  => q{plural: 'tortilla espanola' --> 'tortillas espanolas'};
is noun(q{tortillas espanolas})->plural, q{tortillas espanolas}  => q{plural: 'tortillas espanolas' --> 'tortillas espanolas'};
is noun(q{gastrocnemius})->plural,   q{gastrocnemii}  => q{plural: 'gastrocnemius' --> 'gastrocnemii'};
is noun(q{gastrocnemii})->plural, q{gastrocnemii}  => q{plural: 'gastrocnemii' --> 'gastrocnemii'};
is noun(q{uraeus})->plural,   q{uraei}  => q{plural: 'uraeus' --> 'uraei'};
is noun(q{uraei})->plural, q{uraei}  => q{plural: 'uraei' --> 'uraei'};
is noun(q{paisa})->plural,   q{paisas}  => q{plural: 'paisa' --> 'paisas'};
is noun(q{paisas})->plural, q{paisas}  => q{plural: 'paisas' --> 'paisas'};
is noun(q{hemelytrum})->plural,   q{hemelytra}  => q{plural: 'hemelytrum' --> 'hemelytra'};
is noun(q{hemelytra})->plural, q{hemelytra}  => q{plural: 'hemelytra' --> 'hemelytra'};
is noun(q{parapsis})->plural,   q{parapsides}  => q{plural: 'parapsis' --> 'parapsides'};
is noun(q{parapsides})->plural, q{parapsides}  => q{plural: 'parapsides' --> 'parapsides'};
is noun(q{chintz})->plural,   q{chintzes}  => q{plural: 'chintz' --> 'chintzes'};
is noun(q{chintzes})->plural, q{chintzes}  => q{plural: 'chintzes' --> 'chintzes'};
is noun(q{improvisatrice})->plural,   q{improvisatrici}  => q{plural: 'improvisatrice' --> 'improvisatrici'};
is noun(q{improvisatrici})->plural, q{improvisatrici}  => q{plural: 'improvisatrici' --> 'improvisatrici'};
is noun(q{seminium})->plural,   q{seminia}  => q{plural: 'seminium' --> 'seminia'};
is noun(q{seminia})->plural, q{seminia}  => q{plural: 'seminia' --> 'seminia'};
is noun(q{court-martial})->plural,   q{court-martials}  => q{plural: 'court-martial' --> 'court-martials'};
is noun(q{court-martials})->plural, q{court-martials}  => q{plural: 'court-martials' --> 'court-martials'};
is noun(q{terebellum})->plural,   q{terebella}  => q{plural: 'terebellum' --> 'terebella'};
is noun(q{terebella})->plural, q{terebella}  => q{plural: 'terebella' --> 'terebella'};
is noun(q{quadratrix})->plural,   q{quadratrices}  => q{plural: 'quadratrix' --> 'quadratrices'};
is noun(q{quadratrices})->plural, q{quadratrices}  => q{plural: 'quadratrices' --> 'quadratrices'};
is noun(q{aquarium})->plural,   q{aquariums}  => q{plural: 'aquarium' --> 'aquariums'};
is noun(q{aquariums})->plural, q{aquariums}  => q{plural: 'aquariums' --> 'aquariums'};
is noun(q{him})->plural,   q{them}  => q{plural: 'him' --> 'them'};
is noun(q{veg})->plural,   q{veges}  => q{plural: 'veg' --> 'veges'};
is noun(q{veges})->plural, q{veges}  => q{plural: 'veges' --> 'veges'};
is noun(q{asbestos})->plural,   q{asbestoses}  => q{plural: 'asbestos' --> 'asbestoses'};
is noun(q{asbestoses})->plural, q{asbestoses}  => q{plural: 'asbestoses' --> 'asbestoses'};
is noun(q{temblor})->plural,   q{temblores}  => q{plural: 'temblor' --> 'temblores'};
is noun(q{temblores})->plural, q{temblores}  => q{plural: 'temblores' --> 'temblores'};
is noun(q{mucro})->plural,   q{mucros}  => q{plural: 'mucro' --> 'mucros'};
is noun(q{mucros})->plural, q{mucros}  => q{plural: 'mucros' --> 'mucros'};
is noun(q{villino})->plural,   q{villini}  => q{plural: 'villino' --> 'villini'};
is noun(q{villini})->plural, q{villini}  => q{plural: 'villini' --> 'villini'};
is noun(q{Oslo})->plural,   q{Oslos}  => q{plural: 'Oslo' --> 'Oslos'};
is noun(q{Oslos})->plural, q{Oslos}  => q{plural: 'Oslos' --> 'Oslos'};
is noun(q{commanding general})->plural,   q{commanding generals}  => q{plural: 'commanding general' --> 'commanding generals'};
is noun(q{commanding generals})->plural, q{commanding generals}  => q{plural: 'commanding generals' --> 'commanding generals'};
is noun(q{bison})->plural,   q{bisons}  => q{plural: 'bison' --> 'bisons'};
is noun(q{bisons})->plural, q{bisons}  => q{plural: 'bisons' --> 'bisons'};
is noun(q{furfur})->plural,   q{furfures}  => q{plural: 'furfur' --> 'furfures'};
is noun(q{furfures})->plural, q{furfures}  => q{plural: 'furfures' --> 'furfures'};
is noun(q{endothelioma})->plural,   q{endotheliomata}  => q{plural: 'endothelioma' --> 'endotheliomata'};
is noun(q{endotheliomata})->plural, q{endotheliomata}  => q{plural: 'endotheliomata' --> 'endotheliomata'};
is noun(q{sternum})->plural,   q{sternums}  => q{plural: 'sternum' --> 'sternums'};
is noun(q{sternums})->plural, q{sternums}  => q{plural: 'sternums' --> 'sternums'};
is noun(q{crusta})->plural,   q{crustae}  => q{plural: 'crusta' --> 'crustae'};
is noun(q{crustae})->plural, q{crustae}  => q{plural: 'crustae' --> 'crustae'};
is noun(q{pinetum})->plural,   q{pinetums}  => q{plural: 'pinetum' --> 'pinetums'};
is noun(q{pinetums})->plural, q{pinetums}  => q{plural: 'pinetums' --> 'pinetums'};
is noun(q{thaumaturgus})->plural,   q{thaumaturgi}  => q{plural: 'thaumaturgus' --> 'thaumaturgi'};
is noun(q{thaumaturgi})->plural, q{thaumaturgi}  => q{plural: 'thaumaturgi' --> 'thaumaturgi'};
is noun(q{tyro})->plural,   q{tyros}  => q{plural: 'tyro' --> 'tyros'};
is noun(q{tyros})->plural, q{tyros}  => q{plural: 'tyros' --> 'tyros'};
is noun(q{spiculum})->plural,   q{spicula}  => q{plural: 'spiculum' --> 'spicula'};
is noun(q{spicula})->plural, q{spicula}  => q{plural: 'spicula' --> 'spicula'};
is noun(q{thalamos})->plural,   q{thalamoi}  => q{plural: 'thalamos' --> 'thalamoi'};
is noun(q{thalamoi})->plural, q{thalamoi}  => q{plural: 'thalamoi' --> 'thalamoi'};
is noun(q{anlage})->plural,   q{anlages}  => q{plural: 'anlage' --> 'anlages'};
is noun(q{anlages})->plural, q{anlages}  => q{plural: 'anlages' --> 'anlages'};
is noun(q{chromidium})->plural,   q{chromidia}  => q{plural: 'chromidium' --> 'chromidia'};
is noun(q{chromidia})->plural, q{chromidia}  => q{plural: 'chromidia' --> 'chromidia'};
is noun(q{podium})->plural,   q{podiums}  => q{plural: 'podium' --> 'podiums'};
is noun(q{podiums})->plural, q{podiums}  => q{plural: 'podiums' --> 'podiums'};
is noun(q{whatever})->plural,   q{whatever}  => q{plural: 'whatever' --> 'whatever'};
is noun(q{columna})->plural,   q{columnae}  => q{plural: 'columna' --> 'columnae'};
is noun(q{columnae})->plural, q{columnae}  => q{plural: 'columnae' --> 'columnae'};
is noun(q{prosopium})->plural,   q{prosopia}  => q{plural: 'prosopium' --> 'prosopia'};
is noun(q{prosopia})->plural, q{prosopia}  => q{plural: 'prosopia' --> 'prosopia'};
is noun(q{crafts-child})->plural,   q{crafts-childer}  => q{plural: 'crafts-child' --> 'crafts-childer'};
is noun(q{crafts-childer})->plural, q{crafts-childer}  => q{plural: 'crafts-childer' --> 'crafts-childer'};
is noun(q{dolman})->plural,   q{dolmans}  => q{plural: 'dolman' --> 'dolmans'};
is noun(q{dolmans})->plural, q{dolmans}  => q{plural: 'dolmans' --> 'dolmans'};
is noun(q{humerus})->plural,   q{humeri}  => q{plural: 'humerus' --> 'humeri'};
is noun(q{humeri})->plural, q{humeri}  => q{plural: 'humeri' --> 'humeri'};
is noun(q{amicus curiae})->plural,   q{amici curiae}  => q{plural: 'amicus curiae' --> 'amici curiae'};
is noun(q{amici curiae})->plural, q{amici curiae}  => q{plural: 'amici curiae' --> 'amici curiae'};
is noun(q{frustum})->plural,   q{frustums}  => q{plural: 'frustum' --> 'frustums'};
is noun(q{frustums})->plural, q{frustums}  => q{plural: 'frustums' --> 'frustums'};
is noun(q{redia})->plural,   q{rediae}  => q{plural: 'redia' --> 'rediae'};
is noun(q{rediae})->plural, q{rediae}  => q{plural: 'rediae' --> 'rediae'};
is noun(q{treponema})->plural,   q{treponemata}  => q{plural: 'treponema' --> 'treponemata'};
is noun(q{treponemata})->plural, q{treponemata}  => q{plural: 'treponemata' --> 'treponemata'};
is noun(q{potato})->plural,   q{potatoes}  => q{plural: 'potato' --> 'potatoes'};
is noun(q{potatoes})->plural, q{potatoes}  => q{plural: 'potatoes' --> 'potatoes'};
is noun(q{talea})->plural,   q{taleae}  => q{plural: 'talea' --> 'taleae'};
is noun(q{taleae})->plural, q{taleae}  => q{plural: 'taleae' --> 'taleae'};
is noun(q{nouvel arrive})->plural,   q{nouveaux arrives}  => q{plural: 'nouvel arrive' --> 'nouveaux arrives'};
is noun(q{nouveaux arrives})->plural, q{nouveaux arrives}  => q{plural: 'nouveaux arrives' --> 'nouveaux arrives'};
is noun(q{stratum})->plural,   q{stratums}  => q{plural: 'stratum' --> 'stratums'};
is noun(q{stratums})->plural, q{stratums}  => q{plural: 'stratums' --> 'stratums'};
is noun(q{syrtis})->plural,   q{syrtes}  => q{plural: 'syrtis' --> 'syrtes'};
is noun(q{syrtes})->plural, q{syrtes}  => q{plural: 'syrtes' --> 'syrtes'};
is noun(q{fungo porcino})->plural,   q{funghi porchini}  => q{plural: 'fungo porcino' --> 'funghi porchini'};
is noun(q{funghi porchini})->plural, q{funghi porchini}  => q{plural: 'funghi porchini' --> 'funghi porchini'};
is noun(q{uredosorus})->plural,   q{uredosori}  => q{plural: 'uredosorus' --> 'uredosori'};
is noun(q{uredosori})->plural, q{uredosori}  => q{plural: 'uredosori' --> 'uredosori'};
is noun(q{foot})->plural,   q{feet}  => q{plural: 'foot' --> 'feet'};
is noun(q{feet})->plural, q{feet}  => q{plural: 'feet' --> 'feet'};
is noun(q{branchiopod})->plural,   q{branchiopods}  => q{plural: 'branchiopod' --> 'branchiopods'};
is noun(q{branchiopods})->plural, q{branchiopods}  => q{plural: 'branchiopods' --> 'branchiopods'};
is noun(q{centesimo})->plural,   q{centesimi}  => q{plural: 'centesimo' --> 'centesimi'};
is noun(q{centesimi})->plural, q{centesimi}  => q{plural: 'centesimi' --> 'centesimi'};
is noun(q{cyphella})->plural,   q{cyphellae}  => q{plural: 'cyphella' --> 'cyphellae'};
is noun(q{cyphellae})->plural, q{cyphellae}  => q{plural: 'cyphellae' --> 'cyphellae'};
is noun(q{yourself})->plural,   q{yourselves}  => q{plural: 'yourself' --> 'yourselves'};
is noun(q{yourselves})->plural, q{yourselves}  => q{plural: 'yourselves' --> 'yourselves'};
is noun(q{lepton})->plural,   q{lepta}  => q{plural: 'lepton' --> 'lepta'};
is noun(q{lepta})->plural, q{lepta}  => q{plural: 'lepta' --> 'lepta'};
is noun(q{tarsus})->plural,   q{tarsi}  => q{plural: 'tarsus' --> 'tarsi'};
is noun(q{tarsi})->plural, q{tarsi}  => q{plural: 'tarsi' --> 'tarsi'};
is noun(q{holothuria})->plural,   q{holothurias}  => q{plural: 'holothuria' --> 'holothurias'};
is noun(q{holothurias})->plural, q{holothurias}  => q{plural: 'holothurias' --> 'holothurias'};
is noun(q{Shavese})->plural,   q{Shavese}  => q{plural: 'Shavese' --> 'Shavese'};
is noun(q{hypoderma})->plural,   q{hypodermata}  => q{plural: 'hypoderma' --> 'hypodermata'};
is noun(q{hypodermata})->plural, q{hypodermata}  => q{plural: 'hypodermata' --> 'hypodermata'};
is noun(q{star fish})->plural,   q{star fishes}  => q{plural: 'star fish' --> 'star fishes'};
is noun(q{star fishes})->plural, q{star fishes}  => q{plural: 'star fishes' --> 'star fishes'};
is noun(q{tropaeolum})->plural,   q{tropaeolums}  => q{plural: 'tropaeolum' --> 'tropaeolums'};
is noun(q{tropaeolums})->plural, q{tropaeolums}  => q{plural: 'tropaeolums' --> 'tropaeolums'};
is noun(q{Senegalese})->plural,   q{Senegalese}  => q{plural: 'Senegalese' --> 'Senegalese'};
is noun(q{tetrapleuron})->plural,   q{tetrapleurons}  => q{plural: 'tetrapleuron' --> 'tetrapleurons'};
is noun(q{tetrapleurons})->plural, q{tetrapleurons}  => q{plural: 'tetrapleurons' --> 'tetrapleurons'};
is noun(q{neuroma})->plural,   q{neuromata}  => q{plural: 'neuroma' --> 'neuromata'};
is noun(q{neuromata})->plural, q{neuromata}  => q{plural: 'neuromata' --> 'neuromata'};
is noun(q{angustia})->plural,   q{angustiae}  => q{plural: 'angustia' --> 'angustiae'};
is noun(q{angustiae})->plural, q{angustiae}  => q{plural: 'angustiae' --> 'angustiae'};
is noun(q{Siamese})->plural,   q{Siamese}  => q{plural: 'Siamese' --> 'Siamese'};
is noun(q{superficies})->plural,   q{superficies}  => q{plural: 'superficies' --> 'superficies'};
is noun(q{emblema})->plural,   q{emblememata}  => q{plural: 'emblema' --> 'emblememata'};
is noun(q{emblememata})->plural, q{emblememata}  => q{plural: 'emblememata' --> 'emblememata'};
is noun(q{multigravida})->plural,   q{multigravidas}  => q{plural: 'multigravida' --> 'multigravidas'};
is noun(q{multigravidas})->plural, q{multigravidas}  => q{plural: 'multigravidas' --> 'multigravidas'};
is noun(q{themselves})->plural,   q{themselves}  => q{plural: 'themselves' --> 'themselves'};
is noun(q{sphinx})->plural,   q{sphinxes}  => q{plural: 'sphinx' --> 'sphinxes'};
is noun(q{sphinxes})->plural, q{sphinxes}  => q{plural: 'sphinxes' --> 'sphinxes'};
is noun(q{sensum})->plural,   q{sensa}  => q{plural: 'sensum' --> 'sensa'};
is noun(q{sensa})->plural, q{sensa}  => q{plural: 'sensa' --> 'sensa'};
is noun(q{nouveau riche})->plural,   q{nouvelle riche}  => q{plural: 'nouveau riche' --> 'nouvelle riche'};
is noun(q{nouvelle riche})->plural, q{nouvelle riche}  => q{plural: 'nouvelle riche' --> 'nouvelle riche'};
is noun(q{proglottis})->plural,   q{proglottides}  => q{plural: 'proglottis' --> 'proglottides'};
is noun(q{proglottides})->plural, q{proglottides}  => q{plural: 'proglottides' --> 'proglottides'};
is noun(q{yo})->plural,   q{yoes}  => q{plural: 'yo' --> 'yoes'};
is noun(q{yoes})->plural, q{yoes}  => q{plural: 'yoes' --> 'yoes'};
is noun(q{congius})->plural,   q{congii}  => q{plural: 'congius' --> 'congii'};
is noun(q{congii})->plural, q{congii}  => q{plural: 'congii' --> 'congii'};
is noun(q{Rom})->plural,   q{Roma}  => q{plural: 'Rom' --> 'Roma'};
is noun(q{Roma})->plural, q{Roma}  => q{plural: 'Roma' --> 'Roma'};
is noun(q{adviso})->plural,   q{advisoes}  => q{plural: 'adviso' --> 'advisoes'};
is noun(q{advisoes})->plural, q{advisoes}  => q{plural: 'advisoes' --> 'advisoes'};
is noun(q{terrazzo})->plural,   q{terrazzos}  => q{plural: 'terrazzo' --> 'terrazzos'};
is noun(q{terrazzos})->plural, q{terrazzos}  => q{plural: 'terrazzos' --> 'terrazzos'};
is noun(q{ossiculum})->plural,   q{ossicula}  => q{plural: 'ossiculum' --> 'ossicula'};
is noun(q{ossicula})->plural, q{ossicula}  => q{plural: 'ossicula' --> 'ossicula'};
is noun(q{Sangirese})->plural,   q{Sangirese}  => q{plural: 'Sangirese' --> 'Sangirese'};
is noun(q{moe})->plural,   q{moes}  => q{plural: 'moe' --> 'moes'};
is noun(q{moes})->plural, q{moes}  => q{plural: 'moes' --> 'moes'};
is noun(q{proprium})->plural,   q{propria}  => q{plural: 'proprium' --> 'propria'};
is noun(q{propria})->plural, q{propria}  => q{plural: 'propria' --> 'propria'};
is noun(q{cardo})->plural,   q{cardines}  => q{plural: 'cardo' --> 'cardines'};
is noun(q{cardines})->plural, q{cardines}  => q{plural: 'cardines' --> 'cardines'};
is noun(q{you})->plural,   q{you}  => q{plural: 'you' --> 'you'};
is noun(q{pickerel})->plural,   q{pickerels}  => q{plural: 'pickerel' --> 'pickerels'};
is noun(q{pickerels})->plural, q{pickerels}  => q{plural: 'pickerels' --> 'pickerels'};
is noun(q{piano})->plural,   q{pianos}  => q{plural: 'piano' --> 'pianos'};
is noun(q{pianos})->plural, q{pianos}  => q{plural: 'pianos' --> 'pianos'};
is noun(q{fomes})->plural,   q{fomites}  => q{plural: 'fomes' --> 'fomites'};
is noun(q{fomites})->plural, q{fomites}  => q{plural: 'fomites' --> 'fomites'};
is noun(q{1 star general})->plural,   q{1 star generals}  => q{plural: '1 star general' --> '1 star generals'};
is noun(q{1 star generals})->plural, q{1 star generals}  => q{plural: '1 star generals' --> '1 star generals'};
is noun(q{Porto})->plural,   q{Portos}  => q{plural: 'Porto' --> 'Portos'};
is noun(q{Portos})->plural, q{Portos}  => q{plural: 'Portos' --> 'Portos'};
is noun(q{ghetto})->plural,   q{ghettos}  => q{plural: 'ghetto' --> 'ghettos'};
is noun(q{ghettos})->plural, q{ghettos}  => q{plural: 'ghettos' --> 'ghettos'};
is noun(q{sulcus})->plural,   q{sulci}  => q{plural: 'sulcus' --> 'sulci'};
is noun(q{sulci})->plural, q{sulci}  => q{plural: 'sulci' --> 'sulci'};
is noun(q{corgy})->plural,   q{corgys}  => q{plural: 'corgy' --> 'corgys'};
is noun(q{corgys})->plural, q{corgys}  => q{plural: 'corgys' --> 'corgys'};
is noun(q{protonema})->plural,   q{protonemata}  => q{plural: 'protonema' --> 'protonemata'};
is noun(q{protonemata})->plural, q{protonemata}  => q{plural: 'protonemata' --> 'protonemata'};
is noun(q{speculum})->plural,   q{speculums}  => q{plural: 'speculum' --> 'speculums'};
is noun(q{speculums})->plural, q{speculums}  => q{plural: 'speculums' --> 'speculums'};
is noun(q{line-out})->plural,   q{line-outs}  => q{plural: 'line-out' --> 'line-outs'};
is noun(q{line-outs})->plural, q{line-outs}  => q{plural: 'line-outs' --> 'line-outs'};
is noun(q{codex})->plural,   q{codices}  => q{plural: 'codex' --> 'codices'};
is noun(q{codices})->plural, q{codices}  => q{plural: 'codices' --> 'codices'};
is noun(q{virtuoso})->plural,   q{virtuosos}  => q{plural: 'virtuoso' --> 'virtuosos'};
is noun(q{virtuosos})->plural, q{virtuosos}  => q{plural: 'virtuosos' --> 'virtuosos'};
is noun(q{minnelied})->plural,   q{minnelieder}  => q{plural: 'minnelied' --> 'minnelieder'};
is noun(q{minnelieder})->plural, q{minnelieder}  => q{plural: 'minnelieder' --> 'minnelieder'};
is noun(q{purlieu})->plural,   q{purlieus}  => q{plural: 'purlieu' --> 'purlieus'};
is noun(q{purlieus})->plural, q{purlieus}  => q{plural: 'purlieus' --> 'purlieus'};
is noun(q{this})->plural,   q{these}  => q{plural: 'this' --> 'these'};
is noun(q{these})->plural, q{these}  => q{plural: 'these' --> 'these'};
is noun(q{lox})->plural,   q{loxes}  => q{plural: 'lox' --> 'loxes'};
is noun(q{loxes})->plural, q{loxes}  => q{plural: 'loxes' --> 'loxes'};
is noun(q{nodum})->plural,   q{noda}  => q{plural: 'nodum' --> 'noda'};
is noun(q{noda})->plural, q{noda}  => q{plural: 'noda' --> 'noda'};
is noun(q{tibia})->plural,   q{tibiae}  => q{plural: 'tibia' --> 'tibiae'};
is noun(q{tibiae})->plural, q{tibiae}  => q{plural: 'tibiae' --> 'tibiae'};
is noun(q{Pekingese})->plural,   q{Pekingese}  => q{plural: 'Pekingese' --> 'Pekingese'};
is noun(q{seraph})->plural,   q{seraphs}  => q{plural: 'seraph' --> 'seraphs'};
is noun(q{seraphs})->plural, q{seraphs}  => q{plural: 'seraphs' --> 'seraphs'};
is noun(q{blin})->plural,   q{blinis}  => q{plural: 'blin' --> 'blinis'};
is noun(q{blinis})->plural, q{blinis}  => q{plural: 'blinis' --> 'blinis'};
is noun(q{chorda})->plural,   q{chordae}  => q{plural: 'chorda' --> 'chordae'};
is noun(q{chordae})->plural, q{chordae}  => q{plural: 'chordae' --> 'chordae'};
is noun(q{Bengalese})->plural,   q{Bengalese}  => q{plural: 'Bengalese' --> 'Bengalese'};
is noun(q{caulis})->plural,   q{caules}  => q{plural: 'caulis' --> 'caules'};
is noun(q{caules})->plural, q{caules}  => q{plural: 'caules' --> 'caules'};
is noun(q{carp})->plural,   q{carp}  => q{plural: 'carp' --> 'carp'};
is noun(q{sententia})->plural,   q{sententiae}  => q{plural: 'sententia' --> 'sententiae'};
is noun(q{sententiae})->plural, q{sententiae}  => q{plural: 'sententiae' --> 'sententiae'};
is noun(q{lustrum})->plural,   q{lustrums}  => q{plural: 'lustrum' --> 'lustrums'};
is noun(q{lustrums})->plural, q{lustrums}  => q{plural: 'lustrums' --> 'lustrums'};
is noun(q{stela})->plural,   q{stelas}  => q{plural: 'stela' --> 'stelas'};
is noun(q{stelas})->plural, q{stelas}  => q{plural: 'stelas' --> 'stelas'};
is noun(q{po})->plural,   q{poes}  => q{plural: 'po' --> 'poes'};
is noun(q{poes})->plural, q{poes}  => q{plural: 'poes' --> 'poes'};
is noun(q{hordeolum})->plural,   q{hordeola}  => q{plural: 'hordeolum' --> 'hordeola'};
is noun(q{hordeola})->plural, q{hordeola}  => q{plural: 'hordeola' --> 'hordeola'};
is noun(q{torula})->plural,   q{torulae}  => q{plural: 'torula' --> 'torulae'};
is noun(q{torulae})->plural, q{torulae}  => q{plural: 'torulae' --> 'torulae'};
is noun(q{graffito})->plural,   q{graffiti}  => q{plural: 'graffito' --> 'graffiti'};
is noun(q{hoe})->plural,   q{hoes}  => q{plural: 'hoe' --> 'hoes'};
is noun(q{hoes})->plural, q{hoes}  => q{plural: 'hoes' --> 'hoes'};
is noun(q{teredo})->plural,   q{teredos}  => q{plural: 'teredo' --> 'teredos'};
is noun(q{teredos})->plural, q{teredos}  => q{plural: 'teredos' --> 'teredos'};
is noun(q{interphenomenon})->plural,   q{interphenomena}  => q{plural: 'interphenomenon' --> 'interphenomena'};
is noun(q{interphenomena})->plural, q{interphenomena}  => q{plural: 'interphenomena' --> 'interphenomena'};
is noun(q{tentamen})->plural,   q{tentamina}  => q{plural: 'tentamen' --> 'tentamina'};
is noun(q{tentamina})->plural, q{tentamina}  => q{plural: 'tentamina' --> 'tentamina'};
is noun(q{prosula})->plural,   q{prosulae}  => q{plural: 'prosula' --> 'prosulae'};
is noun(q{prosulae})->plural, q{prosulae}  => q{plural: 'prosulae' --> 'prosulae'};
is noun(q{Kinkimavo})->plural,   q{Kinkimavos}  => q{plural: 'Kinkimavo' --> 'Kinkimavos'};
is noun(q{Kinkimavos})->plural, q{Kinkimavos}  => q{plural: 'Kinkimavos' --> 'Kinkimavos'};
is noun(q{breeches})->plural,   q{breeches}  => q{plural: 'breeches' --> 'breeches'};
is noun(q{persona})->plural,   q{personas}  => q{plural: 'persona' --> 'personas'};
is noun(q{personas})->plural, q{personas}  => q{plural: 'personas' --> 'personas'};
is noun(q{jumbo})->plural,   q{jumbos}  => q{plural: 'jumbo' --> 'jumbos'};
is noun(q{jumbos})->plural, q{jumbos}  => q{plural: 'jumbos' --> 'jumbos'};
is noun(q{proviso})->plural,   q{provisos}  => q{plural: 'proviso' --> 'provisos'};
is noun(q{provisos})->plural, q{provisos}  => q{plural: 'provisos' --> 'provisos'};
is noun(q{pyjamas})->plural,   q{pyjamas}  => q{plural: 'pyjamas' --> 'pyjamas'};
is noun(q{person})->plural,   q{people}  => q{plural: 'person' --> 'people'};
is noun(q{people})->plural, q{people}  => q{plural: 'people' --> 'people'};
is noun(q{trichoma})->plural,   q{trichomata}  => q{plural: 'trichoma' --> 'trichomata'};
is noun(q{trichomata})->plural, q{trichomata}  => q{plural: 'trichomata' --> 'trichomata'};
is noun(q{stichidium})->plural,   q{stichidia}  => q{plural: 'stichidium' --> 'stichidia'};
is noun(q{stichidia})->plural, q{stichidia}  => q{plural: 'stichidia' --> 'stichidia'};
is noun(q{so})->plural,   q{soes}  => q{plural: 'so' --> 'soes'};
is noun(q{soes})->plural, q{soes}  => q{plural: 'soes' --> 'soes'};
is noun(q{lemur})->plural,   q{lemurs}  => q{plural: 'lemur' --> 'lemurs'};
is noun(q{lemurs})->plural, q{lemurs}  => q{plural: 'lemurs' --> 'lemurs'};
is noun(q{nebula})->plural,   q{nebulas}  => q{plural: 'nebula' --> 'nebulas'};
is noun(q{nebulas})->plural, q{nebulas}  => q{plural: 'nebulas' --> 'nebulas'};
is noun(q{palpus})->plural,   q{palpi}  => q{plural: 'palpus' --> 'palpi'};
is noun(q{palpi})->plural, q{palpi}  => q{plural: 'palpi' --> 'palpi'};
is noun(q{cyano})->plural,   q{cyanos}  => q{plural: 'cyano' --> 'cyanos'};
is noun(q{cyanos})->plural, q{cyanos}  => q{plural: 'cyanos' --> 'cyanos'};
is noun(q{vibrio})->plural,   q{vibrios}  => q{plural: 'vibrio' --> 'vibrios'};
is noun(q{vibrios})->plural, q{vibrios}  => q{plural: 'vibrios' --> 'vibrios'};
is noun(q{ambuscado})->plural,   q{ambuscados}  => q{plural: 'ambuscado' --> 'ambuscados'};
is noun(q{ambuscados})->plural, q{ambuscados}  => q{plural: 'ambuscados' --> 'ambuscados'};
is noun(q{suggestum})->plural,   q{suggestums}  => q{plural: 'suggestum' --> 'suggestums'};
is noun(q{suggestums})->plural, q{suggestums}  => q{plural: 'suggestums' --> 'suggestums'};
is noun(q{sterno})->plural,   q{sternos}  => q{plural: 'sterno' --> 'sternos'};
is noun(q{sternos})->plural, q{sternos}  => q{plural: 'sternos' --> 'sternos'};
is noun(q{stella})->plural,   q{stellae}  => q{plural: 'stella' --> 'stellae'};
is noun(q{stellae})->plural, q{stellae}  => q{plural: 'stellae' --> 'stellae'};
is noun(q{Sienese})->plural,   q{Sienese}  => q{plural: 'Sienese' --> 'Sienese'};
is noun(q{zygon})->plural,   q{zyga}  => q{plural: 'zygon' --> 'zyga'};
is noun(q{zyga})->plural, q{zyga}  => q{plural: 'zyga' --> 'zyga'};
is noun(q{Foochowese})->plural,   q{Foochowese}  => q{plural: 'Foochowese' --> 'Foochowese'};
is noun(q{gliosarcoma})->plural,   q{gliosarcomata}  => q{plural: 'gliosarcoma' --> 'gliosarcomata'};
is noun(q{gliosarcomata})->plural, q{gliosarcomata}  => q{plural: 'gliosarcomata' --> 'gliosarcomata'};
is noun(q{pteryla})->plural,   q{pterylae}  => q{plural: 'pteryla' --> 'pterylae'};
is noun(q{pterylae})->plural, q{pterylae}  => q{plural: 'pterylae' --> 'pterylae'};
is noun(q{gigolo})->plural,   q{gigolos}  => q{plural: 'gigolo' --> 'gigolos'};
is noun(q{gigolos})->plural, q{gigolos}  => q{plural: 'gigolos' --> 'gigolos'};
is noun(q{one star general})->plural,   q{one star generals}  => q{plural: 'one star general' --> 'one star generals'};
is noun(q{one star generals})->plural, q{one star generals}  => q{plural: 'one star generals' --> 'one star generals'};
is noun(q{ado})->plural,   q{ados}  => q{plural: 'ado' --> 'ados'};
is noun(q{ados})->plural, q{ados}  => q{plural: 'ados' --> 'ados'};
is noun(q{stadium})->plural,   q{stadiums}  => q{plural: 'stadium' --> 'stadiums'};
is noun(q{stadiums})->plural, q{stadiums}  => q{plural: 'stadiums' --> 'stadiums'};
is noun(q{espanol})->plural,   q{espanoles}  => q{plural: 'espanol' --> 'espanoles'};
is noun(q{espanoles})->plural, q{espanoles}  => q{plural: 'espanoles' --> 'espanoles'};
is noun(q{memo})->plural,   q{memos}  => q{plural: 'memo' --> 'memos'};
is noun(q{memos})->plural, q{memos}  => q{plural: 'memos' --> 'memos'};
is noun(q{cabaletta})->plural,   q{cabalettas}  => q{plural: 'cabaletta' --> 'cabalettas'};
is noun(q{cabalettas})->plural, q{cabalettas}  => q{plural: 'cabalettas' --> 'cabalettas'};
is noun(q{micro})->plural,   q{micros}  => q{plural: 'micro' --> 'micros'};
is noun(q{micros})->plural, q{micros}  => q{plural: 'micros' --> 'micros'};
is noun(q{tonneau})->plural,   q{tonneaus}  => q{plural: 'tonneau' --> 'tonneaus'};
is noun(q{tonneaus})->plural, q{tonneaus}  => q{plural: 'tonneaus' --> 'tonneaus'};
is noun(q{spermatheca})->plural,   q{spermathecae}  => q{plural: 'spermatheca' --> 'spermathecae'};
is noun(q{spermathecae})->plural, q{spermathecae}  => q{plural: 'spermathecae' --> 'spermathecae'};
is noun(q{cul-de-lampe})->plural,   q{culs-de-lampe}  => q{plural: 'cul-de-lampe' --> 'culs-de-lampe'};
is noun(q{culs-de-lampe})->plural, q{culs-de-lampe}  => q{plural: 'culs-de-lampe' --> 'culs-de-lampe'};
is noun(q{4-star general})->plural,   q{4-star generals}  => q{plural: '4-star general' --> '4-star generals'};
is noun(q{4-star generals})->plural, q{4-star generals}  => q{plural: '4-star generals' --> '4-star generals'};
is noun(q{Americanese})->plural,   q{Americanese}  => q{plural: 'Americanese' --> 'Americanese'};
is noun(q{gravamen})->plural,   q{gravamina}  => q{plural: 'gravamen' --> 'gravamina'};
is noun(q{gravamina})->plural, q{gravamina}  => q{plural: 'gravamina' --> 'gravamina'};
is noun(q{themself})->plural,   q{themselves}  => q{plural: 'themself' --> 'themselves'};
is noun(q{chorus})->plural,   q{choruses}  => q{plural: 'chorus' --> 'choruses'};
is noun(q{choruses})->plural, q{choruses}  => q{plural: 'choruses' --> 'choruses'};
is noun(q{trichidium})->plural,   q{trichidia}  => q{plural: 'trichidium' --> 'trichidia'};
is noun(q{trichidia})->plural, q{trichidia}  => q{plural: 'trichidia' --> 'trichidia'};
is noun(q{meretrix})->plural,   q{meretrices}  => q{plural: 'meretrix' --> 'meretrices'};
is noun(q{meretrices})->plural, q{meretrices}  => q{plural: 'meretrices' --> 'meretrices'};
is noun(q{manservant})->plural,   q{menservants}  => q{plural: 'manservant' --> 'menservants'};
is noun(q{menservants})->plural, q{menservants}  => q{plural: 'menservants' --> 'menservants'};
is noun(q{Lebanese})->plural,   q{Lebanese}  => q{plural: 'Lebanese' --> 'Lebanese'};
is noun(q{dictum})->plural,   q{dictums}  => q{plural: 'dictum' --> 'dictums'};
is noun(q{dictums})->plural, q{dictums}  => q{plural: 'dictums' --> 'dictums'};
is noun(q{synangium})->plural,   q{synangia}  => q{plural: 'synangium' --> 'synangia'};
is noun(q{synangia})->plural, q{synangia}  => q{plural: 'synangia' --> 'synangia'};
is noun(q{bandit})->plural,   q{bandits}  => q{plural: 'bandit' --> 'bandits'};
is noun(q{bandits})->plural, q{bandits}  => q{plural: 'bandits' --> 'bandits'};
is noun(q{limbo})->plural,   q{limbos}  => q{plural: 'limbo' --> 'limbos'};
is noun(q{limbos})->plural, q{limbos}  => q{plural: 'limbos' --> 'limbos'};
is noun(q{pullus})->plural,   q{pulli}  => q{plural: 'pullus' --> 'pulli'};
is noun(q{pulli})->plural, q{pulli}  => q{plural: 'pulli' --> 'pulli'};
is noun(q{lemniscus})->plural,   q{lemnisci}  => q{plural: 'lemniscus' --> 'lemnisci'};
is noun(q{lemnisci})->plural, q{lemnisci}  => q{plural: 'lemnisci' --> 'lemnisci'};
is noun(q{synesthesia})->plural,   q{synesthesiae}  => q{plural: 'synesthesia' --> 'synesthesiae'};
is noun(q{synesthesiae})->plural, q{synesthesiae}  => q{plural: 'synesthesiae' --> 'synesthesiae'};
is noun(q{clostridium})->plural,   q{clostridia}  => q{plural: 'clostridium' --> 'clostridia'};
is noun(q{clostridia})->plural, q{clostridia}  => q{plural: 'clostridia' --> 'clostridia'};
is noun(q{mafiosa})->plural,   q{mafiose}  => q{plural: 'mafiosa' --> 'mafiose'};
is noun(q{mafiose})->plural, q{mafiose}  => q{plural: 'mafiose' --> 'mafiose'};
is noun(q{caduceus})->plural,   q{caducei}  => q{plural: 'caduceus' --> 'caducei'};
is noun(q{caducei})->plural, q{caducei}  => q{plural: 'caducei' --> 'caducei'};
is noun(q{aphis})->plural,   q{aphides}  => q{plural: 'aphis' --> 'aphides'};
is noun(q{aphides})->plural, q{aphides}  => q{plural: 'aphides' --> 'aphides'};
is noun(q{psydracium})->plural,   q{psydracia}  => q{plural: 'psydracium' --> 'psydracia'};
is noun(q{psydracia})->plural, q{psydracia}  => q{plural: 'psydracia' --> 'psydracia'};
is noun(q{who})->plural,   q{who}  => q{plural: 'who' --> 'who'};
is noun(q{septemvir})->plural,   q{septemviri}  => q{plural: 'septemvir' --> 'septemviri'};
is noun(q{septemviri})->plural, q{septemviri}  => q{plural: 'septemviri' --> 'septemviri'};
is noun(q{comatula})->plural,   q{comatulae}  => q{plural: 'comatula' --> 'comatulae'};
is noun(q{comatulae})->plural, q{comatulae}  => q{plural: 'comatulae' --> 'comatulae'};
is noun(q{stemma})->plural,   q{stemmata}  => q{plural: 'stemma' --> 'stemmata'};
is noun(q{stemmata})->plural, q{stemmata}  => q{plural: 'stemmata' --> 'stemmata'};
is noun(q{modius})->plural,   q{modii}  => q{plural: 'modius' --> 'modii'};
is noun(q{modii})->plural, q{modii}  => q{plural: 'modii' --> 'modii'};
is noun(q{cremaster})->plural,   q{cremasters}  => q{plural: 'cremaster' --> 'cremasters'};
is noun(q{cremasters})->plural, q{cremasters}  => q{plural: 'cremasters' --> 'cremasters'};
is noun(q{figurante})->plural,   q{figurantes}  => q{plural: 'figurante' --> 'figurantes'};
is noun(q{figurantes})->plural, q{figurantes}  => q{plural: 'figurantes' --> 'figurantes'};
is noun(q{jeu})->plural,   q{jeux}  => q{plural: 'jeu' --> 'jeux'};
is noun(q{jeux})->plural, q{jeux}  => q{plural: 'jeux' --> 'jeux'};
is noun(q{asylum})->plural,   q{asylums}  => q{plural: 'asylum' --> 'asylums'};
is noun(q{asylums})->plural, q{asylums}  => q{plural: 'asylums' --> 'asylums'};
is noun(q{prolabium})->plural,   q{prolabia}  => q{plural: 'prolabium' --> 'prolabia'};
is noun(q{prolabia})->plural, q{prolabia}  => q{plural: 'prolabia' --> 'prolabia'};
is noun(q{gallows})->plural,   q{gallows}  => q{plural: 'gallows' --> 'gallows'};
is noun(q{flocculus})->plural,   q{flocculi}  => q{plural: 'flocculus' --> 'flocculi'};
is noun(q{flocculi})->plural, q{flocculi}  => q{plural: 'flocculi' --> 'flocculi'};
is noun(q{whiting})->plural,   q{whiting}  => q{plural: 'whiting' --> 'whiting'};
is noun(q{route nationale})->plural,   q{routes nationales}  => q{plural: 'route nationale' --> 'routes nationales'};
is noun(q{routes nationales})->plural, q{routes nationales}  => q{plural: 'routes nationales' --> 'routes nationales'};
is noun(q{coccidium})->plural,   q{coccidia}  => q{plural: 'coccidium' --> 'coccidia'};
is noun(q{coccidia})->plural, q{coccidia}  => q{plural: 'coccidia' --> 'coccidia'};
is noun(q{glomus})->plural,   q{glomera}  => q{plural: 'glomus' --> 'glomera'};
is noun(q{glomera})->plural, q{glomera}  => q{plural: 'glomera' --> 'glomera'};
is noun(q{inferno})->plural,   q{infernos}  => q{plural: 'inferno' --> 'infernos'};
is noun(q{infernos})->plural, q{infernos}  => q{plural: 'infernos' --> 'infernos'};
is noun(q{spondylus})->plural,   q{spondyli}  => q{plural: 'spondylus' --> 'spondyli'};
is noun(q{spondyli})->plural, q{spondyli}  => q{plural: 'spondyli' --> 'spondyli'};
is noun(q{sotch})->plural,   q{sotches}  => q{plural: 'sotch' --> 'sotches'};
is noun(q{sotches})->plural, q{sotches}  => q{plural: 'sotches' --> 'sotches'};
is noun(q{bozzetto})->plural,   q{bozzetti}  => q{plural: 'bozzetto' --> 'bozzetti'};
is noun(q{bozzetti})->plural, q{bozzetti}  => q{plural: 'bozzetti' --> 'bozzetti'};
is noun(q{rabies})->plural,   q{rabies}  => q{plural: 'rabies' --> 'rabies'};
is noun(q{set-off})->plural,   q{set-offs}  => q{plural: 'set-off' --> 'set-offs'};
is noun(q{set-offs})->plural, q{set-offs}  => q{plural: 'set-offs' --> 'set-offs'};
is noun(q{bathos})->plural,   q{bathoses}  => q{plural: 'bathos' --> 'bathoses'};
is noun(q{bathoses})->plural, q{bathoses}  => q{plural: 'bathoses' --> 'bathoses'};
is noun(q{Colorado})->plural,   q{Colorados}  => q{plural: 'Colorado' --> 'Colorados'};
is noun(q{Colorados})->plural, q{Colorados}  => q{plural: 'Colorados' --> 'Colorados'};
is noun(q{terebratula})->plural,   q{terebratulas}  => q{plural: 'terebratula' --> 'terebratulas'};
is noun(q{terebratulas})->plural, q{terebratulas}  => q{plural: 'terebratulas' --> 'terebratulas'};
is noun(q{tuberculum})->plural,   q{tubercula}  => q{plural: 'tuberculum' --> 'tubercula'};
is noun(q{tubercula})->plural, q{tubercula}  => q{plural: 'tubercula' --> 'tubercula'};
is noun(q{trachea})->plural,   q{tracheae}  => q{plural: 'trachea' --> 'tracheae'};
is noun(q{tracheae})->plural, q{tracheae}  => q{plural: 'tracheae' --> 'tracheae'};
is noun(q{cecidium})->plural,   q{cecidia}  => q{plural: 'cecidium' --> 'cecidia'};
is noun(q{cecidia})->plural, q{cecidia}  => q{plural: 'cecidia' --> 'cecidia'};
is noun(q{intermedium})->plural,   q{intermedia}  => q{plural: 'intermedium' --> 'intermedia'};
is noun(q{intermedia})->plural, q{intermedia}  => q{plural: 'intermedia' --> 'intermedia'};
is noun(q{auto-de-fe})->plural,   q{auto-de-fes}  => q{plural: 'auto-de-fe' --> 'auto-de-fes'};
is noun(q{auto-de-fes})->plural, q{auto-de-fes}  => q{plural: 'auto-de-fes' --> 'auto-de-fes'};
is noun(q{solenium})->plural,   q{solenia}  => q{plural: 'solenium' --> 'solenia'};
is noun(q{solenia})->plural, q{solenia}  => q{plural: 'solenia' --> 'solenia'};
is noun(q{inukshuk})->plural,   q{inukshuit}  => q{plural: 'inukshuk' --> 'inukshuit'};
is noun(q{inukshuit})->plural, q{inukshuit}  => q{plural: 'inukshuit' --> 'inukshuit'};
is noun(q{umwelt})->plural,   q{umwelten}  => q{plural: 'umwelt' --> 'umwelten'};
is noun(q{umwelten})->plural, q{umwelten}  => q{plural: 'umwelten' --> 'umwelten'};
is noun(q{magilus})->plural,   q{magili}  => q{plural: 'magilus' --> 'magili'};
is noun(q{magili})->plural, q{magili}  => q{plural: 'magili' --> 'magili'};
is noun(q{divertimento})->plural,   q{divertimentos}  => q{plural: 'divertimento' --> 'divertimentos'};
is noun(q{divertimentos})->plural, q{divertimentos}  => q{plural: 'divertimentos' --> 'divertimentos'};
is noun(q{regulus})->plural,   q{reguli}  => q{plural: 'regulus' --> 'reguli'};
is noun(q{reguli})->plural, q{reguli}  => q{plural: 'reguli' --> 'reguli'};
is noun(q{rezidentsia})->plural,   q{rezidentsii}  => q{plural: 'rezidentsia' --> 'rezidentsii'};
is noun(q{rezidentsii})->plural, q{rezidentsii}  => q{plural: 'rezidentsii' --> 'rezidentsii'};
is noun(q{vitta})->plural,   q{vittae}  => q{plural: 'vitta' --> 'vittae'};
is noun(q{vittae})->plural, q{vittae}  => q{plural: 'vittae' --> 'vittae'};
is noun(q{erratum})->plural,   q{errata}  => q{plural: 'erratum' --> 'errata'};
is noun(q{errata})->plural, q{errata}  => q{plural: 'errata' --> 'errata'};
is noun(q{cyathus})->plural,   q{cyathi}  => q{plural: 'cyathus' --> 'cyathi'};
is noun(q{cyathi})->plural, q{cyathi}  => q{plural: 'cyathi' --> 'cyathi'};
is noun(q{schizostylis})->plural,   q{schizostylis}  => q{plural: 'schizostylis' --> 'schizostylis'};
is noun(q{bhikshu})->plural,   q{bhikshus}  => q{plural: 'bhikshu' --> 'bhikshus'};
is noun(q{bhikshus})->plural, q{bhikshus}  => q{plural: 'bhikshus' --> 'bhikshus'};
is noun(q{britches})->plural,   q{britches}  => q{plural: 'britches' --> 'britches'};
is noun(q{evirato})->plural,   q{evirati}  => q{plural: 'evirato' --> 'evirati'};
is noun(q{evirati})->plural, q{evirati}  => q{plural: 'evirati' --> 'evirati'};
is noun(q{herpes})->plural,   q{herpes}  => q{plural: 'herpes' --> 'herpes'};
is noun(q{yoe})->plural,   q{yoes}  => q{plural: 'yoe' --> 'yoes'};
is noun(q{yoes})->plural, q{yoes}  => q{plural: 'yoes' --> 'yoes'};
is noun(q{isidium})->plural,   q{isidia}  => q{plural: 'isidium' --> 'isidia'};
is noun(q{isidia})->plural, q{isidia}  => q{plural: 'isidia' --> 'isidia'};
is noun(q{graben})->plural,   q{grabens}  => q{plural: 'graben' --> 'grabens'};
is noun(q{grabens})->plural, q{grabens}  => q{plural: 'grabens' --> 'grabens'};
is noun(q{kobo})->plural,   q{kobo}  => q{plural: 'kobo' --> 'kobo'};
is noun(q{opus})->plural,   q{opuses}  => q{plural: 'opus' --> 'opuses'};
is noun(q{opuses})->plural, q{opuses}  => q{plural: 'opuses' --> 'opuses'};
is noun(q{septarium})->plural,   q{septaria}  => q{plural: 'septarium' --> 'septaria'};
is noun(q{septaria})->plural, q{septaria}  => q{plural: 'septaria' --> 'septaria'};
is noun(q{limax})->plural,   q{limaces}  => q{plural: 'limax' --> 'limaces'};
is noun(q{limaces})->plural, q{limaces}  => q{plural: 'limaces' --> 'limaces'};
is noun(q{talisman})->plural,   q{talismans}  => q{plural: 'talisman' --> 'talismans'};
is noun(q{talismans})->plural, q{talismans}  => q{plural: 'talismans' --> 'talismans'};
is noun(q{staretz})->plural,   q{startzy}  => q{plural: 'staretz' --> 'startzy'};
is noun(q{startzy})->plural, q{startzy}  => q{plural: 'startzy' --> 'startzy'};
is noun(q{gens})->plural,   q{gentes}  => q{plural: 'gens' --> 'gentes'};
is noun(q{gentes})->plural, q{gentes}  => q{plural: 'gentes' --> 'gentes'};
is noun(q{scirrhus})->plural,   q{scirrhusses}  => q{plural: 'scirrhus' --> 'scirrhusses'};
is noun(q{scirrhusses})->plural, q{scirrhusses}  => q{plural: 'scirrhusses' --> 'scirrhusses'};
is noun(q{flounder})->plural,   q{flounder}  => q{plural: 'flounder' --> 'flounder'};
is noun(q{reductio})->plural,   q{reductiones}  => q{plural: 'reductio' --> 'reductiones'};
is noun(q{reductiones})->plural, q{reductiones}  => q{plural: 'reductiones' --> 'reductiones'};
is noun(q{gladiolus})->plural,   q{gladioluses}  => q{plural: 'gladiolus' --> 'gladioluses'};
is noun(q{gladioluses})->plural, q{gladioluses}  => q{plural: 'gladioluses' --> 'gladioluses'};
is noun(q{rezident})->plural,   q{rezidenty}  => q{plural: 'rezident' --> 'rezidenty'};
is noun(q{rezidenty})->plural, q{rezidenty}  => q{plural: 'rezidenty' --> 'rezidenty'};
is noun(q{karrenfeld})->plural,   q{karrenfelds}  => q{plural: 'karrenfeld' --> 'karrenfelds'};
is noun(q{karrenfelds})->plural, q{karrenfelds}  => q{plural: 'karrenfelds' --> 'karrenfelds'};
is noun(q{leu})->plural,   q{lei}  => q{plural: 'leu' --> 'lei'};
is noun(q{lei})->plural, q{lei}  => q{plural: 'lei' --> 'lei'};
is noun(q{mo})->plural,   q{moes}  => q{plural: 'mo' --> 'moes'};
is noun(q{moes})->plural, q{moes}  => q{plural: 'moes' --> 'moes'};
is noun(q{pied a terre})->plural,   q{pieds a terre}  => q{plural: 'pied a terre' --> 'pieds a terre'};
is noun(q{pieds a terre})->plural, q{pieds a terre}  => q{plural: 'pieds a terre' --> 'pieds a terre'};
is noun(q{isthmus})->plural,   q{isthmuses}  => q{plural: 'isthmus' --> 'isthmuses'};
is noun(q{isthmuses})->plural, q{isthmuses}  => q{plural: 'isthmuses' --> 'isthmuses'};
is noun(q{syphiloma})->plural,   q{syphilomata}  => q{plural: 'syphiloma' --> 'syphilomata'};
is noun(q{syphilomata})->plural, q{syphilomata}  => q{plural: 'syphilomata' --> 'syphilomata'};
is noun(q{tableau})->plural,   q{tableaus}  => q{plural: 'tableau' --> 'tableaus'};
is noun(q{tableaus})->plural, q{tableaus}  => q{plural: 'tableaus' --> 'tableaus'};
is noun(q{protoma})->plural,   q{protomas}  => q{plural: 'protoma' --> 'protomas'};
is noun(q{protomas})->plural, q{protomas}  => q{plural: 'protomas' --> 'protomas'};
is noun(q{maecenas})->plural,   q{maecenases}  => q{plural: 'maecenas' --> 'maecenases'};
is noun(q{maecenases})->plural, q{maecenases}  => q{plural: 'maecenases' --> 'maecenases'};
is noun(q{Bolzano})->plural,   q{Bolzanos}  => q{plural: 'Bolzano' --> 'Bolzanos'};
is noun(q{Bolzanos})->plural, q{Bolzanos}  => q{plural: 'Bolzanos' --> 'Bolzanos'};
is noun(q{rubashka})->plural,   q{rubashkas}  => q{plural: 'rubashka' --> 'rubashkas'};
is noun(q{rubashkas})->plural, q{rubashkas}  => q{plural: 'rubashkas' --> 'rubashkas'};
is noun(q{aboiteau})->plural,   q{aboiteaus}  => q{plural: 'aboiteau' --> 'aboiteaus'};
is noun(q{aboiteaus})->plural, q{aboiteaus}  => q{plural: 'aboiteaus' --> 'aboiteaus'};
is noun(q{convolvulus})->plural,   q{convolvuluses}  => q{plural: 'convolvulus' --> 'convolvuluses'};
is noun(q{convolvuluses})->plural, q{convolvuluses}  => q{plural: 'convolvuluses' --> 'convolvuluses'};
is noun(q{eunuch})->plural,   q{eunuchs}  => q{plural: 'eunuch' --> 'eunuchs'};
is noun(q{eunuchs})->plural, q{eunuchs}  => q{plural: 'eunuchs' --> 'eunuchs'};
is noun(q{Camaldolese})->plural,   q{Camaldolese}  => q{plural: 'Camaldolese' --> 'Camaldolese'};
is noun(q{uredium})->plural,   q{uredia}  => q{plural: 'uredium' --> 'uredia'};
is noun(q{uredia})->plural, q{uredia}  => q{plural: 'uredia' --> 'uredia'};
is noun(q{stolo})->plural,   q{stolones}  => q{plural: 'stolo' --> 'stolones'};
is noun(q{stolones})->plural, q{stolones}  => q{plural: 'stolones' --> 'stolones'};
is noun(q{canto})->plural,   q{cantos}  => q{plural: 'canto' --> 'cantos'};
is noun(q{cantos})->plural, q{cantos}  => q{plural: 'cantos' --> 'cantos'};
is noun(q{armadillo})->plural,   q{armadillos}  => q{plural: 'armadillo' --> 'armadillos'};
is noun(q{armadillos})->plural, q{armadillos}  => q{plural: 'armadillos' --> 'armadillos'};
is noun(q{mortadella})->plural,   q{mortadellas}  => q{plural: 'mortadella' --> 'mortadellas'};
is noun(q{mortadellas})->plural, q{mortadellas}  => q{plural: 'mortadellas' --> 'mortadellas'};
is noun(q{Kiplingese})->plural,   q{Kiplingese}  => q{plural: 'Kiplingese' --> 'Kiplingese'};
is noun(q{feis})->plural,   q{fess}  => q{plural: 'feis' --> 'fess'};
is noun(q{fess})->plural, q{fess}  => q{plural: 'fess' --> 'fess'};
is noun(q{lentigo})->plural,   q{lentigines}  => q{plural: 'lentigo' --> 'lentigines'};
is noun(q{lentigines})->plural, q{lentigines}  => q{plural: 'lentigines' --> 'lentigines'};
is noun(q{albergo})->plural,   q{alberghi}  => q{plural: 'albergo' --> 'alberghi'};
is noun(q{alberghi})->plural, q{alberghi}  => q{plural: 'alberghi' --> 'alberghi'};
is noun(q{nidus})->plural,   q{niduses}  => q{plural: 'nidus' --> 'niduses'};
is noun(q{niduses})->plural, q{niduses}  => q{plural: 'niduses' --> 'niduses'};
is noun(q{Toronto})->plural,   q{Torontos}  => q{plural: 'Toronto' --> 'Torontos'};
is noun(q{Torontos})->plural, q{Torontos}  => q{plural: 'Torontos' --> 'Torontos'};
is noun(q{tuna})->plural,   q{tuna}  => q{plural: 'tuna' --> 'tuna'};
is noun(q{prepenna})->plural,   q{prepennae}  => q{plural: 'prepenna' --> 'prepennae'};
is noun(q{prepennae})->plural, q{prepennae}  => q{plural: 'prepennae' --> 'prepennae'};
is noun(q{parapleurum})->plural,   q{parapleura}  => q{plural: 'parapleurum' --> 'parapleura'};
is noun(q{cantus})->plural,   q{cantuses}  => q{plural: 'cantus' --> 'cantuses'};
is noun(q{cantuses})->plural, q{cantuses}  => q{plural: 'cantuses' --> 'cantuses'};
is noun(q{loggia})->plural,   q{loggias}  => q{plural: 'loggia' --> 'loggias'};
is noun(q{loggias})->plural, q{loggias}  => q{plural: 'loggias' --> 'loggias'};
is noun(q{internodium})->plural,   q{internodia}  => q{plural: 'internodium' --> 'internodia'};
is noun(q{internodia})->plural, q{internodia}  => q{plural: 'internodia' --> 'internodia'};
is noun(q{crista})->plural,   q{cristae}  => q{plural: 'crista' --> 'cristae'};
is noun(q{cristae})->plural, q{cristae}  => q{plural: 'cristae' --> 'cristae'};
is noun(q{torulus})->plural,   q{toruli}  => q{plural: 'torulus' --> 'toruli'};
is noun(q{toruli})->plural, q{toruli}  => q{plural: 'toruli' --> 'toruli'};
is noun(q{sinfonia})->plural,   q{sinfonias}  => q{plural: 'sinfonia' --> 'sinfonias'};
is noun(q{sinfonias})->plural, q{sinfonias}  => q{plural: 'sinfonias' --> 'sinfonias'};
is noun(q{poe})->plural,   q{poes}  => q{plural: 'poe' --> 'poes'};
is noun(q{poes})->plural, q{poes}  => q{plural: 'poes' --> 'poes'};
is noun(q{cod})->plural,   q{cod}  => q{plural: 'cod' --> 'cod'};
is noun(q{pectus})->plural,   q{pectora}  => q{plural: 'pectus' --> 'pectora'};
is noun(q{pectora})->plural, q{pectora}  => q{plural: 'pectora' --> 'pectora'};
is noun(q{wolf})->plural,   q{wolves}  => q{plural: 'wolf' --> 'wolves'};
is noun(q{wolves})->plural, q{wolves}  => q{plural: 'wolves' --> 'wolves'};
is noun(q{vila})->plural,   q{vilas}  => q{plural: 'vila' --> 'vilas'};
is noun(q{vilas})->plural, q{vilas}  => q{plural: 'vilas' --> 'vilas'};
is noun(q{meshumad})->plural,   q{meshumadim}  => q{plural: 'meshumad' --> 'meshumadim'};
is noun(q{meshumadim})->plural, q{meshumadim}  => q{plural: 'meshumadim' --> 'meshumadim'};
is noun(q{adminiculum})->plural,   q{adminicula}  => q{plural: 'adminiculum' --> 'adminicula'};
is noun(q{adminicula})->plural, q{adminicula}  => q{plural: 'adminicula' --> 'adminicula'};
is noun(q{Muqdisho})->plural,   q{Muqdishos}  => q{plural: 'Muqdisho' --> 'Muqdishos'};
is noun(q{Muqdishos})->plural, q{Muqdishos}  => q{plural: 'Muqdishos' --> 'Muqdishos'};
is noun(q{Atlas})->plural,   q{Atlantes}  => q{plural: 'Atlas' --> 'Atlantes'};
is noun(q{Atlantes})->plural, q{Atlantes}  => q{plural: 'Atlantes' --> 'Atlantes'};
is noun(q{sombrero})->plural,   q{sombreros}  => q{plural: 'sombrero' --> 'sombreros'};
is noun(q{sombreros})->plural, q{sombreros}  => q{plural: 'sombreros' --> 'sombreros'};
is noun(q{ho})->plural,   q{hoes}  => q{plural: 'ho' --> 'hoes'};
is noun(q{hoes})->plural, q{hoes}  => q{plural: 'hoes' --> 'hoes'};
is noun(q{pediluvium})->plural,   q{pediluvia}  => q{plural: 'pediluvium' --> 'pediluvia'};
is noun(q{pediluvia})->plural, q{pediluvia}  => q{plural: 'pediluvia' --> 'pediluvia'};
is noun(q{axopodium})->plural,   q{axopodia}  => q{plural: 'axopodium' --> 'axopodia'};
is noun(q{axopodia})->plural, q{axopodia}  => q{plural: 'axopodia' --> 'axopodia'};
is noun(q{tsubo})->plural,   q{tsubos}  => q{plural: 'tsubo' --> 'tsubos'};
is noun(q{tsubos})->plural, q{tsubos}  => q{plural: 'tsubos' --> 'tsubos'};
is noun(q{linctus})->plural,   q{linctuses}  => q{plural: 'linctus' --> 'linctuses'};
is noun(q{linctuses})->plural, q{linctuses}  => q{plural: 'linctuses' --> 'linctuses'};
is noun(q{ale wife})->plural,   q{ale wives}  => q{plural: 'ale wife' --> 'ale wives'};
is noun(q{ale wives})->plural, q{ale wives}  => q{plural: 'ale wives' --> 'ale wives'};
is noun(q{soe})->plural,   q{soes}  => q{plural: 'soe' --> 'soes'};
is noun(q{soes})->plural, q{soes}  => q{plural: 'soes' --> 'soes'};
is noun(q{dumka})->plural,   q{dumkas}  => q{plural: 'dumka' --> 'dumkas'};
is noun(q{dumkas})->plural, q{dumkas}  => q{plural: 'dumkas' --> 'dumkas'};
is noun(q{prora})->plural,   q{prorae}  => q{plural: 'prora' --> 'prorae'};
is noun(q{prorae})->plural, q{prorae}  => q{plural: 'prorae' --> 'prorae'};
is noun(q{imago})->plural,   q{imagos}  => q{plural: 'imago' --> 'imagos'};
is noun(q{imagos})->plural, q{imagos}  => q{plural: 'imagos' --> 'imagos'};
is noun(q{razz})->plural,   q{razzes}  => q{plural: 'razz' --> 'razzes'};
is noun(q{razzes})->plural, q{razzes}  => q{plural: 'razzes' --> 'razzes'};
is noun(q{poculum})->plural,   q{pocula}  => q{plural: 'poculum' --> 'pocula'};
is noun(q{pocula})->plural, q{pocula}  => q{plural: 'pocula' --> 'pocula'};
is noun(q{caecum})->plural,   q{caeca}  => q{plural: 'caecum' --> 'caeca'};
is noun(q{caeca})->plural, q{caeca}  => q{plural: 'caeca' --> 'caeca'};
is noun(q{infima species})->plural,   q{infimae species}  => q{plural: 'infima species' --> 'infimae species'};
is noun(q{infimae species})->plural, q{infimae species}  => q{plural: 'infimae species' --> 'infimae species'};
is noun(q{monota})->plural,   q{monotae}  => q{plural: 'monota' --> 'monotae'};
is noun(q{monotae})->plural, q{monotae}  => q{plural: 'monotae' --> 'monotae'};
is noun(q{craft})->plural,   q{craft}  => q{plural: 'craft' --> 'craft'};
is noun(q{pifferaro})->plural,   q{pifferari}  => q{plural: 'pifferaro' --> 'pifferari'};
is noun(q{pifferari})->plural, q{pifferari}  => q{plural: 'pifferari' --> 'pifferari'};
is noun(q{epithelioma})->plural,   q{epitheliomata}  => q{plural: 'epithelioma' --> 'epitheliomata'};
is noun(q{epitheliomata})->plural, q{epitheliomata}  => q{plural: 'epitheliomata' --> 'epitheliomata'};
is noun(q{ostium})->plural,   q{ostia}  => q{plural: 'ostium' --> 'ostia'};
is noun(q{ostia})->plural, q{ostia}  => q{plural: 'ostia' --> 'ostia'};
is noun(q{bijou})->plural,   q{bijoux}  => q{plural: 'bijou' --> 'bijoux'};
is noun(q{bijoux})->plural, q{bijoux}  => q{plural: 'bijoux' --> 'bijoux'};
is noun(q{oath})->plural,   q{oaths}  => q{plural: 'oath' --> 'oaths'};
is noun(q{oaths})->plural, q{oaths}  => q{plural: 'oaths' --> 'oaths'};
is noun(q{postpubis})->plural,   q{postpubes}  => q{plural: 'postpubis' --> 'postpubes'};
is noun(q{postpubes})->plural, q{postpubes}  => q{plural: 'postpubes' --> 'postpubes'};
is noun(q{Achinese})->plural,   q{Achinese}  => q{plural: 'Achinese' --> 'Achinese'};
is noun(q{Burmese})->plural,   q{Burmese}  => q{plural: 'Burmese' --> 'Burmese'};
is noun(q{halibut})->plural,   q{halibuts}  => q{plural: 'halibut' --> 'halibuts'};
is noun(q{halibuts})->plural, q{halibuts}  => q{plural: 'halibuts' --> 'halibuts'};
is noun(q{Maltese})->plural,   q{Maltese}  => q{plural: 'Maltese' --> 'Maltese'};
is noun(q{path})->plural,   q{paths}  => q{plural: 'path' --> 'paths'};
is noun(q{paths})->plural, q{paths}  => q{plural: 'paths' --> 'paths'};
is noun(q{man-milliner})->plural,   q{man-milliners}  => q{plural: 'man-milliner' --> 'man-milliners'};
is noun(q{man-milliners})->plural, q{man-milliners}  => q{plural: 'man-milliners' --> 'man-milliners'};
is noun(q{myeloma})->plural,   q{myelomas}  => q{plural: 'myeloma' --> 'myelomas'};
is noun(q{myelomas})->plural, q{myelomas}  => q{plural: 'myelomas' --> 'myelomas'};
is noun(q{ex})->plural,   q{exes}  => q{plural: 'ex' --> 'exes'};
is noun(q{exes})->plural, q{exes}  => q{plural: 'exes' --> 'exes'};
is noun(q{prokaryon})->plural,   q{prokarya}  => q{plural: 'prokaryon' --> 'prokarya'};
is noun(q{prokarya})->plural, q{prokarya}  => q{plural: 'prokarya' --> 'prokarya'};
is noun(q{typo})->plural,   q{typos}  => q{plural: 'typo' --> 'typos'};
is noun(q{typos})->plural, q{typos}  => q{plural: 'typos' --> 'typos'};
is noun(q{Assamese})->plural,   q{Assamese}  => q{plural: 'Assamese' --> 'Assamese'};
is noun(q{alto relievo})->plural,   q{alto relievos}  => q{plural: 'alto relievo' --> 'alto relievos'};
is noun(q{alto relievos})->plural, q{alto relievos}  => q{plural: 'alto relievos' --> 'alto relievos'};
is noun(q{break away})->plural,   q{break aways}  => q{plural: 'break away' --> 'break aways'};
is noun(q{break aways})->plural, q{break aways}  => q{plural: 'break aways' --> 'break aways'};
is noun(q{minimum})->plural,   q{minimums}  => q{plural: 'minimum' --> 'minimums'};
is noun(q{minimums})->plural, q{minimums}  => q{plural: 'minimums' --> 'minimums'};
is noun(q{Chinese})->plural,   q{Chinese}  => q{plural: 'Chinese' --> 'Chinese'};
is noun(q{vertex})->plural,   q{vertexes}  => q{plural: 'vertex' --> 'vertexes'};
is noun(q{vertexes})->plural, q{vertexes}  => q{plural: 'vertexes' --> 'vertexes'};
is noun(q{agon})->plural,   q{agones}  => q{plural: 'agon' --> 'agones'};
is noun(q{agones})->plural, q{agones}  => q{plural: 'agones' --> 'agones'};
is noun(q{bolero})->plural,   q{boleros}  => q{plural: 'bolero' --> 'boleros'};
is noun(q{boleros})->plural, q{boleros}  => q{plural: 'boleros' --> 'boleros'};
is noun(q{cranium})->plural,   q{craniums}  => q{plural: 'cranium' --> 'craniums'};
is noun(q{craniums})->plural, q{craniums}  => q{plural: 'craniums' --> 'craniums'};
is noun(q{scomber})->plural,   q{scombri}  => q{plural: 'scomber' --> 'scombri'};
is noun(q{scombri})->plural, q{scombri}  => q{plural: 'scombri' --> 'scombri'};
is noun(q{miracidium})->plural,   q{miracidia}  => q{plural: 'miracidium' --> 'miracidia'};
is noun(q{miracidia})->plural, q{miracidia}  => q{plural: 'miracidia' --> 'miracidia'};
is noun(q{flag-staff})->plural,   q{flag-staffs}  => q{plural: 'flag-staff' --> 'flag-staffs'};
is noun(q{flag-staffs})->plural, q{flag-staffs}  => q{plural: 'flag-staffs' --> 'flag-staffs'};
is noun(q{secretum})->plural,   q{secreta}  => q{plural: 'secretum' --> 'secreta'};
is noun(q{secreta})->plural, q{secreta}  => q{plural: 'secreta' --> 'secreta'};
is noun(q{schisma})->plural,   q{schismata}  => q{plural: 'schisma' --> 'schismata'};
is noun(q{schismata})->plural, q{schismata}  => q{plural: 'schismata' --> 'schismata'};
is noun(q{3-star general})->plural,   q{3-star generals}  => q{plural: '3-star general' --> '3-star generals'};
is noun(q{3-star generals})->plural, q{3-star generals}  => q{plural: '3-star generals' --> '3-star generals'};
is noun(q{tractellum})->plural,   q{tractella}  => q{plural: 'tractellum' --> 'tractella'};
is noun(q{tractella})->plural, q{tractella}  => q{plural: 'tractella' --> 'tractella'};
is noun(q{cultellus})->plural,   q{cultelli}  => q{plural: 'cultellus' --> 'cultelli'};
is noun(q{cultelli})->plural, q{cultelli}  => q{plural: 'cultelli' --> 'cultelli'};
is noun(q{Lapith})->plural,   q{Lapiths}  => q{plural: 'Lapith' --> 'Lapiths'};
is noun(q{Lapiths})->plural, q{Lapiths}  => q{plural: 'Lapiths' --> 'Lapiths'};
is noun(q{guardia civil})->plural,   q{guardias civiles}  => q{plural: 'guardia civil' --> 'guardias civiles'};
is noun(q{guardias civiles})->plural, q{guardias civiles}  => q{plural: 'guardias civiles' --> 'guardias civiles'};
is noun(q{Asherah})->plural,   q{Asherahs}  => q{plural: 'Asherah' --> 'Asherahs'};
is noun(q{Asherahs})->plural, q{Asherahs}  => q{plural: 'Asherahs' --> 'Asherahs'};
is noun(q{streptococcus})->plural,   q{streptococci}  => q{plural: 'streptococcus' --> 'streptococci'};
is noun(q{streptococci})->plural, q{streptococci}  => q{plural: 'streptococci' --> 'streptococci'};
is noun(q{Bernese})->plural,   q{Bernese}  => q{plural: 'Bernese' --> 'Bernese'};
is noun(q{zoarium})->plural,   q{zoaria}  => q{plural: 'zoarium' --> 'zoaria'};
is noun(q{zoaria})->plural, q{zoaria}  => q{plural: 'zoaria' --> 'zoaria'};
is noun(q{mya})->plural,   q{myas}  => q{plural: 'mya' --> 'myas'};
is noun(q{myas})->plural, q{myas}  => q{plural: 'myas' --> 'myas'};
is noun(q{fecula})->plural,   q{feculae}  => q{plural: 'fecula' --> 'feculae'};
is noun(q{feculae})->plural, q{feculae}  => q{plural: 'feculae' --> 'feculae'};
is noun(q{acicula})->plural,   q{aciculae}  => q{plural: 'acicula' --> 'aciculae'};
is noun(q{aciculae})->plural, q{aciculae}  => q{plural: 'aciculae' --> 'aciculae'};
is noun(q{Genevese})->plural,   q{Genevese}  => q{plural: 'Genevese' --> 'Genevese'};
is noun(q{cystidium})->plural,   q{cystidia}  => q{plural: 'cystidium' --> 'cystidia'};
is noun(q{cystidia})->plural, q{cystidia}  => q{plural: 'cystidia' --> 'cystidia'};
is noun(q{pul})->plural,   q{puls}  => q{plural: 'pul' --> 'puls'};
is noun(q{puls})->plural, q{puls}  => q{plural: 'puls' --> 'puls'};
is noun(q{lactobacillus})->plural,   q{lactobacilli}  => q{plural: 'lactobacillus' --> 'lactobacilli'};
is noun(q{lactobacilli})->plural, q{lactobacilli}  => q{plural: 'lactobacilli' --> 'lactobacilli'};
is noun(q{cuniculus})->plural,   q{cuniculi}  => q{plural: 'cuniculus' --> 'cuniculi'};
is noun(q{cuniculi})->plural, q{cuniculi}  => q{plural: 'cuniculi' --> 'cuniculi'};
is noun(q{rhythmus})->plural,   q{rhythmi}  => q{plural: 'rhythmus' --> 'rhythmi'};
is noun(q{rhythmi})->plural, q{rhythmi}  => q{plural: 'rhythmi' --> 'rhythmi'};
is noun(q{rondeau})->plural,   q{rondeaus}  => q{plural: 'rondeau' --> 'rondeaus'};
is noun(q{rondeaus})->plural, q{rondeaus}  => q{plural: 'rondeaus' --> 'rondeaus'};
is noun(q{lineno})->plural,   q{linenos}  => q{plural: 'lineno' --> 'linenos'};
is noun(q{linenos})->plural, q{linenos}  => q{plural: 'linenos' --> 'linenos'};
is noun(q{milieu})->plural,   q{milieus}  => q{plural: 'milieu' --> 'milieus'};
is noun(q{milieus})->plural, q{milieus}  => q{plural: 'milieus' --> 'milieus'};
is noun(q{sarcophagus})->plural,   q{sarcophagi}  => q{plural: 'sarcophagus' --> 'sarcophagi'};
is noun(q{sarcophagi})->plural, q{sarcophagi}  => q{plural: 'sarcophagi' --> 'sarcophagi'};
is noun(q{vaquero})->plural,   q{vaqueros}  => q{plural: 'vaquero' --> 'vaqueros'};
is noun(q{vaqueros})->plural, q{vaqueros}  => q{plural: 'vaqueros' --> 'vaqueros'};
is noun(q{idee fixe})->plural,   q{idees fixes}  => q{plural: 'idee fixe' --> 'idees fixes'};
is noun(q{idees fixes})->plural, q{idees fixes}  => q{plural: 'idees fixes' --> 'idees fixes'};
is noun(q{pupa})->plural,   q{pupae}  => q{plural: 'pupa' --> 'pupae'};
is noun(q{pupae})->plural, q{pupae}  => q{plural: 'pupae' --> 'pupae'};
is noun(q{cri de coeur})->plural,   q{cris de coeur}  => q{plural: 'cri de coeur' --> 'cris de coeur'};
is noun(q{cris de coeur})->plural, q{cris de coeur}  => q{plural: 'cris de coeur' --> 'cris de coeur'};
is noun(q{silex})->plural,   q{silices}  => q{plural: 'silex' --> 'silices'};
is noun(q{silices})->plural, q{silices}  => q{plural: 'silices' --> 'silices'};
is noun(q{spermatoon})->plural,   q{spermatoa}  => q{plural: 'spermatoon' --> 'spermatoa'};
is noun(q{spermatoa})->plural, q{spermatoa}  => q{plural: 'spermatoa' --> 'spermatoa'};
is noun(q{uredinium})->plural,   q{uredinia}  => q{plural: 'uredinium' --> 'uredinia'};
is noun(q{uredinia})->plural, q{uredinia}  => q{plural: 'uredinia' --> 'uredinia'};
is noun(q{pileus})->plural,   q{pilei}  => q{plural: 'pileus' --> 'pilei'};
is noun(q{pilei})->plural, q{pilei}  => q{plural: 'pilei' --> 'pilei'};
is noun(q{xanthoma})->plural,   q{xanthomas}  => q{plural: 'xanthoma' --> 'xanthomas'};
is noun(q{xanthomas})->plural, q{xanthomas}  => q{plural: 'xanthomas' --> 'xanthomas'};
is noun(q{commando})->plural,   q{commandos}  => q{plural: 'commando' --> 'commandos'};
is noun(q{commandos})->plural, q{commandos}  => q{plural: 'commandos' --> 'commandos'};
is noun(q{casino})->plural,   q{casinos}  => q{plural: 'casino' --> 'casinos'};
is noun(q{casinos})->plural, q{casinos}  => q{plural: 'casinos' --> 'casinos'};
is noun(q{mycorrhiza})->plural,   q{mycorrhizas}  => q{plural: 'mycorrhiza' --> 'mycorrhizas'};
is noun(q{mycorrhizas})->plural, q{mycorrhizas}  => q{plural: 'mycorrhizas' --> 'mycorrhizas'};
is noun(q{lumbricus})->plural,   q{lumbrici}  => q{plural: 'lumbricus' --> 'lumbrici'};
is noun(q{lumbrici})->plural, q{lumbrici}  => q{plural: 'lumbrici' --> 'lumbrici'};
is noun(q{supracleithrum})->plural,   q{supracleithra}  => q{plural: 'supracleithrum' --> 'supracleithra'};
is noun(q{supracleithra})->plural, q{supracleithra}  => q{plural: 'supracleithra' --> 'supracleithra'};
is noun(q{shelf})->plural,   q{shelves}  => q{plural: 'shelf' --> 'shelves'};
is noun(q{shelves})->plural, q{shelves}  => q{plural: 'shelves' --> 'shelves'};
is noun(q{guano})->plural,   q{guanos}  => q{plural: 'guano' --> 'guanos'};
is noun(q{guanos})->plural, q{guanos}  => q{plural: 'guanos' --> 'guanos'};
is noun(q{Leonese})->plural,   q{Leonese}  => q{plural: 'Leonese' --> 'Leonese'};
is noun(q{atman})->plural,   q{atmas}  => q{plural: 'atman' --> 'atmas'};
is noun(q{atmas})->plural, q{atmas}  => q{plural: 'atmas' --> 'atmas'};
is noun(q{lied})->plural,   q{lieder}  => q{plural: 'lied' --> 'lieder'};
is noun(q{lieder})->plural, q{lieder}  => q{plural: 'lieder' --> 'lieder'};
is noun(q{papilla})->plural,   q{papillae}  => q{plural: 'papilla' --> 'papillae'};
is noun(q{papillae})->plural, q{papillae}  => q{plural: 'papillae' --> 'papillae'};
is noun(q{tsuba})->plural,   q{tsubas}  => q{plural: 'tsuba' --> 'tsubas'};
is noun(q{tsubas})->plural, q{tsubas}  => q{plural: 'tsubas' --> 'tsubas'};
is noun(q{dragoman})->plural,   q{dragomen}  => q{plural: 'dragoman' --> 'dragomen'};
is noun(q{dragomen})->plural, q{dragomen}  => q{plural: 'dragomen' --> 'dragomen'};
is noun(q{decennium})->plural,   q{decennia}  => q{plural: 'decennium' --> 'decennia'};
is noun(q{decennia})->plural, q{decennia}  => q{plural: 'decennia' --> 'decennia'};
is noun(q{carmen})->plural,   q{carmens}  => q{plural: 'carmen' --> 'carmens'};
is noun(q{carmens})->plural, q{carmens}  => q{plural: 'carmens' --> 'carmens'};
is noun(q{quarto})->plural,   q{quartos}  => q{plural: 'quarto' --> 'quartos'};
is noun(q{quartos})->plural, q{quartos}  => q{plural: 'quartos' --> 'quartos'};
is noun(q{cistophorus})->plural,   q{cistophorori}  => q{plural: 'cistophorus' --> 'cistophorori'};
is noun(q{cistophorori})->plural, q{cistophorori}  => q{plural: 'cistophorori' --> 'cistophorori'};
is noun(q{postnatus})->plural,   q{postnati}  => q{plural: 'postnatus' --> 'postnati'};
is noun(q{postnati})->plural, q{postnati}  => q{plural: 'postnati' --> 'postnati'};
is noun(q{oxyuris})->plural,   q{oxyurides}  => q{plural: 'oxyuris' --> 'oxyurides'};
is noun(q{oxyurides})->plural, q{oxyurides}  => q{plural: 'oxyurides' --> 'oxyurides'};
is noun(q{xiphoplastron})->plural,   q{xiphoplastra}  => q{plural: 'xiphoplastron' --> 'xiphoplastra'};
is noun(q{xiphoplastra})->plural, q{xiphoplastra}  => q{plural: 'xiphoplastra' --> 'xiphoplastra'};
is noun(q{radix})->plural,   q{radixes}  => q{plural: 'radix' --> 'radixes'};
is noun(q{radixes})->plural, q{radixes}  => q{plural: 'radixes' --> 'radixes'};
is noun(q{glutaeus})->plural,   q{glutei}  => q{plural: 'glutaeus' --> 'glutei'};
is noun(q{glutei})->plural, q{glutei}  => q{plural: 'glutei' --> 'glutei'};
is noun(q{coelia})->plural,   q{coeliae}  => q{plural: 'coelia' --> 'coeliae'};
is noun(q{coeliae})->plural, q{coeliae}  => q{plural: 'coeliae' --> 'coeliae'};
is noun(q{asyndeton})->plural,   q{asyndeta}  => q{plural: 'asyndeton' --> 'asyndeta'};
is noun(q{asyndeta})->plural, q{asyndeta}  => q{plural: 'asyndeta' --> 'asyndeta'};
is noun(q{dipsas})->plural,   q{dipsades}  => q{plural: 'dipsas' --> 'dipsades'};
is noun(q{dipsades})->plural, q{dipsades}  => q{plural: 'dipsades' --> 'dipsades'};
is noun(q{radius})->plural,   q{radiuses}  => q{plural: 'radius' --> 'radiuses'};
is noun(q{radiuses})->plural, q{radiuses}  => q{plural: 'radiuses' --> 'radiuses'};
is noun(q{espresso})->plural,   q{espressos}  => q{plural: 'espresso' --> 'espressos'};
is noun(q{espressos})->plural, q{espressos}  => q{plural: 'espressos' --> 'espressos'};
is noun(q{fiasco})->plural,   q{fiascos}  => q{plural: 'fiasco' --> 'fiascos'};
is noun(q{fiascos})->plural, q{fiascos}  => q{plural: 'fiascos' --> 'fiascos'};
is noun(q{base})->plural,   q{bases}  => q{plural: 'base' --> 'bases'};
is noun(q{bases})->plural, q{bases}  => q{plural: 'bases' --> 'bases'};
is noun(q{hydria})->plural,   q{hydriae}  => q{plural: 'hydria' --> 'hydriae'};
is noun(q{hydriae})->plural, q{hydriae}  => q{plural: 'hydriae' --> 'hydriae'};
is noun(q{nova})->plural,   q{novas}  => q{plural: 'nova' --> 'novas'};
is noun(q{novas})->plural, q{novas}  => q{plural: 'novas' --> 'novas'};
is noun(q{vaporetto})->plural,   q{vaporettos}  => q{plural: 'vaporetto' --> 'vaporettos'};
is noun(q{vaporettos})->plural, q{vaporettos}  => q{plural: 'vaporettos' --> 'vaporettos'};
is noun(q{bulimus})->plural,   q{bulimi}  => q{plural: 'bulimus' --> 'bulimi'};
is noun(q{bulimi})->plural, q{bulimi}  => q{plural: 'bulimi' --> 'bulimi'};
is noun(q{terrarium})->plural,   q{terrariums}  => q{plural: 'terrarium' --> 'terrariums'};
is noun(q{terrariums})->plural, q{terrariums}  => q{plural: 'terrariums' --> 'terrariums'};
is noun(q{cementoma})->plural,   q{cementomata}  => q{plural: 'cementoma' --> 'cementomata'};
is noun(q{cementomata})->plural, q{cementomata}  => q{plural: 'cementomata' --> 'cementomata'};
is noun(q{genius})->plural,   q{geniuses}  => q{plural: 'genius' --> 'geniuses'};
is noun(q{geniuses})->plural, q{geniuses}  => q{plural: 'geniuses' --> 'geniuses'};
is noun(q{haustrum})->plural,   q{haustra}  => q{plural: 'haustrum' --> 'haustra'};
is noun(q{haustra})->plural, q{haustra}  => q{plural: 'haustra' --> 'haustra'};
is noun(q{zita})->plural,   q{ziti}  => q{plural: 'zita' --> 'ziti'};
is noun(q{ziti})->plural, q{ziti}  => q{plural: 'ziti' --> 'ziti'};
is noun(q{cavea})->plural,   q{caveae}  => q{plural: 'cavea' --> 'caveae'};
is noun(q{caveae})->plural, q{caveae}  => q{plural: 'caveae' --> 'caveae'};
is noun(q{anti serum})->plural,   q{anti serums}  => q{plural: 'anti serum' --> 'anti serums'};
is noun(q{anti serums})->plural, q{anti serums}  => q{plural: 'anti serums' --> 'anti serums'};
is noun(q{Buginese})->plural,   q{Buginese}  => q{plural: 'Buginese' --> 'Buginese'};
is noun(q{choana})->plural,   q{choanae}  => q{plural: 'choana' --> 'choanae'};
is noun(q{choanae})->plural, q{choanae}  => q{plural: 'choanae' --> 'choanae'};
is noun(q{peninsula})->plural,   q{peninsulas}  => q{plural: 'peninsula' --> 'peninsulas'};
is noun(q{peninsulas})->plural, q{peninsulas}  => q{plural: 'peninsulas' --> 'peninsulas'};
is noun(q{scriptorium})->plural,   q{scriptoriums}  => q{plural: 'scriptorium' --> 'scriptoriums'};
is noun(q{scriptoriums})->plural, q{scriptoriums}  => q{plural: 'scriptoriums' --> 'scriptoriums'};
is noun(q{regidor})->plural,   q{regidors}  => q{plural: 'regidor' --> 'regidors'};
is noun(q{regidors})->plural, q{regidors}  => q{plural: 'regidors' --> 'regidors'};
is noun(q{hoof})->plural,   q{hoofs}  => q{plural: 'hoof' --> 'hoofs'};
is noun(q{hoofs})->plural, q{hoofs}  => q{plural: 'hoofs' --> 'hoofs'};
is noun(q{whosesoever})->plural,   q{whosesoever}  => q{plural: 'whosesoever' --> 'whosesoever'};
is noun(q{pulmonarium})->plural,   q{pulmonaria}  => q{plural: 'pulmonarium' --> 'pulmonaria'};
is noun(q{pulmonaria})->plural, q{pulmonaria}  => q{plural: 'pulmonaria' --> 'pulmonaria'};
is noun(q{zeitgeber})->plural,   q{zeitgebers}  => q{plural: 'zeitgeber' --> 'zeitgebers'};
is noun(q{zeitgebers})->plural, q{zeitgebers}  => q{plural: 'zeitgebers' --> 'zeitgebers'};
is noun(q{siemens})->plural,   q{siemens}  => q{plural: 'siemens' --> 'siemens'};
is noun(q{whomsoever})->plural,   q{whomsoever}  => q{plural: 'whomsoever' --> 'whomsoever'};
is noun(q{Colombo})->plural,   q{Colombos}  => q{plural: 'Colombo' --> 'Colombos'};
is noun(q{Colombos})->plural, q{Colombos}  => q{plural: 'Colombos' --> 'Colombos'};
is noun(q{shomer})->plural,   q{shomrim}  => q{plural: 'shomer' --> 'shomrim'};
is noun(q{shomrim})->plural, q{shomrim}  => q{plural: 'shomrim' --> 'shomrim'};
is noun(q{staminidium})->plural,   q{staminidia}  => q{plural: 'staminidium' --> 'staminidia'};
is noun(q{staminidia})->plural, q{staminidia}  => q{plural: 'staminidia' --> 'staminidia'};
is noun(q{tagma})->plural,   q{tagmata}  => q{plural: 'tagma' --> 'tagmata'};
is noun(q{tagmata})->plural, q{tagmata}  => q{plural: 'tagmata' --> 'tagmata'};
is noun(q{cappuccino})->plural,   q{cappuccinos}  => q{plural: 'cappuccino' --> 'cappuccinos'};
is noun(q{cappuccinos})->plural, q{cappuccinos}  => q{plural: 'cappuccinos' --> 'cappuccinos'};
is noun(q{thos})->plural,   q{thoes}  => q{plural: 'thos' --> 'thoes'};
is noun(q{thoes})->plural, q{thoes}  => q{plural: 'thoes' --> 'thoes'};
is noun(q{nautilus})->plural,   q{nautiluses}  => q{plural: 'nautilus' --> 'nautiluses'};
is noun(q{nautiluses})->plural, q{nautiluses}  => q{plural: 'nautiluses' --> 'nautiluses'};
is noun(q{ammo})->plural,   q{ammos}  => q{plural: 'ammo' --> 'ammos'};
is noun(q{ammos})->plural, q{ammos}  => q{plural: 'ammos' --> 'ammos'};
is noun(q{rione})->plural,   q{rioni}  => q{plural: 'rione' --> 'rioni'};
is noun(q{rioni})->plural, q{rioni}  => q{plural: 'rioni' --> 'rioni'};
is noun(q{scutulum})->plural,   q{scutula}  => q{plural: 'scutulum' --> 'scutula'};
is noun(q{scutula})->plural, q{scutula}  => q{plural: 'scutula' --> 'scutula'};
is noun(q{inuk})->plural,   q{inuit}  => q{plural: 'inuk' --> 'inuit'};
is noun(q{inuit})->plural, q{inuit}  => q{plural: 'inuit' --> 'inuit'};
is noun(q{udarnik})->plural,   q{udarniki}  => q{plural: 'udarnik' --> 'udarniki'};
is noun(q{udarniki})->plural, q{udarniki}  => q{plural: 'udarniki' --> 'udarniki'};
is noun(q{intermezzo})->plural,   q{intermezzos}  => q{plural: 'intermezzo' --> 'intermezzos'};
is noun(q{intermezzos})->plural, q{intermezzos}  => q{plural: 'intermezzos' --> 'intermezzos'};
is noun(q{five star general})->plural,   q{five star generals}  => q{plural: 'five star general' --> 'five star generals'};
is noun(q{five star generals})->plural, q{five star generals}  => q{plural: 'five star generals' --> 'five star generals'};
is noun(q{parnas})->plural,   q{parnassim}  => q{plural: 'parnas' --> 'parnassim'};
is noun(q{parnassim})->plural, q{parnassim}  => q{plural: 'parnassim' --> 'parnassim'};
is noun(q{virga})->plural,   q{virgae}  => q{plural: 'virga' --> 'virgae'};
is noun(q{virgae})->plural, q{virgae}  => q{plural: 'virgae' --> 'virgae'};
is noun(q{testis})->plural,   q{testes}  => q{plural: 'testis' --> 'testes'};
is noun(q{Niasese})->plural,   q{Niasese}  => q{plural: 'Niasese' --> 'Niasese'};
is noun(q{short})->plural,   q{shorts}  => q{plural: 'short' --> 'shorts'};
is noun(q{solvus})->plural,   q{solvi}  => q{plural: 'solvus' --> 'solvi'};
is noun(q{solvi})->plural, q{solvi}  => q{plural: 'solvi' --> 'solvi'};
is noun(q{indigena})->plural,   q{indigenae}  => q{plural: 'indigena' --> 'indigenae'};
is noun(q{indigenae})->plural, q{indigenae}  => q{plural: 'indigenae' --> 'indigenae'};
is noun(q{interradius})->plural,   q{interradii}  => q{plural: 'interradius' --> 'interradii'};
is noun(q{interradii})->plural, q{interradii}  => q{plural: 'interradii' --> 'interradii'};
is noun(q{miliola})->plural,   q{miliolae}  => q{plural: 'miliola' --> 'miliolae'};
is noun(q{miliolae})->plural, q{miliolae}  => q{plural: 'miliolae' --> 'miliolae'};
is noun(q{trockenbeerenauslese})->plural,   q{trockenbeerenauslesen}  => q{plural: 'trockenbeerenauslese' --> 'trockenbeerenauslesen'};
is noun(q{trockenbeerenauslesen})->plural, q{trockenbeerenauslesen}  => q{plural: 'trockenbeerenauslesen' --> 'trockenbeerenauslesen'};
is noun(q{trabecula})->plural,   q{trabeculae}  => q{plural: 'trabecula' --> 'trabeculae'};
is noun(q{trabeculae})->plural, q{trabeculae}  => q{plural: 'trabeculae' --> 'trabeculae'};
is noun(q{cornetto})->plural,   q{cornetti}  => q{plural: 'cornetto' --> 'cornetti'};
is noun(q{cornetti})->plural, q{cornetti}  => q{plural: 'cornetti' --> 'cornetti'};
is noun(q{brother-german})->plural,   q{brothers-german}  => q{plural: 'brother-german' --> 'brothers-german'};
is noun(q{brothers-german})->plural, q{brothers-german}  => q{plural: 'brothers-german' --> 'brothers-german'};
is noun(q{cheval})->plural,   q{chevaux}  => q{plural: 'cheval' --> 'chevaux'};
is noun(q{chevaux})->plural, q{chevaux}  => q{plural: 'chevaux' --> 'chevaux'};
is noun(q{pedalo})->plural,   q{pedalos}  => q{plural: 'pedalo' --> 'pedalos'};
is noun(q{pedalos})->plural, q{pedalos}  => q{plural: 'pedalos' --> 'pedalos'};
is noun(q{Dongolese})->plural,   q{Dongolese}  => q{plural: 'Dongolese' --> 'Dongolese'};
is noun(q{psammoma})->plural,   q{psammomata}  => q{plural: 'psammoma' --> 'psammomata'};
is noun(q{psammomata})->plural, q{psammomata}  => q{plural: 'psammomata' --> 'psammomata'};
is noun(q{quartz})->plural,   q{quartzes}  => q{plural: 'quartz' --> 'quartzes'};
is noun(q{quartzes})->plural, q{quartzes}  => q{plural: 'quartzes' --> 'quartzes'};
is noun(q{memento})->plural,   q{mementos}  => q{plural: 'memento' --> 'mementos'};
is noun(q{mementos})->plural, q{mementos}  => q{plural: 'mementos' --> 'mementos'};
is noun(q{zingano})->plural,   q{zingani}  => q{plural: 'zingano' --> 'zingani'};
is noun(q{zingani})->plural, q{zingani}  => q{plural: 'zingani' --> 'zingani'};
is noun(q{xoanon})->plural,   q{xoana}  => q{plural: 'xoanon' --> 'xoana'};
is noun(q{xoana})->plural, q{xoana}  => q{plural: 'xoana' --> 'xoana'};
is noun(q{canaliculus})->plural,   q{canaliculi}  => q{plural: 'canaliculus' --> 'canaliculi'};
is noun(q{canaliculi})->plural, q{canaliculi}  => q{plural: 'canaliculi' --> 'canaliculi'};
is noun(q{mezuza})->plural,   q{mezuzoth}  => q{plural: 'mezuza' --> 'mezuzoth'};
is noun(q{mezuzoth})->plural, q{mezuzoth}  => q{plural: 'mezuzoth' --> 'mezuzoth'};
is noun(q{ax})->plural,   q{axes}  => q{plural: 'ax' --> 'axes'};
is noun(q{axes})->plural, q{axes}  => q{plural: 'axes' --> 'axes'};
is noun(q{apparatus})->plural,   q{apparatuses}  => q{plural: 'apparatus' --> 'apparatuses'};
is noun(q{apparatuses})->plural, q{apparatuses}  => q{plural: 'apparatuses' --> 'apparatuses'};
is noun(q{punctum})->plural,   q{puncta}  => q{plural: 'punctum' --> 'puncta'};
is noun(q{puncta})->plural, q{puncta}  => q{plural: 'puncta' --> 'puncta'};
is noun(q{alga})->plural,   q{algae}  => q{plural: 'alga' --> 'algae'};
is noun(q{algae})->plural, q{algae}  => q{plural: 'algae' --> 'algae'};
is noun(q{his})->plural,   q{theirs}  => q{plural: 'his' --> 'theirs'};
is noun(q{flatfoot})->plural,   q{flatfoots}  => q{plural: 'flatfoot' --> 'flatfoots'};
is noun(q{flatfoots})->plural, q{flatfoots}  => q{plural: 'flatfoots' --> 'flatfoots'};
is noun(q{varella})->plural,   q{varellaes}  => q{plural: 'varella' --> 'varellaes'};
is noun(q{varellaes})->plural, q{varellaes}  => q{plural: 'varellaes' --> 'varellaes'};
is noun(q{carabiniere})->plural,   q{carabinieri}  => q{plural: 'carabiniere' --> 'carabinieri'};
is noun(q{carabinieri})->plural, q{carabinieri}  => q{plural: 'carabinieri' --> 'carabinieri'};
is noun(q{zloty})->plural,   q{zlotys}  => q{plural: 'zloty' --> 'zlotys'};
is noun(q{zlotys})->plural, q{zlotys}  => q{plural: 'zlotys' --> 'zlotys'};
is noun(q{lemma})->plural,   q{lemmas}  => q{plural: 'lemma' --> 'lemmas'};
is noun(q{lemmas})->plural, q{lemmas}  => q{plural: 'lemmas' --> 'lemmas'};
is noun(q{subbotnik})->plural,   q{subbotniks}  => q{plural: 'subbotnik' --> 'subbotniks'};
is noun(q{subbotniks})->plural, q{subbotniks}  => q{plural: 'subbotniks' --> 'subbotniks'};
is noun(q{oto})->plural,   q{otos}  => q{plural: 'oto' --> 'otos'};
is noun(q{otos})->plural, q{otos}  => q{plural: 'otos' --> 'otos'};
is noun(q{osmeterium})->plural,   q{osmeteria}  => q{plural: 'osmeterium' --> 'osmeteria'};
is noun(q{osmeteria})->plural, q{osmeteria}  => q{plural: 'osmeteria' --> 'osmeteria'};
is noun(q{nephridium})->plural,   q{nephridia}  => q{plural: 'nephridium' --> 'nephridia'};
is noun(q{nephridia})->plural, q{nephridia}  => q{plural: 'nephridia' --> 'nephridia'};
is noun(q{clavula})->plural,   q{clavulae}  => q{plural: 'clavula' --> 'clavulae'};
is noun(q{clavulae})->plural, q{clavulae}  => q{plural: 'clavulae' --> 'clavulae'};
is noun(q{romanze})->plural,   q{romanzen}  => q{plural: 'romanze' --> 'romanzen'};
is noun(q{romanzen})->plural, q{romanzen}  => q{plural: 'romanzen' --> 'romanzen'};
is noun(q{scherzo})->plural,   q{scherzos}  => q{plural: 'scherzo' --> 'scherzos'};
is noun(q{scherzos})->plural, q{scherzos}  => q{plural: 'scherzos' --> 'scherzos'};
is noun(q{wanderjahr})->plural,   q{wanderjahre}  => q{plural: 'wanderjahr' --> 'wanderjahre'};
is noun(q{wanderjahre})->plural, q{wanderjahre}  => q{plural: 'wanderjahre' --> 'wanderjahre'};
is noun(q{explanandum})->plural,   q{explananda}  => q{plural: 'explanandum' --> 'explananda'};
is noun(q{explananda})->plural, q{explananda}  => q{plural: 'explananda' --> 'explananda'};
is noun(q{radiale})->plural,   q{radialia}  => q{plural: 'radiale' --> 'radialia'};
is noun(q{radialia})->plural, q{radialia}  => q{plural: 'radialia' --> 'radialia'};
is noun(q{cognoscente})->plural,   q{cognoscenti}  => q{plural: 'cognoscente' --> 'cognoscenti'};
is noun(q{cognoscenti})->plural, q{cognoscenti}  => q{plural: 'cognoscenti' --> 'cognoscenti'};
is noun(q{meningioma})->plural,   q{meningiomas}  => q{plural: 'meningioma' --> 'meningiomas'};
is noun(q{meningiomas})->plural, q{meningiomas}  => q{plural: 'meningiomas' --> 'meningiomas'};
is noun(q{ramus})->plural,   q{rami}  => q{plural: 'ramus' --> 'rami'};
is noun(q{rami})->plural, q{rami}  => q{plural: 'rami' --> 'rami'};
is noun(q{gymnotus})->plural,   q{gymnoti}  => q{plural: 'gymnotus' --> 'gymnoti'};
is noun(q{gymnoti})->plural, q{gymnoti}  => q{plural: 'gymnoti' --> 'gymnoti'};
is noun(q{nachtlokal})->plural,   q{nachtlokale}  => q{plural: 'nachtlokal' --> 'nachtlokale'};
is noun(q{nachtlokale})->plural, q{nachtlokale}  => q{plural: 'nachtlokale' --> 'nachtlokale'};
is noun(q{stamen})->plural,   q{stamen}  => q{plural: 'stamen' --> 'stamen'};
is noun(q{strobilus})->plural,   q{strobili}  => q{plural: 'strobilus' --> 'strobili'};
is noun(q{strobili})->plural, q{strobili}  => q{plural: 'strobili' --> 'strobili'};
is noun(q{mixolimnion})->plural,   q{mixolimnia}  => q{plural: 'mixolimnion' --> 'mixolimnia'};
is noun(q{mixolimnia})->plural, q{mixolimnia}  => q{plural: 'mixolimnia' --> 'mixolimnia'};
is noun(q{go})->plural,   q{goes}  => q{plural: 'go' --> 'goes'};
is noun(q{goes})->plural, q{goes}  => q{plural: 'goes' --> 'goes'};
is noun(q{nimbus})->plural,   q{nimbuses}  => q{plural: 'nimbus' --> 'nimbuses'};
is noun(q{nimbuses})->plural, q{nimbuses}  => q{plural: 'nimbuses' --> 'nimbuses'};
is noun(q{optimum})->plural,   q{optimums}  => q{plural: 'optimum' --> 'optimums'};
is noun(q{optimums})->plural, q{optimums}  => q{plural: 'optimums' --> 'optimums'};
is noun(q{confluvium})->plural,   q{confluvia}  => q{plural: 'confluvium' --> 'confluvia'};
is noun(q{confluvia})->plural, q{confluvia}  => q{plural: 'confluvia' --> 'confluvia'};
is noun(q{micrococcus})->plural,   q{micrococci}  => q{plural: 'micrococcus' --> 'micrococci'};
is noun(q{micrococci})->plural, q{micrococci}  => q{plural: 'micrococci' --> 'micrococci'};
is noun(q{satelles})->plural,   q{satellites}  => q{plural: 'satelles' --> 'satellites'};
is noun(q{satellites})->plural, q{satellites}  => q{plural: 'satellites' --> 'satellites'};
is noun(q{salpa})->plural,   q{salpas}  => q{plural: 'salpa' --> 'salpas'};
is noun(q{salpas})->plural, q{salpas}  => q{plural: 'salpas' --> 'salpas'};
is noun(q{kilo})->plural,   q{kilos}  => q{plural: 'kilo' --> 'kilos'};
is noun(q{kilos})->plural, q{kilos}  => q{plural: 'kilos' --> 'kilos'};
is noun(q{sequestrum})->plural,   q{sequestra}  => q{plural: 'sequestrum' --> 'sequestra'};
is noun(q{sequestra})->plural, q{sequestra}  => q{plural: 'sequestra' --> 'sequestra'};
is noun(q{Togo})->plural,   q{Togos}  => q{plural: 'Togo' --> 'Togos'};
is noun(q{Togos})->plural, q{Togos}  => q{plural: 'Togos' --> 'Togos'};
is noun(q{prytanis})->plural,   q{prytanes}  => q{plural: 'prytanis' --> 'prytanes'};
is noun(q{prytanes})->plural, q{prytanes}  => q{plural: 'prytanes' --> 'prytanes'};
is noun(q{antiserum})->plural,   q{antisera}  => q{plural: 'antiserum' --> 'antisera'};
is noun(q{antisera})->plural, q{antisera}  => q{plural: 'antisera' --> 'antisera'};
is noun(q{caribou})->plural,   q{caribous}  => q{plural: 'caribou' --> 'caribous'};
is noun(q{caribous})->plural, q{caribous}  => q{plural: 'caribous' --> 'caribous'};
is noun(q{amoeba})->plural,   q{amoebas}  => q{plural: 'amoeba' --> 'amoebas'};
is noun(q{amoebas})->plural, q{amoebas}  => q{plural: 'amoebas' --> 'amoebas'};
is noun(q{manubrium})->plural,   q{manubriums}  => q{plural: 'manubrium' --> 'manubriums'};
is noun(q{manubriums})->plural, q{manubriums}  => q{plural: 'manubriums' --> 'manubriums'};
is noun(q{didymis})->plural,   q{didymes}  => q{plural: 'didymis' --> 'didymes'};
is noun(q{didymes})->plural, q{didymes}  => q{plural: 'didymes' --> 'didymes'};
is noun(q{cherub})->plural,   q{cherubs}  => q{plural: 'cherub' --> 'cherubs'};
is noun(q{cherubs})->plural, q{cherubs}  => q{plural: 'cherubs' --> 'cherubs'};
is noun(q{braccio})->plural,   q{braccia}  => q{plural: 'braccio' --> 'braccia'};
is noun(q{braccia})->plural, q{braccia}  => q{plural: 'braccia' --> 'braccia'};
is noun(q{measles})->plural,   q{measles}  => q{plural: 'measles' --> 'measles'};
is noun(q{cayman})->plural,   q{caymans}  => q{plural: 'cayman' --> 'caymans'};
is noun(q{caymans})->plural, q{caymans}  => q{plural: 'caymans' --> 'caymans'};
is noun(q{Panaman})->plural,   q{Panamans}  => q{plural: 'Panaman' --> 'Panamans'};
is noun(q{Panamans})->plural, q{Panamans}  => q{plural: 'Panamans' --> 'Panamans'};
is noun(q{cyclops})->plural,   q{cyclopses}  => q{plural: 'cyclops' --> 'cyclopses'};
is noun(q{cyclopses})->plural, q{cyclopses}  => q{plural: 'cyclopses' --> 'cyclopses'};
is noun(q{myself})->plural,   q{ourselves}  => q{plural: 'myself' --> 'ourselves'};
is noun(q{ourselves})->plural, q{ourselves}  => q{plural: 'ourselves' --> 'ourselves'};
is noun(q{paraglossa})->plural,   q{paraglossae}  => q{plural: 'paraglossa' --> 'paraglossae'};
is noun(q{paraglossae})->plural, q{paraglossae}  => q{plural: 'paraglossae' --> 'paraglossae'};
is noun(q{monosyllabon})->plural,   q{monosyllaba}  => q{plural: 'monosyllabon' --> 'monosyllaba'};
is noun(q{monosyllaba})->plural, q{monosyllaba}  => q{plural: 'monosyllaba' --> 'monosyllaba'};
is noun(q{gaon})->plural,   q{gaons}  => q{plural: 'gaon' --> 'gaons'};
is noun(q{gaons})->plural, q{gaons}  => q{plural: 'gaons' --> 'gaons'};
is noun(q{four-star general})->plural,   q{four-star generals}  => q{plural: 'four-star general' --> 'four-star generals'};
is noun(q{four-star generals})->plural, q{four-star generals}  => q{plural: 'four-star generals' --> 'four-star generals'};
is noun(q{pseudostoma})->plural,   q{pseudostomata}  => q{plural: 'pseudostoma' --> 'pseudostomata'};
is noun(q{pseudostomata})->plural, q{pseudostomata}  => q{plural: 'pseudostomata' --> 'pseudostomata'};
is noun(q{autostrada})->plural,   q{autostradas}  => q{plural: 'autostrada' --> 'autostradas'};
is noun(q{autostradas})->plural, q{autostradas}  => q{plural: 'autostradas' --> 'autostradas'};
is noun(q{trumeau})->plural,   q{trumeaux}  => q{plural: 'trumeau' --> 'trumeaux'};
is noun(q{trumeaux})->plural, q{trumeaux}  => q{plural: 'trumeaux' --> 'trumeaux'};
is noun(q{apparatchik})->plural,   q{apparatchiks}  => q{plural: 'apparatchik' --> 'apparatchiks'};
is noun(q{apparatchiks})->plural, q{apparatchiks}  => q{plural: 'apparatchiks' --> 'apparatchiks'};
is noun(q{dolphinarium})->plural,   q{dolphinariums}  => q{plural: 'dolphinarium' --> 'dolphinariums'};
is noun(q{dolphinariums})->plural, q{dolphinariums}  => q{plural: 'dolphinariums' --> 'dolphinariums'};
is noun(q{verruca})->plural,   q{verrucae}  => q{plural: 'verruca' --> 'verrucae'};
is noun(q{verrucae})->plural, q{verrucae}  => q{plural: 'verrucae' --> 'verrucae'};
is noun(q{math})->plural,   q{maths}  => q{plural: 'math' --> 'maths'};
is noun(q{maths})->plural, q{maths}  => q{plural: 'maths' --> 'maths'};
is noun(q{uva})->plural,   q{uvae}  => q{plural: 'uva' --> 'uvae'};
is noun(q{uvae})->plural, q{uvae}  => q{plural: 'uvae' --> 'uvae'};
is noun(q{conferva})->plural,   q{confervae}  => q{plural: 'conferva' --> 'confervae'};
is noun(q{confervae})->plural, q{confervae}  => q{plural: 'confervae' --> 'confervae'};
is noun(q{hemangeioma})->plural,   q{hemangeiomas}  => q{plural: 'hemangeioma' --> 'hemangeiomas'};
is noun(q{hemangeiomas})->plural, q{hemangeiomas}  => q{plural: 'hemangeiomas' --> 'hemangeiomas'};
is noun(q{aelf})->plural,   q{aelfe}  => q{plural: 'aelf' --> 'aelfe'};
is noun(q{aelfe})->plural, q{aelfe}  => q{plural: 'aelfe' --> 'aelfe'};
is noun(q{sandr})->plural,   q{sandrs}  => q{plural: 'sandr' --> 'sandrs'};
is noun(q{sandrs})->plural, q{sandrs}  => q{plural: 'sandrs' --> 'sandrs'};
is noun(q{granita})->plural,   q{granite}  => q{plural: 'granita' --> 'granite'};
is noun(q{granite})->plural, q{granite}  => q{plural: 'granite' --> 'granite'};
is noun(q{sertularia})->plural,   q{sertularias}  => q{plural: 'sertularia' --> 'sertularias'};
is noun(q{sertularias})->plural, q{sertularias}  => q{plural: 'sertularias' --> 'sertularias'};
is noun(q{Genoese})->plural,   q{Genoese}  => q{plural: 'Genoese' --> 'Genoese'};
is noun(q{principium})->plural,   q{principia}  => q{plural: 'principium' --> 'principia'};
is noun(q{principia})->plural, q{principia}  => q{plural: 'principia' --> 'principia'};
is noun(q{Goanese})->plural,   q{Goanese}  => q{plural: 'Goanese' --> 'Goanese'};
is noun(q{lebensform})->plural,   q{lebensformen}  => q{plural: 'lebensform' --> 'lebensformen'};
is noun(q{lebensformen})->plural, q{lebensformen}  => q{plural: 'lebensformen' --> 'lebensformen'};
is noun(q{xystus})->plural,   q{xysti}  => q{plural: 'xystus' --> 'xysti'};
is noun(q{xysti})->plural, q{xysti}  => q{plural: 'xysti' --> 'xysti'};
is noun(q{tooth})->plural,   q{teeth}  => q{plural: 'tooth' --> 'teeth'};
is noun(q{teeth})->plural, q{teeth}  => q{plural: 'teeth' --> 'teeth'};
is noun(q{Maracaibo})->plural,   q{Maracaibos}  => q{plural: 'Maracaibo' --> 'Maracaibos'};
is noun(q{Maracaibos})->plural, q{Maracaibos}  => q{plural: 'Maracaibos' --> 'Maracaibos'};
is noun(q{zooea})->plural,   q{zooeae}  => q{plural: 'zooea' --> 'zooeae'};
is noun(q{zooeae})->plural, q{zooeae}  => q{plural: 'zooeae' --> 'zooeae'};
is noun(q{Nankingese})->plural,   q{Nankingese}  => q{plural: 'Nankingese' --> 'Nankingese'};
is noun(q{shaman})->plural,   q{shamans}  => q{plural: 'shaman' --> 'shamans'};
is noun(q{shamans})->plural, q{shamans}  => q{plural: 'shamans' --> 'shamans'};
is noun(q{zemirah})->plural,   q{zemiroth}  => q{plural: 'zemirah' --> 'zemiroth'};
is noun(q{zemiroth})->plural, q{zemiroth}  => q{plural: 'zemiroth' --> 'zemiroth'};
is noun(q{taxis})->plural,   q{taxes}  => q{plural: 'taxis' --> 'taxes'};
is noun(q{taxes})->plural, q{taxes}  => q{plural: 'taxes' --> 'taxes'};
is noun(q{lino})->plural,   q{linos}  => q{plural: 'lino' --> 'linos'};
is noun(q{linos})->plural, q{linos}  => q{plural: 'linos' --> 'linos'};
is noun(q{pteroma})->plural,   q{pteromata}  => q{plural: 'pteroma' --> 'pteromata'};
is noun(q{pteromata})->plural, q{pteromata}  => q{plural: 'pteromata' --> 'pteromata'};
is noun(q{squilla})->plural,   q{squillae}  => q{plural: 'squilla' --> 'squillae'};
is noun(q{squillae})->plural, q{squillae}  => q{plural: 'squillae' --> 'squillae'};
is noun(q{tuberculoma})->plural,   q{tuberculomas}  => q{plural: 'tuberculoma' --> 'tuberculomas'};
is noun(q{tuberculomas})->plural, q{tuberculomas}  => q{plural: 'tuberculomas' --> 'tuberculomas'};
is noun(q{stigmaria})->plural,   q{stigmariae}  => q{plural: 'stigmaria' --> 'stigmariae'};
is noun(q{stigmariae})->plural, q{stigmariae}  => q{plural: 'stigmariae' --> 'stigmariae'};
is noun(q{macacus})->plural,   q{macaci}  => q{plural: 'macacus' --> 'macaci'};
is noun(q{macaci})->plural, q{macaci}  => q{plural: 'macaci' --> 'macaci'};
is noun(q{vallecula})->plural,   q{valleculae}  => q{plural: 'vallecula' --> 'valleculae'};
is noun(q{valleculae})->plural, q{valleculae}  => q{plural: 'valleculae' --> 'valleculae'};
is noun(q{hijinks})->plural,   q{hijinks}  => q{plural: 'hijinks' --> 'hijinks'};
is noun(q{Czech})->plural,   q{Czechs}  => q{plural: 'Czech' --> 'Czechs'};
is noun(q{Czechs})->plural, q{Czechs}  => q{plural: 'Czechs' --> 'Czechs'};
is noun(q{orthoceras})->plural,   q{orthocerata}  => q{plural: 'orthoceras' --> 'orthocerata'};
is noun(q{orthocerata})->plural, q{orthocerata}  => q{plural: 'orthocerata' --> 'orthocerata'};
is noun(q{risotto})->plural,   q{risottos}  => q{plural: 'risotto' --> 'risottos'};
is noun(q{risottos})->plural, q{risottos}  => q{plural: 'risottos' --> 'risottos'};
is noun(q{scandalum magnatum})->plural,   q{scandala magnatum}  => q{plural: 'scandalum magnatum' --> 'scandala magnatum'};
is noun(q{scandala magnatum})->plural, q{scandala magnatum}  => q{plural: 'scandala magnatum' --> 'scandala magnatum'};
is noun(q{pithos})->plural,   q{pithoi}  => q{plural: 'pithos' --> 'pithoi'};
is noun(q{pithoi})->plural, q{pithoi}  => q{plural: 'pithoi' --> 'pithoi'};
is noun(q{syllabus})->plural,   q{syllabuses}  => q{plural: 'syllabus' --> 'syllabuses'};
is noun(q{syllabuses})->plural, q{syllabuses}  => q{plural: 'syllabuses' --> 'syllabuses'};
is noun(q{clitoris})->plural,   q{clitorises}  => q{plural: 'clitoris' --> 'clitorises'};
is noun(q{clitorises})->plural, q{clitorises}  => q{plural: 'clitorises' --> 'clitorises'};
is noun(q{organon})->plural,   q{organa}  => q{plural: 'organon' --> 'organa'};
is noun(q{organa})->plural, q{organa}  => q{plural: 'organa' --> 'organa'};
is noun(q{listeria})->plural,   q{listerias}  => q{plural: 'listeria' --> 'listerias'};
is noun(q{listerias})->plural, q{listerias}  => q{plural: 'listerias' --> 'listerias'};
is noun(q{sum total})->plural,   q{sum totals}  => q{plural: 'sum total' --> 'sum totals'};
is noun(q{sum totals})->plural, q{sum totals}  => q{plural: 'sum totals' --> 'sum totals'};
is noun(q{piscina})->plural,   q{piscinas}  => q{plural: 'piscina' --> 'piscinas'};
is noun(q{piscinas})->plural, q{piscinas}  => q{plural: 'piscinas' --> 'piscinas'};
is noun(q{promerops})->plural,   q{promeropes}  => q{plural: 'promerops' --> 'promeropes'};
is noun(q{promeropes})->plural, q{promeropes}  => q{plural: 'promeropes' --> 'promeropes'};
is noun(q{ ox})->plural,   q{ oxen}  => q{plural: ' ox' --> ' oxen'};
is noun(q{ oxen})->plural, q{ oxen}  => q{plural: ' oxen' --> ' oxen'};
is noun(q{malleolus})->plural,   q{malleoli}  => q{plural: 'malleolus' --> 'malleoli'};
is noun(q{malleoli})->plural, q{malleoli}  => q{plural: 'malleoli' --> 'malleoli'};
is noun(q{crowfoot})->plural,   q{crowfoots}  => q{plural: 'crowfoot' --> 'crowfoots'};
is noun(q{crowfoots})->plural, q{crowfoots}  => q{plural: 'crowfoots' --> 'crowfoots'};
is noun(q{monsignor})->plural,   q{monsignors}  => q{plural: 'monsignor' --> 'monsignors'};
is noun(q{monsignors})->plural, q{monsignors}  => q{plural: 'monsignors' --> 'monsignors'};
is noun(q{capo})->plural,   q{capos}  => q{plural: 'capo' --> 'capos'};
is noun(q{capos})->plural, q{capos}  => q{plural: 'capos' --> 'capos'};
is noun(q{pike})->plural,   q{pikes}  => q{plural: 'pike' --> 'pikes'};
is noun(q{pikes})->plural, q{pikes}  => q{plural: 'pikes' --> 'pikes'};
is noun(q{syrinx})->plural,   q{syrinxes}  => q{plural: 'syrinx' --> 'syrinxes'};
is noun(q{syrinxes})->plural, q{syrinxes}  => q{plural: 'syrinxes' --> 'syrinxes'};
is noun(q{frizz})->plural,   q{frizzes}  => q{plural: 'frizz' --> 'frizzes'};
is noun(q{frizzes})->plural, q{frizzes}  => q{plural: 'frizzes' --> 'frizzes'};
is noun(q{gena})->plural,   q{genae}  => q{plural: 'gena' --> 'genae'};
is noun(q{genae})->plural, q{genae}  => q{plural: 'genae' --> 'genae'};
is noun(q{sinus})->plural,   q{sinuses}  => q{plural: 'sinus' --> 'sinuses'};
is noun(q{sinuses})->plural, q{sinuses}  => q{plural: 'sinuses' --> 'sinuses'};
is noun(q{lymphangioma})->plural,   q{lymphangiomata}  => q{plural: 'lymphangioma' --> 'lymphangiomata'};
is noun(q{lymphangiomata})->plural, q{lymphangiomata}  => q{plural: 'lymphangiomata' --> 'lymphangiomata'};
is noun(q{jazz})->plural,   q{jazzes}  => q{plural: 'jazz' --> 'jazzes'};
is noun(q{jazzes})->plural, q{jazzes}  => q{plural: 'jazzes' --> 'jazzes'};
is noun(q{cornu})->plural,   q{cornua}  => q{plural: 'cornu' --> 'cornua'};
is noun(q{cornua})->plural, q{cornua}  => q{plural: 'cornua' --> 'cornua'};
is noun(q{synusia})->plural,   q{synusiae}  => q{plural: 'synusia' --> 'synusiae'};
is noun(q{synusiae})->plural, q{synusiae}  => q{plural: 'synusiae' --> 'synusiae'};
is noun(q{sphaeridium})->plural,   q{sphaeridia}  => q{plural: 'sphaeridium' --> 'sphaeridia'};
is noun(q{sphaeridia})->plural, q{sphaeridia}  => q{plural: 'sphaeridia' --> 'sphaeridia'};
is noun(q{stomatium})->plural,   q{stomatia}  => q{plural: 'stomatium' --> 'stomatia'};
is noun(q{stomatia})->plural, q{stomatia}  => q{plural: 'stomatia' --> 'stomatia'};
is noun(q{scungille})->plural,   q{scungilli}  => q{plural: 'scungille' --> 'scungilli'};
is noun(q{scungilli})->plural, q{scungilli}  => q{plural: 'scungilli' --> 'scungilli'};
is noun(q{descriptum})->plural,   q{descripta}  => q{plural: 'descriptum' --> 'descripta'};
is noun(q{descripta})->plural, q{descripta}  => q{plural: 'descripta' --> 'descripta'};
is noun(q{axilla})->plural,   q{axillae}  => q{plural: 'axilla' --> 'axillae'};
is noun(q{axillae})->plural, q{axillae}  => q{plural: 'axillae' --> 'axillae'};
is noun(q{tomium})->plural,   q{tomia}  => q{plural: 'tomium' --> 'tomia'};
is noun(q{tomia})->plural, q{tomia}  => q{plural: 'tomia' --> 'tomia'};
is noun(q{ulpan})->plural,   q{ulpanim}  => q{plural: 'ulpan' --> 'ulpanim'};
is noun(q{ulpanim})->plural, q{ulpanim}  => q{plural: 'ulpanim' --> 'ulpanim'};
is noun(q{tondo})->plural,   q{tondi}  => q{plural: 'tondo' --> 'tondi'};
is noun(q{tondi})->plural, q{tondi}  => q{plural: 'tondi' --> 'tondi'};
is noun(q{bon vivant})->plural,   q{bon vivants}  => q{plural: 'bon vivant' --> 'bon vivants'};
is noun(q{bon vivants})->plural, q{bon vivants}  => q{plural: 'bon vivants' --> 'bon vivants'};
is noun(q{precognitum})->plural,   q{precognita}  => q{plural: 'precognitum' --> 'precognita'};
is noun(q{precognita})->plural, q{precognita}  => q{plural: 'precognita' --> 'precognita'};
is noun(q{suprascapula})->plural,   q{suprascapulae}  => q{plural: 'suprascapula' --> 'suprascapulae'};
is noun(q{suprascapulae})->plural, q{suprascapulae}  => q{plural: 'suprascapulae' --> 'suprascapulae'};
is noun(q{sestertium})->plural,   q{sestertia}  => q{plural: 'sestertium' --> 'sestertia'};
is noun(q{sestertia})->plural, q{sestertia}  => q{plural: 'sestertia' --> 'sestertia'};
is noun(q{medusa})->plural,   q{medusas}  => q{plural: 'medusa' --> 'medusas'};
is noun(q{medusas})->plural, q{medusas}  => q{plural: 'medusas' --> 'medusas'};
is noun(q{fanfoot})->plural,   q{fanfoots}  => q{plural: 'fanfoot' --> 'fanfoots'};
is noun(q{fanfoots})->plural, q{fanfoots}  => q{plural: 'fanfoots' --> 'fanfoots'};
is noun(q{uncinus})->plural,   q{uncini}  => q{plural: 'uncinus' --> 'uncini'};
is noun(q{uncini})->plural, q{uncini}  => q{plural: 'uncini' --> 'uncini'};
is noun(q{Porto-Novo})->plural,   q{Porto-Novos}  => q{plural: 'Porto-Novo' --> 'Porto-Novos'};
is noun(q{Porto-Novos})->plural, q{Porto-Novos}  => q{plural: 'Porto-Novos' --> 'Porto-Novos'};
is noun(q{life})->plural,   q{lives}  => q{plural: 'life' --> 'lives'};
is noun(q{lives})->plural, q{lives}  => q{plural: 'lives' --> 'lives'};
is noun(q{fait accompli})->plural,   q{faits accomplis}  => q{plural: 'fait accompli' --> 'faits accomplis'};
is noun(q{faits accomplis})->plural, q{faits accomplis}  => q{plural: 'faits accomplis' --> 'faits accomplis'};
is noun(q{hedron})->plural,   q{hedrons}  => q{plural: 'hedron' --> 'hedrons'};
is noun(q{hedrons})->plural, q{hedrons}  => q{plural: 'hedrons' --> 'hedrons'};
is noun(q{sis})->plural,   q{ses}  => q{plural: 'sis' --> 'ses'};
is noun(q{ses})->plural, q{ses}  => q{plural: 'ses' --> 'ses'};
is noun(q{sacculus})->plural,   q{sacculi}  => q{plural: 'sacculus' --> 'sacculi'};
is noun(q{sacculi})->plural, q{sacculi}  => q{plural: 'sacculi' --> 'sacculi'};
is noun(q{pyla})->plural,   q{pylae}  => q{plural: 'pyla' --> 'pylae'};
is noun(q{pylae})->plural, q{pylae}  => q{plural: 'pylae' --> 'pylae'};
is noun(q{stucco})->plural,   q{stuccos}  => q{plural: 'stucco' --> 'stuccos'};
is noun(q{stuccos})->plural, q{stuccos}  => q{plural: 'stuccos' --> 'stuccos'};
is noun(q{papilloma})->plural,   q{papillomata}  => q{plural: 'papilloma' --> 'papillomata'};
is noun(q{papillomata})->plural, q{papillomata}  => q{plural: 'papillomata' --> 'papillomata'};
is noun(q{loculus})->plural,   q{loculi}  => q{plural: 'loculus' --> 'loculi'};
is noun(q{loculi})->plural, q{loculi}  => q{plural: 'loculi' --> 'loculi'};
is noun(q{poncho})->plural,   q{ponchos}  => q{plural: 'poncho' --> 'ponchos'};
is noun(q{ponchos})->plural, q{ponchos}  => q{plural: 'ponchos' --> 'ponchos'};
is noun(q{caudex})->plural,   q{caudices}  => q{plural: 'caudex' --> 'caudices'};
is noun(q{caudices})->plural, q{caudices}  => q{plural: 'caudices' --> 'caudices'};
is noun(q{solstitium})->plural,   q{solstitia}  => q{plural: 'solstitium' --> 'solstitia'};
is noun(q{solstitia})->plural, q{solstitia}  => q{plural: 'solstitia' --> 'solstitia'};
is noun(q{macula})->plural,   q{maculas}  => q{plural: 'macula' --> 'maculas'};
is noun(q{maculas})->plural, q{maculas}  => q{plural: 'maculas' --> 'maculas'};
is noun(q{axe})->plural,   q{axes}  => q{plural: 'axe' --> 'axes'};
is noun(q{axes})->plural, q{axes}  => q{plural: 'axes' --> 'axes'};
is noun(q{bordereau})->plural,   q{bordereaux}  => q{plural: 'bordereau' --> 'bordereaux'};
is noun(q{bordereaux})->plural, q{bordereaux}  => q{plural: 'bordereaux' --> 'bordereaux'};
is noun(q{Bolognese})->plural,   q{Bolognese}  => q{plural: 'Bolognese' --> 'Bolognese'};
is noun(q{voorbok})->plural,   q{voorbokke}  => q{plural: 'voorbok' --> 'voorbokke'};
is noun(q{voorbokke})->plural, q{voorbokke}  => q{plural: 'voorbokke' --> 'voorbokke'};
is noun(q{two-star general})->plural,   q{two-star generals}  => q{plural: 'two-star general' --> 'two-star generals'};
is noun(q{two-star generals})->plural, q{two-star generals}  => q{plural: 'two-star generals' --> 'two-star generals'};
is noun(q{non ens})->plural,   q{nonentia}  => q{plural: 'non ens' --> 'nonentia'};
is noun(q{nonentia})->plural, q{nonentia}  => q{plural: 'nonentia' --> 'nonentia'};
is noun(q{vermiculus})->plural,   q{vermiculi}  => q{plural: 'vermiculus' --> 'vermiculi'};
is noun(q{vermiculi})->plural, q{vermiculi}  => q{plural: 'vermiculi' --> 'vermiculi'};
is noun(q{hemi elytrum})->plural,   q{hemi elytra}  => q{plural: 'hemi elytrum' --> 'hemi elytra'};
is noun(q{hemi elytra})->plural, q{hemi elytra}  => q{plural: 'hemi elytra' --> 'hemi elytra'};
is noun(q{felo})->plural,   q{felones}  => q{plural: 'felo' --> 'felones'};
is noun(q{felones})->plural, q{felones}  => q{plural: 'felones' --> 'felones'};
is noun(q{sphex})->plural,   q{spheges}  => q{plural: 'sphex' --> 'spheges'};
is noun(q{spheges})->plural, q{spheges}  => q{plural: 'spheges' --> 'spheges'};
is noun(q{ischium})->plural,   q{ischia}  => q{plural: 'ischium' --> 'ischia'};
is noun(q{ischia})->plural, q{ischia}  => q{plural: 'ischia' --> 'ischia'};
is noun(q{camera obscura})->plural,   q{camera obscuras}  => q{plural: 'camera obscura' --> 'camera obscuras'};
is noun(q{camera obscuras})->plural, q{camera obscuras}  => q{plural: 'camera obscuras' --> 'camera obscuras'};
is noun(q{sacellum})->plural,   q{sacella}  => q{plural: 'sacellum' --> 'sacella'};
is noun(q{sacella})->plural, q{sacella}  => q{plural: 'sacella' --> 'sacella'};
is noun(q{cleithrum})->plural,   q{cleithra}  => q{plural: 'cleithrum' --> 'cleithra'};
is noun(q{cleithra})->plural, q{cleithra}  => q{plural: 'cleithra' --> 'cleithra'};
is noun(q{conidium})->plural,   q{conidia}  => q{plural: 'conidium' --> 'conidia'};
is noun(q{conidia})->plural, q{conidia}  => q{plural: 'conidia' --> 'conidia'};
is noun(q{strambotto})->plural,   q{strambotti}  => q{plural: 'strambotto' --> 'strambotti'};
is noun(q{strambotti})->plural, q{strambotti}  => q{plural: 'strambotti' --> 'strambotti'};
is noun(q{squadrist})->plural,   q{squadrists}  => q{plural: 'squadrist' --> 'squadrists'};
is noun(q{squadrists})->plural, q{squadrists}  => q{plural: 'squadrists' --> 'squadrists'};
is noun(q{ogle})->plural,   q{oglys}  => q{plural: 'ogle' --> 'oglys'};
is noun(q{oglys})->plural, q{oglys}  => q{plural: 'oglys' --> 'oglys'};
is noun(q{fauna})->plural,   q{faunas}  => q{plural: 'fauna' --> 'faunas'};
is noun(q{faunas})->plural, q{faunas}  => q{plural: 'faunas' --> 'faunas'};
is noun(q{fibrilla})->plural,   q{fibrillae}  => q{plural: 'fibrilla' --> 'fibrillae'};
is noun(q{fibrillae})->plural, q{fibrillae}  => q{plural: 'fibrillae' --> 'fibrillae'};
is noun(q{Kongoese})->plural,   q{Kongoese}  => q{plural: 'Kongoese' --> 'Kongoese'};
is noun(q{Gabunese})->plural,   q{Gabunese}  => q{plural: 'Gabunese' --> 'Gabunese'};
is noun(q{Faro})->plural,   q{Faros}  => q{plural: 'Faro' --> 'Faros'};
is noun(q{Faros})->plural, q{Faros}  => q{plural: 'Faros' --> 'Faros'};
is noun(q{cul-de-sac})->plural,   q{culs-de-sac}  => q{plural: 'cul-de-sac' --> 'culs-de-sac'};
is noun(q{culs-de-sac})->plural, q{culs-de-sac}  => q{plural: 'culs-de-sac' --> 'culs-de-sac'};
is noun(q{Muranese})->plural,   q{Muranese}  => q{plural: 'Muranese' --> 'Muranese'};
is noun(q{brother})->plural,   q{brothers}  => q{plural: 'brother' --> 'brothers'};
is noun(q{brothers})->plural, q{brothers}  => q{plural: 'brothers' --> 'brothers'};
is noun(q{ephemera})->plural,   q{ephemeras}  => q{plural: 'ephemera' --> 'ephemeras'};
is noun(q{ephemeras})->plural, q{ephemeras}  => q{plural: 'ephemeras' --> 'ephemeras'};
is noun(q{knopper})->plural,   q{knoppers}  => q{plural: 'knopper' --> 'knoppers'};
is noun(q{knoppers})->plural, q{knoppers}  => q{plural: 'knoppers' --> 'knoppers'};
is noun(q{monsignore})->plural,   q{monsignori}  => q{plural: 'monsignore' --> 'monsignori'};
is noun(q{monsignori})->plural, q{monsignori}  => q{plural: 'monsignori' --> 'monsignori'};
is noun(q{milieu interieur})->plural,   q{milieux interieurs}  => q{plural: 'milieu interieur' --> 'milieux interieurs'};
is noun(q{milieux interieurs})->plural, q{milieux interieurs}  => q{plural: 'milieux interieurs' --> 'milieux interieurs'};
is noun(q{man milliner})->plural,   q{man milliners}  => q{plural: 'man milliner' --> 'man milliners'};
is noun(q{man milliners})->plural, q{man milliners}  => q{plural: 'man milliners' --> 'man milliners'};
is noun(q{intermaxilla})->plural,   q{intermaxillae}  => q{plural: 'intermaxilla' --> 'intermaxillae'};
is noun(q{intermaxillae})->plural, q{intermaxillae}  => q{plural: 'intermaxillae' --> 'intermaxillae'};
is noun(q{argumentum})->plural,   q{argumenta}  => q{plural: 'argumentum' --> 'argumenta'};
is noun(q{argumenta})->plural, q{argumenta}  => q{plural: 'argumenta' --> 'argumenta'};
is noun(q{washer up})->plural,   q{washers up}  => q{plural: 'washer up' --> 'washers up'};
is noun(q{washers up})->plural, q{washers up}  => q{plural: 'washers up' --> 'washers up'};
is noun(q{Tacoman})->plural,   q{Tacomans}  => q{plural: 'Tacoman' --> 'Tacomans'};
is noun(q{Tacomans})->plural, q{Tacomans}  => q{plural: 'Tacomans' --> 'Tacomans'};
is noun(q{subsidium})->plural,   q{subsidia}  => q{plural: 'subsidium' --> 'subsidia'};
is noun(q{subsidia})->plural, q{subsidia}  => q{plural: 'subsidia' --> 'subsidia'};
is noun(q{syndendrium})->plural,   q{syndendria}  => q{plural: 'syndendrium' --> 'syndendria'};
is noun(q{syndendria})->plural, q{syndendria}  => q{plural: 'syndendria' --> 'syndendria'};
is noun(q{epidermis})->plural,   q{epidermises}  => q{plural: 'epidermis' --> 'epidermises'};
is noun(q{epidermises})->plural, q{epidermises}  => q{plural: 'epidermises' --> 'epidermises'};
is noun(q{rom})->plural,   q{roms}  => q{plural: 'rom' --> 'roms'};
is noun(q{roms})->plural, q{roms}  => q{plural: 'roms' --> 'roms'};
is noun(q{them})->plural,   q{them}  => q{plural: 'them' --> 'them'};
is noun(q{ricercar})->plural,   q{ricercars}  => q{plural: 'ricercar' --> 'ricercars'};
is noun(q{ricercars})->plural, q{ricercars}  => q{plural: 'ricercars' --> 'ricercars'};
is noun(q{mongoose})->plural,   q{mongooses}  => q{plural: 'mongoose' --> 'mongooses'};
is noun(q{mongooses})->plural, q{mongooses}  => q{plural: 'mongooses' --> 'mongooses'};
is noun(q{Tirolese})->plural,   q{Tirolese}  => q{plural: 'Tirolese' --> 'Tirolese'};
is noun(q{angioma})->plural,   q{angiomata}  => q{plural: 'angioma' --> 'angiomata'};
is noun(q{angiomata})->plural, q{angiomata}  => q{plural: 'angiomata' --> 'angiomata'};
is noun(q{gringo})->plural,   q{gringos}  => q{plural: 'gringo' --> 'gringos'};
is noun(q{gringos})->plural, q{gringos}  => q{plural: 'gringos' --> 'gringos'};
is noun(q{viaticum})->plural,   q{viatica}  => q{plural: 'viaticum' --> 'viatica'};
is noun(q{viatica})->plural, q{viatica}  => q{plural: 'viatica' --> 'viatica'};
is noun(q{rhinophyma})->plural,   q{rhinophymas}  => q{plural: 'rhinophyma' --> 'rhinophymas'};
is noun(q{rhinophymas})->plural, q{rhinophymas}  => q{plural: 'rhinophymas' --> 'rhinophymas'};
is noun(q{porron})->plural,   q{porrons}  => q{plural: 'porron' --> 'porrons'};
is noun(q{porrons})->plural, q{porrons}  => q{plural: 'porrons' --> 'porrons'};
is noun(q{famulus})->plural,   q{famuli}  => q{plural: 'famulus' --> 'famuli'};
is noun(q{famuli})->plural, q{famuli}  => q{plural: 'famuli' --> 'famuli'};
is noun(q{kimono})->plural,   q{kimonos}  => q{plural: 'kimono' --> 'kimonos'};
is noun(q{kimonos})->plural, q{kimonos}  => q{plural: 'kimonos' --> 'kimonos'};
is noun(q{afrit})->plural,   q{afrits}  => q{plural: 'afrit' --> 'afrits'};
is noun(q{afrits})->plural, q{afrits}  => q{plural: 'afrits' --> 'afrits'};
is noun(q{peronium})->plural,   q{peronia}  => q{plural: 'peronium' --> 'peronia'};
is noun(q{peronia})->plural, q{peronia}  => q{plural: 'peronia' --> 'peronia'};
is noun(q{mew})->plural,   q{mews}  => q{plural: 'mew' --> 'mews'};
is noun(q{thyridium})->plural,   q{thyridia}  => q{plural: 'thyridium' --> 'thyridia'};
is noun(q{thyridia})->plural, q{thyridia}  => q{plural: 'thyridia' --> 'thyridia'};
is noun(q{condottiere})->plural,   q{condottieri}  => q{plural: 'condottiere' --> 'condottieri'};
is noun(q{condottieri})->plural, q{condottieri}  => q{plural: 'condottieri' --> 'condottieri'};
is noun(q{nouveau pauvre})->plural,   q{nouvelle pauvre}  => q{plural: 'nouveau pauvre' --> 'nouvelle pauvre'};
is noun(q{nouvelle pauvre})->plural, q{nouvelle pauvre}  => q{plural: 'nouvelle pauvre' --> 'nouvelle pauvre'};
is noun(q{Boto})->plural,   q{Botos}  => q{plural: 'Boto' --> 'Botos'};
is noun(q{Botos})->plural, q{Botos}  => q{plural: 'Botos' --> 'Botos'};
is noun(q{albino})->plural,   q{albinos}  => q{plural: 'albino' --> 'albinos'};
is noun(q{albinos})->plural, q{albinos}  => q{plural: 'albinos' --> 'albinos'};
is noun(q{scutellum})->plural,   q{scutella}  => q{plural: 'scutellum' --> 'scutella'};
is noun(q{scutella})->plural, q{scutella}  => q{plural: 'scutella' --> 'scutella'};
is noun(q{basilica})->plural,   q{basilicas}  => q{plural: 'basilica' --> 'basilicas'};
is noun(q{basilicas})->plural, q{basilicas}  => q{plural: 'basilicas' --> 'basilicas'};
is noun(q{mimosa})->plural,   q{mimosas}  => q{plural: 'mimosa' --> 'mimosas'};
is noun(q{mimosas})->plural, q{mimosas}  => q{plural: 'mimosas' --> 'mimosas'};
is noun(q{Romagnese})->plural,   q{Romagnese}  => q{plural: 'Romagnese' --> 'Romagnese'};
is noun(q{compendium})->plural,   q{compendiums}  => q{plural: 'compendium' --> 'compendiums'};
is noun(q{compendiums})->plural, q{compendiums}  => q{plural: 'compendiums' --> 'compendiums'};
is noun(q{velarium})->plural,   q{velaria}  => q{plural: 'velarium' --> 'velaria'};
is noun(q{velaria})->plural, q{velaria}  => q{plural: 'velaria' --> 'velaria'};
is noun(q{malagma})->plural,   q{malagmata}  => q{plural: 'malagma' --> 'malagmata'};
is noun(q{malagmata})->plural, q{malagmata}  => q{plural: 'malagmata' --> 'malagmata'};
is noun(q{ovolo})->plural,   q{ovoli}  => q{plural: 'ovolo' --> 'ovoli'};
is noun(q{ovoli})->plural, q{ovoli}  => q{plural: 'ovoli' --> 'ovoli'};
is noun(q{Maputo})->plural,   q{Maputos}  => q{plural: 'Maputo' --> 'Maputos'};
is noun(q{Maputos})->plural, q{Maputos}  => q{plural: 'Maputos' --> 'Maputos'};
is noun(q{monas})->plural,   q{monades}  => q{plural: 'monas' --> 'monades'};
is noun(q{monades})->plural, q{monades}  => q{plural: 'monades' --> 'monades'};
is noun(q{matin})->plural,   q{matins}  => q{plural: 'matin' --> 'matins'};
is noun(q{matins})->plural, q{matins}  => q{plural: 'matins' --> 'matins'};
is noun(q{crus})->plural,   q{crura}  => q{plural: 'crus' --> 'crura'};
is noun(q{crura})->plural, q{crura}  => q{plural: 'crura' --> 'crura'};
is noun(q{portiforium})->plural,   q{portiforia}  => q{plural: 'portiforium' --> 'portiforia'};
is noun(q{portiforia})->plural, q{portiforia}  => q{plural: 'portiforia' --> 'portiforia'};
is noun(q{vermicello})->plural,   q{vermicellos}  => q{plural: 'vermicello' --> 'vermicellos'};
is noun(q{vermicellos})->plural, q{vermicellos}  => q{plural: 'vermicellos' --> 'vermicellos'};
is noun(q{Hoosierese})->plural,   q{Hoosierese}  => q{plural: 'Hoosierese' --> 'Hoosierese'};
is noun(q{leproma})->plural,   q{lepromas}  => q{plural: 'leproma' --> 'lepromas'};
is noun(q{lepromas})->plural, q{lepromas}  => q{plural: 'lepromas' --> 'lepromas'};
is noun(q{pinax})->plural,   q{pinaces}  => q{plural: 'pinax' --> 'pinaces'};
is noun(q{pinaces})->plural, q{pinaces}  => q{plural: 'pinaces' --> 'pinaces'};
is noun(q{momentum})->plural,   q{momentums}  => q{plural: 'momentum' --> 'momentums'};
is noun(q{momentums})->plural, q{momentums}  => q{plural: 'momentums' --> 'momentums'};
is noun(q{plateau})->plural,   q{plateaus}  => q{plural: 'plateau' --> 'plateaus'};
is noun(q{plateaus})->plural, q{plateaus}  => q{plural: 'plateaus' --> 'plateaus'};
is noun(q{soshi})->plural,   q{soshi}  => q{plural: 'soshi' --> 'soshi'};
is noun(q{sensillum})->plural,   q{sensilla}  => q{plural: 'sensillum' --> 'sensilla'};
is noun(q{sensilla})->plural, q{sensilla}  => q{plural: 'sensilla' --> 'sensilla'};
is noun(q{politico})->plural,   q{politicos}  => q{plural: 'politico' --> 'politicos'};
is noun(q{politicos})->plural, q{politicos}  => q{plural: 'politicos' --> 'politicos'};
is noun(q{barrico})->plural,   q{barricoes}  => q{plural: 'barrico' --> 'barricoes'};
is noun(q{barricoes})->plural, q{barricoes}  => q{plural: 'barricoes' --> 'barricoes'};
is noun(q{sbirro})->plural,   q{sbirri}  => q{plural: 'sbirro' --> 'sbirri'};
is noun(q{sbirri})->plural, q{sbirri}  => q{plural: 'sbirri' --> 'sbirri'};
is noun(q{cantharus})->plural,   q{canthari}  => q{plural: 'cantharus' --> 'canthari'};
is noun(q{canthari})->plural, q{canthari}  => q{plural: 'canthari' --> 'canthari'};
is noun(q{nucleolonema})->plural,   q{nucleolonemas}  => q{plural: 'nucleolonema' --> 'nucleolonemas'};
is noun(q{nucleolonemas})->plural, q{nucleolonemas}  => q{plural: 'nucleolonemas' --> 'nucleolonemas'};
is noun(q{Hiroshiman})->plural,   q{Hiroshimans}  => q{plural: 'Hiroshiman' --> 'Hiroshimans'};
is noun(q{Hiroshimans})->plural, q{Hiroshimans}  => q{plural: 'Hiroshimans' --> 'Hiroshimans'};
is noun(q{pathos})->plural,   q{pathoses}  => q{plural: 'pathos' --> 'pathoses'};
is noun(q{pathoses})->plural, q{pathoses}  => q{plural: 'pathoses' --> 'pathoses'};
is noun(q{cilantro})->plural,   q{cilantros}  => q{plural: 'cilantro' --> 'cilantros'};
is noun(q{cilantros})->plural, q{cilantros}  => q{plural: 'cilantros' --> 'cilantros'};
is noun(q{telamon})->plural,   q{telamones}  => q{plural: 'telamon' --> 'telamones'};
is noun(q{telamones})->plural, q{telamones}  => q{plural: 'telamones' --> 'telamones'};
is noun(q{platypus})->plural,   q{platypuses}  => q{plural: 'platypus' --> 'platypuses'};
is noun(q{platypuses})->plural, q{platypuses}  => q{plural: 'platypuses' --> 'platypuses'};
is noun(q{imbrex})->plural,   q{imbrices}  => q{plural: 'imbrex' --> 'imbrices'};
is noun(q{imbrices})->plural, q{imbrices}  => q{plural: 'imbrices' --> 'imbrices'};
is noun(q{politbureau})->plural,   q{politbureaus}  => q{plural: 'politbureau' --> 'politbureaus'};
is noun(q{politbureaus})->plural, q{politbureaus}  => q{plural: 'politbureaus' --> 'politbureaus'};
is noun(q{oxymoron})->plural,   q{oxymorons}  => q{plural: 'oxymoron' --> 'oxymorons'};
is noun(q{oxymorons})->plural, q{oxymorons}  => q{plural: 'oxymorons' --> 'oxymorons'};
is noun(q{formula})->plural,   q{formulas}  => q{plural: 'formula' --> 'formulas'};
is noun(q{formulas})->plural, q{formulas}  => q{plural: 'formulas' --> 'formulas'};
is noun(q{apex})->plural,   q{apexes}  => q{plural: 'apex' --> 'apexes'};
is noun(q{apexes})->plural, q{apexes}  => q{plural: 'apexes' --> 'apexes'};
is noun(q{corpusculum})->plural,   q{corpuscula}  => q{plural: 'corpusculum' --> 'corpuscula'};
is noun(q{corpuscula})->plural, q{corpuscula}  => q{plural: 'corpuscula' --> 'corpuscula'};
is noun(q{bongo})->plural,   q{bongos}  => q{plural: 'bongo' --> 'bongos'};
is noun(q{bongos})->plural, q{bongos}  => q{plural: 'bongos' --> 'bongos'};
is noun(q{pharmakos})->plural,   q{pharmakoi}  => q{plural: 'pharmakos' --> 'pharmakoi'};
is noun(q{pharmakoi})->plural, q{pharmakoi}  => q{plural: 'pharmakoi' --> 'pharmakoi'};
is noun(q{pollinarium})->plural,   q{pollinaria}  => q{plural: 'pollinarium' --> 'pollinaria'};
is noun(q{pollinaria})->plural, q{pollinaria}  => q{plural: 'pollinaria' --> 'pollinaria'};
is noun(q{synedrium})->plural,   q{synedria}  => q{plural: 'synedrium' --> 'synedria'};
is noun(q{synedria})->plural, q{synedria}  => q{plural: 'synedria' --> 'synedria'};
is noun(q{embryoma})->plural,   q{embryomata}  => q{plural: 'embryoma' --> 'embryomata'};
is noun(q{embryomata})->plural, q{embryomata}  => q{plural: 'embryomata' --> 'embryomata'};
is noun(q{precis})->plural,   q{precis}  => q{plural: 'precis' --> 'precis'};
is noun(q{stasimon})->plural,   q{stasimons}  => q{plural: 'stasimon' --> 'stasimons'};
is noun(q{stasimons})->plural, q{stasimons}  => q{plural: 'stasimons' --> 'stasimons'};
is noun(q{nse})->plural,   q{nses}  => q{plural: 'nse' --> 'nses'};
is noun(q{nses})->plural, q{nses}  => q{plural: 'nses' --> 'nses'};
is noun(q{fossa})->plural,   q{fossae}  => q{plural: 'fossa' --> 'fossae'};
is noun(q{fossae})->plural, q{fossae}  => q{plural: 'fossae' --> 'fossae'};
is noun(q{tobacco})->plural,   q{tobaccos}  => q{plural: 'tobacco' --> 'tobaccos'};
is noun(q{tobaccos})->plural, q{tobaccos}  => q{plural: 'tobaccos' --> 'tobaccos'};
is noun(q{hamulus})->plural,   q{hamuli}  => q{plural: 'hamulus' --> 'hamuli'};
is noun(q{hamuli})->plural, q{hamuli}  => q{plural: 'hamuli' --> 'hamuli'};
is noun(q{collegium})->plural,   q{collegia}  => q{plural: 'collegium' --> 'collegia'};
is noun(q{collegia})->plural, q{collegia}  => q{plural: 'collegia' --> 'collegia'};
is noun(q{libretto})->plural,   q{librettos}  => q{plural: 'libretto' --> 'librettos'};
is noun(q{librettos})->plural, q{librettos}  => q{plural: 'librettos' --> 'librettos'};
is noun(q{wreath})->plural,   q{wreaths}  => q{plural: 'wreath' --> 'wreaths'};
is noun(q{wreaths})->plural, q{wreaths}  => q{plural: 'wreaths' --> 'wreaths'};
is noun(q{yo-yo})->plural,   q{yo-yos}  => q{plural: 'yo-yo' --> 'yo-yos'};
is noun(q{yo-yos})->plural, q{yo-yos}  => q{plural: 'yo-yos' --> 'yo-yos'};
is noun(q{tenia})->plural,   q{tenias}  => q{plural: 'tenia' --> 'tenias'};
is noun(q{tenias})->plural, q{tenias}  => q{plural: 'tenias' --> 'tenias'};
is noun(q{silo})->plural,   q{silos}  => q{plural: 'silo' --> 'silos'};
is noun(q{silos})->plural, q{silos}  => q{plural: 'silos' --> 'silos'};
is noun(q{snipe})->plural,   q{snipes}  => q{plural: 'snipe' --> 'snipes'};
is noun(q{snipes})->plural, q{snipes}  => q{plural: 'snipes' --> 'snipes'};
is noun(q{mondo})->plural,   q{mondi}  => q{plural: 'mondo' --> 'mondi'};
is noun(q{mondi})->plural, q{mondi}  => q{plural: 'mondi' --> 'mondi'};
is noun(q{basis})->plural,   q{bases}  => q{plural: 'basis' --> 'bases'};
is noun(q{bases})->plural, q{bases}  => q{plural: 'bases' --> 'bases'};
is noun(q{quinquennium})->plural,   q{quinquennia}  => q{plural: 'quinquennium' --> 'quinquennia'};
is noun(q{quinquennia})->plural, q{quinquennia}  => q{plural: 'quinquennia' --> 'quinquennia'};
is noun(q{gonimium})->plural,   q{gonimia}  => q{plural: 'gonimium' --> 'gonimia'};
is noun(q{gonimia})->plural, q{gonimia}  => q{plural: 'gonimia' --> 'gonimia'};
is noun(q{info})->plural,   q{infos}  => q{plural: 'info' --> 'infos'};
is noun(q{infos})->plural, q{infos}  => q{plural: 'infos' --> 'infos'};
is noun(q{coney})->plural,   q{coneys}  => q{plural: 'coney' --> 'coneys'};
is noun(q{coneys})->plural, q{coneys}  => q{plural: 'coneys' --> 'coneys'};
is noun(q{latex})->plural,   q{latexes}  => q{plural: 'latex' --> 'latexes'};
is noun(q{latexes})->plural, q{latexes}  => q{plural: 'latexes' --> 'latexes'};
is noun(q{major general})->plural,   q{major generals}  => q{plural: 'major general' --> 'major generals'};
is noun(q{major generals})->plural, q{major generals}  => q{plural: 'major generals' --> 'major generals'};
is noun(q{motto})->plural,   q{mottos}  => q{plural: 'motto' --> 'mottos'};
is noun(q{mottos})->plural, q{mottos}  => q{plural: 'mottos' --> 'mottos'};
is noun(q{tolkach})->plural,   q{tolkachi}  => q{plural: 'tolkach' --> 'tolkachi'};
is noun(q{tolkachi})->plural, q{tolkachi}  => q{plural: 'tolkachi' --> 'tolkachi'};
is noun(q{corps})->plural,   q{corps}  => q{plural: 'corps' --> 'corps'};
is noun(q{chaeta})->plural,   q{chaetae}  => q{plural: 'chaeta' --> 'chaetae'};
is noun(q{chaetae})->plural, q{chaetae}  => q{plural: 'chaetae' --> 'chaetae'};
is noun(q{hers})->plural,   q{theirs}  => q{plural: 'hers' --> 'theirs'};
is noun(q{whoever})->plural,   q{whoever}  => q{plural: 'whoever' --> 'whoever'};
is noun(q{squadra})->plural,   q{squadre}  => q{plural: 'squadra' --> 'squadre'};
is noun(q{squadre})->plural, q{squadre}  => q{plural: 'squadre' --> 'squadre'};
is noun(q{bias})->plural,   q{biases}  => q{plural: 'bias' --> 'biases'};
is noun(q{biases})->plural, q{biases}  => q{plural: 'biases' --> 'biases'};
is noun(q{Kokako})->plural,   q{Kokakos}  => q{plural: 'Kokako' --> 'Kokakos'};
is noun(q{Kokakos})->plural, q{Kokakos}  => q{plural: 'Kokakos' --> 'Kokakos'};
is noun(q{syllabarium})->plural,   q{syllabaria}  => q{plural: 'syllabarium' --> 'syllabaria'};
is noun(q{syllabaria})->plural, q{syllabaria}  => q{plural: 'syllabaria' --> 'syllabaria'};
is noun(q{succus})->plural,   q{succi}  => q{plural: 'succus' --> 'succi'};
is noun(q{succi})->plural, q{succi}  => q{plural: 'succi' --> 'succi'};
is noun(q{fro})->plural,   q{froes}  => q{plural: 'fro' --> 'froes'};
is noun(q{froes})->plural, q{froes}  => q{plural: 'froes' --> 'froes'};
is noun(q{striatum})->plural,   q{striata}  => q{plural: 'striatum' --> 'striata'};
is noun(q{striata})->plural, q{striata}  => q{plural: 'striata' --> 'striata'};
is noun(q{thorax})->plural,   q{thoraxes}  => q{plural: 'thorax' --> 'thoraxes'};
is noun(q{thoraxes})->plural, q{thoraxes}  => q{plural: 'thoraxes' --> 'thoraxes'};
is noun(q{coagulum})->plural,   q{coagula}  => q{plural: 'coagulum' --> 'coagula'};
is noun(q{coagula})->plural, q{coagula}  => q{plural: 'coagula' --> 'coagula'};
is noun(q{alan})->plural,   q{alans}  => q{plural: 'alan' --> 'alans'};
is noun(q{alans})->plural, q{alans}  => q{plural: 'alans' --> 'alans'};
is noun(q{ganglion})->plural,   q{ganglions}  => q{plural: 'ganglion' --> 'ganglions'};
is noun(q{ganglions})->plural, q{ganglions}  => q{plural: 'ganglions' --> 'ganglions'};
is noun(q{forum})->plural,   q{forums}  => q{plural: 'forum' --> 'forums'};
is noun(q{forums})->plural, q{forums}  => q{plural: 'forums' --> 'forums'};
is noun(q{dentalium})->plural,   q{dentalia}  => q{plural: 'dentalium' --> 'dentalia'};
is noun(q{dentalia})->plural, q{dentalia}  => q{plural: 'dentalia' --> 'dentalia'};
is noun(q{gametangium})->plural,   q{gametangia}  => q{plural: 'gametangium' --> 'gametangia'};
is noun(q{gametangia})->plural, q{gametangia}  => q{plural: 'gametangia' --> 'gametangia'};
is noun(q{kouros})->plural,   q{kouroi}  => q{plural: 'kouros' --> 'kouroi'};
is noun(q{kouroi})->plural, q{kouroi}  => q{plural: 'kouroi' --> 'kouroi'};
is noun(q{shochet})->plural,   q{shochetim}  => q{plural: 'shochet' --> 'shochetim'};
is noun(q{shochetim})->plural, q{shochetim}  => q{plural: 'shochetim' --> 'shochetim'};
is noun(q{propleuron})->plural,   q{propleura}  => q{plural: 'propleuron' --> 'propleura'};
is noun(q{propleura})->plural, q{propleura}  => q{plural: 'propleura' --> 'propleura'};
is noun(q{vestigium})->plural,   q{vestigia}  => q{plural: 'vestigium' --> 'vestigia'};
is noun(q{vestigia})->plural, q{vestigia}  => q{plural: 'vestigia' --> 'vestigia'};
is noun(q{abstractum})->plural,   q{abstracta}  => q{plural: 'abstractum' --> 'abstracta'};
is noun(q{abstracta})->plural, q{abstracta}  => q{plural: 'abstracta' --> 'abstracta'};
is noun(q{nubecula})->plural,   q{nubeculae}  => q{plural: 'nubecula' --> 'nubeculae'};
is noun(q{nubeculae})->plural, q{nubeculae}  => q{plural: 'nubeculae' --> 'nubeculae'};
is noun(q{bersagliere})->plural,   q{bersaglieri}  => q{plural: 'bersagliere' --> 'bersaglieri'};
is noun(q{bersaglieri})->plural, q{bersaglieri}  => q{plural: 'bersaglieri' --> 'bersaglieri'};
is noun(q{psycho})->plural,   q{psychos}  => q{plural: 'psycho' --> 'psychos'};
is noun(q{psychos})->plural, q{psychos}  => q{plural: 'psychos' --> 'psychos'};
is noun(q{syncytium})->plural,   q{syncytia}  => q{plural: 'syncytium' --> 'syncytia'};
is noun(q{syncytia})->plural, q{syncytia}  => q{plural: 'syncytia' --> 'syncytia'};
is noun(q{species})->plural,   q{species}  => q{plural: 'species' --> 'species'};
is noun(q{hyperbaton})->plural,   q{hyperbata}  => q{plural: 'hyperbaton' --> 'hyperbata'};
is noun(q{hyperbata})->plural, q{hyperbata}  => q{plural: 'hyperbata' --> 'hyperbata'};
is noun(q{tragus})->plural,   q{tragi}  => q{plural: 'tragus' --> 'tragi'};
is noun(q{tragi})->plural, q{tragi}  => q{plural: 'tragi' --> 'tragi'};
is noun(q{larnax})->plural,   q{larnakes}  => q{plural: 'larnax' --> 'larnakes'};
is noun(q{larnakes})->plural, q{larnakes}  => q{plural: 'larnakes' --> 'larnakes'};
is noun(q{lacunar})->plural,   q{lacunars}  => q{plural: 'lacunar' --> 'lacunars'};
is noun(q{lacunars})->plural, q{lacunars}  => q{plural: 'lacunars' --> 'lacunars'};
is noun(q{lymphoma})->plural,   q{lymphomas}  => q{plural: 'lymphoma' --> 'lymphomas'};
is noun(q{lymphomas})->plural, q{lymphomas}  => q{plural: 'lymphomas' --> 'lymphomas'};
is noun(q{ovarium})->plural,   q{ovaria}  => q{plural: 'ovarium' --> 'ovaria'};
is noun(q{ovaria})->plural, q{ovaria}  => q{plural: 'ovaria' --> 'ovaria'};
is noun(q{headquarters})->plural,   q{headquarters}  => q{plural: 'headquarters' --> 'headquarters'};
is noun(q{Sikkimese})->plural,   q{Sikkimese}  => q{plural: 'Sikkimese' --> 'Sikkimese'};
is noun(q{vibrato})->plural,   q{vibratos}  => q{plural: 'vibrato' --> 'vibratos'};
is noun(q{vibratos})->plural, q{vibratos}  => q{plural: 'vibratos' --> 'vibratos'};
is noun(q{soma})->plural,   q{somas}  => q{plural: 'soma' --> 'somas'};
is noun(q{somas})->plural, q{somas}  => q{plural: 'somas' --> 'somas'};
is noun(q{synechia})->plural,   q{synechiae}  => q{plural: 'synechia' --> 'synechiae'};
is noun(q{synechiae})->plural, q{synechiae}  => q{plural: 'synechiae' --> 'synechiae'};
is noun(q{castrum})->plural,   q{castra}  => q{plural: 'castrum' --> 'castra'};
is noun(q{castra})->plural, q{castra}  => q{plural: 'castra' --> 'castra'};
is noun(q{suffrutex})->plural,   q{suffrutices}  => q{plural: 'suffrutex' --> 'suffrutices'};
is noun(q{suffrutices})->plural, q{suffrutices}  => q{plural: 'suffrutices' --> 'suffrutices'};
is noun(q{leman})->plural,   q{lemans}  => q{plural: 'leman' --> 'lemans'};
is noun(q{lemans})->plural, q{lemans}  => q{plural: 'lemans' --> 'lemans'};
is noun(q{soredium})->plural,   q{soredia}  => q{plural: 'soredium' --> 'soredia'};
is noun(q{soredia})->plural, q{soredia}  => q{plural: 'soredia' --> 'soredia'};
is noun(q{ox})->plural,   q{oxen}  => q{plural: 'ox' --> 'oxen'};
is noun(q{oxen})->plural, q{oxen}  => q{plural: 'oxen' --> 'oxen'};
is noun(q{lar})->plural,   q{lars}  => q{plural: 'lar' --> 'lars'};
is noun(q{lars})->plural, q{lars}  => q{plural: 'lars' --> 'lars'};
is noun(q{charisma})->plural,   q{charismas}  => q{plural: 'charisma' --> 'charismas'};
is noun(q{charismas})->plural, q{charismas}  => q{plural: 'charismas' --> 'charismas'};
is noun(q{synedrion})->plural,   q{synedria}  => q{plural: 'synedrion' --> 'synedria'};
is noun(q{synedria})->plural, q{synedria}  => q{plural: 'synedria' --> 'synedria'};
is noun(q{pulsellum})->plural,   q{pulsella}  => q{plural: 'pulsellum' --> 'pulsella'};
is noun(q{pulsella})->plural, q{pulsella}  => q{plural: 'pulsella' --> 'pulsella'};
is noun(q{nexus})->plural,   q{nexuses}  => q{plural: 'nexus' --> 'nexuses'};
is noun(q{nexuses})->plural, q{nexuses}  => q{plural: 'nexuses' --> 'nexuses'};
is noun(q{vasculum})->plural,   q{vasculums}  => q{plural: 'vasculum' --> 'vasculums'};
is noun(q{vasculums})->plural, q{vasculums}  => q{plural: 'vasculums' --> 'vasculums'};
is noun(q{Viennese})->plural,   q{Viennese}  => q{plural: 'Viennese' --> 'Viennese'};
is noun(q{trattoria})->plural,   q{trattorias}  => q{plural: 'trattoria' --> 'trattorias'};
is noun(q{trattorias})->plural, q{trattorias}  => q{plural: 'trattorias' --> 'trattorias'};
is noun(q{mycoplasma})->plural,   q{mycoplasmas}  => q{plural: 'mycoplasma' --> 'mycoplasmas'};
is noun(q{mycoplasmas})->plural, q{mycoplasmas}  => q{plural: 'mycoplasmas' --> 'mycoplasmas'};
is noun(q{hairdo})->plural,   q{hairdos}  => q{plural: 'hairdo' --> 'hairdos'};
is noun(q{hairdos})->plural, q{hairdos}  => q{plural: 'hairdos' --> 'hairdos'};
is noun(q{Lilo})->plural,   q{Lilos}  => q{plural: 'Lilo' --> 'Lilos'};
is noun(q{Lilos})->plural, q{Lilos}  => q{plural: 'Lilos' --> 'Lilos'};
is noun(q{craspedon})->plural,   q{craspeda}  => q{plural: 'craspedon' --> 'craspeda'};
is noun(q{craspeda})->plural, q{craspeda}  => q{plural: 'craspeda' --> 'craspeda'};
is noun(q{lumbago})->plural,   q{lumbagos}  => q{plural: 'lumbago' --> 'lumbagos'};
is noun(q{lumbagos})->plural, q{lumbagos}  => q{plural: 'lumbagos' --> 'lumbagos'};
is noun(q{cladus})->plural,   q{cladi}  => q{plural: 'cladus' --> 'cladi'};
is noun(q{cladi})->plural, q{cladi}  => q{plural: 'cladi' --> 'cladi'};
is noun(q{pro})->plural,   q{pros}  => q{plural: 'pro' --> 'pros'};
is noun(q{pros})->plural, q{pros}  => q{plural: 'pros' --> 'pros'};
is noun(q{metalimnion})->plural,   q{metalimnia}  => q{plural: 'metalimnion' --> 'metalimnia'};
is noun(q{metalimnia})->plural, q{metalimnia}  => q{plural: 'metalimnia' --> 'metalimnia'};
is noun(q{microfiche})->plural,   q{microfiches}  => q{plural: 'microfiche' --> 'microfiches'};
is noun(q{microfiches})->plural, q{microfiches}  => q{plural: 'microfiches' --> 'microfiches'};
is noun(q{herself})->plural,   q{themselves}  => q{plural: 'herself' --> 'themselves'};
is noun(q{impetus})->plural,   q{impetuses}  => q{plural: 'impetus' --> 'impetuses'};
is noun(q{impetuses})->plural, q{impetuses}  => q{plural: 'impetuses' --> 'impetuses'};
is noun(q{glasses})->plural,   q{glasses}  => q{plural: 'glasses' --> 'glasses'};
is noun(q{proscolla})->plural,   q{proscollae}  => q{plural: 'proscolla' --> 'proscollae'};
is noun(q{proscollae})->plural, q{proscollae}  => q{plural: 'proscollae' --> 'proscollae'};
is noun(q{thema})->plural,   q{themata}  => q{plural: 'thema' --> 'themata'};
is noun(q{themata})->plural, q{themata}  => q{plural: 'themata' --> 'themata'};
is noun(q{modus})->plural,   q{moduses}  => q{plural: 'modus' --> 'moduses'};
is noun(q{moduses})->plural, q{moduses}  => q{plural: 'moduses' --> 'moduses'};
is noun(q{vorstellung})->plural,   q{vorstellungen}  => q{plural: 'vorstellung' --> 'vorstellungen'};
is noun(q{vorstellungen})->plural, q{vorstellungen}  => q{plural: 'vorstellungen' --> 'vorstellungen'};
is noun(q{womanchild})->plural,   q{womenchildren}  => q{plural: 'womanchild' --> 'womenchildren'};
is noun(q{womenchildren})->plural, q{womenchildren}  => q{plural: 'womenchildren' --> 'womenchildren'};
is noun(q{foramen})->plural,   q{foramens}  => q{plural: 'foramen' --> 'foramens'};
is noun(q{foramens})->plural, q{foramens}  => q{plural: 'foramens' --> 'foramens'};
is noun(q{oratrix})->plural,   q{oratrices}  => q{plural: 'oratrix' --> 'oratrices'};
is noun(q{oratrices})->plural, q{oratrices}  => q{plural: 'oratrices' --> 'oratrices'};
is noun(q{blues})->plural,   q{blues}  => q{plural: 'blues' --> 'blues'};
is noun(q{lieu})->plural,   q{lieus}  => q{plural: 'lieu' --> 'lieus'};
is noun(q{lieus})->plural, q{lieus}  => q{plural: 'lieus' --> 'lieus'};
is noun(q{pence})->plural,   q{pence}  => q{plural: 'pence' --> 'pence'};
is noun(q{agape})->plural,   q{agapes}  => q{plural: 'agape' --> 'agapes'};
is noun(q{agapes})->plural, q{agapes}  => q{plural: 'agapes' --> 'agapes'};
is noun(q{logion})->plural,   q{logia}  => q{plural: 'logion' --> 'logia'};
is noun(q{logia})->plural, q{logia}  => q{plural: 'logia' --> 'logia'};
is noun(q{pes})->plural,   q{pedes}  => q{plural: 'pes' --> 'pedes'};
is noun(q{pedes})->plural, q{pedes}  => q{plural: 'pedes' --> 'pedes'};
is noun(q{pycnium})->plural,   q{pycnia}  => q{plural: 'pycnium' --> 'pycnia'};
is noun(q{pycnia})->plural, q{pycnia}  => q{plural: 'pycnia' --> 'pycnia'};
is noun(q{miles gloriosus})->plural,   q{milites gloriosi}  => q{plural: 'miles gloriosus' --> 'milites gloriosi'};
is noun(q{milites gloriosi})->plural, q{milites gloriosi}  => q{plural: 'milites gloriosi' --> 'milites gloriosi'};
is noun(q{pycnidium})->plural,   q{pycnidia}  => q{plural: 'pycnidium' --> 'pycnidia'};
is noun(q{pycnidia})->plural, q{pycnidia}  => q{plural: 'pycnidia' --> 'pycnidia'};
is noun(q{syntaxis})->plural,   q{syntaxes}  => q{plural: 'syntaxis' --> 'syntaxes'};
is noun(q{syntaxes})->plural, q{syntaxes}  => q{plural: 'syntaxes' --> 'syntaxes'};
is noun(q{crazia})->plural,   q{crazie}  => q{plural: 'crazia' --> 'crazie'};
is noun(q{crazie})->plural, q{crazie}  => q{plural: 'crazie' --> 'crazie'};
is noun(q{tong})->plural,   q{tongs}  => q{plural: 'tong' --> 'tongs'};
is noun(q{Harlemese})->plural,   q{Harlemese}  => q{plural: 'Harlemese' --> 'Harlemese'};
is noun(q{modelletto})->plural,   q{modelletti}  => q{plural: 'modelletto' --> 'modelletti'};
is noun(q{modelletti})->plural, q{modelletti}  => q{plural: 'modelletti' --> 'modelletti'};
is noun(q{pleurum})->plural,   q{pleura}  => q{plural: 'pleurum' --> 'pleura'};
is noun(q{hake})->plural,   q{hakes}  => q{plural: 'hake' --> 'hakes'};
is noun(q{hakes})->plural, q{hakes}  => q{plural: 'hakes' --> 'hakes'};
is noun(q{Borghese})->plural,   q{Borghese}  => q{plural: 'Borghese' --> 'Borghese'};
is noun(q{calix})->plural,   q{calices}  => q{plural: 'calix' --> 'calices'};
is noun(q{calices})->plural, q{calices}  => q{plural: 'calices' --> 'calices'};
is noun(q{Zibo})->plural,   q{Zibos}  => q{plural: 'Zibo' --> 'Zibos'};
is noun(q{Zibos})->plural, q{Zibos}  => q{plural: 'Zibos' --> 'Zibos'};
is noun(q{thalamus})->plural,   q{thalami}  => q{plural: 'thalamus' --> 'thalami'};
is noun(q{thalami})->plural, q{thalami}  => q{plural: 'thalami' --> 'thalami'};
is noun(q{dace})->plural,   q{daces}  => q{plural: 'dace' --> 'daces'};
is noun(q{daces})->plural, q{daces}  => q{plural: 'daces' --> 'daces'};
is noun(q{its})->plural,   q{theirs}  => q{plural: 'its' --> 'theirs'};
is noun(q{sensoriolum})->plural,   q{sensoriola}  => q{plural: 'sensoriolum' --> 'sensoriola'};
is noun(q{sensoriola})->plural, q{sensoriola}  => q{plural: 'sensoriola' --> 'sensoriola'};
is noun(q{oceanarium})->plural,   q{oceanaria}  => q{plural: 'oceanarium' --> 'oceanaria'};
is noun(q{oceanaria})->plural, q{oceanaria}  => q{plural: 'oceanaria' --> 'oceanaria'};
is noun(q{ichthyosaurus})->plural,   q{ichthyosauri}  => q{plural: 'ichthyosaurus' --> 'ichthyosauri'};
is noun(q{ichthyosauri})->plural, q{ichthyosauri}  => q{plural: 'ichthyosauri' --> 'ichthyosauri'};
is noun(q{scholium})->plural,   q{scholia}  => q{plural: 'scholium' --> 'scholia'};
is noun(q{scholia})->plural, q{scholia}  => q{plural: 'scholia' --> 'scholia'};
is noun(q{cheval-de-bataille})->plural,   q{chevaux-de-bataille}  => q{plural: 'cheval-de-bataille' --> 'chevaux-de-bataille'};
is noun(q{chevaux-de-bataille})->plural, q{chevaux-de-bataille}  => q{plural: 'chevaux-de-bataille' --> 'chevaux-de-bataille'};
is noun(q{cannabis})->plural,   q{cannabises}  => q{plural: 'cannabis' --> 'cannabises'};
is noun(q{cannabises})->plural, q{cannabises}  => q{plural: 'cannabises' --> 'cannabises'};
is noun(q{calzone})->plural,   q{calzones}  => q{plural: 'calzone' --> 'calzones'};
is noun(q{calzones})->plural, q{calzones}  => q{plural: 'calzones' --> 'calzones'};
is noun(q{pycnis})->plural,   q{pycnides}  => q{plural: 'pycnis' --> 'pycnides'};
is noun(q{pycnides})->plural, q{pycnides}  => q{plural: 'pycnides' --> 'pycnides'};
is noun(q{moose})->plural,   q{moose}  => q{plural: 'moose' --> 'moose'};
is noun(q{lacuna})->plural,   q{lacunas}  => q{plural: 'lacuna' --> 'lacunas'};
is noun(q{lacunas})->plural, q{lacunas}  => q{plural: 'lacunas' --> 'lacunas'};
is noun(q{junto})->plural,   q{juntos}  => q{plural: 'junto' --> 'juntos'};
is noun(q{juntos})->plural, q{juntos}  => q{plural: 'juntos' --> 'juntos'};
is noun(q{court martial})->plural,   q{court-martials}  => q{plural: 'court martial' --> 'court-martials'};
is noun(q{court-martials})->plural, q{court-martials}  => q{plural: 'court-martials' --> 'court-martials'};
is noun(q{costa})->plural,   q{costae}  => q{plural: 'costa' --> 'costae'};
is noun(q{costae})->plural, q{costae}  => q{plural: 'costae' --> 'costae'};
is noun(q{toxicum})->plural,   q{toxica}  => q{plural: 'toxicum' --> 'toxica'};
is noun(q{toxica})->plural, q{toxica}  => q{plural: 'toxica' --> 'toxica'};
is noun(q{squalus})->plural,   q{squali}  => q{plural: 'squalus' --> 'squali'};
is noun(q{squali})->plural, q{squali}  => q{plural: 'squali' --> 'squali'};
is noun(q{chou})->plural,   q{choux}  => q{plural: 'chou' --> 'choux'};
is noun(q{choux})->plural, q{choux}  => q{plural: 'choux' --> 'choux'};
is noun(q{silbador})->plural,   q{silbadors}  => q{plural: 'silbador' --> 'silbadors'};
is noun(q{silbadors})->plural, q{silbadors}  => q{plural: 'silbadors' --> 'silbadors'};
is noun(q{curriculum})->plural,   q{curriculums}  => q{plural: 'curriculum' --> 'curriculums'};
is noun(q{curriculums})->plural, q{curriculums}  => q{plural: 'curriculums' --> 'curriculums'};
is noun(q{pliers})->plural,   q{pliers}  => q{plural: 'pliers' --> 'pliers'};
is noun(q{tumulus})->plural,   q{tumuli}  => q{plural: 'tumulus' --> 'tumuli'};
is noun(q{tumuli})->plural, q{tumuli}  => q{plural: 'tumuli' --> 'tumuli'};
is noun(q{kylix})->plural,   q{kylixes}  => q{plural: 'kylix' --> 'kylixes'};
is noun(q{kylixes})->plural, q{kylixes}  => q{plural: 'kylixes' --> 'kylixes'};
is noun(q{yes})->plural,   q{yeses}  => q{plural: 'yes' --> 'yeses'};
is noun(q{yeses})->plural, q{yeses}  => q{plural: 'yeses' --> 'yeses'};
is noun(q{curioso})->plural,   q{curiosos}  => q{plural: 'curioso' --> 'curiosos'};
is noun(q{curiosos})->plural, q{curiosos}  => q{plural: 'curiosos' --> 'curiosos'};
is noun(q{matzah})->plural,   q{matzahs}  => q{plural: 'matzah' --> 'matzahs'};
is noun(q{matzahs})->plural, q{matzahs}  => q{plural: 'matzahs' --> 'matzahs'};
is noun(q{knife})->plural,   q{knives}  => q{plural: 'knife' --> 'knives'};
is noun(q{knives})->plural, q{knives}  => q{plural: 'knives' --> 'knives'};
is noun(q{craspedum})->plural,   q{craspeda}  => q{plural: 'craspedum' --> 'craspeda'};
is noun(q{craspeda})->plural, q{craspeda}  => q{plural: 'craspeda' --> 'craspeda'};
is noun(q{pimento})->plural,   q{pimentos}  => q{plural: 'pimento' --> 'pimentos'};
is noun(q{pimentos})->plural, q{pimentos}  => q{plural: 'pimentos' --> 'pimentos'};
is noun(q{graffiti})->plural,   q{graffiti}  => q{plural: 'graffiti' --> 'graffiti'};
is noun(q{sum-total})->plural,   q{sum-totals}  => q{plural: 'sum-total' --> 'sum-totals'};
is noun(q{sum-totals})->plural, q{sum-totals}  => q{plural: 'sum-totals' --> 'sum-totals'};
is noun(q{Silurus})->plural,   q{Siluri}  => q{plural: 'Silurus' --> 'Siluri'};
is noun(q{Siluri})->plural, q{Siluri}  => q{plural: 'Siluri' --> 'Siluri'};
is noun(q{naya paisa})->plural,   q{naye paise}  => q{plural: 'naya paisa' --> 'naye paise'};
is noun(q{naye paise})->plural, q{naye paise}  => q{plural: 'naye paise' --> 'naye paise'};
is noun(q{fly})->plural,   q{flies}  => q{plural: 'fly' --> 'flies'};
is noun(q{flies})->plural, q{flies}  => q{plural: 'flies' --> 'flies'};
is noun(q{bandeau})->plural,   q{bandeaux}  => q{plural: 'bandeau' --> 'bandeaux'};
is noun(q{bandeaux})->plural, q{bandeaux}  => q{plural: 'bandeaux' --> 'bandeaux'};
is noun(q{pernio})->plural,   q{perniones}  => q{plural: 'pernio' --> 'perniones'};
is noun(q{perniones})->plural, q{perniones}  => q{plural: 'perniones' --> 'perniones'};
is noun(q{exencephalus})->plural,   q{exencephali}  => q{plural: 'exencephalus' --> 'exencephali'};
is noun(q{exencephali})->plural, q{exencephali}  => q{plural: 'exencephali' --> 'exencephali'};
is noun(q{tempo})->plural,   q{tempos}  => q{plural: 'tempo' --> 'tempos'};
is noun(q{tempos})->plural, q{tempos}  => q{plural: 'tempos' --> 'tempos'};
is noun(q{Paramaribo})->plural,   q{Paramaribos}  => q{plural: 'Paramaribo' --> 'Paramaribos'};
is noun(q{Paramaribos})->plural, q{Paramaribos}  => q{plural: 'Paramaribos' --> 'Paramaribos'};
is noun(q{nomisma})->plural,   q{nomismata}  => q{plural: 'nomisma' --> 'nomismata'};
is noun(q{nomismata})->plural, q{nomismata}  => q{plural: 'nomismata' --> 'nomismata'};
is noun(q{rond de jambe})->plural,   q{rond de jambes}  => q{plural: 'rond de jambe' --> 'rond de jambes'};
is noun(q{rond de jambes})->plural, q{rond de jambes}  => q{plural: 'rond de jambes' --> 'rond de jambes'};
is noun(q{Londonese})->plural,   q{Londonese}  => q{plural: 'Londonese' --> 'Londonese'};
is noun(q{malleus})->plural,   q{mallei}  => q{plural: 'malleus' --> 'mallei'};
is noun(q{mallei})->plural, q{mallei}  => q{plural: 'mallei' --> 'mallei'};
is noun(q{gmina})->plural,   q{gminy}  => q{plural: 'gmina' --> 'gminy'};
is noun(q{gminy})->plural, q{gminy}  => q{plural: 'gminy' --> 'gminy'};
is noun(q{bon mot})->plural,   q{bon mots}  => q{plural: 'bon mot' --> 'bon mots'};
is noun(q{bon mots})->plural, q{bon mots}  => q{plural: 'bon mots' --> 'bon mots'};
is noun(q{mousetrap})->plural,   q{mousetraps}  => q{plural: 'mousetrap' --> 'mousetraps'};
is noun(q{mousetraps})->plural, q{mousetraps}  => q{plural: 'mousetraps' --> 'mousetraps'};
is noun(q{sachverhalt})->plural,   q{sachverhalte}  => q{plural: 'sachverhalt' --> 'sachverhalte'};
is noun(q{sachverhalte})->plural, q{sachverhalte}  => q{plural: 'sachverhalte' --> 'sachverhalte'};
is noun(q{rhomboideus})->plural,   q{rhomboidei}  => q{plural: 'rhomboideus' --> 'rhomboidei'};
is noun(q{rhomboidei})->plural, q{rhomboidei}  => q{plural: 'rhomboidei' --> 'rhomboidei'};
is noun(q{sheep})->plural,   q{sheep}  => q{plural: 'sheep' --> 'sheep'};
is noun(q{cercus})->plural,   q{cerci}  => q{plural: 'cercus' --> 'cerci'};
is noun(q{cerci})->plural, q{cerci}  => q{plural: 'cerci' --> 'cerci'};
is noun(q{mono})->plural,   q{monos}  => q{plural: 'mono' --> 'monos'};
is noun(q{monos})->plural, q{monos}  => q{plural: 'monos' --> 'monos'};
is noun(q{paraganglion})->plural,   q{paraganglia}  => q{plural: 'paraganglion' --> 'paraganglia'};
is noun(q{paraganglia})->plural, q{paraganglia}  => q{plural: 'paraganglia' --> 'paraganglia'};
is noun(q{toril})->plural,   q{toriles}  => q{plural: 'toril' --> 'toriles'};
is noun(q{toriles})->plural, q{toriles}  => q{plural: 'toriles' --> 'toriles'};
is noun(q{solarium})->plural,   q{solaria}  => q{plural: 'solarium' --> 'solaria'};
is noun(q{solaria})->plural, q{solaria}  => q{plural: 'solaria' --> 'solaria'};
is noun(q{tenderfoot})->plural,   q{tenderfoots}  => q{plural: 'tenderfoot' --> 'tenderfoots'};
is noun(q{tenderfoots})->plural, q{tenderfoots}  => q{plural: 'tenderfoots' --> 'tenderfoots'};
is noun(q{Yuman})->plural,   q{Yumans}  => q{plural: 'Yuman' --> 'Yumans'};
is noun(q{Yumans})->plural, q{Yumans}  => q{plural: 'Yumans' --> 'Yumans'};
is noun(q{zucca})->plural,   q{zucche}  => q{plural: 'zucca' --> 'zucche'};
is noun(q{zucche})->plural, q{zucche}  => q{plural: 'zucche' --> 'zucche'};
is noun(q{mesothelioma})->plural,   q{mesotheliomas}  => q{plural: 'mesothelioma' --> 'mesotheliomas'};
is noun(q{mesotheliomas})->plural, q{mesotheliomas}  => q{plural: 'mesotheliomas' --> 'mesotheliomas'};
is noun(q{surimono})->plural,   q{surimonos}  => q{plural: 'surimono' --> 'surimonos'};
is noun(q{surimonos})->plural, q{surimonos}  => q{plural: 'surimonos' --> 'surimonos'};
is noun(q{sephardi})->plural,   q{sephardim}  => q{plural: 'sephardi' --> 'sephardim'};
is noun(q{sephardim})->plural, q{sephardim}  => q{plural: 'sephardim' --> 'sephardim'};
is noun(q{propodium})->plural,   q{propodia}  => q{plural: 'propodium' --> 'propodia'};
is noun(q{propodia})->plural, q{propodia}  => q{plural: 'propodia' --> 'propodia'};
is noun(q{maquereau})->plural,   q{maquereaux}  => q{plural: 'maquereau' --> 'maquereaux'};
is noun(q{maquereaux})->plural, q{maquereaux}  => q{plural: 'maquereaux' --> 'maquereaux'};
is noun(q{embryo})->plural,   q{embryos}  => q{plural: 'embryo' --> 'embryos'};
is noun(q{embryos})->plural, q{embryos}  => q{plural: 'embryos' --> 'embryos'};
is noun(q{mycorhiza})->plural,   q{mycorhizas}  => q{plural: 'mycorhiza' --> 'mycorhizas'};
is noun(q{mycorhizas})->plural, q{mycorhizas}  => q{plural: 'mycorhizas' --> 'mycorhizas'};
is noun(q{bacterium})->plural,   q{bacteria}  => q{plural: 'bacterium' --> 'bacteria'};
is noun(q{bacteria})->plural, q{bacteria}  => q{plural: 'bacteria' --> 'bacteria'};
is noun(q{Macassarese})->plural,   q{Macassarese}  => q{plural: 'Macassarese' --> 'Macassarese'};
is noun(q{Ceylonese})->plural,   q{Ceylonese}  => q{plural: 'Ceylonese' --> 'Ceylonese'};
is noun(q{juelet})->plural,   q{iueles}  => q{plural: 'juelet' --> 'iueles'};
is noun(q{iueles})->plural, q{iueles}  => q{plural: 'iueles' --> 'iueles'};
is noun(q{mithraeum})->plural,   q{mithraea}  => q{plural: 'mithraeum' --> 'mithraea'};
is noun(q{mithraea})->plural, q{mithraea}  => q{plural: 'mithraea' --> 'mithraea'};
is noun(q{haustellum})->plural,   q{haustella}  => q{plural: 'haustellum' --> 'haustella'};
is noun(q{haustella})->plural, q{haustella}  => q{plural: 'haustella' --> 'haustella'};
is noun(q{anta})->plural,   q{antae}  => q{plural: 'anta' --> 'antae'};
is noun(q{antae})->plural, q{antae}  => q{plural: 'antae' --> 'antae'};
is noun(q{sphagnum})->plural,   q{sphagnums}  => q{plural: 'sphagnum' --> 'sphagnums'};
is noun(q{sphagnums})->plural, q{sphagnums}  => q{plural: 'sphagnums' --> 'sphagnums'};
is noun(q{ottoman})->plural,   q{ottomans}  => q{plural: 'ottoman' --> 'ottomans'};
is noun(q{ottomans})->plural, q{ottomans}  => q{plural: 'ottomans' --> 'ottomans'};
is noun(q{microbion})->plural,   q{microbia}  => q{plural: 'microbion' --> 'microbia'};
is noun(q{microbia})->plural, q{microbia}  => q{plural: 'microbia' --> 'microbia'};
is noun(q{concerto grosso})->plural,   q{concerti grossi}  => q{plural: 'concerto grosso' --> 'concerti grossi'};
is noun(q{concerti grossi})->plural, q{concerti grossi}  => q{plural: 'concerti grossi' --> 'concerti grossi'};
is noun(q{vorspiel})->plural,   q{vorspiele}  => q{plural: 'vorspiel' --> 'vorspiele'};
is noun(q{vorspiele})->plural, q{vorspiele}  => q{plural: 'vorspiele' --> 'vorspiele'};
is noun(q{ragazzo})->plural,   q{ragazzi}  => q{plural: 'ragazzo' --> 'ragazzi'};
is noun(q{ragazzi})->plural, q{ragazzi}  => q{plural: 'ragazzi' --> 'ragazzi'};
is noun(q{gyro})->plural,   q{gyros}  => q{plural: 'gyro' --> 'gyros'};
is noun(q{gyros})->plural, q{gyros}  => q{plural: 'gyros' --> 'gyros'};
is noun(q{coco})->plural,   q{cocos}  => q{plural: 'coco' --> 'cocos'};
is noun(q{cocos})->plural, q{cocos}  => q{plural: 'cocos' --> 'cocos'};
is noun(q{nympheum})->plural,   q{nymphea}  => q{plural: 'nympheum' --> 'nymphea'};
is noun(q{nymphea})->plural, q{nymphea}  => q{plural: 'nymphea' --> 'nymphea'};
is noun(q{magma})->plural,   q{magmas}  => q{plural: 'magma' --> 'magmas'};
is noun(q{magmas})->plural, q{magmas}  => q{plural: 'magmas' --> 'magmas'};
is noun(q{toxius})->plural,   q{toxii}  => q{plural: 'toxius' --> 'toxii'};
is noun(q{toxii})->plural, q{toxii}  => q{plural: 'toxii' --> 'toxii'};
is noun(q{ri})->plural,   q{ri}  => q{plural: 'ri' --> 'ri'};
is noun(q{rete})->plural,   q{retia}  => q{plural: 'rete' --> 'retia'};
is noun(q{retia})->plural, q{retia}  => q{plural: 'retia' --> 'retia'};
is noun(q{vibraculum})->plural,   q{vibracula}  => q{plural: 'vibraculum' --> 'vibracula'};
is noun(q{vibracula})->plural, q{vibracula}  => q{plural: 'vibracula' --> 'vibracula'};
is noun(q{hormogonium})->plural,   q{hormogonia}  => q{plural: 'hormogonium' --> 'hormogonia'};
is noun(q{hormogonia})->plural, q{hormogonia}  => q{plural: 'hormogonia' --> 'hormogonia'};
is noun(q{scapula})->plural,   q{scapulas}  => q{plural: 'scapula' --> 'scapulas'};
is noun(q{scapulas})->plural, q{scapulas}  => q{plural: 'scapulas' --> 'scapulas'};
is noun(q{hetaera})->plural,   q{hetaerae}  => q{plural: 'hetaera' --> 'hetaerae'};
is noun(q{hetaerae})->plural, q{hetaerae}  => q{plural: 'hetaerae' --> 'hetaerae'};
is noun(q{rhizoma})->plural,   q{rhizomas}  => q{plural: 'rhizoma' --> 'rhizomas'};
is noun(q{rhizomas})->plural, q{rhizomas}  => q{plural: 'rhizomas' --> 'rhizomas'};
is noun(q{melisma})->plural,   q{melismas}  => q{plural: 'melisma' --> 'melismas'};
is noun(q{melismas})->plural, q{melismas}  => q{plural: 'melismas' --> 'melismas'};
is noun(q{individuum})->plural,   q{individuums}  => q{plural: 'individuum' --> 'individuums'};
is noun(q{individuums})->plural, q{individuums}  => q{plural: 'individuums' --> 'individuums'};
is noun(q{Montenegro})->plural,   q{Montenegros}  => q{plural: 'Montenegro' --> 'Montenegros'};
is noun(q{Montenegros})->plural, q{Montenegros}  => q{plural: 'Montenegros' --> 'Montenegros'};
is noun(q{saddo})->plural,   q{saddos}  => q{plural: 'saddo' --> 'saddos'};
is noun(q{saddos})->plural, q{saddos}  => q{plural: 'saddos' --> 'saddos'};
is noun(q{blouse})->plural,   q{blouses}  => q{plural: 'blouse' --> 'blouses'};
is noun(q{blouses})->plural, q{blouses}  => q{plural: 'blouses' --> 'blouses'};
is noun(q{mantelletta})->plural,   q{mantellette}  => q{plural: 'mantelletta' --> 'mantellette'};
is noun(q{mantellette})->plural, q{mantellette}  => q{plural: 'mantellette' --> 'mantellette'};
is noun(q{meniscus})->plural,   q{menisci}  => q{plural: 'meniscus' --> 'menisci'};
is noun(q{menisci})->plural, q{menisci}  => q{plural: 'menisci' --> 'menisci'};
is noun(q{granula})->plural,   q{granulae}  => q{plural: 'granula' --> 'granulae'};
is noun(q{granulae})->plural, q{granulae}  => q{plural: 'granulae' --> 'granulae'};
is noun(q{thyrsus})->plural,   q{thyrsi}  => q{plural: 'thyrsus' --> 'thyrsi'};
is noun(q{thyrsi})->plural, q{thyrsi}  => q{plural: 'thyrsi' --> 'thyrsi'};
is noun(q{faecula})->plural,   q{faeculae}  => q{plural: 'faecula' --> 'faeculae'};
is noun(q{faeculae})->plural, q{faeculae}  => q{plural: 'faeculae' --> 'faeculae'};
is noun(q{Orinoco})->plural,   q{Orinocos}  => q{plural: 'Orinoco' --> 'Orinocos'};
is noun(q{Orinocos})->plural, q{Orinocos}  => q{plural: 'Orinocos' --> 'Orinocos'};
is noun(q{pyrophorus})->plural,   q{pyrophori}  => q{plural: 'pyrophorus' --> 'pyrophori'};
is noun(q{pyrophori})->plural, q{pyrophori}  => q{plural: 'pyrophori' --> 'pyrophori'};
is noun(q{two star general})->plural,   q{two star generals}  => q{plural: 'two star general' --> 'two star generals'};
is noun(q{two star generals})->plural, q{two star generals}  => q{plural: 'two star generals' --> 'two star generals'};
is noun(q{non-ens})->plural,   q{nonentia}  => q{plural: 'non-ens' --> 'nonentia'};
is noun(q{nonentia})->plural, q{nonentia}  => q{plural: 'nonentia' --> 'nonentia'};
is noun(q{chassis})->plural,   q{chassis}  => q{plural: 'chassis' --> 'chassis'};
is noun(q{sensedatum})->plural,   q{sensedata}  => q{plural: 'sensedatum' --> 'sensedata'};
is noun(q{sensedata})->plural, q{sensedata}  => q{plural: 'sensedata' --> 'sensedata'};
is noun(q{devoto})->plural,   q{devotos}  => q{plural: 'devoto' --> 'devotos'};
is noun(q{devotos})->plural, q{devotos}  => q{plural: 'devotos' --> 'devotos'};
is noun(q{striola})->plural,   q{striolae}  => q{plural: 'striola' --> 'striolae'};
is noun(q{striolae})->plural, q{striolae}  => q{plural: 'striolae' --> 'striolae'};
is noun(q{odeum})->plural,   q{odea}  => q{plural: 'odeum' --> 'odea'};
is noun(q{odea})->plural, q{odea}  => q{plural: 'odea' --> 'odea'};
is noun(q{lentiscus})->plural,   q{lentisci}  => q{plural: 'lentiscus' --> 'lentisci'};
is noun(q{lentisci})->plural, q{lentisci}  => q{plural: 'lentisci' --> 'lentisci'};
is noun(q{floccus})->plural,   q{flocci}  => q{plural: 'floccus' --> 'flocci'};
is noun(q{flocci})->plural, q{flocci}  => q{plural: 'flocci' --> 'flocci'};
is noun(q{sirocco})->plural,   q{siroccos}  => q{plural: 'sirocco' --> 'siroccos'};
is noun(q{siroccos})->plural, q{siroccos}  => q{plural: 'siroccos' --> 'siroccos'};
is noun(q{ophiophagus})->plural,   q{ophiophagi}  => q{plural: 'ophiophagus' --> 'ophiophagi'};
is noun(q{ophiophagi})->plural, q{ophiophagi}  => q{plural: 'ophiophagi' --> 'ophiophagi'};
is noun(q{pants})->plural,   q{pants}  => q{plural: 'pants' --> 'pants'};
is noun(q{stomach})->plural,   q{stomachs}  => q{plural: 'stomach' --> 'stomachs'};
is noun(q{stomachs})->plural, q{stomachs}  => q{plural: 'stomachs' --> 'stomachs'};
is noun(q{plexus})->plural,   q{plexuses}  => q{plural: 'plexus' --> 'plexuses'};
is noun(q{plexuses})->plural, q{plexuses}  => q{plural: 'plexuses' --> 'plexuses'};
is noun(q{canzonetta})->plural,   q{canzonettas}  => q{plural: 'canzonetta' --> 'canzonettas'};
is noun(q{canzonettas})->plural, q{canzonettas}  => q{plural: 'canzonettas' --> 'canzonettas'};
is noun(q{pelta})->plural,   q{peltae}  => q{plural: 'pelta' --> 'peltae'};
is noun(q{peltae})->plural, q{peltae}  => q{plural: 'peltae' --> 'peltae'};
is noun(q{shorts})->plural,   q{shorts}  => q{plural: 'shorts' --> 'shorts'};
is noun(q{sporodochium})->plural,   q{sporodochia}  => q{plural: 'sporodochium' --> 'sporodochia'};
is noun(q{sporodochia})->plural, q{sporodochia}  => q{plural: 'sporodochia' --> 'sporodochia'};
is noun(q{pinna})->plural,   q{pinnas}  => q{plural: 'pinna' --> 'pinnas'};
is noun(q{pinnas})->plural, q{pinnas}  => q{plural: 'pinnas' --> 'pinnas'};
is noun(q{poise})->plural,   q{poises}  => q{plural: 'poise' --> 'poises'};
is noun(q{poises})->plural, q{poises}  => q{plural: 'poises' --> 'poises'};
is noun(q{sanctum sanctorum})->plural,   q{sancta sanctorum}  => q{plural: 'sanctum sanctorum' --> 'sancta sanctorum'};
is noun(q{sancta sanctorum})->plural, q{sancta sanctorum}  => q{plural: 'sancta sanctorum' --> 'sancta sanctorum'};
is noun(q{whose})->plural,   q{whose}  => q{plural: 'whose' --> 'whose'};
is noun(q{involucrum})->plural,   q{involucra}  => q{plural: 'involucrum' --> 'involucra'};
is noun(q{involucra})->plural, q{involucra}  => q{plural: 'involucra' --> 'involucra'};
is noun(q{intertrigo})->plural,   q{intertrigos}  => q{plural: 'intertrigo' --> 'intertrigos'};
is noun(q{intertrigos})->plural, q{intertrigos}  => q{plural: 'intertrigos' --> 'intertrigos'};
is noun(q{penni})->plural,   q{pennia}  => q{plural: 'penni' --> 'pennia'};
is noun(q{pennia})->plural, q{pennia}  => q{plural: 'pennia' --> 'pennia'};
is noun(q{incubus})->plural,   q{incubuses}  => q{plural: 'incubus' --> 'incubuses'};
is noun(q{incubuses})->plural, q{incubuses}  => q{plural: 'incubuses' --> 'incubuses'};
is noun(q{sanatorium})->plural,   q{sanatoriums}  => q{plural: 'sanatorium' --> 'sanatoriums'};
is noun(q{sanatoriums})->plural, q{sanatoriums}  => q{plural: 'sanatoriums' --> 'sanatoriums'};
is noun(q{gizmo})->plural,   q{gizmos}  => q{plural: 'gizmo' --> 'gizmos'};
is noun(q{gizmos})->plural, q{gizmos}  => q{plural: 'gizmos' --> 'gizmos'};
is noun(q{wife})->plural,   q{wives}  => q{plural: 'wife' --> 'wives'};
is noun(q{wives})->plural, q{wives}  => q{plural: 'wives' --> 'wives'};
is noun(q{elk})->plural,   q{elks}  => q{plural: 'elk' --> 'elks'};
is noun(q{elks})->plural, q{elks}  => q{plural: 'elks' --> 'elks'};
is noun(q{uterus})->plural,   q{uteruses}  => q{plural: 'uterus' --> 'uteruses'};
is noun(q{uteruses})->plural, q{uteruses}  => q{plural: 'uteruses' --> 'uteruses'};
is noun(q{5 star general})->plural,   q{5 star generals}  => q{plural: '5 star general' --> '5 star generals'};
is noun(q{5 star generals})->plural, q{5 star generals}  => q{plural: '5 star generals' --> '5 star generals'};
is noun(q{parison})->plural,   q{parisa}  => q{plural: 'parison' --> 'parisa'};
is noun(q{parisa})->plural, q{parisa}  => q{plural: 'parisa' --> 'parisa'};
is noun(q{manifesto})->plural,   q{manifestos}  => q{plural: 'manifesto' --> 'manifestos'};
is noun(q{manifestos})->plural, q{manifestos}  => q{plural: 'manifestos' --> 'manifestos'};
is noun(q{enema})->plural,   q{enemas}  => q{plural: 'enema' --> 'enemas'};
is noun(q{enemas})->plural, q{enemas}  => q{plural: 'enemas' --> 'enemas'};
is noun(q{prolegomenon})->plural,   q{prolegomena}  => q{plural: 'prolegomenon' --> 'prolegomena'};
is noun(q{prolegomena})->plural, q{prolegomena}  => q{plural: 'prolegomena' --> 'prolegomena'};
is noun(q{planctus})->plural,   q{planctus}  => q{plural: 'planctus' --> 'planctus'};
is noun(q{sezession})->plural,   q{sezessionen}  => q{plural: 'sezession' --> 'sezessionen'};
is noun(q{sezessionen})->plural, q{sezessionen}  => q{plural: 'sezessionen' --> 'sezessionen'};
is noun(q{lingo})->plural,   q{lingos}  => q{plural: 'lingo' --> 'lingos'};
is noun(q{lingos})->plural, q{lingos}  => q{plural: 'lingos' --> 'lingos'};
is noun(q{vesicula})->plural,   q{vesiculae}  => q{plural: 'vesicula' --> 'vesiculae'};
is noun(q{vesiculae})->plural, q{vesiculae}  => q{plural: 'vesiculae' --> 'vesiculae'};
is noun(q{mackerel})->plural,   q{mackerels}  => q{plural: 'mackerel' --> 'mackerels'};
is noun(q{mackerels})->plural, q{mackerels}  => q{plural: 'mackerels' --> 'mackerels'};
is noun(q{cubiculum})->plural,   q{cubicula}  => q{plural: 'cubiculum' --> 'cubicula'};
is noun(q{cubicula})->plural, q{cubicula}  => q{plural: 'cubicula' --> 'cubicula'};
is noun(q{contagium})->plural,   q{contagia}  => q{plural: 'contagium' --> 'contagia'};
is noun(q{contagia})->plural, q{contagia}  => q{plural: 'contagia' --> 'contagia'};
is noun(q{Idaho})->plural,   q{Idahos}  => q{plural: 'Idaho' --> 'Idahos'};
is noun(q{Idahos})->plural, q{Idahos}  => q{plural: 'Idahos' --> 'Idahos'};
is noun(q{pendulum})->plural,   q{pendulums}  => q{plural: 'pendulum' --> 'pendulums'};
is noun(q{pendulums})->plural, q{pendulums}  => q{plural: 'pendulums' --> 'pendulums'};
is noun(q{explicandum})->plural,   q{explicanda}  => q{plural: 'explicandum' --> 'explicanda'};
is noun(q{explicanda})->plural, q{explicanda}  => q{plural: 'explicanda' --> 'explicanda'};
is noun(q{globigerina})->plural,   q{globigerinae}  => q{plural: 'globigerina' --> 'globigerinae'};
is noun(q{globigerinae})->plural, q{globigerinae}  => q{plural: 'globigerinae' --> 'globigerinae'};
is noun(q{reich})->plural,   q{reiche}  => q{plural: 'reich' --> 'reiche'};
is noun(q{reiche})->plural, q{reiche}  => q{plural: 'reiche' --> 'reiche'};
is noun(q{vaalpens})->plural,   q{vaalpens}  => q{plural: 'vaalpens' --> 'vaalpens'};
is noun(q{bursitis})->plural,   q{bursitises}  => q{plural: 'bursitis' --> 'bursitises'};
is noun(q{bursitises})->plural, q{bursitises}  => q{plural: 'bursitises' --> 'bursitises'};
is noun(q{zoaea})->plural,   q{zoaeae}  => q{plural: 'zoaea' --> 'zoaeae'};
is noun(q{zoaeae})->plural, q{zoaeae}  => q{plural: 'zoaeae' --> 'zoaeae'};
is noun(q{guy})->plural,   q{guys}  => q{plural: 'guy' --> 'guys'};
is noun(q{guys})->plural, q{guys}  => q{plural: 'guys' --> 'guys'};
is noun(q{cul de four})->plural,   q{culs de four}  => q{plural: 'cul de four' --> 'culs de four'};
is noun(q{culs de four})->plural, q{culs de four}  => q{plural: 'culs de four' --> 'culs de four'};
is noun(q{pogo})->plural,   q{pogos}  => q{plural: 'pogo' --> 'pogos'};
is noun(q{pogos})->plural, q{pogos}  => q{plural: 'pogos' --> 'pogos'};
is noun(q{noumenon})->plural,   q{noumena}  => q{plural: 'noumenon' --> 'noumena'};
is noun(q{noumena})->plural, q{noumena}  => q{plural: 'noumena' --> 'noumena'};
is noun(q{legomenon})->plural,   q{legomena}  => q{plural: 'legomenon' --> 'legomena'};
is noun(q{legomena})->plural, q{legomena}  => q{plural: 'legomena' --> 'legomena'};
is noun(q{ommatidium})->plural,   q{ommatidia}  => q{plural: 'ommatidium' --> 'ommatidia'};
is noun(q{ommatidia})->plural, q{ommatidia}  => q{plural: 'ommatidia' --> 'ommatidia'};
is noun(q{Faroese})->plural,   q{Faroese}  => q{plural: 'Faroese' --> 'Faroese'};
is noun(q{spadix})->plural,   q{spadixes}  => q{plural: 'spadix' --> 'spadixes'};
is noun(q{spadixes})->plural, q{spadixes}  => q{plural: 'spadixes' --> 'spadixes'};
is noun(q{replum})->plural,   q{repla}  => q{plural: 'replum' --> 'repla'};
is noun(q{repla})->plural, q{repla}  => q{plural: 'repla' --> 'repla'};
is noun(q{sipunculus})->plural,   q{sipunculi}  => q{plural: 'sipunculus' --> 'sipunculi'};
is noun(q{sipunculi})->plural, q{sipunculi}  => q{plural: 'sipunculi' --> 'sipunculi'};
is noun(q{cynocephalus})->plural,   q{cynocephali}  => q{plural: 'cynocephalus' --> 'cynocephali'};
is noun(q{cynocephali})->plural, q{cynocephali}  => q{plural: 'cynocephali' --> 'cynocephali'};
is noun(q{anthodium})->plural,   q{anthodia}  => q{plural: 'anthodium' --> 'anthodia'};
is noun(q{anthodia})->plural, q{anthodia}  => q{plural: 'anthodia' --> 'anthodia'};
is noun(q{bursa})->plural,   q{bursae}  => q{plural: 'bursa' --> 'bursae'};
is noun(q{bursae})->plural, q{bursae}  => q{plural: 'bursae' --> 'bursae'};
is noun(q{jugum})->plural,   q{juga}  => q{plural: 'jugum' --> 'juga'};
is noun(q{juga})->plural, q{juga}  => q{plural: 'juga' --> 'juga'};
is noun(q{spermatium})->plural,   q{spermatia}  => q{plural: 'spermatium' --> 'spermatia'};
is noun(q{spermatia})->plural, q{spermatia}  => q{plural: 'spermatia' --> 'spermatia'};
is noun(q{vagina})->plural,   q{vaginas}  => q{plural: 'vagina' --> 'vaginas'};
is noun(q{vaginas})->plural, q{vaginas}  => q{plural: 'vaginas' --> 'vaginas'};
is noun(q{scoria})->plural,   q{scorias}  => q{plural: 'scoria' --> 'scorias'};
is noun(q{scorias})->plural, q{scorias}  => q{plural: 'scorias' --> 'scorias'};
is noun(q{demo})->plural,   q{demos}  => q{plural: 'demo' --> 'demos'};
is noun(q{demos})->plural, q{demos}  => q{plural: 'demos' --> 'demos'};
is noun(q{palea})->plural,   q{paleae}  => q{plural: 'palea' --> 'paleae'};
is noun(q{paleae})->plural, q{paleae}  => q{plural: 'paleae' --> 'paleae'};
is noun(q{ngwee})->plural,   q{ngwee}  => q{plural: 'ngwee' --> 'ngwee'};
is noun(q{afreet})->plural,   q{afreets}  => q{plural: 'afreet' --> 'afreets'};
is noun(q{afreets})->plural, q{afreets}  => q{plural: 'afreets' --> 'afreets'};
is noun(q{pallium})->plural,   q{pallia}  => q{plural: 'pallium' --> 'pallia'};
is noun(q{pallia})->plural, q{pallia}  => q{plural: 'pallia' --> 'pallia'};
is noun(q{macaroni})->plural,   q{macaronies}  => q{plural: 'macaroni' --> 'macaronies'};
is noun(q{macaronies})->plural, q{macaronies}  => q{plural: 'macaronies' --> 'macaronies'};
is noun(q{synapticula})->plural,   q{synapticulas}  => q{plural: 'synapticula' --> 'synapticulas'};
is noun(q{synapticulas})->plural, q{synapticulas}  => q{plural: 'synapticulas' --> 'synapticulas'};
is noun(q{focus})->plural,   q{focuses}  => q{plural: 'focus' --> 'focuses'};
is noun(q{focuses})->plural, q{focuses}  => q{plural: 'focuses' --> 'focuses'};
is noun(q{flagellum})->plural,   q{flagella}  => q{plural: 'flagellum' --> 'flagella'};
is noun(q{flagella})->plural, q{flagella}  => q{plural: 'flagella' --> 'flagella'};
is noun(q{linea})->plural,   q{lineae}  => q{plural: 'linea' --> 'lineae'};
is noun(q{lineae})->plural, q{lineae}  => q{plural: 'lineae' --> 'lineae'};
is noun(q{stomion})->plural,   q{stomia}  => q{plural: 'stomion' --> 'stomia'};
is noun(q{stomia})->plural, q{stomia}  => q{plural: 'stomia' --> 'stomia'};
is noun(q{myxoma})->plural,   q{myxomata}  => q{plural: 'myxoma' --> 'myxomata'};
is noun(q{myxomata})->plural, q{myxomata}  => q{plural: 'myxomata' --> 'myxomata'};
is noun(q{tombarolo})->plural,   q{tombaroli}  => q{plural: 'tombarolo' --> 'tombaroli'};
is noun(q{tombaroli})->plural, q{tombaroli}  => q{plural: 'tombaroli' --> 'tombaroli'};
is noun(q{stiletto})->plural,   q{stilettoes}  => q{plural: 'stiletto' --> 'stilettoes'};
is noun(q{stilettoes})->plural, q{stilettoes}  => q{plural: 'stilettoes' --> 'stilettoes'};
is noun(q{studium generale})->plural,   q{studia generali}  => q{plural: 'studium generale' --> 'studia generali'};
is noun(q{studia generali})->plural, q{studia generali}  => q{plural: 'studia generali' --> 'studia generali'};
is noun(q{Porto Novo})->plural,   q{Porto Novos}  => q{plural: 'Porto Novo' --> 'Porto Novos'};
is noun(q{Porto Novos})->plural, q{Porto Novos}  => q{plural: 'Porto Novos' --> 'Porto Novos'};
is noun(q{seta})->plural,   q{setae}  => q{plural: 'seta' --> 'setae'};
is noun(q{setae})->plural, q{setae}  => q{plural: 'setae' --> 'setae'};
is noun(q{blemya})->plural,   q{blemyae}  => q{plural: 'blemya' --> 'blemyae'};
is noun(q{blemyae})->plural, q{blemyae}  => q{plural: 'blemyae' --> 'blemyae'};
is noun(q{raggare})->plural,   q{raggares}  => q{plural: 'raggare' --> 'raggares'};
is noun(q{raggares})->plural, q{raggares}  => q{plural: 'raggares' --> 'raggares'};
is noun(q{spatha})->plural,   q{spathae}  => q{plural: 'spatha' --> 'spathae'};
is noun(q{spathae})->plural, q{spathae}  => q{plural: 'spathae' --> 'spathae'};
is noun(q{parabolanus})->plural,   q{parabolani}  => q{plural: 'parabolanus' --> 'parabolani'};
is noun(q{parabolani})->plural, q{parabolani}  => q{plural: 'parabolani' --> 'parabolani'};
is noun(q{genus})->plural,   q{genera}  => q{plural: 'genus' --> 'genera'};
is noun(q{genera})->plural, q{genera}  => q{plural: 'genera' --> 'genera'};
is noun(q{what})->plural,   q{what}  => q{plural: 'what' --> 'what'};
is noun(q{pincers})->plural,   q{pincers}  => q{plural: 'pincers' --> 'pincers'};
is noun(q{thymiaterion})->plural,   q{thymiateria}  => q{plural: 'thymiaterion' --> 'thymiateria'};
is noun(q{thymiateria})->plural, q{thymiateria}  => q{plural: 'thymiateria' --> 'thymiateria'};
is noun(q{pied noir})->plural,   q{pieds noirs}  => q{plural: 'pied noir' --> 'pieds noirs'};
is noun(q{pieds noirs})->plural, q{pieds noirs}  => q{plural: 'pieds noirs' --> 'pieds noirs'};
is noun(q{pteropus})->plural,   q{pteropi}  => q{plural: 'pteropus' --> 'pteropi'};
is noun(q{pteropi})->plural, q{pteropi}  => q{plural: 'pteropi' --> 'pteropi'};
is noun(q{serpula})->plural,   q{serpulae}  => q{plural: 'serpula' --> 'serpulae'};
is noun(q{serpulae})->plural, q{serpulae}  => q{plural: 'serpulae' --> 'serpulae'};
is noun(q{jacobus})->plural,   q{jacobuses}  => q{plural: 'jacobus' --> 'jacobuses'};
is noun(q{jacobuses})->plural, q{jacobuses}  => q{plural: 'jacobuses' --> 'jacobuses'};
is noun(q{noema})->plural,   q{noemata}  => q{plural: 'noema' --> 'noemata'};
is noun(q{noemata})->plural, q{noemata}  => q{plural: 'noemata' --> 'noemata'};
is noun(q{territorium})->plural,   q{territoria}  => q{plural: 'territorium' --> 'territoria'};
is noun(q{territoria})->plural, q{territoria}  => q{plural: 'territoria' --> 'territoria'};
is noun(q{bierstube})->plural,   q{bierstubes}  => q{plural: 'bierstube' --> 'bierstubes'};
is noun(q{bierstubes})->plural, q{bierstubes}  => q{plural: 'bierstubes' --> 'bierstubes'};
is noun(q{contadina})->plural,   q{contadine}  => q{plural: 'contadina' --> 'contadine'};
is noun(q{contadine})->plural, q{contadine}  => q{plural: 'contadine' --> 'contadine'};
is noun(q{enigma})->plural,   q{enigmas}  => q{plural: 'enigma' --> 'enigmas'};
is noun(q{enigmas})->plural, q{enigmas}  => q{plural: 'enigmas' --> 'enigmas'};
is noun(q{efreet})->plural,   q{efreets}  => q{plural: 'efreet' --> 'efreets'};
is noun(q{efreets})->plural, q{efreets}  => q{plural: 'efreets' --> 'efreets'};
is noun(q{conoscente})->plural,   q{conoscenti}  => q{plural: 'conoscente' --> 'conoscenti'};
is noun(q{conoscenti})->plural, q{conoscenti}  => q{plural: 'conoscenti' --> 'conoscenti'};
is noun(q{Yamoussoukro})->plural,   q{Yamoussoukros}  => q{plural: 'Yamoussoukro' --> 'Yamoussoukros'};
is noun(q{Yamoussoukros})->plural, q{Yamoussoukros}  => q{plural: 'Yamoussoukros' --> 'Yamoussoukros'};
is noun(q{haustorium})->plural,   q{haustoria}  => q{plural: 'haustorium' --> 'haustoria'};
is noun(q{haustoria})->plural, q{haustoria}  => q{plural: 'haustoria' --> 'haustoria'};
is noun(q{Burman})->plural,   q{Burmans}  => q{plural: 'Burman' --> 'Burmans'};
is noun(q{Burmans})->plural, q{Burmans}  => q{plural: 'Burmans' --> 'Burmans'};
is noun(q{arango})->plural,   q{arangoes}  => q{plural: 'arango' --> 'arangoes'};
is noun(q{arangoes})->plural, q{arangoes}  => q{plural: 'arangoes' --> 'arangoes'};
is noun(q{mouse})->plural,   q{mice}  => q{plural: 'mouse' --> 'mice'};
is noun(q{mice})->plural, q{mice}  => q{plural: 'mice' --> 'mice'};
is noun(q{stornello})->plural,   q{stornelli}  => q{plural: 'stornello' --> 'stornelli'};
is noun(q{stornelli})->plural, q{stornelli}  => q{plural: 'stornelli' --> 'stornelli'};
is noun(q{hemera})->plural,   q{hemerae}  => q{plural: 'hemera' --> 'hemerae'};
is noun(q{hemerae})->plural, q{hemerae}  => q{plural: 'hemerae' --> 'hemerae'};
is noun(q{modello})->plural,   q{modellos}  => q{plural: 'modello' --> 'modellos'};
is noun(q{modellos})->plural, q{modellos}  => q{plural: 'modellos' --> 'modellos'};
is noun(q{prodromus})->plural,   q{prodromi}  => q{plural: 'prodromus' --> 'prodromi'};
is noun(q{prodromi})->plural, q{prodromi}  => q{plural: 'prodromi' --> 'prodromi'};
is noun(q{sedile})->plural,   q{sedilia}  => q{plural: 'sedile' --> 'sedilia'};
is noun(q{sedilia})->plural, q{sedilia}  => q{plural: 'sedilia' --> 'sedilia'};
is noun(q{memorandum})->plural,   q{memorandums}  => q{plural: 'memorandum' --> 'memorandums'};
is noun(q{memorandums})->plural, q{memorandums}  => q{plural: 'memorandums' --> 'memorandums'};
is noun(q{trapezohedron})->plural,   q{trapezohedrons}  => q{plural: 'trapezohedron' --> 'trapezohedrons'};
is noun(q{trapezohedrons})->plural, q{trapezohedrons}  => q{plural: 'trapezohedrons' --> 'trapezohedrons'};
is noun(q{laika})->plural,   q{laiki}  => q{plural: 'laika' --> 'laiki'};
is noun(q{laiki})->plural, q{laiki}  => q{plural: 'laiki' --> 'laiki'};
is noun(q{prosencephalon})->plural,   q{prosencephala}  => q{plural: 'prosencephalon' --> 'prosencephala'};
is noun(q{prosencephala})->plural, q{prosencephala}  => q{plural: 'prosencephala' --> 'prosencephala'};
is noun(q{army corps general})->plural,   q{army corps generals}  => q{plural: 'army corps general' --> 'army corps generals'};
is noun(q{army corps generals})->plural, q{army corps generals}  => q{plural: 'army corps generals' --> 'army corps generals'};
is noun(q{limes})->plural,   q{limites}  => q{plural: 'limes' --> 'limites'};
is noun(q{limites})->plural, q{limites}  => q{plural: 'limites' --> 'limites'};
is noun(q{umbilicus})->plural,   q{umbilicuses}  => q{plural: 'umbilicus' --> 'umbilicuses'};
is noun(q{umbilicuses})->plural, q{umbilicuses}  => q{plural: 'umbilicuses' --> 'umbilicuses'};
is noun(q{vomica})->plural,   q{vomicas}  => q{plural: 'vomica' --> 'vomicas'};
is noun(q{vomicas})->plural, q{vomicas}  => q{plural: 'vomicas' --> 'vomicas'};
is noun(q{pillie})->plural,   q{pilleis}  => q{plural: 'pillie' --> 'pilleis'};
is noun(q{pilleis})->plural, q{pilleis}  => q{plural: 'pilleis' --> 'pilleis'};
is noun(q{bolus})->plural,   q{boluses}  => q{plural: 'bolus' --> 'boluses'};
is noun(q{boluses})->plural, q{boluses}  => q{plural: 'boluses' --> 'boluses'};
is noun(q{magnum opus})->plural,   q{magnum opuses}  => q{plural: 'magnum opus' --> 'magnum opuses'};
is noun(q{magnum opuses})->plural, q{magnum opuses}  => q{plural: 'magnum opuses' --> 'magnum opuses'};
is noun(q{tuber})->plural,   q{tuberes}  => q{plural: 'tuber' --> 'tuberes'};
is noun(q{tuberes})->plural, q{tuberes}  => q{plural: 'tuberes' --> 'tuberes'};
is noun(q{cow})->plural,   q{cows}  => q{plural: 'cow' --> 'cows'};
is noun(q{cows})->plural, q{cows}  => q{plural: 'cows' --> 'cows'};
is noun(q{contango})->plural,   q{contangos}  => q{plural: 'contango' --> 'contangos'};
is noun(q{contangos})->plural, q{contangos}  => q{plural: 'contangos' --> 'contangos'};
is noun(q{lithodomus})->plural,   q{lithodomi}  => q{plural: 'lithodomus' --> 'lithodomi'};
is noun(q{lithodomi})->plural, q{lithodomi}  => q{plural: 'lithodomi' --> 'lithodomi'};
is noun(q{tropis})->plural,   q{tropides}  => q{plural: 'tropis' --> 'tropides'};
is noun(q{tropides})->plural, q{tropides}  => q{plural: 'tropides' --> 'tropides'};
is noun(q{acinus})->plural,   q{acini}  => q{plural: 'acinus' --> 'acini'};
is noun(q{acini})->plural, q{acini}  => q{plural: 'acini' --> 'acini'};
is noun(q{gymnasium})->plural,   q{gymnasiums}  => q{plural: 'gymnasium' --> 'gymnasiums'};
is noun(q{gymnasiums})->plural, q{gymnasiums}  => q{plural: 'gymnasiums' --> 'gymnasiums'};
is noun(q{schistosomulum})->plural,   q{schistosomula}  => q{plural: 'schistosomulum' --> 'schistosomula'};
is noun(q{schistosomula})->plural, q{schistosomula}  => q{plural: 'schistosomula' --> 'schistosomula'};
is noun(q{plasmoma})->plural,   q{plasmomata}  => q{plural: 'plasmoma' --> 'plasmomata'};
is noun(q{plasmomata})->plural, q{plasmomata}  => q{plural: 'plasmomata' --> 'plasmomata'};
is noun(q{apsis})->plural,   q{apsides}  => q{plural: 'apsis' --> 'apsides'};
is noun(q{apsides})->plural, q{apsides}  => q{plural: 'apsides' --> 'apsides'};
is noun(q{one-star general})->plural,   q{one-star generals}  => q{plural: 'one-star general' --> 'one-star generals'};
is noun(q{one-star generals})->plural, q{one-star generals}  => q{plural: 'one-star generals' --> 'one-star generals'};
is noun(q{astrocytoma})->plural,   q{astrocytomas}  => q{plural: 'astrocytoma' --> 'astrocytomas'};
is noun(q{astrocytomas})->plural, q{astrocytomas}  => q{plural: 'astrocytomas' --> 'astrocytomas'};
is noun(q{Yakiman})->plural,   q{Yakimans}  => q{plural: 'Yakiman' --> 'Yakimans'};
is noun(q{Yakimans})->plural, q{Yakimans}  => q{plural: 'Yakimans' --> 'Yakimans'};
is noun(q{rilievo})->plural,   q{rilievos}  => q{plural: 'rilievo' --> 'rilievos'};
is noun(q{rilievos})->plural, q{rilievos}  => q{plural: 'rilievos' --> 'rilievos'};
is noun(q{labrum})->plural,   q{labra}  => q{plural: 'labrum' --> 'labra'};
is noun(q{labra})->plural, q{labra}  => q{plural: 'labra' --> 'labra'};
is noun(q{denkmal})->plural,   q{denkmaler}  => q{plural: 'denkmal' --> 'denkmaler'};
is noun(q{denkmaler})->plural, q{denkmaler}  => q{plural: 'denkmaler' --> 'denkmaler'};
is noun(q{macro})->plural,   q{macros}  => q{plural: 'macro' --> 'macros'};
is noun(q{macros})->plural, q{macros}  => q{plural: 'macros' --> 'macros'};
is noun(q{Sarajevo})->plural,   q{Sarajevos}  => q{plural: 'Sarajevo' --> 'Sarajevos'};
is noun(q{Sarajevos})->plural, q{Sarajevos}  => q{plural: 'Sarajevos' --> 'Sarajevos'};
is noun(q{Tonkinese})->plural,   q{Tonkinese}  => q{plural: 'Tonkinese' --> 'Tonkinese'};
is noun(q{Johnsonese})->plural,   q{Johnsonese}  => q{plural: 'Johnsonese' --> 'Johnsonese'};
is noun(q{Navarrese})->plural,   q{Navarrese}  => q{plural: 'Navarrese' --> 'Navarrese'};
is noun(q{Hottentotese})->plural,   q{Hottentotese}  => q{plural: 'Hottentotese' --> 'Hottentotese'};
is noun(q{thief})->plural,   q{thieves}  => q{plural: 'thief' --> 'thieves'};
is noun(q{thieves})->plural, q{thieves}  => q{plural: 'thieves' --> 'thieves'};
is noun(q{prima donna})->plural,   q{prima donnas}  => q{plural: 'prima donna' --> 'prima donnas'};
is noun(q{prima donnas})->plural, q{prima donnas}  => q{plural: 'prima donnas' --> 'prima donnas'};
is noun(q{archegonium})->plural,   q{archegonia}  => q{plural: 'archegonium' --> 'archegonia'};
is noun(q{archegonia})->plural, q{archegonia}  => q{plural: 'archegonia' --> 'archegonia'};
is noun(q{Parmese})->plural,   q{Parmese}  => q{plural: 'Parmese' --> 'Parmese'};
is noun(q{do})->plural,   q{does}  => q{plural: 'do' --> 'does'};
is noun(q{does})->plural, q{does}  => q{plural: 'does' --> 'does'};
is noun(q{to})->plural,   q{toes}  => q{plural: 'to' --> 'toes'};
is noun(q{toes})->plural, q{toes}  => q{plural: 'toes' --> 'toes'};
is noun(q{altorelievo})->plural,   q{altorelievos}  => q{plural: 'altorelievo' --> 'altorelievos'};
is noun(q{altorelievos})->plural, q{altorelievos}  => q{plural: 'altorelievos' --> 'altorelievos'};
is noun(q{wadi})->plural,   q{wadies}  => q{plural: 'wadi' --> 'wadies'};
is noun(q{wadies})->plural, q{wadies}  => q{plural: 'wadies' --> 'wadies'};
is noun(q{extispex})->plural,   q{extispices}  => q{plural: 'extispex' --> 'extispices'};
is noun(q{extispices})->plural, q{extispices}  => q{plural: 'extispices' --> 'extispices'};
is noun(q{Kakapo})->plural,   q{Kakapos}  => q{plural: 'Kakapo' --> 'Kakapos'};
is noun(q{Kakapos})->plural, q{Kakapos}  => q{plural: 'Kakapos' --> 'Kakapos'};
is noun(q{Sacramento})->plural,   q{Sacramentos}  => q{plural: 'Sacramento' --> 'Sacramentos'};
is noun(q{Sacramentos})->plural, q{Sacramentos}  => q{plural: 'Sacramentos' --> 'Sacramentos'};
is noun(q{neutrino})->plural,   q{neutrinos}  => q{plural: 'neutrino' --> 'neutrinos'};
is noun(q{neutrinos})->plural, q{neutrinos}  => q{plural: 'neutrinos' --> 'neutrinos'};
is noun(q{harman})->plural,   q{harmans}  => q{plural: 'harman' --> 'harmans'};
is noun(q{harmans})->plural, q{harmans}  => q{plural: 'harmans' --> 'harmans'};
is noun(q{glioma})->plural,   q{gliomata}  => q{plural: 'glioma' --> 'gliomata'};
is noun(q{gliomata})->plural, q{gliomata}  => q{plural: 'gliomata' --> 'gliomata'};
is noun(q{Havanese})->plural,   q{Havanese}  => q{plural: 'Havanese' --> 'Havanese'};
is noun(q{dais})->plural,   q{daises}  => q{plural: 'dais' --> 'daises'};
is noun(q{daises})->plural, q{daises}  => q{plural: 'daises' --> 'daises'};
is noun(q{octavo})->plural,   q{octavos}  => q{plural: 'octavo' --> 'octavos'};
is noun(q{octavos})->plural, q{octavos}  => q{plural: 'octavos' --> 'octavos'};
is noun(q{froe})->plural,   q{froes}  => q{plural: 'froe' --> 'froes'};
is noun(q{froes})->plural, q{froes}  => q{plural: 'froes' --> 'froes'};
is noun(q{rococo})->plural,   q{rococos}  => q{plural: 'rococo' --> 'rococos'};
is noun(q{rococos})->plural, q{rococos}  => q{plural: 'rococos' --> 'rococos'};
is noun(q{arcanum})->plural,   q{arcana}  => q{plural: 'arcanum' --> 'arcana'};
is noun(q{arcana})->plural, q{arcana}  => q{plural: 'arcana' --> 'arcana'};
is noun(q{corona})->plural,   q{coronas}  => q{plural: 'corona' --> 'coronas'};
is noun(q{coronas})->plural, q{coronas}  => q{plural: 'coronas' --> 'coronas'};
is noun(q{sequela})->plural,   q{sequelae}  => q{plural: 'sequela' --> 'sequelae'};
is noun(q{sequelae})->plural, q{sequelae}  => q{plural: 'sequelae' --> 'sequelae'};
is noun(q{statera})->plural,   q{staterae}  => q{plural: 'statera' --> 'staterae'};
is noun(q{staterae})->plural, q{staterae}  => q{plural: 'staterae' --> 'staterae'};
is noun(q{breakaway})->plural,   q{breakaways}  => q{plural: 'breakaway' --> 'breakaways'};
is noun(q{breakaways})->plural, q{breakaways}  => q{plural: 'breakaways' --> 'breakaways'};
is noun(q{hetman})->plural,   q{hetmans}  => q{plural: 'hetman' --> 'hetmans'};
is noun(q{hetmans})->plural, q{hetmans}  => q{plural: 'hetmans' --> 'hetmans'};
is noun(q{corno})->plural,   q{corni}  => q{plural: 'corno' --> 'corni'};
is noun(q{corni})->plural, q{corni}  => q{plural: 'corni' --> 'corni'};
is noun(q{parhelion})->plural,   q{parhelions}  => q{plural: 'parhelion' --> 'parhelions'};
is noun(q{parhelions})->plural, q{parhelions}  => q{plural: 'parhelions' --> 'parhelions'};
is noun(q{refugium})->plural,   q{refugia}  => q{plural: 'refugium' --> 'refugia'};
is noun(q{refugia})->plural, q{refugia}  => q{plural: 'refugia' --> 'refugia'};
is noun(q{podere})->plural,   q{poderi}  => q{plural: 'podere' --> 'poderi'};
is noun(q{poderi})->plural, q{poderi}  => q{plural: 'poderi' --> 'poderi'};
is noun(q{avicularium})->plural,   q{avicularia}  => q{plural: 'avicularium' --> 'avicularia'};
is noun(q{avicularia})->plural, q{avicularia}  => q{plural: 'avicularia' --> 'avicularia'};
is noun(q{prima ballerina})->plural,   q{prima ballerinas}  => q{plural: 'prima ballerina' --> 'prima ballerinas'};
is noun(q{prima ballerinas})->plural, q{prima ballerinas}  => q{plural: 'prima ballerinas' --> 'prima ballerinas'};
is noun(q{bath})->plural,   q{baths}  => q{plural: 'bath' --> 'baths'};
is noun(q{baths})->plural, q{baths}  => q{plural: 'baths' --> 'baths'};
is noun(q{libido})->plural,   q{libidos}  => q{plural: 'libido' --> 'libidos'};
is noun(q{libidos})->plural, q{libidos}  => q{plural: 'libidos' --> 'libidos'};
is noun(q{2 star general})->plural,   q{2 star generals}  => q{plural: '2 star general' --> '2 star generals'};
is noun(q{2 star generals})->plural, q{2 star generals}  => q{plural: '2 star generals' --> '2 star generals'};
is noun(q{hapteron})->plural,   q{haptera}  => q{plural: 'hapteron' --> 'haptera'};
is noun(q{haptera})->plural, q{haptera}  => q{plural: 'haptera' --> 'haptera'};
is noun(q{loco})->plural,   q{locos}  => q{plural: 'loco' --> 'locos'};
is noun(q{locos})->plural, q{locos}  => q{plural: 'locos' --> 'locos'};
is noun(q{triens})->plural,   q{trientes}  => q{plural: 'triens' --> 'trientes'};
is noun(q{trientes})->plural, q{trientes}  => q{plural: 'trientes' --> 'trientes'};
is noun(q{triclinium})->plural,   q{triclinia}  => q{plural: 'triclinium' --> 'triclinia'};
is noun(q{triclinia})->plural, q{triclinia}  => q{plural: 'triclinia' --> 'triclinia'};
is noun(q{manteau})->plural,   q{manteaus}  => q{plural: 'manteau' --> 'manteaus'};
is noun(q{manteaus})->plural, q{manteaus}  => q{plural: 'manteaus' --> 'manteaus'};
is noun(q{amorino})->plural,   q{amorini}  => q{plural: 'amorino' --> 'amorini'};
is noun(q{amorini})->plural, q{amorini}  => q{plural: 'amorini' --> 'amorini'};
is noun(q{ethos})->plural,   q{ethoses}  => q{plural: 'ethos' --> 'ethoses'};
is noun(q{ethoses})->plural, q{ethoses}  => q{plural: 'ethoses' --> 'ethoses'};
is noun(q{cystoma})->plural,   q{cystomata}  => q{plural: 'cystoma' --> 'cystomata'};
is noun(q{cystomata})->plural, q{cystomata}  => q{plural: 'cystomata' --> 'cystomata'};
is noun(q{erf})->plural,   q{erfs}  => q{plural: 'erf' --> 'erfs'};
is noun(q{erfs})->plural, q{erfs}  => q{plural: 'erfs' --> 'erfs'};
is noun(q{rhynchodaeum})->plural,   q{rhynchodaea}  => q{plural: 'rhynchodaeum' --> 'rhynchodaea'};
is noun(q{rhynchodaea})->plural, q{rhynchodaea}  => q{plural: 'rhynchodaea' --> 'rhynchodaea'};
is noun(q{Nicobarese})->plural,   q{Nicobarese}  => q{plural: 'Nicobarese' --> 'Nicobarese'};
is noun(q{thelycum})->plural,   q{thelyca}  => q{plural: 'thelycum' --> 'thelyca'};
is noun(q{thelyca})->plural, q{thelyca}  => q{plural: 'thelyca' --> 'thelyca'};
is noun(q{tarantata})->plural,   q{tarantate}  => q{plural: 'tarantata' --> 'tarantate'};
is noun(q{tarantate})->plural, q{tarantate}  => q{plural: 'tarantate' --> 'tarantate'};
is noun(q{bruschetta})->plural,   q{bruschette}  => q{plural: 'bruschetta' --> 'bruschette'};
is noun(q{bruschette})->plural, q{bruschette}  => q{plural: 'bruschette' --> 'bruschette'};
is noun(q{auslese})->plural,   q{ausleses}  => q{plural: 'auslese' --> 'ausleses'};
is noun(q{ausleses})->plural, q{ausleses}  => q{plural: 'ausleses' --> 'ausleses'};
is noun(q{urodaeum})->plural,   q{urodaea}  => q{plural: 'urodaeum' --> 'urodaea'};
is noun(q{urodaea})->plural, q{urodaea}  => q{plural: 'urodaea' --> 'urodaea'};
is noun(q{meliceris})->plural,   q{melicerides}  => q{plural: 'meliceris' --> 'melicerides'};
is noun(q{melicerides})->plural, q{melicerides}  => q{plural: 'melicerides' --> 'melicerides'};
is noun(q{solidus})->plural,   q{solidi}  => q{plural: 'solidus' --> 'solidi'};
is noun(q{solidi})->plural, q{solidi}  => q{plural: 'solidi' --> 'solidi'};
is noun(q{parabola})->plural,   q{parabolas}  => q{plural: 'parabola' --> 'parabolas'};
is noun(q{parabolas})->plural, q{parabolas}  => q{plural: 'parabolas' --> 'parabolas'};
is noun(q{hymenium})->plural,   q{hymenia}  => q{plural: 'hymenium' --> 'hymenia'};
is noun(q{hymenia})->plural, q{hymenia}  => q{plural: 'hymenia' --> 'hymenia'};
is noun(q{ilium})->plural,   q{ilia}  => q{plural: 'ilium' --> 'ilia'};
is noun(q{ilia})->plural, q{ilia}  => q{plural: 'ilia' --> 'ilia'};
is noun(q{megatherium})->plural,   q{megatheria}  => q{plural: 'megatherium' --> 'megatheria'};
is noun(q{megatheria})->plural, q{megatheria}  => q{plural: 'megatheria' --> 'megatheria'};
is noun(q{set off})->plural,   q{set offs}  => q{plural: 'set off' --> 'set offs'};
is noun(q{set offs})->plural, q{set offs}  => q{plural: 'set offs' --> 'set offs'};
is noun(q{plesiosaurus})->plural,   q{plesiosauri}  => q{plural: 'plesiosaurus' --> 'plesiosauri'};
is noun(q{plesiosauri})->plural, q{plesiosauri}  => q{plural: 'plesiosauri' --> 'plesiosauri'};
is noun(q{break-away})->plural,   q{break-aways}  => q{plural: 'break-away' --> 'break-aways'};
is noun(q{break-aways})->plural, q{break-aways}  => q{plural: 'break-aways' --> 'break-aways'};
is noun(q{jackanapes})->plural,   q{jackanapes}  => q{plural: 'jackanapes' --> 'jackanapes'};
is noun(q{stomodaeum})->plural,   q{stomodea}  => q{plural: 'stomodaeum' --> 'stomodea'};
is noun(q{stomodea})->plural, q{stomodea}  => q{plural: 'stomodea' --> 'stomodea'};
is noun(q{phalangium})->plural,   q{phalangia}  => q{plural: 'phalangium' --> 'phalangia'};
is noun(q{phalangia})->plural, q{phalangia}  => q{plural: 'phalangia' --> 'phalangia'};
is noun(q{signum})->plural,   q{signa}  => q{plural: 'signum' --> 'signa'};
is noun(q{signa})->plural, q{signa}  => q{plural: 'signa' --> 'signa'};
is noun(q{nockerl})->plural,   q{nockerln}  => q{plural: 'nockerl' --> 'nockerln'};
is noun(q{nockerln})->plural, q{nockerln}  => q{plural: 'nockerln' --> 'nockerln'};
is noun(q{adieu})->plural,   q{adieus}  => q{plural: 'adieu' --> 'adieus'};
is noun(q{adieus})->plural, q{adieus}  => q{plural: 'adieus' --> 'adieus'};
is noun(q{editio princeps})->plural,   q{editiones principes}  => q{plural: 'editio princeps' --> 'editiones principes'};
is noun(q{editiones principes})->plural, q{editiones principes}  => q{plural: 'editiones principes' --> 'editiones principes'};
is noun(q{ens rationis})->plural,   q{entia rationis}  => q{plural: 'ens rationis' --> 'entia rationis'};
is noun(q{entia rationis})->plural, q{entia rationis}  => q{plural: 'entia rationis' --> 'entia rationis'};
is noun(q{toxoplasma})->plural,   q{toxoplasmata}  => q{plural: 'toxoplasma' --> 'toxoplasmata'};
is noun(q{toxoplasmata})->plural, q{toxoplasmata}  => q{plural: 'toxoplasmata' --> 'toxoplasmata'};
is noun(q{carex})->plural,   q{carices}  => q{plural: 'carex' --> 'carices'};
is noun(q{carices})->plural, q{carices}  => q{plural: 'carices' --> 'carices'};
is noun(q{auto de fe})->plural,   q{auto de fes}  => q{plural: 'auto de fe' --> 'auto de fes'};
is noun(q{auto de fes})->plural, q{auto de fes}  => q{plural: 'auto de fes' --> 'auto de fes'};
is noun(q{centumvir})->plural,   q{centumviri}  => q{plural: 'centumvir' --> 'centumviri'};
is noun(q{centumviri})->plural, q{centumviri}  => q{plural: 'centumviri' --> 'centumviri'};
is noun(q{Amboinese})->plural,   q{Amboinese}  => q{plural: 'Amboinese' --> 'Amboinese'};
is noun(q{trichina})->plural,   q{trichine}  => q{plural: 'trichina' --> 'trichine'};
is noun(q{trichine})->plural, q{trichine}  => q{plural: 'trichine' --> 'trichine'};
is noun(q{operculum})->plural,   q{opercula}  => q{plural: 'operculum' --> 'opercula'};
is noun(q{opercula})->plural, q{opercula}  => q{plural: 'opercula' --> 'opercula'};
is noun(q{news})->plural,   q{news}  => q{plural: 'news' --> 'news'};
is noun(q{Gilbertese})->plural,   q{Gilbertese}  => q{plural: 'Gilbertese' --> 'Gilbertese'};
is noun(q{protococcus})->plural,   q{protococci}  => q{plural: 'protococcus' --> 'protococci'};
is noun(q{protococci})->plural, q{protococci}  => q{plural: 'protococci' --> 'protococci'};
is noun(q{Calabrese})->plural,   q{Calabrese}  => q{plural: 'Calabrese' --> 'Calabrese'};
is noun(q{myo})->plural,   q{myos}  => q{plural: 'myo' --> 'myos'};
is noun(q{myos})->plural, q{myos}  => q{plural: 'myos' --> 'myos'};
is noun(q{areola})->plural,   q{areolae}  => q{plural: 'areola' --> 'areolae'};
is noun(q{areolae})->plural, q{areolae}  => q{plural: 'areolae' --> 'areolae'};
is noun(q{haruspex})->plural,   q{haruspices}  => q{plural: 'haruspex' --> 'haruspices'};
is noun(q{haruspices})->plural, q{haruspices}  => q{plural: 'haruspices' --> 'haruspices'};
is noun(q{potestas})->plural,   q{potestates}  => q{plural: 'potestas' --> 'potestates'};
is noun(q{potestates})->plural, q{potestates}  => q{plural: 'potestates' --> 'potestates'};
is noun(q{parvenu})->plural,   q{parvenus}  => q{plural: 'parvenu' --> 'parvenus'};
is noun(q{parvenus})->plural, q{parvenus}  => q{plural: 'parvenus' --> 'parvenus'};
is noun(q{Filipino})->plural,   q{Filipinos}  => q{plural: 'Filipino' --> 'Filipinos'};
is noun(q{Filipinos})->plural, q{Filipinos}  => q{plural: 'Filipinos' --> 'Filipinos'};
is noun(q{monochasium})->plural,   q{monochasia}  => q{plural: 'monochasium' --> 'monochasia'};
is noun(q{monochasia})->plural, q{monochasia}  => q{plural: 'monochasia' --> 'monochasia'};
is noun(q{lord lieutenant})->plural,   q{lord lieutenants}  => q{plural: 'lord lieutenant' --> 'lord lieutenants'};
is noun(q{lord lieutenants})->plural, q{lord lieutenants}  => q{plural: 'lord lieutenants' --> 'lord lieutenants'};
is noun(q{Congoese})->plural,   q{Congoese}  => q{plural: 'Congoese' --> 'Congoese'};
is noun(q{iris})->plural,   q{irises}  => q{plural: 'iris' --> 'irises'};
is noun(q{irises})->plural, q{irises}  => q{plural: 'irises' --> 'irises'};
is noun(q{panino})->plural,   q{panini}  => q{plural: 'panino' --> 'panini'};
is noun(q{panini})->plural, q{panini}  => q{plural: 'panini' --> 'panini'};
is noun(q{fricandeau})->plural,   q{fricandeaux}  => q{plural: 'fricandeau' --> 'fricandeaux'};
is noun(q{fricandeaux})->plural, q{fricandeaux}  => q{plural: 'fricandeaux' --> 'fricandeaux'};
is noun(q{secundagravida})->plural,   q{secundagravidas}  => q{plural: 'secundagravida' --> 'secundagravidas'};
is noun(q{secundagravidas})->plural, q{secundagravidas}  => q{plural: 'secundagravidas' --> 'secundagravidas'};
is noun(q{ritardando})->plural,   q{ritardandos}  => q{plural: 'ritardando' --> 'ritardandos'};
is noun(q{ritardandos})->plural, q{ritardandos}  => q{plural: 'ritardandos' --> 'ritardandos'};
is noun(q{Nenets})->plural,   q{Nenets}  => q{plural: 'Nenets' --> 'Nenets'};
is noun(q{magus})->plural,   q{magi}  => q{plural: 'magus' --> 'magi'};
is noun(q{magi})->plural, q{magi}  => q{plural: 'magi' --> 'magi'};
is noun(q{pyralis})->plural,   q{pyralides}  => q{plural: 'pyralis' --> 'pyralides'};
is noun(q{pyralides})->plural, q{pyralides}  => q{plural: 'pyralides' --> 'pyralides'};
is noun(q{celia})->plural,   q{celiae}  => q{plural: 'celia' --> 'celiae'};
is noun(q{celiae})->plural, q{celiae}  => q{plural: 'celiae' --> 'celiae'};
is noun(q{fraenum})->plural,   q{fraena}  => q{plural: 'fraenum' --> 'fraena'};
is noun(q{fraena})->plural, q{fraena}  => q{plural: 'fraena' --> 'fraena'};
is noun(q{appendix})->plural,   q{appendixes}  => q{plural: 'appendix' --> 'appendixes'};
is noun(q{appendixes})->plural, q{appendixes}  => q{plural: 'appendixes' --> 'appendixes'};
is noun(q{versiculus})->plural,   q{versiculi}  => q{plural: 'versiculus' --> 'versiculi'};
is noun(q{versiculi})->plural, q{versiculi}  => q{plural: 'versiculi' --> 'versiculi'};
is noun(q{sumo})->plural,   q{sumos}  => q{plural: 'sumo' --> 'sumos'};
is noun(q{sumos})->plural, q{sumos}  => q{plural: 'sumos' --> 'sumos'};
is noun(q{bacillus})->plural,   q{bacilli}  => q{plural: 'bacillus' --> 'bacilli'};
is noun(q{bacilli})->plural, q{bacilli}  => q{plural: 'bacilli' --> 'bacilli'};
is noun(q{status})->plural,   q{statuses}  => q{plural: 'status' --> 'statuses'};
is noun(q{statuses})->plural, q{statuses}  => q{plural: 'statuses' --> 'statuses'};
is noun(q{phylum})->plural,   q{phylums}  => q{plural: 'phylum' --> 'phylums'};
is noun(q{phylums})->plural, q{phylums}  => q{plural: 'phylums' --> 'phylums'};
is noun(q{auspex})->plural,   q{auspices}  => q{plural: 'auspex' --> 'auspices'};
is noun(q{auspices})->plural, q{auspices}  => q{plural: 'auspices' --> 'auspices'};
is noun(q{parergon})->plural,   q{parerga}  => q{plural: 'parergon' --> 'parerga'};
is noun(q{parerga})->plural, q{parerga}  => q{plural: 'parerga' --> 'parerga'};
is noun(q{musique concrete})->plural,   q{musiques concretes}  => q{plural: 'musique concrete' --> 'musiques concretes'};
is noun(q{musiques concretes})->plural, q{musiques concretes}  => q{plural: 'musiques concretes' --> 'musiques concretes'};
is noun(q{peridium})->plural,   q{peridia}  => q{plural: 'peridium' --> 'peridia'};
is noun(q{peridia})->plural, q{peridia}  => q{plural: 'peridia' --> 'peridia'};
is noun(q{farman})->plural,   q{farmans}  => q{plural: 'farman' --> 'farmans'};
is noun(q{farmans})->plural, q{farmans}  => q{plural: 'farmans' --> 'farmans'};
is noun(q{ens reale})->plural,   q{entia realia}  => q{plural: 'ens reale' --> 'entia realia'};
is noun(q{entia realia})->plural, q{entia realia}  => q{plural: 'entia realia' --> 'entia realia'};
is noun(q{plankter})->plural,   q{plankton}  => q{plural: 'plankter' --> 'plankton'};
is noun(q{plankton})->plural, q{plankton}  => q{plural: 'plankton' --> 'plankton'};
is noun(q{leaf})->plural,   q{leaves}  => q{plural: 'leaf' --> 'leaves'};
is noun(q{leaves})->plural, q{leaves}  => q{plural: 'leaves' --> 'leaves'};
is noun(q{neurinoma})->plural,   q{neurinomas}  => q{plural: 'neurinoma' --> 'neurinomas'};
is noun(q{neurinomas})->plural, q{neurinomas}  => q{plural: 'neurinomas' --> 'neurinomas'};
is noun(q{busto})->plural,   q{bustos}  => q{plural: 'busto' --> 'bustos'};
is noun(q{bustos})->plural, q{bustos}  => q{plural: 'bustos' --> 'bustos'};
is noun(q{beerenauslese})->plural,   q{beerenauslesen}  => q{plural: 'beerenauslese' --> 'beerenauslesen'};
is noun(q{beerenauslesen})->plural, q{beerenauslesen}  => q{plural: 'beerenauslesen' --> 'beerenauslesen'};
is noun(q{patagium})->plural,   q{patagia}  => q{plural: 'patagium' --> 'patagia'};
is noun(q{patagia})->plural, q{patagia}  => q{plural: 'patagia' --> 'patagia'};
is noun(q{sacrum})->plural,   q{sacrums}  => q{plural: 'sacrum' --> 'sacrums'};
is noun(q{sacrums})->plural, q{sacrums}  => q{plural: 'sacrums' --> 'sacrums'};
is noun(q{xiphiplastron})->plural,   q{xiphiplastra}  => q{plural: 'xiphiplastron' --> 'xiphiplastra'};
is noun(q{xiphiplastra})->plural, q{xiphiplastra}  => q{plural: 'xiphiplastra' --> 'xiphiplastra'};
is noun(q{gousblom})->plural,   q{gousblomme}  => q{plural: 'gousblom' --> 'gousblomme'};
is noun(q{gousblomme})->plural, q{gousblomme}  => q{plural: 'gousblomme' --> 'gousblomme'};
is noun(q{podion})->plural,   q{podia}  => q{plural: 'podion' --> 'podia'};
is noun(q{podia})->plural, q{podia}  => q{plural: 'podia' --> 'podia'};
is noun(q{paraselene})->plural,   q{paraselenae}  => q{plural: 'paraselene' --> 'paraselenae'};
is noun(q{paraselenae})->plural, q{paraselenae}  => q{plural: 'paraselenae' --> 'paraselenae'};
is noun(q{arf})->plural,   q{arves}  => q{plural: 'arf' --> 'arves'};
is noun(q{arves})->plural, q{arves}  => q{plural: 'arves' --> 'arves'};
is noun(q{carcinoma})->plural,   q{carcinomas}  => q{plural: 'carcinoma' --> 'carcinomas'};
is noun(q{carcinomas})->plural, q{carcinomas}  => q{plural: 'carcinomas' --> 'carcinomas'};
is noun(q{finger end})->plural,   q{finger ends}  => q{plural: 'finger end' --> 'finger ends'};
is noun(q{finger ends})->plural, q{finger ends}  => q{plural: 'finger ends' --> 'finger ends'};
is noun(q{goose})->plural,   q{geese}  => q{plural: 'goose' --> 'geese'};
is noun(q{geese})->plural, q{geese}  => q{plural: 'geese' --> 'geese'};
is noun(q{vibex})->plural,   q{vibices}  => q{plural: 'vibex' --> 'vibices'};
is noun(q{vibices})->plural, q{vibices}  => q{plural: 'vibices' --> 'vibices'};
is noun(q{tortrix})->plural,   q{tortrices}  => q{plural: 'tortrix' --> 'tortrices'};
is noun(q{tortrices})->plural, q{tortrices}  => q{plural: 'tortrices' --> 'tortrices'};
is noun(q{kernos})->plural,   q{kernoi}  => q{plural: 'kernos' --> 'kernoi'};
is noun(q{kernoi})->plural, q{kernoi}  => q{plural: 'kernoi' --> 'kernoi'};
is noun(q{pyxidium})->plural,   q{pyxidia}  => q{plural: 'pyxidium' --> 'pyxidia'};
is noun(q{pyxidia})->plural, q{pyxidia}  => q{plural: 'pyxidia' --> 'pyxidia'};
is noun(q{placitum})->plural,   q{placita}  => q{plural: 'placitum' --> 'placita'};
is noun(q{placita})->plural, q{placita}  => q{plural: 'placita' --> 'placita'};
is noun(q{trilby})->plural,   q{trilbys}  => q{plural: 'trilby' --> 'trilbys'};
is noun(q{trilbys})->plural, q{trilbys}  => q{plural: 'trilbys' --> 'trilbys'};
is noun(q{ambulacrum})->plural,   q{ambulacra}  => q{plural: 'ambulacrum' --> 'ambulacra'};
is noun(q{ambulacra})->plural, q{ambulacra}  => q{plural: 'ambulacra' --> 'ambulacra'};
is noun(q{galla})->plural,   q{gallas}  => q{plural: 'galla' --> 'gallas'};
is noun(q{gallas})->plural, q{gallas}  => q{plural: 'gallas' --> 'gallas'};
is noun(q{Hainanese})->plural,   q{Hainanese}  => q{plural: 'Hainanese' --> 'Hainanese'};
is noun(q{polythecium})->plural,   q{polythecia}  => q{plural: 'polythecium' --> 'polythecia'};
is noun(q{polythecia})->plural, q{polythecia}  => q{plural: 'polythecia' --> 'polythecia'};
is noun(q{hypolimnion})->plural,   q{hypolimnia}  => q{plural: 'hypolimnion' --> 'hypolimnia'};
is noun(q{hypolimnia})->plural, q{hypolimnia}  => q{plural: 'hypolimnia' --> 'hypolimnia'};
is noun(q{triradius})->plural,   q{triradii}  => q{plural: 'triradius' --> 'triradii'};
is noun(q{triradii})->plural, q{triradii}  => q{plural: 'triradii' --> 'triradii'};
is noun(q{felsenmeer})->plural,   q{felsenmeere}  => q{plural: 'felsenmeer' --> 'felsenmeere'};
is noun(q{felsenmeere})->plural, q{felsenmeere}  => q{plural: 'felsenmeere' --> 'felsenmeere'};
is noun(q{bulla})->plural,   q{bullae}  => q{plural: 'bulla' --> 'bullae'};
is noun(q{bullae})->plural, q{bullae}  => q{plural: 'bullae' --> 'bullae'};
is noun(q{somaten})->plural,   q{somatenes}  => q{plural: 'somaten' --> 'somatenes'};
is noun(q{somatenes})->plural, q{somatenes}  => q{plural: 'somatenes' --> 'somatenes'};
is noun(q{caffe macchiato})->plural,   q{caffe macchiatos}  => q{plural: 'caffe macchiato' --> 'caffe macchiatos'};
is noun(q{caffe macchiatos})->plural, q{caffe macchiatos}  => q{plural: 'caffe macchiatos' --> 'caffe macchiatos'};
is noun(q{Amoyese})->plural,   q{Amoyese}  => q{plural: 'Amoyese' --> 'Amoyese'};
is noun(q{gonangium})->plural,   q{gonangia}  => q{plural: 'gonangium' --> 'gonangia'};
is noun(q{gonangia})->plural, q{gonangia}  => q{plural: 'gonangia' --> 'gonangia'};
is noun(q{6 star general})->plural,   q{6 star generals}  => q{plural: '6 star general' --> '6 star generals'};
is noun(q{6 star generals})->plural, q{6 star generals}  => q{plural: '6 star generals' --> '6 star generals'};
is noun(q{chitarrone})->plural,   q{chitarroni}  => q{plural: 'chitarrone' --> 'chitarroni'};
is noun(q{chitarroni})->plural, q{chitarroni}  => q{plural: 'chitarroni' --> 'chitarroni'};
is noun(q{Vermontese})->plural,   q{Vermontese}  => q{plural: 'Vermontese' --> 'Vermontese'};
is noun(q{doe})->plural,   q{does}  => q{plural: 'doe' --> 'does'};
is noun(q{does})->plural, q{does}  => q{plural: 'does' --> 'does'};
is noun(q{toe})->plural,   q{toes}  => q{plural: 'toe' --> 'toes'};
is noun(q{toes})->plural, q{toes}  => q{plural: 'toes' --> 'toes'};
is noun(q{ale-wife})->plural,   q{ale-wives}  => q{plural: 'ale-wife' --> 'ale-wives'};
is noun(q{ale-wives})->plural, q{ale-wives}  => q{plural: 'ale-wives' --> 'ale-wives'};
is noun(q{competent})->plural,   q{competentes}  => q{plural: 'competent' --> 'competentes'};
is noun(q{competentes})->plural, q{competentes}  => q{plural: 'competentes' --> 'competentes'};
is noun(q{mouth})->plural,   q{mouths}  => q{plural: 'mouth' --> 'mouths'};
is noun(q{mouths})->plural, q{mouths}  => q{plural: 'mouths' --> 'mouths'};
is noun(q{meta})->plural,   q{metae}  => q{plural: 'meta' --> 'metae'};
is noun(q{metae})->plural, q{metae}  => q{plural: 'metae' --> 'metae'};
is noun(q{ovulum})->plural,   q{ovula}  => q{plural: 'ovulum' --> 'ovula'};
is noun(q{ovula})->plural, q{ovula}  => q{plural: 'ovula' --> 'ovula'};

done_testing();
