use Test::More;
use Lingua::EN::Inflexion;

is noun(q{portico})->classical->plural,   q{porticoes}  => q{classical plural: 'portico' --> 'porticoes'};
is noun(q{porticoes})->classical->plural, q{porticoes}  => q{classical plural: 'porticoes' --> 'porticoes'};
is noun(q{lux})->classical->plural,   q{lux}  => q{classical plural: 'lux' --> 'lux'};
is noun(q{livedo})->classical->plural,   q{livedos}  => q{classical plural: 'livedo' --> 'livedos'};
is noun(q{livedos})->classical->plural, q{livedos}  => q{classical plural: 'livedos' --> 'livedos'};
is noun(q{Annamese})->classical->plural,   q{Annamese}  => q{classical plural: 'Annamese' --> 'Annamese'};
is noun(q{molimen})->classical->plural,   q{molimina}  => q{classical plural: 'molimen' --> 'molimina'};
is noun(q{molimina})->classical->plural, q{molimina}  => q{classical plural: 'molimina' --> 'molimina'};
is noun(q{epididymis})->classical->plural,   q{epididymides}  => q{classical plural: 'epididymis' --> 'epididymides'};
is noun(q{epididymides})->classical->plural, q{epididymides}  => q{classical plural: 'epididymides' --> 'epididymides'};
is noun(q{pleura})->classical->plural,   q{pleura}  => q{classical plural: 'pleura' --> 'pleura'};
is noun(q{syncellus})->classical->plural,   q{syncelli}  => q{classical plural: 'syncellus' --> 'syncelli'};
is noun(q{syncelli})->classical->plural, q{syncelli}  => q{classical plural: 'syncelli' --> 'syncelli'};
is noun(q{coz})->classical->plural,   q{cozes}  => q{classical plural: 'coz' --> 'cozes'};
is noun(q{cozes})->classical->plural, q{cozes}  => q{classical plural: 'cozes' --> 'cozes'};
is noun(q{bilbo})->classical->plural,   q{bilboes}  => q{classical plural: 'bilbo' --> 'bilboes'};
is noun(q{bilboes})->classical->plural, q{bilboes}  => q{classical plural: 'bilboes' --> 'bilboes'};
is noun(q{mine})->classical->plural,   q{ours}  => q{classical plural: 'mine' --> 'ours'};
is noun(q{ours})->classical->plural, q{ours}  => q{classical plural: 'ours' --> 'ours'};
is noun(q{pneumothorax})->classical->plural,   q{pneumothoraces}  => q{classical plural: 'pneumothorax' --> 'pneumothoraces'};
is noun(q{pneumothoraces})->classical->plural, q{pneumothoraces}  => q{classical plural: 'pneumothoraces' --> 'pneumothoraces'};
is noun(q{alias})->classical->plural,   q{aliases}  => q{classical plural: 'alias' --> 'aliases'};
is noun(q{aliases})->classical->plural, q{aliases}  => q{classical plural: 'aliases' --> 'aliases'};
is noun(q{mare})->classical->plural,   q{maria}  => q{classical plural: 'mare' --> 'maria'};
is noun(q{maria})->classical->plural, q{maria}  => q{classical plural: 'maria' --> 'maria'};
is noun(q{fioritura})->classical->plural,   q{fioriture}  => q{classical plural: 'fioritura' --> 'fioriture'};
is noun(q{fioriture})->classical->plural, q{fioriture}  => q{classical plural: 'fioriture' --> 'fioriture'};
is noun(q{port de bras})->classical->plural,   q{ports de bras}  => q{classical plural: 'port de bras' --> 'ports de bras'};
is noun(q{ports de bras})->classical->plural, q{ports de bras}  => q{classical plural: 'ports de bras' --> 'ports de bras'};
is noun(q{fidei defensor})->classical->plural,   q{fidei defensores}  => q{classical plural: 'fidei defensor' --> 'fidei defensores'};
is noun(q{fidei defensores})->classical->plural, q{fidei defensores}  => q{classical plural: 'fidei defensores' --> 'fidei defensores'};
is noun(q{avocado})->classical->plural,   q{avocados}  => q{classical plural: 'avocado' --> 'avocados'};
is noun(q{avocados})->classical->plural, q{avocados}  => q{classical plural: 'avocados' --> 'avocados'};
is noun(q{sago})->classical->plural,   q{sagos}  => q{classical plural: 'sago' --> 'sagos'};
is noun(q{sagos})->classical->plural, q{sagos}  => q{classical plural: 'sagos' --> 'sagos'};
is noun(q{desma})->classical->plural,   q{desmata}  => q{classical plural: 'desma' --> 'desmata'};
is noun(q{desmata})->classical->plural, q{desmata}  => q{classical plural: 'desmata' --> 'desmata'};
is noun(q{Sundanese})->classical->plural,   q{Sundanese}  => q{classical plural: 'Sundanese' --> 'Sundanese'};
is noun(q{washer-up})->classical->plural,   q{washers-up}  => q{classical plural: 'washer-up' --> 'washers-up'};
is noun(q{washers-up})->classical->plural, q{washers-up}  => q{classical plural: 'washers-up' --> 'washers-up'};
is noun(q{Lyonese})->classical->plural,   q{Lyonese}  => q{classical plural: 'Lyonese' --> 'Lyonese'};
is noun(q{Alfurese})->classical->plural,   q{Alfurese}  => q{classical plural: 'Alfurese' --> 'Alfurese'};
is noun(q{secans})->classical->plural,   q{secantes}  => q{classical plural: 'secans' --> 'secantes'};
is noun(q{secantes})->classical->plural, q{secantes}  => q{classical plural: 'secantes' --> 'secantes'};
is noun(q{coma})->classical->plural,   q{comae}  => q{classical plural: 'coma' --> 'comae'};
is noun(q{comae})->classical->plural, q{comae}  => q{classical plural: 'comae' --> 'comae'};
is noun(q{protypon})->classical->plural,   q{protypa}  => q{classical plural: 'protypon' --> 'protypa'};
is noun(q{protypa})->classical->plural, q{protypa}  => q{classical plural: 'protypa' --> 'protypa'};
is noun(q{ploshchadka})->classical->plural,   q{ploshchadki}  => q{classical plural: 'ploshchadka' --> 'ploshchadki'};
is noun(q{ploshchadki})->classical->plural, q{ploshchadki}  => q{classical plural: 'ploshchadki' --> 'ploshchadki'};
is noun(q{she})->classical->plural,   q{they}  => q{classical plural: 'she' --> 'they'};
is noun(q{moscardino})->classical->plural,   q{moscardini}  => q{classical plural: 'moscardino' --> 'moscardini'};
is noun(q{moscardini})->classical->plural, q{moscardini}  => q{classical plural: 'moscardini' --> 'moscardini'};
is noun(q{I})->classical->plural,   q{we}  => q{classical plural: 'I' --> 'we'};
is noun(q{we})->classical->plural, q{we}  => q{classical plural: 'we' --> 'we'};
is noun(q{nodus})->classical->plural,   q{nodi}  => q{classical plural: 'nodus' --> 'nodi'};
is noun(q{nodi})->classical->plural, q{nodi}  => q{classical plural: 'nodi' --> 'nodi'};
is noun(q{filaria})->classical->plural,   q{filariae}  => q{classical plural: 'filaria' --> 'filariae'};
is noun(q{filariae})->classical->plural, q{filariae}  => q{classical plural: 'filariae' --> 'filariae'};
is noun(q{pingo})->classical->plural,   q{pingoes}  => q{classical plural: 'pingo' --> 'pingoes'};
is noun(q{pingoes})->classical->plural, q{pingoes}  => q{classical plural: 'pingoes' --> 'pingoes'};
is noun(q{maximum})->classical->plural,   q{maxima}  => q{classical plural: 'maximum' --> 'maxima'};
is noun(q{maxima})->classical->plural, q{maxima}  => q{classical plural: 'maxima' --> 'maxima'};
is noun(q{alguacil})->classical->plural,   q{alguaciles}  => q{classical plural: 'alguacil' --> 'alguaciles'};
is noun(q{alguaciles})->classical->plural, q{alguaciles}  => q{classical plural: 'alguaciles' --> 'alguaciles'};
is noun(q{itself})->classical->plural,   q{themselves}  => q{classical plural: 'itself' --> 'themselves'};
is noun(q{chateau})->classical->plural,   q{chateaux}  => q{classical plural: 'chateau' --> 'chateaux'};
is noun(q{chateaux})->classical->plural, q{chateaux}  => q{classical plural: 'chateaux' --> 'chateaux'};
is noun(q{furioso})->classical->plural,   q{furiosos}  => q{classical plural: 'furioso' --> 'furiosos'};
is noun(q{furiosos})->classical->plural, q{furiosos}  => q{classical plural: 'furiosos' --> 'furiosos'};
is noun(q{aculeus})->classical->plural,   q{aculei}  => q{classical plural: 'aculeus' --> 'aculei'};
is noun(q{aculei})->classical->plural, q{aculei}  => q{classical plural: 'aculei' --> 'aculei'};
is noun(q{heroon})->classical->plural,   q{heroa}  => q{classical plural: 'heroon' --> 'heroa'};
is noun(q{heroa})->classical->plural, q{heroa}  => q{classical plural: 'heroa' --> 'heroa'};
is noun(q{Greensboro})->classical->plural,   q{Greensboros}  => q{classical plural: 'Greensboro' --> 'Greensboros'};
is noun(q{Greensboros})->classical->plural, q{Greensboros}  => q{classical plural: 'Greensboros' --> 'Greensboros'};
is noun(q{casus belli})->classical->plural,   q{casus belli}  => q{classical plural: 'casus belli' --> 'casus belli'};
is noun(q{jerry})->classical->plural,   q{jerries}  => q{classical plural: 'jerry' --> 'jerries'};
is noun(q{jerries})->classical->plural, q{jerries}  => q{classical plural: 'jerries' --> 'jerries'};
is noun(q{summum bonum})->classical->plural,   q{summa bona}  => q{classical plural: 'summum bonum' --> 'summa bona'};
is noun(q{summa bona})->classical->plural, q{summa bona}  => q{classical plural: 'summa bona' --> 'summa bona'};
is noun(q{acropolis})->classical->plural,   q{acropolises}  => q{classical plural: 'acropolis' --> 'acropolises'};
is noun(q{acropolises})->classical->plural, q{acropolises}  => q{classical plural: 'acropolises' --> 'acropolises'};
is noun(q{uomo universale})->classical->plural,   q{uomini universali}  => q{classical plural: 'uomo universale' --> 'uomini universali'};
is noun(q{uomini universali})->classical->plural, q{uomini universali}  => q{classical plural: 'uomini universali' --> 'uomini universali'};
is noun(q{metropolis})->classical->plural,   q{metropolises}  => q{classical plural: 'metropolis' --> 'metropolises'};
is noun(q{metropolises})->classical->plural, q{metropolises}  => q{classical plural: 'metropolises' --> 'metropolises'};
is noun(q{denarius})->classical->plural,   q{denarii}  => q{classical plural: 'denarius' --> 'denarii'};
is noun(q{denarii})->classical->plural, q{denarii}  => q{classical plural: 'denarii' --> 'denarii'};
is noun(q{terrae filius})->classical->plural,   q{terrae filii}  => q{classical plural: 'terrae filius' --> 'terrae filii'};
is noun(q{terrae filii})->classical->plural, q{terrae filii}  => q{classical plural: 'terrae filii' --> 'terrae filii'};
is noun(q{diplococcus})->classical->plural,   q{diplococci}  => q{classical plural: 'diplococcus' --> 'diplococci'};
is noun(q{diplococci})->classical->plural, q{diplococci}  => q{classical plural: 'diplococci' --> 'diplococci'};
is noun(q{zizz})->classical->plural,   q{zizzes}  => q{classical plural: 'zizz' --> 'zizzes'};
is noun(q{zizzes})->classical->plural, q{zizzes}  => q{classical plural: 'zizzes' --> 'zizzes'};
is noun(q{meatus})->classical->plural,   q{meatus}  => q{classical plural: 'meatus' --> 'meatus'};
is noun(q{mesothelium})->classical->plural,   q{mesothelia}  => q{classical plural: 'mesothelium' --> 'mesothelia'};
is noun(q{mesothelia})->classical->plural, q{mesothelia}  => q{classical plural: 'mesothelia' --> 'mesothelia'};
is noun(q{logo})->classical->plural,   q{logos}  => q{classical plural: 'logo' --> 'logos'};
is noun(q{logos})->classical->plural, q{logos}  => q{classical plural: 'logos' --> 'logos'};
is noun(q{ipse dixit})->classical->plural,   q{ipse dixits}  => q{classical plural: 'ipse dixit' --> 'ipse dixits'};
is noun(q{ipse dixits})->classical->plural, q{ipse dixits}  => q{classical plural: 'ipse dixits' --> 'ipse dixits'};
is noun(q{talouse})->classical->plural,   q{talouses}  => q{classical plural: 'talouse' --> 'talouses'};
is noun(q{talouses})->classical->plural, q{talouses}  => q{classical plural: 'talouses' --> 'talouses'};
is noun(q{pedicellaria})->classical->plural,   q{pedicellariae}  => q{classical plural: 'pedicellaria' --> 'pedicellariae'};
is noun(q{pedicellariae})->classical->plural, q{pedicellariae}  => q{classical plural: 'pedicellariae' --> 'pedicellariae'};
is noun(q{1-star general})->classical->plural,   q{1-star generals}  => q{classical plural: '1-star general' --> '1-star generals'};
is noun(q{1-star generals})->classical->plural, q{1-star generals}  => q{classical plural: '1-star generals' --> '1-star generals'};
is noun(q{vagus})->classical->plural,   q{vagi}  => q{classical plural: 'vagus' --> 'vagi'};
is noun(q{vagi})->classical->plural, q{vagi}  => q{classical plural: 'vagi' --> 'vagi'};
is noun(q{pseudopodium})->classical->plural,   q{pseudopodia}  => q{classical plural: 'pseudopodium' --> 'pseudopodia'};
is noun(q{pseudopodia})->classical->plural, q{pseudopodia}  => q{classical plural: 'pseudopodia' --> 'pseudopodia'};
is noun(q{yo yo})->classical->plural,   q{yo yos}  => q{classical plural: 'yo yo' --> 'yo yos'};
is noun(q{yo yos})->classical->plural, q{yo yos}  => q{classical plural: 'yo yos' --> 'yo yos'};
is noun(q{allegro})->classical->plural,   q{allegros}  => q{classical plural: 'allegro' --> 'allegros'};
is noun(q{allegros})->classical->plural, q{allegros}  => q{classical plural: 'allegros' --> 'allegros'};
is noun(q{vertebra})->classical->plural,   q{vertebrae}  => q{classical plural: 'vertebra' --> 'vertebrae'};
is noun(q{vertebrae})->classical->plural, q{vertebrae}  => q{classical plural: 'vertebrae' --> 'vertebrae'};
is noun(q{Ningbo})->classical->plural,   q{Ningbos}  => q{classical plural: 'Ningbo' --> 'Ningbos'};
is noun(q{Ningbos})->classical->plural, q{Ningbos}  => q{classical plural: 'Ningbos' --> 'Ningbos'};
is noun(q{fedai})->classical->plural,   q{fedai}  => q{classical plural: 'fedai' --> 'fedai'};
is noun(q{protarsus})->classical->plural,   q{protarsi}  => q{classical plural: 'protarsus' --> 'protarsi'};
is noun(q{protarsi})->classical->plural, q{protarsi}  => q{classical plural: 'protarsi' --> 'protarsi'};
is noun(q{Pardusco})->classical->plural,   q{Parduscos}  => q{classical plural: 'Pardusco' --> 'Parduscos'};
is noun(q{Parduscos})->classical->plural, q{Parduscos}  => q{classical plural: 'Parduscos' --> 'Parduscos'};
is noun(q{calathus})->classical->plural,   q{calathi}  => q{classical plural: 'calathus' --> 'calathi'};
is noun(q{calathi})->classical->plural, q{calathi}  => q{classical plural: 'calathi' --> 'calathi'};
is noun(q{Malabarese})->classical->plural,   q{Malabarese}  => q{classical plural: 'Malabarese' --> 'Malabarese'};
is noun(q{sciolus})->classical->plural,   q{scioli}  => q{classical plural: 'sciolus' --> 'scioli'};
is noun(q{scioli})->classical->plural, q{scioli}  => q{classical plural: 'scioli' --> 'scioli'};
is noun(q{paraganglioma})->classical->plural,   q{paragangliomata}  => q{classical plural: 'paraganglioma' --> 'paragangliomata'};
is noun(q{paragangliomata})->classical->plural, q{paragangliomata}  => q{classical plural: 'paragangliomata' --> 'paragangliomata'};
is noun(q{salivarium})->classical->plural,   q{salivaria}  => q{classical plural: 'salivarium' --> 'salivaria'};
is noun(q{salivaria})->classical->plural, q{salivaria}  => q{classical plural: 'salivaria' --> 'salivaria'};
is noun(q{tegmentum})->classical->plural,   q{tegmenta}  => q{classical plural: 'tegmentum' --> 'tegmenta'};
is noun(q{tegmenta})->classical->plural, q{tegmenta}  => q{classical plural: 'tegmenta' --> 'tegmenta'};
is noun(q{stylopodium})->classical->plural,   q{stylopodia}  => q{classical plural: 'stylopodium' --> 'stylopodia'};
is noun(q{stylopodia})->classical->plural, q{stylopodia}  => q{classical plural: 'stylopodia' --> 'stylopodia'};
is noun(q{loa})->classical->plural,   q{loa}  => q{classical plural: 'loa' --> 'loa'};
is noun(q{elf})->classical->plural,   q{elves}  => q{classical plural: 'elf' --> 'elves'};
is noun(q{elves})->classical->plural, q{elves}  => q{classical plural: 'elves' --> 'elves'};
is noun(q{sericterium})->classical->plural,   q{sericteria}  => q{classical plural: 'sericterium' --> 'sericteria'};
is noun(q{sericteria})->classical->plural, q{sericteria}  => q{classical plural: 'sericteria' --> 'sericteria'};
is noun(q{quinarius})->classical->plural,   q{quinarii}  => q{classical plural: 'quinarius' --> 'quinarii'};
is noun(q{quinarii})->classical->plural, q{quinarii}  => q{classical plural: 'quinarii' --> 'quinarii'};
is noun(q{zitella})->classical->plural,   q{zitelle}  => q{classical plural: 'zitella' --> 'zitelle'};
is noun(q{zitelle})->classical->plural, q{zitelle}  => q{classical plural: 'zitelle' --> 'zitelle'};
is noun(q{triforium})->classical->plural,   q{triforia}  => q{classical plural: 'triforium' --> 'triforia'};
is noun(q{triforia})->classical->plural, q{triforia}  => q{classical plural: 'triforia' --> 'triforia'};
is noun(q{propylon})->classical->plural,   q{propyla}  => q{classical plural: 'propylon' --> 'propyla'};
is noun(q{propyla})->classical->plural, q{propyla}  => q{classical plural: 'propyla' --> 'propyla'};
is noun(q{woman child})->classical->plural,   q{women children}  => q{classical plural: 'woman child' --> 'women children'};
is noun(q{women children})->classical->plural, q{women children}  => q{classical plural: 'women children' --> 'women children'};
is noun(q{limo})->classical->plural,   q{limos}  => q{classical plural: 'limo' --> 'limos'};
is noun(q{limos})->classical->plural, q{limos}  => q{classical plural: 'limos' --> 'limos'};
is noun(q{yarraman})->classical->plural,   q{yarramans}  => q{classical plural: 'yarraman' --> 'yarramans'};
is noun(q{yarramans})->classical->plural, q{yarramans}  => q{classical plural: 'yarramans' --> 'yarramans'};
is noun(q{pomme de terre})->classical->plural,   q{pommes de terre}  => q{classical plural: 'pomme de terre' --> 'pommes de terre'};
is noun(q{pommes de terre})->classical->plural, q{pommes de terre}  => q{classical plural: 'pommes de terre' --> 'pommes de terre'};
is noun(q{nymphaeum})->classical->plural,   q{nymphaea}  => q{classical plural: 'nymphaeum' --> 'nymphaea'};
is noun(q{nymphaea})->classical->plural, q{nymphaea}  => q{classical plural: 'nymphaea' --> 'nymphaea'};
is noun(q{tremolo})->classical->plural,   q{tremolos}  => q{classical plural: 'tremolo' --> 'tremolos'};
is noun(q{tremolos})->classical->plural, q{tremolos}  => q{classical plural: 'tremolos' --> 'tremolos'};
is noun(q{Avignonese})->classical->plural,   q{Avignonese}  => q{classical plural: 'Avignonese' --> 'Avignonese'};
is noun(q{aide-de-camp})->classical->plural,   q{aides-de-camp}  => q{classical plural: 'aide-de-camp' --> 'aides-de-camp'};
is noun(q{aides-de-camp})->classical->plural, q{aides-de-camp}  => q{classical plural: 'aides-de-camp' --> 'aides-de-camp'};
is noun(q{index})->classical->plural,   q{indices}  => q{classical plural: 'index' --> 'indices'};
is noun(q{indices})->classical->plural, q{indices}  => q{classical plural: 'indices' --> 'indices'};
is noun(q{pedion})->classical->plural,   q{pedia}  => q{classical plural: 'pedion' --> 'pedia'};
is noun(q{pedia})->classical->plural, q{pedia}  => q{classical plural: 'pedia' --> 'pedia'};
is noun(q{scudo})->classical->plural,   q{scudi}  => q{classical plural: 'scudo' --> 'scudi'};
is noun(q{scudi})->classical->plural, q{scudi}  => q{classical plural: 'scudi' --> 'scudi'};
is noun(q{scuola})->classical->plural,   q{scuole}  => q{classical plural: 'scuola' --> 'scuole'};
is noun(q{scuole})->classical->plural, q{scuole}  => q{classical plural: 'scuole' --> 'scuole'};
is noun(q{larynx})->classical->plural,   q{larynges}  => q{classical plural: 'larynx' --> 'larynges'};
is noun(q{larynges})->classical->plural, q{larynges}  => q{classical plural: 'larynges' --> 'larynges'};
is noun(q{metatarsus})->classical->plural,   q{metatarsi}  => q{classical plural: 'metatarsus' --> 'metatarsi'};
is noun(q{metatarsi})->classical->plural, q{metatarsi}  => q{classical plural: 'metatarsi' --> 'metatarsi'};
is noun(q{Andamanese})->classical->plural,   q{Andamanese}  => q{classical plural: 'Andamanese' --> 'Andamanese'};
is noun(q{interaxis})->classical->plural,   q{interaxes}  => q{classical plural: 'interaxis' --> 'interaxes'};
is noun(q{interaxes})->classical->plural, q{interaxes}  => q{classical plural: 'interaxes' --> 'interaxes'};
is noun(q{zadruga})->classical->plural,   q{zadruge}  => q{classical plural: 'zadruga' --> 'zadruge'};
is noun(q{zadruge})->classical->plural, q{zadruge}  => q{classical plural: 'zadruge' --> 'zadruge'};
is noun(q{bursch})->classical->plural,   q{burschen}  => q{classical plural: 'bursch' --> 'burschen'};
is noun(q{burschen})->classical->plural, q{burschen}  => q{classical plural: 'burschen' --> 'burschen'};
is noun(q{fabliau})->classical->plural,   q{fabliaux}  => q{classical plural: 'fabliau' --> 'fabliaux'};
is noun(q{fabliaux})->classical->plural, q{fabliaux}  => q{classical plural: 'fabliaux' --> 'fabliaux'};
is noun(q{suggestio falsi})->classical->plural,   q{suggestiones falsi}  => q{classical plural: 'suggestio falsi' --> 'suggestiones falsi'};
is noun(q{suggestiones falsi})->classical->plural, q{suggestiones falsi}  => q{classical plural: 'suggestiones falsi' --> 'suggestiones falsi'};
is noun(q{germarium})->classical->plural,   q{germaria}  => q{classical plural: 'germarium' --> 'germaria'};
is noun(q{germaria})->classical->plural, q{germaria}  => q{classical plural: 'germaria' --> 'germaria'};
is noun(q{plasmalemma})->classical->plural,   q{plasmalemmae}  => q{classical plural: 'plasmalemma' --> 'plasmalemmae'};
is noun(q{plasmalemmae})->classical->plural, q{plasmalemmae}  => q{classical plural: 'plasmalemmae' --> 'plasmalemmae'};
is noun(q{pala})->classical->plural,   q{palae}  => q{classical plural: 'pala' --> 'palae'};
is noun(q{palae})->classical->plural, q{palae}  => q{classical plural: 'palae' --> 'palae'};
is noun(q{porcino})->classical->plural,   q{porcini}  => q{classical plural: 'porcino' --> 'porcini'};
is noun(q{porcini})->classical->plural, q{porcini}  => q{classical plural: 'porcini' --> 'porcini'};
is noun(q{Sogdianese})->classical->plural,   q{Sogdianese}  => q{classical plural: 'Sogdianese' --> 'Sogdianese'};
is noun(q{glass})->classical->plural,   q{glasses}  => q{classical plural: 'glass' --> 'glasses'};
is noun(q{diabetes})->classical->plural,   q{diabetes}  => q{classical plural: 'diabetes' --> 'diabetes'};
is noun(q{Tyrolese})->classical->plural,   q{Tyrolese}  => q{classical plural: 'Tyrolese' --> 'Tyrolese'};
is noun(q{scolopidium})->classical->plural,   q{scolopidia}  => q{classical plural: 'scolopidium' --> 'scolopidia'};
is noun(q{scolopidia})->classical->plural, q{scolopidia}  => q{classical plural: 'scolopidia' --> 'scolopidia'};
is noun(q{Singhalese})->classical->plural,   q{Singhalese}  => q{classical plural: 'Singhalese' --> 'Singhalese'};
is noun(q{caddis})->classical->plural,   q{caddises}  => q{classical plural: 'caddis' --> 'caddises'};
is noun(q{caddises})->classical->plural, q{caddises}  => q{classical plural: 'caddises' --> 'caddises'};
is noun(q{concetto})->classical->plural,   q{concetti}  => q{classical plural: 'concetto' --> 'concetti'};
is noun(q{concetti})->classical->plural, q{concetti}  => q{classical plural: 'concetti' --> 'concetti'};
is noun(q{monstre sacre})->classical->plural,   q{monstres sacres}  => q{classical plural: 'monstre sacre' --> 'monstres sacres'};
is noun(q{monstres sacres})->classical->plural, q{monstres sacres}  => q{classical plural: 'monstres sacres' --> 'monstres sacres'};
is noun(q{tarantato})->classical->plural,   q{tarantati}  => q{classical plural: 'tarantato' --> 'tarantati'};
is noun(q{tarantati})->classical->plural, q{tarantati}  => q{classical plural: 'tarantati' --> 'tarantati'};
is noun(q{diastema})->classical->plural,   q{diastemata}  => q{classical plural: 'diastema' --> 'diastemata'};
is noun(q{diastemata})->classical->plural, q{diastemata}  => q{classical plural: 'diastemata' --> 'diastemata'};
is noun(q{ranunculus})->classical->plural,   q{ranunculi}  => q{classical plural: 'ranunculus' --> 'ranunculi'};
is noun(q{ranunculi})->classical->plural, q{ranunculi}  => q{classical plural: 'ranunculi' --> 'ranunculi'};
is noun(q{nauplius})->classical->plural,   q{nauplii}  => q{classical plural: 'nauplius' --> 'nauplii'};
is noun(q{nauplii})->classical->plural, q{nauplii}  => q{classical plural: 'nauplii' --> 'nauplii'};
is noun(q{neuma})->classical->plural,   q{neumata}  => q{classical plural: 'neuma' --> 'neumata'};
is noun(q{neumata})->classical->plural, q{neumata}  => q{classical plural: 'neumata' --> 'neumata'};
is noun(q{osculum})->classical->plural,   q{oscula}  => q{classical plural: 'osculum' --> 'oscula'};
is noun(q{oscula})->classical->plural, q{oscula}  => q{classical plural: 'oscula' --> 'oscula'};
is noun(q{fungus})->classical->plural,   q{fungi}  => q{classical plural: 'fungus' --> 'fungi'};
is noun(q{fungi})->classical->plural, q{fungi}  => q{classical plural: 'fungi' --> 'fungi'};
is noun(q{hinaki})->classical->plural,   q{hinaki}  => q{classical plural: 'hinaki' --> 'hinaki'};
is noun(q{monorchis})->classical->plural,   q{monorchides}  => q{classical plural: 'monorchis' --> 'monorchides'};
is noun(q{monorchides})->classical->plural, q{monorchides}  => q{classical plural: 'monorchides' --> 'monorchides'};
is noun(q{pincer})->classical->plural,   q{pincers}  => q{classical plural: 'pincer' --> 'pincers'};
is noun(q{brother german})->classical->plural,   q{brethren german}  => q{classical plural: 'brother german' --> 'brethren german'};
is noun(q{brethren german})->classical->plural, q{brethren german}  => q{classical plural: 'brethren german' --> 'brethren german'};
is noun(q{mezuzah})->classical->plural,   q{mezuzoth}  => q{classical plural: 'mezuzah' --> 'mezuzoth'};
is noun(q{mezuzoth})->classical->plural, q{mezuzoth}  => q{classical plural: 'mezuzoth' --> 'mezuzoth'};
is noun(q{designatum})->classical->plural,   q{designata}  => q{classical plural: 'designatum' --> 'designata'};
is noun(q{designata})->classical->plural, q{designata}  => q{classical plural: 'designata' --> 'designata'};
is noun(q{ruse de guerre})->classical->plural,   q{ruses de guerre}  => q{classical plural: 'ruse de guerre' --> 'ruses de guerre'};
is noun(q{ruses de guerre})->classical->plural, q{ruses de guerre}  => q{classical plural: 'ruses de guerre' --> 'ruses de guerre'};
is noun(q{pleuron})->classical->plural,   q{pleura}  => q{classical plural: 'pleuron' --> 'pleura'};
is noun(q{amentum})->classical->plural,   q{amenta}  => q{classical plural: 'amentum' --> 'amenta'};
is noun(q{amenta})->classical->plural, q{amenta}  => q{classical plural: 'amenta' --> 'amenta'};
is noun(q{gumma})->classical->plural,   q{gummata}  => q{classical plural: 'gumma' --> 'gummata'};
is noun(q{gummata})->classical->plural, q{gummata}  => q{classical plural: 'gummata' --> 'gummata'};
is noun(q{loaf})->classical->plural,   q{loaves}  => q{classical plural: 'loaf' --> 'loaves'};
is noun(q{loaves})->classical->plural, q{loaves}  => q{classical plural: 'loaves' --> 'loaves'};
is noun(q{fabella})->classical->plural,   q{fabellae}  => q{classical plural: 'fabella' --> 'fabellae'};
is noun(q{fabellae})->classical->plural, q{fabellae}  => q{classical plural: 'fabellae' --> 'fabellae'};
is noun(q{phenomenon})->classical->plural,   q{phenomena}  => q{classical plural: 'phenomenon' --> 'phenomena'};
is noun(q{phenomena})->classical->plural, q{phenomena}  => q{classical plural: 'phenomena' --> 'phenomena'};
is noun(q{honorarium})->classical->plural,   q{honoraria}  => q{classical plural: 'honorarium' --> 'honoraria'};
is noun(q{honoraria})->classical->plural, q{honoraria}  => q{classical plural: 'honoraria' --> 'honoraria'};
is noun(q{man-servant})->classical->plural,   q{men-servants}  => q{classical plural: 'man-servant' --> 'men-servants'};
is noun(q{men-servants})->classical->plural, q{men-servants}  => q{classical plural: 'men-servants' --> 'men-servants'};
is noun(q{generalissimo})->classical->plural,   q{generalissimos}  => q{classical plural: 'generalissimo' --> 'generalissimos'};
is noun(q{generalissimos})->classical->plural, q{generalissimos}  => q{classical plural: 'generalissimos' --> 'generalissimos'};
is noun(q{guglio})->classical->plural,   q{guglioes}  => q{classical plural: 'guglio' --> 'guglioes'};
is noun(q{guglioes})->classical->plural, q{guglioes}  => q{classical plural: 'guglioes' --> 'guglioes'};
is noun(q{paries})->classical->plural,   q{parietes}  => q{classical plural: 'paries' --> 'parietes'};
is noun(q{parietes})->classical->plural, q{parietes}  => q{classical plural: 'parietes' --> 'parietes'};
is noun(q{sambo})->classical->plural,   q{samboes}  => q{classical plural: 'sambo' --> 'samboes'};
is noun(q{samboes})->classical->plural, q{samboes}  => q{classical plural: 'samboes' --> 'samboes'};
is noun(q{stephanion})->classical->plural,   q{stephania}  => q{classical plural: 'stephanion' --> 'stephania'};
is noun(q{stephania})->classical->plural, q{stephania}  => q{classical plural: 'stephania' --> 'stephania'};
is noun(q{perithecium})->classical->plural,   q{perithecia}  => q{classical plural: 'perithecium' --> 'perithecia'};
is noun(q{perithecia})->classical->plural, q{perithecia}  => q{classical plural: 'perithecia' --> 'perithecia'};
is noun(q{Macanese})->classical->plural,   q{Macanese}  => q{classical plural: 'Macanese' --> 'Macanese'};
is noun(q{niello})->classical->plural,   q{nielli}  => q{classical plural: 'niello' --> 'nielli'};
is noun(q{nielli})->classical->plural, q{nielli}  => q{classical plural: 'nielli' --> 'nielli'};
is noun(q{villanella})->classical->plural,   q{villanelle}  => q{classical plural: 'villanella' --> 'villanelle'};
is noun(q{villanelle})->classical->plural, q{villanelle}  => q{classical plural: 'villanelle' --> 'villanelle'};
is noun(q{faveolus})->classical->plural,   q{faveoli}  => q{classical plural: 'faveolus' --> 'faveoli'};
is noun(q{faveoli})->classical->plural, q{faveoli}  => q{classical plural: 'faveoli' --> 'faveoli'};
is noun(q{ala})->classical->plural,   q{alae}  => q{classical plural: 'ala' --> 'alae'};
is noun(q{alae})->classical->plural, q{alae}  => q{classical plural: 'alae' --> 'alae'};
is noun(q{giuncus})->classical->plural,   q{giunchi}  => q{classical plural: 'giuncus' --> 'giunchi'};
is noun(q{giunchi})->classical->plural, q{giunchi}  => q{classical plural: 'giunchi' --> 'giunchi'};
is noun(q{ramulus})->classical->plural,   q{ramuli}  => q{classical plural: 'ramulus' --> 'ramuli'};
is noun(q{ramuli})->classical->plural, q{ramuli}  => q{classical plural: 'ramuli' --> 'ramuli'};
is noun(q{hippocampus})->classical->plural,   q{hippocampi}  => q{classical plural: 'hippocampus' --> 'hippocampi'};
is noun(q{hippocampi})->classical->plural, q{hippocampi}  => q{classical plural: 'hippocampi' --> 'hippocampi'};
is noun(q{Gestapo})->classical->plural,   q{Gestapos}  => q{classical plural: 'Gestapo' --> 'Gestapos'};
is noun(q{Gestapos})->classical->plural, q{Gestapos}  => q{classical plural: 'Gestapos' --> 'Gestapos'};
is noun(q{batz})->classical->plural,   q{batzes}  => q{classical plural: 'batz' --> 'batzes'};
is noun(q{batzes})->classical->plural, q{batzes}  => q{classical plural: 'batzes' --> 'batzes'};
is noun(q{money})->classical->plural,   q{monies}  => q{classical plural: 'money' --> 'monies'};
is noun(q{monies})->classical->plural, q{monies}  => q{classical plural: 'monies' --> 'monies'};
is noun(q{aficionado})->classical->plural,   q{aficionados}  => q{classical plural: 'aficionado' --> 'aficionados'};
is noun(q{aficionados})->classical->plural, q{aficionados}  => q{classical plural: 'aficionados' --> 'aficionados'};
is noun(q{abortorium})->classical->plural,   q{abortoria}  => q{classical plural: 'abortorium' --> 'abortoria'};
is noun(q{abortoria})->classical->plural, q{abortoria}  => q{classical plural: 'abortoria' --> 'abortoria'};
is noun(q{zucchini})->classical->plural,   q{zucchini}  => q{classical plural: 'zucchini' --> 'zucchini'};
is noun(q{pueblo})->classical->plural,   q{pueblos}  => q{classical plural: 'pueblo' --> 'pueblos'};
is noun(q{pueblos})->classical->plural, q{pueblos}  => q{classical plural: 'pueblos' --> 'pueblos'};
is noun(q{condo})->classical->plural,   q{condos}  => q{classical plural: 'condo' --> 'condos'};
is noun(q{condos})->classical->plural, q{condos}  => q{classical plural: 'condos' --> 'condos'};
is noun(q{bel-esprit})->classical->plural,   q{beaux esprits}  => q{classical plural: 'bel-esprit' --> 'beaux esprits'};
is noun(q{beaux esprits})->classical->plural, q{beaux esprits}  => q{classical plural: 'beaux esprits' --> 'beaux esprits'};
is noun(q{varix})->classical->plural,   q{varices}  => q{classical plural: 'varix' --> 'varices'};
is noun(q{varices})->classical->plural, q{varices}  => q{classical plural: 'varices' --> 'varices'};
is noun(q{programma})->classical->plural,   q{programmata}  => q{classical plural: 'programma' --> 'programmata'};
is noun(q{programmata})->classical->plural, q{programmata}  => q{classical plural: 'programmata' --> 'programmata'};
is noun(q{franc-archer})->classical->plural,   q{francs-archers}  => q{classical plural: 'franc-archer' --> 'francs-archers'};
is noun(q{francs-archers})->classical->plural, q{francs-archers}  => q{classical plural: 'francs-archers' --> 'francs-archers'};
is noun(q{contretemps})->classical->plural,   q{contretemps}  => q{classical plural: 'contretemps' --> 'contretemps'};
is noun(q{regma})->classical->plural,   q{regmata}  => q{classical plural: 'regma' --> 'regmata'};
is noun(q{regmata})->classical->plural, q{regmata}  => q{classical plural: 'regmata' --> 'regmata'};
is noun(q{ballista})->classical->plural,   q{ballistae}  => q{classical plural: 'ballista' --> 'ballistae'};
is noun(q{ballistae})->classical->plural, q{ballistae}  => q{classical plural: 'ballistae' --> 'ballistae'};
is noun(q{arcosolium})->classical->plural,   q{arcosolia}  => q{classical plural: 'arcosolium' --> 'arcosolia'};
is noun(q{arcosolia})->classical->plural, q{arcosolia}  => q{classical plural: 'arcosolia' --> 'arcosolia'};
is noun(q{likuta})->classical->plural,   q{makuta}  => q{classical plural: 'likuta' --> 'makuta'};
is noun(q{makuta})->classical->plural, q{makuta}  => q{classical plural: 'makuta' --> 'makuta'};
is noun(q{epilimnion})->classical->plural,   q{epilimnia}  => q{classical plural: 'epilimnion' --> 'epilimnia'};
is noun(q{epilimnia})->classical->plural, q{epilimnia}  => q{classical plural: 'epilimnia' --> 'epilimnia'};
is noun(q{genie})->classical->plural,   q{genii}  => q{classical plural: 'genie' --> 'genii'};
is noun(q{genii})->classical->plural, q{genii}  => q{classical plural: 'genii' --> 'genii'};
is noun(q{responsum})->classical->plural,   q{responsa}  => q{classical plural: 'responsum' --> 'responsa'};
is noun(q{responsa})->classical->plural, q{responsa}  => q{classical plural: 'responsa' --> 'responsa'};
is noun(q{intervallum})->classical->plural,   q{intervalla}  => q{classical plural: 'intervallum' --> 'intervalla'};
is noun(q{intervalla})->classical->plural, q{intervalla}  => q{classical plural: 'intervalla' --> 'intervalla'};
is noun(q{plica})->classical->plural,   q{plicae}  => q{classical plural: 'plica' --> 'plicae'};
is noun(q{plicae})->classical->plural, q{plicae}  => q{classical plural: 'plicae' --> 'plicae'};
is noun(q{Cassinese})->classical->plural,   q{Cassinese}  => q{classical plural: 'Cassinese' --> 'Cassinese'};
is noun(q{falx})->classical->plural,   q{falces}  => q{classical plural: 'falx' --> 'falces'};
is noun(q{falces})->classical->plural, q{falces}  => q{classical plural: 'falces' --> 'falces'};
is noun(q{teratoma})->classical->plural,   q{teratomata}  => q{classical plural: 'teratoma' --> 'teratomata'};
is noun(q{teratomata})->classical->plural, q{teratomata}  => q{classical plural: 'teratomata' --> 'teratomata'};
is noun(q{fasciculus})->classical->plural,   q{fasciculi}  => q{classical plural: 'fasciculus' --> 'fasciculi'};
is noun(q{fasciculi})->classical->plural, q{fasciculi}  => q{classical plural: 'fasciculi' --> 'fasciculi'};
is noun(q{scotoma})->classical->plural,   q{scotomata}  => q{classical plural: 'scotoma' --> 'scotomata'};
is noun(q{scotomata})->classical->plural, q{scotomata}  => q{classical plural: 'scotomata' --> 'scotomata'};
is noun(q{thraso})->classical->plural,   q{thrasones}  => q{classical plural: 'thraso' --> 'thrasones'};
is noun(q{thrasones})->classical->plural, q{thrasones}  => q{classical plural: 'thrasones' --> 'thrasones'};
is noun(q{mezzo-rilievo})->classical->plural,   q{mezzo-rilievos}  => q{classical plural: 'mezzo-rilievo' --> 'mezzo-rilievos'};
is noun(q{mezzo-rilievos})->classical->plural, q{mezzo-rilievos}  => q{classical plural: 'mezzo-rilievos' --> 'mezzo-rilievos'};
is noun(q{proseucha})->classical->plural,   q{proseuchae}  => q{classical plural: 'proseucha' --> 'proseuchae'};
is noun(q{proseuchae})->classical->plural, q{proseuchae}  => q{classical plural: 'proseuchae' --> 'proseuchae'};
is noun(q{Barquisimeto})->classical->plural,   q{Barquisimetos}  => q{classical plural: 'Barquisimeto' --> 'Barquisimetos'};
is noun(q{Barquisimetos})->classical->plural, q{Barquisimetos}  => q{classical plural: 'Barquisimetos' --> 'Barquisimetos'};
is noun(q{caffe ristretto})->classical->plural,   q{caffe ristretti}  => q{classical plural: 'caffe ristretto' --> 'caffe ristretti'};
is noun(q{caffe ristretti})->classical->plural, q{caffe ristretti}  => q{classical plural: 'caffe ristretti' --> 'caffe ristretti'};
is noun(q{set-to})->classical->plural,   q{sets-to}  => q{classical plural: 'set-to' --> 'sets-to'};
is noun(q{sets-to})->classical->plural, q{sets-to}  => q{classical plural: 'sets-to' --> 'sets-to'};
is noun(q{gluteus})->classical->plural,   q{glutaei}  => q{classical plural: 'gluteus' --> 'glutaei'};
is noun(q{glutaei})->classical->plural, q{glutaei}  => q{classical plural: 'glutaei' --> 'glutaei'};
is noun(q{scyphus})->classical->plural,   q{scyphi}  => q{classical plural: 'scyphus' --> 'scyphi'};
is noun(q{scyphi})->classical->plural, q{scyphi}  => q{classical plural: 'scyphi' --> 'scyphi'};
is noun(q{paranucleus})->classical->plural,   q{paranuclei}  => q{classical plural: 'paranucleus' --> 'paranuclei'};
is noun(q{paranuclei})->classical->plural, q{paranuclei}  => q{classical plural: 'paranuclei' --> 'paranuclei'};
is noun(q{frenum})->classical->plural,   q{fraena}  => q{classical plural: 'frenum' --> 'fraena'};
is noun(q{fraena})->classical->plural, q{fraena}  => q{classical plural: 'fraena' --> 'fraena'};
is noun(q{Norman})->classical->plural,   q{Normans}  => q{classical plural: 'Norman' --> 'Normans'};
is noun(q{Normans})->classical->plural, q{Normans}  => q{classical plural: 'Normans' --> 'Normans'};
is noun(q{silenus})->classical->plural,   q{sileni}  => q{classical plural: 'silenus' --> 'sileni'};
is noun(q{sileni})->classical->plural, q{sileni}  => q{classical plural: 'sileni' --> 'sileni'};
is noun(q{vlakte})->classical->plural,   q{vlakten}  => q{classical plural: 'vlakte' --> 'vlakten'};
is noun(q{vlakten})->classical->plural, q{vlakten}  => q{classical plural: 'vlakten' --> 'vlakten'};
is noun(q{pietra})->classical->plural,   q{pietre}  => q{classical plural: 'pietra' --> 'pietre'};
is noun(q{pietre})->classical->plural, q{pietre}  => q{classical plural: 'pietre' --> 'pietre'};
is noun(q{wady})->classical->plural,   q{wadys}  => q{classical plural: 'wady' --> 'wadys'};
is noun(q{wadys})->classical->plural, q{wadys}  => q{classical plural: 'wadys' --> 'wadys'};
is noun(q{contadino})->classical->plural,   q{contadini}  => q{classical plural: 'contadino' --> 'contadini'};
is noun(q{contadini})->classical->plural, q{contadini}  => q{classical plural: 'contadini' --> 'contadini'};
is noun(q{osteoma})->classical->plural,   q{osteomata}  => q{classical plural: 'osteoma' --> 'osteomata'};
is noun(q{osteomata})->classical->plural, q{osteomata}  => q{classical plural: 'osteomata' --> 'osteomata'};
is noun(q{kantharos})->classical->plural,   q{kantharoi}  => q{classical plural: 'kantharos' --> 'kantharoi'};
is noun(q{kantharoi})->classical->plural, q{kantharoi}  => q{classical plural: 'kantharoi' --> 'kantharoi'};
is noun(q{chromonema})->classical->plural,   q{chromonemata}  => q{classical plural: 'chromonema' --> 'chromonemata'};
is noun(q{chromonemata})->classical->plural, q{chromonemata}  => q{classical plural: 'chromonemata' --> 'chromonemata'};
is noun(q{ispravnik})->classical->plural,   q{ispravniki}  => q{classical plural: 'ispravnik' --> 'ispravniki'};
is noun(q{ispravniki})->classical->plural, q{ispravniki}  => q{classical plural: 'ispravniki' --> 'ispravniki'};
is noun(q{rondo})->classical->plural,   q{rondos}  => q{classical plural: 'rondo' --> 'rondos'};
is noun(q{rondos})->classical->plural, q{rondos}  => q{classical plural: 'rondos' --> 'rondos'};
is noun(q{interregnum})->classical->plural,   q{interregna}  => q{classical plural: 'interregnum' --> 'interregna'};
is noun(q{interregna})->classical->plural, q{interregna}  => q{classical plural: 'interregna' --> 'interregna'};
is noun(q{planula})->classical->plural,   q{planulae}  => q{classical plural: 'planula' --> 'planulae'};
is noun(q{planulae})->classical->plural, q{planulae}  => q{classical plural: 'planulae' --> 'planulae'};
is noun(q{kioko})->classical->plural,   q{kioko}  => q{classical plural: 'kioko' --> 'kioko'};
is noun(q{penny})->classical->plural,   q{pence}  => q{classical plural: 'penny' --> 'pence'};
is noun(q{soralium})->classical->plural,   q{soralia}  => q{classical plural: 'soralium' --> 'soralia'};
is noun(q{soralia})->classical->plural, q{soralia}  => q{classical plural: 'soralia' --> 'soralia'};
is noun(q{Lorrainese})->classical->plural,   q{Lorrainese}  => q{classical plural: 'Lorrainese' --> 'Lorrainese'};
is noun(q{hernia})->classical->plural,   q{herniae}  => q{classical plural: 'hernia' --> 'herniae'};
is noun(q{herniae})->classical->plural, q{herniae}  => q{classical plural: 'herniae' --> 'herniae'};
is noun(q{haddock})->classical->plural,   q{haddock}  => q{classical plural: 'haddock' --> 'haddock'};
is noun(q{man-child})->classical->plural,   q{men-children}  => q{classical plural: 'man-child' --> 'men-children'};
is noun(q{men-children})->classical->plural, q{men-children}  => q{classical plural: 'men-children' --> 'men-children'};
is noun(q{calamistrum})->classical->plural,   q{calamistra}  => q{classical plural: 'calamistrum' --> 'calamistra'};
is noun(q{calamistra})->classical->plural, q{calamistra}  => q{classical plural: 'calamistra' --> 'calamistra'};
is noun(q{indusium})->classical->plural,   q{indusia}  => q{classical plural: 'indusium' --> 'indusia'};
is noun(q{indusia})->classical->plural, q{indusia}  => q{classical plural: 'indusia' --> 'indusia'};
is noun(q{inoculum})->classical->plural,   q{inocula}  => q{classical plural: 'inoculum' --> 'inocula'};
is noun(q{inocula})->classical->plural, q{inocula}  => q{classical plural: 'inocula' --> 'inocula'};
is noun(q{minutia})->classical->plural,   q{minutiae}  => q{classical plural: 'minutia' --> 'minutiae'};
is noun(q{minutiae})->classical->plural, q{minutiae}  => q{classical plural: 'minutiae' --> 'minutiae'};
is noun(q{torma})->classical->plural,   q{torma}  => q{classical plural: 'torma' --> 'torma'};
is noun(q{ragazza})->classical->plural,   q{ragazze}  => q{classical plural: 'ragazza' --> 'ragazze'};
is noun(q{ragazze})->classical->plural, q{ragazze}  => q{classical plural: 'ragazze' --> 'ragazze'};
is noun(q{parador})->classical->plural,   q{paradores}  => q{classical plural: 'parador' --> 'paradores'};
is noun(q{paradores})->classical->plural, q{paradores}  => q{classical plural: 'paradores' --> 'paradores'};
is noun(q{melastoma})->classical->plural,   q{melastomae}  => q{classical plural: 'melastoma' --> 'melastomae'};
is noun(q{melastomae})->classical->plural, q{melastomae}  => q{classical plural: 'melastomae' --> 'melastomae'};
is noun(q{octohedron})->classical->plural,   q{octohedra}  => q{classical plural: 'octohedron' --> 'octohedra'};
is noun(q{octohedra})->classical->plural, q{octohedra}  => q{classical plural: 'octohedra' --> 'octohedra'};
is noun(q{trousers})->classical->plural,   q{trousers}  => q{classical plural: 'trousers' --> 'trousers'};
is noun(q{whosever})->classical->plural,   q{whosever}  => q{classical plural: 'whosever' --> 'whosever'};
is noun(q{osteoclastoma})->classical->plural,   q{osteoclastomata}  => q{classical plural: 'osteoclastoma' --> 'osteoclastomata'};
is noun(q{osteoclastomata})->classical->plural, q{osteoclastomata}  => q{classical plural: 'osteoclastomata' --> 'osteoclastomata'};
is noun(q{phyllobranchia})->classical->plural,   q{phyllobranchiae}  => q{classical plural: 'phyllobranchia' --> 'phyllobranchiae'};
is noun(q{phyllobranchiae})->classical->plural, q{phyllobranchiae}  => q{classical plural: 'phyllobranchiae' --> 'phyllobranchiae'};
is noun(q{helix})->classical->plural,   q{helices}  => q{classical plural: 'helix' --> 'helices'};
is noun(q{helices})->classical->plural, q{helices}  => q{classical plural: 'helices' --> 'helices'};
is noun(q{suppositum})->classical->plural,   q{supposita}  => q{classical plural: 'suppositum' --> 'supposita'};
is noun(q{supposita})->classical->plural, q{supposita}  => q{classical plural: 'supposita' --> 'supposita'};
is noun(q{Purum})->classical->plural,   q{Purum}  => q{classical plural: 'Purum' --> 'Purum'};
is noun(q{verso})->classical->plural,   q{versos}  => q{classical plural: 'verso' --> 'versos'};
is noun(q{versos})->classical->plural, q{versos}  => q{classical plural: 'versos' --> 'versos'};
is noun(q{acarus})->classical->plural,   q{acari}  => q{classical plural: 'acarus' --> 'acari'};
is noun(q{acari})->classical->plural, q{acari}  => q{classical plural: 'acari' --> 'acari'};
is noun(q{scolex})->classical->plural,   q{scoleces}  => q{classical plural: 'scolex' --> 'scoleces'};
is noun(q{scoleces})->classical->plural, q{scoleces}  => q{classical plural: 'scoleces' --> 'scoleces'};
is noun(q{sterigma})->classical->plural,   q{sterigmata}  => q{classical plural: 'sterigma' --> 'sterigmata'};
is noun(q{sterigmata})->classical->plural, q{sterigmata}  => q{classical plural: 'sterigmata' --> 'sterigmata'};
is noun(q{Esperanto})->classical->plural,   q{Esperantos}  => q{classical plural: 'Esperanto' --> 'Esperantos'};
is noun(q{Esperantos})->classical->plural, q{Esperantos}  => q{classical plural: 'Esperantos' --> 'Esperantos'};
is noun(q{urus})->classical->plural,   q{uri}  => q{classical plural: 'urus' --> 'uri'};
is noun(q{uri})->classical->plural, q{uri}  => q{classical plural: 'uri' --> 'uri'};
is noun(q{seecatch})->classical->plural,   q{seecatchie}  => q{classical plural: 'seecatch' --> 'seecatchie'};
is noun(q{seecatchie})->classical->plural, q{seecatchie}  => q{classical plural: 'seecatchie' --> 'seecatchie'};
is noun(q{verticillus})->classical->plural,   q{verticilli}  => q{classical plural: 'verticillus' --> 'verticilli'};
is noun(q{verticilli})->classical->plural, q{verticilli}  => q{classical plural: 'verticilli' --> 'verticilli'};
is noun(q{bregma})->classical->plural,   q{bregmata}  => q{classical plural: 'bregma' --> 'bregmata'};
is noun(q{bregmata})->classical->plural, q{bregmata}  => q{classical plural: 'bregmata' --> 'bregmata'};
is noun(q{waldo})->classical->plural,   q{waldoes}  => q{classical plural: 'waldo' --> 'waldoes'};
is noun(q{waldoes})->classical->plural, q{waldoes}  => q{classical plural: 'waldoes' --> 'waldoes'};
is noun(q{woman servant})->classical->plural,   q{women servants}  => q{classical plural: 'woman servant' --> 'women servants'};
is noun(q{women servants})->classical->plural, q{women servants}  => q{classical plural: 'women servants' --> 'women servants'};
is noun(q{penis})->classical->plural,   q{penes}  => q{classical plural: 'penis' --> 'penes'};
is noun(q{penes})->classical->plural, q{penes}  => q{classical plural: 'penes' --> 'penes'};
is noun(q{indicium})->classical->plural,   q{indicia}  => q{classical plural: 'indicium' --> 'indicia'};
is noun(q{indicia})->classical->plural, q{indicia}  => q{classical plural: 'indicia' --> 'indicia'};
is noun(q{stimulus})->classical->plural,   q{stimuli}  => q{classical plural: 'stimulus' --> 'stimuli'};
is noun(q{stimuli})->classical->plural, q{stimuli}  => q{classical plural: 'stimuli' --> 'stimuli'};
is noun(q{alveolus})->classical->plural,   q{alveoli}  => q{classical plural: 'alveolus' --> 'alveoli'};
is noun(q{alveoli})->classical->plural, q{alveoli}  => q{classical plural: 'alveoli' --> 'alveoli'};
is noun(q{profluvium})->classical->plural,   q{profluvia}  => q{classical plural: 'profluvium' --> 'profluvia'};
is noun(q{profluvia})->classical->plural, q{profluvia}  => q{classical plural: 'profluvia' --> 'profluvia'};
is noun(q{Majuro})->classical->plural,   q{Majuros}  => q{classical plural: 'Majuro' --> 'Majuros'};
is noun(q{Majuros})->classical->plural, q{Majuros}  => q{classical plural: 'Majuros' --> 'Majuros'};
is noun(q{glochidium})->classical->plural,   q{glochidia}  => q{classical plural: 'glochidium' --> 'glochidia'};
is noun(q{glochidia})->classical->plural, q{glochidia}  => q{classical plural: 'glochidia' --> 'glochidia'};
is noun(q{ruga})->classical->plural,   q{rugae}  => q{classical plural: 'ruga' --> 'rugae'};
is noun(q{rugae})->classical->plural, q{rugae}  => q{classical plural: 'rugae' --> 'rugae'};
is noun(q{res})->classical->plural,   q{res}  => q{classical plural: 'res' --> 'res'};
is noun(q{edema})->classical->plural,   q{edemata}  => q{classical plural: 'edema' --> 'edemata'};
is noun(q{edemata})->classical->plural, q{edemata}  => q{classical plural: 'edemata' --> 'edemata'};
is noun(q{simpulum})->classical->plural,   q{simpula}  => q{classical plural: 'simpulum' --> 'simpula'};
is noun(q{simpula})->classical->plural, q{simpula}  => q{classical plural: 'simpula' --> 'simpula'};
is noun(q{mustachio})->classical->plural,   q{mustachios}  => q{classical plural: 'mustachio' --> 'mustachios'};
is noun(q{mustachios})->classical->plural, q{mustachios}  => q{classical plural: 'mustachios' --> 'mustachios'};
is noun(q{enteron})->classical->plural,   q{entera}  => q{classical plural: 'enteron' --> 'entera'};
is noun(q{entera})->classical->plural, q{entera}  => q{classical plural: 'entera' --> 'entera'};
is noun(q{symplasma})->classical->plural,   q{symplasmata}  => q{classical plural: 'symplasma' --> 'symplasmata'};
is noun(q{symplasmata})->classical->plural, q{symplasmata}  => q{classical plural: 'symplasmata' --> 'symplasmata'};
is noun(q{marquis})->classical->plural,   q{marquises}  => q{classical plural: 'marquis' --> 'marquises'};
is noun(q{marquises})->classical->plural, q{marquises}  => q{classical plural: 'marquises' --> 'marquises'};
is noun(q{noctiluca})->classical->plural,   q{noctilucae}  => q{classical plural: 'noctiluca' --> 'noctilucae'};
is noun(q{noctilucae})->classical->plural, q{noctilucae}  => q{classical plural: 'noctilucae' --> 'noctilucae'};
is noun(q{septum})->classical->plural,   q{septa}  => q{classical plural: 'septum' --> 'septa'};
is noun(q{septa})->classical->plural, q{septa}  => q{classical plural: 'septa' --> 'septa'};
is noun(q{follis})->classical->plural,   q{folles}  => q{classical plural: 'follis' --> 'folles'};
is noun(q{folles})->classical->plural, q{folles}  => q{classical plural: 'folles' --> 'folles'};
is noun(q{logodaedalus})->classical->plural,   q{logodaedale}  => q{classical plural: 'logodaedalus' --> 'logodaedale'};
is noun(q{logodaedale})->classical->plural, q{logodaedale}  => q{classical plural: 'logodaedale' --> 'logodaedale'};
is noun(q{4 star general})->classical->plural,   q{4 star generals}  => q{classical plural: '4 star general' --> '4 star generals'};
is noun(q{4 star generals})->classical->plural, q{4 star generals}  => q{classical plural: '4 star generals' --> '4 star generals'};
is noun(q{legionella})->classical->plural,   q{legionellae}  => q{classical plural: 'legionella' --> 'legionellae'};
is noun(q{legionellae})->classical->plural, q{legionellae}  => q{classical plural: 'legionellae' --> 'legionellae'};
is noun(q{epiphenomenon})->classical->plural,   q{epiphenomena}  => q{classical plural: 'epiphenomenon' --> 'epiphenomena'};
is noun(q{epiphenomena})->classical->plural, q{epiphenomena}  => q{classical plural: 'epiphenomena' --> 'epiphenomena'};
is noun(q{tempietto})->classical->plural,   q{tempietti}  => q{classical plural: 'tempietto' --> 'tempietti'};
is noun(q{tempietti})->classical->plural, q{tempietti}  => q{classical plural: 'tempietti' --> 'tempietti'};
is noun(q{staphylococcus})->classical->plural,   q{staphylococci}  => q{classical plural: 'staphylococcus' --> 'staphylococci'};
is noun(q{staphylococci})->classical->plural, q{staphylococci}  => q{classical plural: 'staphylococci' --> 'staphylococci'};
is noun(q{locus})->classical->plural,   q{loci}  => q{classical plural: 'locus' --> 'loci'};
is noun(q{loci})->classical->plural, q{loci}  => q{classical plural: 'loci' --> 'loci'};
is noun(q{phalanx})->classical->plural,   q{phalanges}  => q{classical plural: 'phalanx' --> 'phalanges'};
is noun(q{phalanges})->classical->plural, q{phalanges}  => q{classical plural: 'phalanges' --> 'phalanges'};
is noun(q{menage a trois})->classical->plural,   q{menages a trois}  => q{classical plural: 'menage a trois' --> 'menages a trois'};
is noun(q{menages a trois})->classical->plural, q{menages a trois}  => q{classical plural: 'menages a trois' --> 'menages a trois'};
is noun(q{tango})->classical->plural,   q{tangoes}  => q{classical plural: 'tango' --> 'tangoes'};
is noun(q{tangoes})->classical->plural, q{tangoes}  => q{classical plural: 'tangoes' --> 'tangoes'};
is noun(q{viale})->classical->plural,   q{viali}  => q{classical plural: 'viale' --> 'viali'};
is noun(q{viali})->classical->plural, q{viali}  => q{classical plural: 'viali' --> 'viali'};
is noun(q{soprano})->classical->plural,   q{soprani}  => q{classical plural: 'soprano' --> 'soprani'};
is noun(q{soprani})->classical->plural, q{soprani}  => q{classical plural: 'soprani' --> 'soprani'};
is noun(q{postulatum})->classical->plural,   q{postulata}  => q{classical plural: 'postulatum' --> 'postulata'};
is noun(q{postulata})->classical->plural, q{postulata}  => q{classical plural: 'postulata' --> 'postulata'};
is noun(q{rite de passage})->classical->plural,   q{rites de passage}  => q{classical plural: 'rite de passage' --> 'rites de passage'};
is noun(q{rites de passage})->classical->plural, q{rites de passage}  => q{classical plural: 'rites de passage' --> 'rites de passage'};
is noun(q{series})->classical->plural,   q{series}  => q{classical plural: 'series' --> 'series'};
is noun(q{stroma})->classical->plural,   q{stromata}  => q{classical plural: 'stroma' --> 'stromata'};
is noun(q{stromata})->classical->plural, q{stromata}  => q{classical plural: 'stromata' --> 'stromata'};
is noun(q{louse})->classical->plural,   q{lice}  => q{classical plural: 'louse' --> 'lice'};
is noun(q{lice})->classical->plural, q{lice}  => q{classical plural: 'lice' --> 'lice'};
is noun(q{leptospira})->classical->plural,   q{leptospirae}  => q{classical plural: 'leptospira' --> 'leptospirae'};
is noun(q{leptospirae})->classical->plural, q{leptospirae}  => q{classical plural: 'leptospirae' --> 'leptospirae'};
is noun(q{usnea})->classical->plural,   q{usneae}  => q{classical plural: 'usnea' --> 'usneae'};
is noun(q{usneae})->classical->plural, q{usneae}  => q{classical plural: 'usneae' --> 'usneae'};
is noun(q{equinoctium})->classical->plural,   q{equinoctia}  => q{classical plural: 'equinoctium' --> 'equinoctia'};
is noun(q{equinoctia})->classical->plural, q{equinoctia}  => q{classical plural: 'equinoctia' --> 'equinoctia'};
is noun(q{rejon})->classical->plural,   q{rejones}  => q{classical plural: 'rejon' --> 'rejones'};
is noun(q{rejones})->classical->plural, q{rejones}  => q{classical plural: 'rejones' --> 'rejones'};
is noun(q{retinaculum})->classical->plural,   q{retinacula}  => q{classical plural: 'retinaculum' --> 'retinacula'};
is noun(q{retinacula})->classical->plural, q{retinacula}  => q{classical plural: 'retinacula' --> 'retinacula'};
is noun(q{stoma})->classical->plural,   q{stomata}  => q{classical plural: 'stoma' --> 'stomata'};
is noun(q{stomata})->classical->plural, q{stomata}  => q{classical plural: 'stomata' --> 'stomata'};
is noun(q{septenarius})->classical->plural,   q{septenarii}  => q{classical plural: 'septenarius' --> 'septenarii'};
is noun(q{septenarii})->classical->plural, q{septenarii}  => q{classical plural: 'septenarii' --> 'septenarii'};
is noun(q{microcephalus})->classical->plural,   q{microcephali}  => q{classical plural: 'microcephalus' --> 'microcephali'};
is noun(q{microcephali})->classical->plural, q{microcephali}  => q{classical plural: 'microcephali' --> 'microcephali'};
is noun(q{intaglio})->classical->plural,   q{intaglios}  => q{classical plural: 'intaglio' --> 'intaglios'};
is noun(q{intaglios})->classical->plural, q{intaglios}  => q{classical plural: 'intaglios' --> 'intaglios'};
is noun(q{panorpa})->classical->plural,   q{panorpae}  => q{classical plural: 'panorpa' --> 'panorpae'};
is noun(q{panorpae})->classical->plural, q{panorpae}  => q{classical plural: 'panorpae' --> 'panorpae'};
is noun(q{Cantonese})->classical->plural,   q{Cantonese}  => q{classical plural: 'Cantonese' --> 'Cantonese'};
is noun(q{tour de force})->classical->plural,   q{tours de force}  => q{classical plural: 'tour de force' --> 'tours de force'};
is noun(q{tours de force})->classical->plural, q{tours de force}  => q{classical plural: 'tours de force' --> 'tours de force'};
is noun(q{faciendum})->classical->plural,   q{facienda}  => q{classical plural: 'faciendum' --> 'facienda'};
is noun(q{facienda})->classical->plural, q{facienda}  => q{classical plural: 'facienda' --> 'facienda'};
is noun(q{interambulacrum})->classical->plural,   q{interambulacra}  => q{classical plural: 'interambulacrum' --> 'interambulacra'};
is noun(q{interambulacra})->classical->plural, q{interambulacra}  => q{classical plural: 'interambulacra' --> 'interambulacra'};
is noun(q{Nakayaman})->classical->plural,   q{Nakayamans}  => q{classical plural: 'Nakayaman' --> 'Nakayamans'};
is noun(q{Nakayamans})->classical->plural, q{Nakayamans}  => q{classical plural: 'Nakayamans' --> 'Nakayamans'};
is noun(q{white staff})->classical->plural,   q{white staves}  => q{classical plural: 'white staff' --> 'white staves'};
is noun(q{white staves})->classical->plural, q{white staves}  => q{classical plural: 'white staves' --> 'white staves'};
is noun(q{felo-de-se})->classical->plural,   q{felones-de-se}  => q{classical plural: 'felo-de-se' --> 'felones-de-se'};
is noun(q{felones-de-se})->classical->plural, q{felones-de-se}  => q{classical plural: 'felones-de-se' --> 'felones-de-se'};
is noun(q{tenaculum})->classical->plural,   q{tenacula}  => q{classical plural: 'tenaculum' --> 'tenacula'};
is noun(q{tenacula})->classical->plural, q{tenacula}  => q{classical plural: 'tenacula' --> 'tenacula'};
is noun(q{biscotto})->classical->plural,   q{biscotti}  => q{classical plural: 'biscotto' --> 'biscotti'};
is noun(q{biscotti})->classical->plural, q{biscotti}  => q{classical plural: 'biscotti' --> 'biscotti'};
is noun(q{synaxis})->classical->plural,   q{synaxes}  => q{classical plural: 'synaxis' --> 'synaxes'};
is noun(q{synaxes})->classical->plural, q{synaxes}  => q{classical plural: 'synaxes' --> 'synaxes'};
is noun(q{bimbo})->classical->plural,   q{bimbos}  => q{classical plural: 'bimbo' --> 'bimbos'};
is noun(q{bimbos})->classical->plural, q{bimbos}  => q{classical plural: 'bimbos' --> 'bimbos'};
is noun(q{flamenco})->classical->plural,   q{flamencos}  => q{classical plural: 'flamenco' --> 'flamencos'};
is noun(q{flamencos})->classical->plural, q{flamencos}  => q{classical plural: 'flamencos' --> 'flamencos'};
is noun(q{Hararese})->classical->plural,   q{Hararese}  => q{classical plural: 'Hararese' --> 'Hararese'};
is noun(q{six-star general})->classical->plural,   q{six-star generals}  => q{classical plural: 'six-star general' --> 'six-star generals'};
is noun(q{six-star generals})->classical->plural, q{six-star generals}  => q{classical plural: 'six-star generals' --> 'six-star generals'};
is noun(q{serum})->classical->plural,   q{sera}  => q{classical plural: 'serum' --> 'sera'};
is noun(q{sera})->classical->plural, q{sera}  => q{classical plural: 'sera' --> 'sera'};
is noun(q{fibroma})->classical->plural,   q{fibromata}  => q{classical plural: 'fibroma' --> 'fibromata'};
is noun(q{fibromata})->classical->plural, q{fibromata}  => q{classical plural: 'fibromata' --> 'fibromata'};
is noun(q{pensiero})->classical->plural,   q{pensieri}  => q{classical plural: 'pensiero' --> 'pensieri'};
is noun(q{pensieri})->classical->plural, q{pensieri}  => q{classical plural: 'pensieri' --> 'pensieri'};
is noun(q{vinculum})->classical->plural,   q{vincula}  => q{classical plural: 'vinculum' --> 'vincula'};
is noun(q{vincula})->classical->plural, q{vincula}  => q{classical plural: 'vincula' --> 'vincula'};
is noun(q{Morocco})->classical->plural,   q{Moroccos}  => q{classical plural: 'Morocco' --> 'Moroccos'};
is noun(q{Moroccos})->classical->plural, q{Moroccos}  => q{classical plural: 'Moroccos' --> 'Moroccos'};
is noun(q{fuzz})->classical->plural,   q{fuzzes}  => q{classical plural: 'fuzz' --> 'fuzzes'};
is noun(q{fuzzes})->classical->plural, q{fuzzes}  => q{classical plural: 'fuzzes' --> 'fuzzes'};
is noun(q{Yokohaman})->classical->plural,   q{Yokohamans}  => q{classical plural: 'Yokohaman' --> 'Yokohamans'};
is noun(q{Yokohamans})->classical->plural, q{Yokohamans}  => q{classical plural: 'Yokohamans' --> 'Yokohamans'};
is noun(q{mater lectionis})->classical->plural,   q{matres lectionis}  => q{classical plural: 'mater lectionis' --> 'matres lectionis'};
is noun(q{matres lectionis})->classical->plural, q{matres lectionis}  => q{classical plural: 'matres lectionis' --> 'matres lectionis'};
is noun(q{buffalo})->classical->plural,   q{buffalo}  => q{classical plural: 'buffalo' --> 'buffalo'};
is noun(q{maestro})->classical->plural,   q{maestri}  => q{classical plural: 'maestro' --> 'maestri'};
is noun(q{maestri})->classical->plural, q{maestri}  => q{classical plural: 'maestri' --> 'maestri'};
is noun(q{lf})->classical->plural,   q{lves}  => q{classical plural: 'lf' --> 'lves'};
is noun(q{lves})->classical->plural, q{lves}  => q{classical plural: 'lves' --> 'lves'};
is noun(q{Quito})->classical->plural,   q{Quitos}  => q{classical plural: 'Quito' --> 'Quitos'};
is noun(q{Quitos})->classical->plural, q{Quitos}  => q{classical plural: 'Quitos' --> 'Quitos'};
is noun(q{taenia})->classical->plural,   q{taeniae}  => q{classical plural: 'taenia' --> 'taeniae'};
is noun(q{taeniae})->classical->plural, q{taeniae}  => q{classical plural: 'taeniae' --> 'taeniae'};
is noun(q{scazon})->classical->plural,   q{scazons}  => q{classical plural: 'scazon' --> 'scazons'};
is noun(q{scazons})->classical->plural, q{scazons}  => q{classical plural: 'scazons' --> 'scazons'};
is noun(q{belle epoque})->classical->plural,   q{belles epoques}  => q{classical plural: 'belle epoque' --> 'belles epoques'};
is noun(q{belles epoques})->classical->plural, q{belles epoques}  => q{classical plural: 'belles epoques' --> 'belles epoques'};
is noun(q{nympha})->classical->plural,   q{nymphae}  => q{classical plural: 'nympha' --> 'nymphae'};
is noun(q{nymphae})->classical->plural, q{nymphae}  => q{classical plural: 'nymphae' --> 'nymphae'};
is noun(q{striga})->classical->plural,   q{strigae}  => q{classical plural: 'striga' --> 'strigae'};
is noun(q{strigae})->classical->plural, q{strigae}  => q{classical plural: 'strigae' --> 'strigae'};
is noun(q{remex})->classical->plural,   q{remiges}  => q{classical plural: 'remex' --> 'remiges'};
is noun(q{remiges})->classical->plural, q{remiges}  => q{classical plural: 'remiges' --> 'remiges'};
is noun(q{stromodeum})->classical->plural,   q{stromodaea}  => q{classical plural: 'stromodeum' --> 'stromodaea'};
is noun(q{stromodaea})->classical->plural, q{stromodaea}  => q{classical plural: 'stromodaea' --> 'stromodaea'};
is noun(q{shauri})->classical->plural,   q{shauries}  => q{classical plural: 'shauri' --> 'shauries'};
is noun(q{shauries})->classical->plural, q{shauries}  => q{classical plural: 'shauries' --> 'shauries'};
is noun(q{wharf})->classical->plural,   q{wharves}  => q{classical plural: 'wharf' --> 'wharves'};
is noun(q{wharves})->classical->plural, q{wharves}  => q{classical plural: 'wharves' --> 'wharves'};
is noun(q{chrysalis})->classical->plural,   q{chrysalides}  => q{classical plural: 'chrysalis' --> 'chrysalides'};
is noun(q{chrysalides})->classical->plural, q{chrysalides}  => q{classical plural: 'chrysalides' --> 'chrysalides'};
is noun(q{strategos})->classical->plural,   q{strategoi}  => q{classical plural: 'strategos' --> 'strategoi'};
is noun(q{strategoi})->classical->plural, q{strategoi}  => q{classical plural: 'strategoi' --> 'strategoi'};
is noun(q{agend})->classical->plural,   q{agenda}  => q{classical plural: 'agend' --> 'agenda'};
is noun(q{agenda})->classical->plural, q{agenda}  => q{classical plural: 'agenda' --> 'agenda'};
is noun(q{tetrahedron})->classical->plural,   q{tetrahedra}  => q{classical plural: 'tetrahedron' --> 'tetrahedra'};
is noun(q{tetrahedra})->classical->plural, q{tetrahedra}  => q{classical plural: 'tetrahedra' --> 'tetrahedra'};
is noun(q{trabea})->classical->plural,   q{trabeae}  => q{classical plural: 'trabea' --> 'trabeae'};
is noun(q{trabeae})->classical->plural, q{trabeae}  => q{classical plural: 'trabeae' --> 'trabeae'};
is noun(q{parc ferme})->classical->plural,   q{parcs fermes}  => q{classical plural: 'parc ferme' --> 'parcs fermes'};
is noun(q{parcs fermes})->classical->plural, q{parcs fermes}  => q{classical plural: 'parcs fermes' --> 'parcs fermes'};
is noun(q{nuntius})->classical->plural,   q{nuntii}  => q{classical plural: 'nuntius' --> 'nuntii'};
is noun(q{nuntii})->classical->plural, q{nuntii}  => q{classical plural: 'nuntii' --> 'nuntii'};
is noun(q{entrochus})->classical->plural,   q{entrochi}  => q{classical plural: 'entrochus' --> 'entrochi'};
is noun(q{entrochi})->classical->plural, q{entrochi}  => q{classical plural: 'entrochi' --> 'entrochi'};
is noun(q{ditto})->classical->plural,   q{dittos}  => q{classical plural: 'ditto' --> 'dittos'};
is noun(q{dittos})->classical->plural, q{dittos}  => q{classical plural: 'dittos' --> 'dittos'};
is noun(q{pleco})->classical->plural,   q{plecos}  => q{classical plural: 'pleco' --> 'plecos'};
is noun(q{plecos})->classical->plural, q{plecos}  => q{classical plural: 'plecos' --> 'plecos'};
is noun(q{starfish})->classical->plural,   q{starfish}  => q{classical plural: 'starfish' --> 'starfish'};
is noun(q{syringe})->classical->plural,   q{syringes}  => q{classical plural: 'syringe' --> 'syringes'};
is noun(q{syringes})->classical->plural, q{syringes}  => q{classical plural: 'syringes' --> 'syringes'};
is noun(q{mary})->classical->plural,   q{maries}  => q{classical plural: 'mary' --> 'maries'};
is noun(q{maries})->classical->plural, q{maries}  => q{classical plural: 'maries' --> 'maries'};
is noun(q{quantum})->classical->plural,   q{quanta}  => q{classical plural: 'quantum' --> 'quanta'};
is noun(q{quanta})->classical->plural, q{quanta}  => q{classical plural: 'quanta' --> 'quanta'};
is noun(q{secundigravida})->classical->plural,   q{secundigravidae}  => q{classical plural: 'secundigravida' --> 'secundigravidae'};
is noun(q{secundigravidae})->classical->plural, q{secundigravidae}  => q{classical plural: 'secundigravidae' --> 'secundigravidae'};
is noun(q{chapplis})->classical->plural,   q{chapplies}  => q{classical plural: 'chapplis' --> 'chapplies'};
is noun(q{chapplies})->classical->plural, q{chapplies}  => q{classical plural: 'chapplies' --> 'chapplies'};
is noun(q{Pangasinan})->classical->plural,   q{Pangasinanes}  => q{classical plural: 'Pangasinan' --> 'Pangasinanes'};
is noun(q{Pangasinanes})->classical->plural, q{Pangasinanes}  => q{classical plural: 'Pangasinanes' --> 'Pangasinanes'};
is noun(q{coxendix})->classical->plural,   q{coxendices}  => q{classical plural: 'coxendix' --> 'coxendices'};
is noun(q{coxendices})->classical->plural, q{coxendices}  => q{classical plural: 'coxendices' --> 'coxendices'};
is noun(q{man-midwife})->classical->plural,   q{men-midwives}  => q{classical plural: 'man-midwife' --> 'men-midwives'};
is noun(q{men-midwives})->classical->plural, q{men-midwives}  => q{classical plural: 'men-midwives' --> 'men-midwives'};
is noun(q{magnifico})->classical->plural,   q{magnificos}  => q{classical plural: 'magnifico' --> 'magnificos'};
is noun(q{magnificos})->classical->plural, q{magnificos}  => q{classical plural: 'magnificos' --> 'magnificos'};
is noun(q{hypha})->classical->plural,   q{hyphae}  => q{classical plural: 'hypha' --> 'hyphae'};
is noun(q{hyphae})->classical->plural, q{hyphae}  => q{classical plural: 'hyphae' --> 'hyphae'};
is noun(q{podetium})->classical->plural,   q{podetia}  => q{classical plural: 'podetium' --> 'podetia'};
is noun(q{podetia})->classical->plural, q{podetia}  => q{classical plural: 'podetia' --> 'podetia'};
is noun(q{prosa})->classical->plural,   q{prosae}  => q{classical plural: 'prosa' --> 'prosae'};
is noun(q{prosae})->classical->plural, q{prosae}  => q{classical plural: 'prosae' --> 'prosae'};
is noun(q{progymnasium})->classical->plural,   q{progymnasia}  => q{classical plural: 'progymnasium' --> 'progymnasia'};
is noun(q{progymnasia})->classical->plural, q{progymnasia}  => q{classical plural: 'progymnasia' --> 'progymnasia'};
is noun(q{aptychus})->classical->plural,   q{aptychi}  => q{classical plural: 'aptychus' --> 'aptychi'};
is noun(q{aptychi})->classical->plural, q{aptychi}  => q{classical plural: 'aptychi' --> 'aptychi'};
is noun(q{cello})->classical->plural,   q{cellos}  => q{classical plural: 'cello' --> 'cellos'};
is noun(q{cellos})->classical->plural, q{cellos}  => q{classical plural: 'cellos' --> 'cellos'};
is noun(q{Jerry})->classical->plural,   q{Jerrys}  => q{classical plural: 'Jerry' --> 'Jerrys'};
is noun(q{Jerrys})->classical->plural, q{Jerrys}  => q{classical plural: 'Jerrys' --> 'Jerrys'};
is noun(q{trellis})->classical->plural,   q{trellises}  => q{classical plural: 'trellis' --> 'trellises'};
is noun(q{trellises})->classical->plural, q{trellises}  => q{classical plural: 'trellises' --> 'trellises'};
is noun(q{fowl})->classical->plural,   q{fowl}  => q{classical plural: 'fowl' --> 'fowl'};
is noun(q{frate})->classical->plural,   q{frati}  => q{classical plural: 'frate' --> 'frati'};
is noun(q{frati})->classical->plural, q{frati}  => q{classical plural: 'frati' --> 'frati'};
is noun(q{Antananarivo})->classical->plural,   q{Antananarivos}  => q{classical plural: 'Antananarivo' --> 'Antananarivos'};
is noun(q{Antananarivos})->classical->plural, q{Antananarivos}  => q{classical plural: 'Antananarivos' --> 'Antananarivos'};
is noun(q{tenuis})->classical->plural,   q{tenues}  => q{classical plural: 'tenuis' --> 'tenues'};
is noun(q{tenues})->classical->plural, q{tenues}  => q{classical plural: 'tenues' --> 'tenues'};
is noun(q{referendum})->classical->plural,   q{referenda}  => q{classical plural: 'referendum' --> 'referenda'};
is noun(q{referenda})->classical->plural, q{referenda}  => q{classical plural: 'referenda' --> 'referenda'};
is noun(q{hippo})->classical->plural,   q{hippos}  => q{classical plural: 'hippo' --> 'hippos'};
is noun(q{hippos})->classical->plural, q{hippos}  => q{classical plural: 'hippos' --> 'hippos'};
is noun(q{mews})->classical->plural,   q{mews}  => q{classical plural: 'mews' --> 'mews'};
is noun(q{Vietnamese})->classical->plural,   q{Vietnamese}  => q{classical plural: 'Vietnamese' --> 'Vietnamese'};
is noun(q{Japanese})->classical->plural,   q{Japanese}  => q{classical plural: 'Japanese' --> 'Japanese'};
is noun(q{paxilla})->classical->plural,   q{paxillae}  => q{classical plural: 'paxilla' --> 'paxillae'};
is noun(q{paxillae})->classical->plural, q{paxillae}  => q{classical plural: 'paxillae' --> 'paxillae'};
is noun(q{thymus})->classical->plural,   q{thymi}  => q{classical plural: 'thymus' --> 'thymi'};
is noun(q{thymi})->classical->plural, q{thymi}  => q{classical plural: 'thymi' --> 'thymi'};
is noun(q{halteridium})->classical->plural,   q{halteridia}  => q{classical plural: 'halteridium' --> 'halteridia'};
is noun(q{halteridia})->classical->plural, q{halteridia}  => q{classical plural: 'halteridia' --> 'halteridia'};
is noun(q{octopus})->classical->plural,   q{octopuses}  => q{classical plural: 'octopus' --> 'octopuses'};
is noun(q{octopuses})->classical->plural, q{octopuses}  => q{classical plural: 'octopuses' --> 'octopuses'};
is noun(q{proferens})->classical->plural,   q{proferentes}  => q{classical plural: 'proferens' --> 'proferentes'};
is noun(q{proferentes})->classical->plural, q{proferentes}  => q{classical plural: 'proferentes' --> 'proferentes'};
is noun(q{Chicago})->classical->plural,   q{Chicagos}  => q{classical plural: 'Chicago' --> 'Chicagos'};
is noun(q{Chicagos})->classical->plural, q{Chicagos}  => q{classical plural: 'Chicagos' --> 'Chicagos'};
is noun(q{Draco})->classical->plural,   q{Dracos}  => q{classical plural: 'Draco' --> 'Dracos'};
is noun(q{Dracos})->classical->plural, q{Dracos}  => q{classical plural: 'Dracos' --> 'Dracos'};
is noun(q{pilus})->classical->plural,   q{pili}  => q{classical plural: 'pilus' --> 'pili'};
is noun(q{pili})->classical->plural, q{pili}  => q{classical plural: 'pili' --> 'pili'};
is noun(q{termes})->classical->plural,   q{termites}  => q{classical plural: 'termes' --> 'termites'};
is noun(q{termites})->classical->plural, q{termites}  => q{classical plural: 'termites' --> 'termites'};
is noun(q{nectocalyx})->classical->plural,   q{nectocalyces}  => q{classical plural: 'nectocalyx' --> 'nectocalyces'};
is noun(q{nectocalyces})->classical->plural, q{nectocalyces}  => q{classical plural: 'nectocalyces' --> 'nectocalyces'};
is noun(q{tazza})->classical->plural,   q{tazze}  => q{classical plural: 'tazza' --> 'tazze'};
is noun(q{tazze})->classical->plural, q{tazze}  => q{classical plural: 'tazze' --> 'tazze'};
is noun(q{metapleuron})->classical->plural,   q{metapleura}  => q{classical plural: 'metapleuron' --> 'metapleura'};
is noun(q{metapleura})->classical->plural, q{metapleura}  => q{classical plural: 'metapleura' --> 'metapleura'};
is noun(q{aggro})->classical->plural,   q{aggros}  => q{classical plural: 'aggro' --> 'aggros'};
is noun(q{aggros})->classical->plural, q{aggros}  => q{classical plural: 'aggros' --> 'aggros'};
is noun(q{nucleus})->classical->plural,   q{nuclei}  => q{classical plural: 'nucleus' --> 'nuclei'};
is noun(q{nuclei})->classical->plural, q{nuclei}  => q{classical plural: 'nuclei' --> 'nuclei'};
is noun(q{flabellum})->classical->plural,   q{flabella}  => q{classical plural: 'flabellum' --> 'flabella'};
is noun(q{flabella})->classical->plural, q{flabella}  => q{classical plural: 'flabella' --> 'flabella'};
is noun(q{turf})->classical->plural,   q{turves}  => q{classical plural: 'turf' --> 'turves'};
is noun(q{turves})->classical->plural, q{turves}  => q{classical plural: 'turves' --> 'turves'};
is noun(q{modernus})->classical->plural,   q{moderni}  => q{classical plural: 'modernus' --> 'moderni'};
is noun(q{moderni})->classical->plural, q{moderni}  => q{classical plural: 'moderni' --> 'moderni'};
is noun(q{conductus})->classical->plural,   q{conducti}  => q{classical plural: 'conductus' --> 'conducti'};
is noun(q{conducti})->classical->plural, q{conducti}  => q{classical plural: 'conducti' --> 'conducti'};
is noun(q{autobahn})->classical->plural,   q{autobahnen}  => q{classical plural: 'autobahn' --> 'autobahnen'};
is noun(q{autobahnen})->classical->plural, q{autobahnen}  => q{classical plural: 'autobahnen' --> 'autobahnen'};
is noun(q{seed})->classical->plural,   q{seed}  => q{classical plural: 'seed' --> 'seed'};
is noun(q{vas})->classical->plural,   q{vasa}  => q{classical plural: 'vas' --> 'vasa'};
is noun(q{vasa})->classical->plural, q{vasa}  => q{classical plural: 'vasa' --> 'vasa'};
is noun(q{unguis})->classical->plural,   q{ungues}  => q{classical plural: 'unguis' --> 'ungues'};
is noun(q{ungues})->classical->plural, q{ungues}  => q{classical plural: 'ungues' --> 'ungues'};
is noun(q{pluteus})->classical->plural,   q{plutei}  => q{classical plural: 'pluteus' --> 'plutei'};
is noun(q{plutei})->classical->plural, q{plutei}  => q{classical plural: 'plutei' --> 'plutei'};
is noun(q{extremum})->classical->plural,   q{extrema}  => q{classical plural: 'extremum' --> 'extrema'};
is noun(q{extrema})->classical->plural, q{extrema}  => q{classical plural: 'extrema' --> 'extrema'};
is noun(q{depositum})->classical->plural,   q{deposita}  => q{classical plural: 'depositum' --> 'deposita'};
is noun(q{deposita})->classical->plural, q{deposita}  => q{classical plural: 'deposita' --> 'deposita'};
is noun(q{vetturino})->classical->plural,   q{vetturini}  => q{classical plural: 'vetturino' --> 'vetturini'};
is noun(q{vetturini})->classical->plural, q{vetturini}  => q{classical plural: 'vetturini' --> 'vetturini'};
is noun(q{trousseau})->classical->plural,   q{trousseaux}  => q{classical plural: 'trousseau' --> 'trousseaux'};
is noun(q{trousseaux})->classical->plural, q{trousseaux}  => q{classical plural: 'trousseaux' --> 'trousseaux'};
is noun(q{zygoma})->classical->plural,   q{zygomata}  => q{classical plural: 'zygoma' --> 'zygomata'};
is noun(q{zygomata})->classical->plural, q{zygomata}  => q{classical plural: 'zygomata' --> 'zygomata'};
is noun(q{Mexico})->classical->plural,   q{Mexicos}  => q{classical plural: 'Mexico' --> 'Mexicos'};
is noun(q{Mexicos})->classical->plural, q{Mexicos}  => q{classical plural: 'Mexicos' --> 'Mexicos'};
is noun(q{mediastinum})->classical->plural,   q{mediastina}  => q{classical plural: 'mediastinum' --> 'mediastina'};
is noun(q{mediastina})->classical->plural, q{mediastina}  => q{classical plural: 'mediastina' --> 'mediastina'};
is noun(q{bateau})->classical->plural,   q{bateaux}  => q{classical plural: 'bateau' --> 'bateaux'};
is noun(q{bateaux})->classical->plural, q{bateaux}  => q{classical plural: 'bateaux' --> 'bateaux'};
is noun(q{photo})->classical->plural,   q{photos}  => q{classical plural: 'photo' --> 'photos'};
is noun(q{photos})->classical->plural, q{photos}  => q{classical plural: 'photos' --> 'photos'};
is noun(q{Arakanese})->classical->plural,   q{Arakanese}  => q{classical plural: 'Arakanese' --> 'Arakanese'};
is noun(q{turron})->classical->plural,   q{turrones}  => q{classical plural: 'turron' --> 'turrones'};
is noun(q{turrones})->classical->plural, q{turrones}  => q{classical plural: 'turrones' --> 'turrones'};
is noun(q{papula})->classical->plural,   q{papulae}  => q{classical plural: 'papula' --> 'papulae'};
is noun(q{papulae})->classical->plural, q{papulae}  => q{classical plural: 'papulae' --> 'papulae'};
is noun(q{supernova})->classical->plural,   q{supernovae}  => q{classical plural: 'supernova' --> 'supernovae'};
is noun(q{supernovae})->classical->plural, q{supernovae}  => q{classical plural: 'supernovae' --> 'supernovae'};
is noun(q{intercalarium})->classical->plural,   q{intercalare}  => q{classical plural: 'intercalarium' --> 'intercalare'};
is noun(q{intercalare})->classical->plural, q{intercalare}  => q{classical plural: 'intercalare' --> 'intercalare'};
is noun(q{sol})->classical->plural,   q{soles}  => q{classical plural: 'sol' --> 'soles'};
is noun(q{soles})->classical->plural, q{soles}  => q{classical plural: 'soles' --> 'soles'};
is noun(q{sarcina})->classical->plural,   q{sarcinae}  => q{classical plural: 'sarcina' --> 'sarcinae'};
is noun(q{sarcinae})->classical->plural, q{sarcinae}  => q{classical plural: 'sarcinae' --> 'sarcinae'};
is noun(q{ignoramus})->classical->plural,   q{ignoramus}  => q{classical plural: 'ignoramus' --> 'ignoramus'};
is noun(q{sizz})->classical->plural,   q{sizzes}  => q{classical plural: 'sizz' --> 'sizzes'};
is noun(q{sizzes})->classical->plural, q{sizzes}  => q{classical plural: 'sizzes' --> 'sizzes'};
is noun(q{secundipara})->classical->plural,   q{secundiparae}  => q{classical plural: 'secundipara' --> 'secundiparae'};
is noun(q{secundiparae})->classical->plural, q{secundiparae}  => q{classical plural: 'secundiparae' --> 'secundiparae'};
is noun(q{vivarium})->classical->plural,   q{vivaria}  => q{classical plural: 'vivarium' --> 'vivaria'};
is noun(q{vivaria})->classical->plural, q{vivaria}  => q{classical plural: 'vivaria' --> 'vivaria'};
is noun(q{poblador})->classical->plural,   q{pobladores}  => q{classical plural: 'poblador' --> 'pobladores'};
is noun(q{pobladores})->classical->plural, q{pobladores}  => q{classical plural: 'pobladores' --> 'pobladores'};
is noun(q{army-corps general})->classical->plural,   q{army-corps generals}  => q{classical plural: 'army-corps general' --> 'army-corps generals'};
is noun(q{army-corps generals})->classical->plural, q{army-corps generals}  => q{classical plural: 'army-corps generals' --> 'army-corps generals'};
is noun(q{pinto})->classical->plural,   q{pintos}  => q{classical plural: 'pinto' --> 'pintos'};
is noun(q{pintos})->classical->plural, q{pintos}  => q{classical plural: 'pintos' --> 'pintos'};
is noun(q{velum})->classical->plural,   q{vela}  => q{classical plural: 'velum' --> 'vela'};
is noun(q{vela})->classical->plural, q{vela}  => q{classical plural: 'vela' --> 'vela'};
is noun(q{brigadier general})->classical->plural,   q{brigadier generals}  => q{classical plural: 'brigadier general' --> 'brigadier generals'};
is noun(q{brigadier generals})->classical->plural, q{brigadier generals}  => q{classical plural: 'brigadier generals' --> 'brigadier generals'};
is noun(q{succinea})->classical->plural,   q{succineae}  => q{classical plural: 'succinea' --> 'succineae'};
is noun(q{succineae})->classical->plural, q{succineae}  => q{classical plural: 'succineae' --> 'succineae'};
is noun(q{hapax legomenon})->classical->plural,   q{hapax legomena}  => q{classical plural: 'hapax legomenon' --> 'hapax legomena'};
is noun(q{hapax legomena})->classical->plural, q{hapax legomena}  => q{classical plural: 'hapax legomena' --> 'hapax legomena'};
is noun(q{oedema})->classical->plural,   q{oedemata}  => q{classical plural: 'oedema' --> 'oedemata'};
is noun(q{oedemata})->classical->plural, q{oedemata}  => q{classical plural: 'oedemata' --> 'oedemata'};
is noun(q{anacoluthon})->classical->plural,   q{anacolutha}  => q{classical plural: 'anacoluthon' --> 'anacolutha'};
is noun(q{anacolutha})->classical->plural, q{anacolutha}  => q{classical plural: 'anacolutha' --> 'anacolutha'};
is noun(q{loma})->classical->plural,   q{lomata}  => q{classical plural: 'loma' --> 'lomata'};
is noun(q{lomata})->classical->plural, q{lomata}  => q{classical plural: 'lomata' --> 'lomata'};
is noun(q{stabilimentum})->classical->plural,   q{stabilimenta}  => q{classical plural: 'stabilimentum' --> 'stabilimenta'};
is noun(q{stabilimenta})->classical->plural, q{stabilimenta}  => q{classical plural: 'stabilimenta' --> 'stabilimenta'};
is noun(q{bel homme})->classical->plural,   q{beaux hommes}  => q{classical plural: 'bel homme' --> 'beaux hommes'};
is noun(q{beaux hommes})->classical->plural, q{beaux hommes}  => q{classical plural: 'beaux hommes' --> 'beaux hommes'};
is noun(q{Iquico})->classical->plural,   q{Iquicos}  => q{classical plural: 'Iquico' --> 'Iquicos'};
is noun(q{Iquicos})->classical->plural, q{Iquicos}  => q{classical plural: 'Iquicos' --> 'Iquicos'};
is noun(q{her})->classical->plural,   q{them}  => q{classical plural: 'her' --> 'them'};
is noun(q{bronchus})->classical->plural,   q{bronchi}  => q{classical plural: 'bronchus' --> 'bronchi'};
is noun(q{bronchi})->classical->plural, q{bronchi}  => q{classical plural: 'bronchi' --> 'bronchi'};
is noun(q{concertino})->classical->plural,   q{concertinos}  => q{classical plural: 'concertino' --> 'concertinos'};
is noun(q{concertinos})->classical->plural, q{concertinos}  => q{classical plural: 'concertinos' --> 'concertinos'};
is noun(q{oxybaphon})->classical->plural,   q{oxybapha}  => q{classical plural: 'oxybaphon' --> 'oxybapha'};
is noun(q{oxybapha})->classical->plural, q{oxybapha}  => q{classical plural: 'oxybapha' --> 'oxybapha'};
is noun(q{tegula})->classical->plural,   q{tegulae}  => q{classical plural: 'tegula' --> 'tegulae'};
is noun(q{tegulae})->classical->plural, q{tegulae}  => q{classical plural: 'tegulae' --> 'tegulae'};
is noun(q{hertz})->classical->plural,   q{hertz}  => q{classical plural: 'hertz' --> 'hertz'};
is noun(q{epicardium})->classical->plural,   q{epicardia}  => q{classical plural: 'epicardium' --> 'epicardia'};
is noun(q{epicardia})->classical->plural, q{epicardia}  => q{classical plural: 'epicardia' --> 'epicardia'};
is noun(q{cochito})->classical->plural,   q{cochitos}  => q{classical plural: 'cochito' --> 'cochitos'};
is noun(q{cochitos})->classical->plural, q{cochitos}  => q{classical plural: 'cochitos' --> 'cochitos'};
is noun(q{cosmos})->classical->plural,   q{cosmoses}  => q{classical plural: 'cosmos' --> 'cosmoses'};
is noun(q{cosmoses})->classical->plural, q{cosmoses}  => q{classical plural: 'cosmoses' --> 'cosmoses'};
is noun(q{rostrum})->classical->plural,   q{rostra}  => q{classical plural: 'rostrum' --> 'rostra'};
is noun(q{rostra})->classical->plural, q{rostra}  => q{classical plural: 'rostra' --> 'rostra'};
is noun(q{dynamo})->classical->plural,   q{dynamos}  => q{classical plural: 'dynamo' --> 'dynamos'};
is noun(q{dynamos})->classical->plural, q{dynamos}  => q{classical plural: 'dynamos' --> 'dynamos'};
is noun(q{3 star general})->classical->plural,   q{3 star generals}  => q{classical plural: '3 star general' --> '3 star generals'};
is noun(q{3 star generals})->classical->plural, q{3 star generals}  => q{classical plural: '3 star generals' --> '3 star generals'};
is noun(q{muzz})->classical->plural,   q{muzzes}  => q{classical plural: 'muzz' --> 'muzzes'};
is noun(q{muzzes})->classical->plural, q{muzzes}  => q{classical plural: 'muzzes' --> 'muzzes'};
is noun(q{vers libre})->classical->plural,   q{vers libres}  => q{classical plural: 'vers libre' --> 'vers libres'};
is noun(q{vers libres})->classical->plural, q{vers libres}  => q{classical plural: 'vers libres' --> 'vers libres'};
is noun(q{collegium musicum})->classical->plural,   q{collegia musica}  => q{classical plural: 'collegium musicum' --> 'collegia musica'};
is noun(q{collegia musica})->classical->plural, q{collegia musica}  => q{classical plural: 'collegia musica' --> 'collegia musica'};
is noun(q{macho})->classical->plural,   q{machos}  => q{classical plural: 'macho' --> 'machos'};
is noun(q{machos})->classical->plural, q{machos}  => q{classical plural: 'machos' --> 'machos'};
is noun(q{pyramidion})->classical->plural,   q{pyramidia}  => q{classical plural: 'pyramidion' --> 'pyramidia'};
is noun(q{pyramidia})->classical->plural, q{pyramidia}  => q{classical plural: 'pyramidia' --> 'pyramidia'};
is noun(q{virus})->classical->plural,   q{viruses}  => q{classical plural: 'virus' --> 'viruses'};
is noun(q{viruses})->classical->plural, q{viruses}  => q{classical plural: 'viruses' --> 'viruses'};
is noun(q{caryopsis})->classical->plural,   q{caryopsides}  => q{classical plural: 'caryopsis' --> 'caryopsides'};
is noun(q{caryopsides})->classical->plural, q{caryopsides}  => q{classical plural: 'caryopsides' --> 'caryopsides'};
is noun(q{Modenese})->classical->plural,   q{Modenese}  => q{classical plural: 'Modenese' --> 'Modenese'};
is noun(q{simulacrum})->classical->plural,   q{simulacra}  => q{classical plural: 'simulacrum' --> 'simulacra'};
is noun(q{simulacra})->classical->plural, q{simulacra}  => q{classical plural: 'simulacra' --> 'simulacra'};
is noun(q{statua})->classical->plural,   q{statuae}  => q{classical plural: 'statua' --> 'statuae'};
is noun(q{statuae})->classical->plural, q{statuae}  => q{classical plural: 'statuae' --> 'statuae'};
is noun(q{cardophagus})->classical->plural,   q{cardophagi}  => q{classical plural: 'cardophagus' --> 'cardophagi'};
is noun(q{cardophagi})->classical->plural, q{cardophagi}  => q{classical plural: 'cardophagi' --> 'cardophagi'};
is noun(q{proboscis})->classical->plural,   q{proboscides}  => q{classical plural: 'proboscis' --> 'proboscides'};
is noun(q{proboscides})->classical->plural, q{proboscides}  => q{classical plural: 'proboscides' --> 'proboscides'};
is noun(q{nenets})->classical->plural,   q{nentsy}  => q{classical plural: 'nenets' --> 'nentsy'};
is noun(q{nentsy})->classical->plural, q{nentsy}  => q{classical plural: 'nentsy' --> 'nentsy'};
is noun(q{Timorese})->classical->plural,   q{Timorese}  => q{classical plural: 'Timorese' --> 'Timorese'};
is noun(q{shears})->classical->plural,   q{shears}  => q{classical plural: 'shears' --> 'shears'};
is noun(q{glissando})->classical->plural,   q{glissandi}  => q{classical plural: 'glissando' --> 'glissandi'};
is noun(q{glissandi})->classical->plural, q{glissandi}  => q{classical plural: 'glissandi' --> 'glissandi'};
is noun(q{uncia})->classical->plural,   q{unciae}  => q{classical plural: 'uncia' --> 'unciae'};
is noun(q{unciae})->classical->plural, q{unciae}  => q{classical plural: 'unciae' --> 'unciae'};
is noun(q{Tenggerese})->classical->plural,   q{Tenggerese}  => q{classical plural: 'Tenggerese' --> 'Tenggerese'};
is noun(q{prosecutrix})->classical->plural,   q{prosecutrices}  => q{classical plural: 'prosecutrix' --> 'prosecutrices'};
is noun(q{prosecutrices})->classical->plural, q{prosecutrices}  => q{classical plural: 'prosecutrices' --> 'prosecutrices'};
is noun(q{Otomi})->classical->plural,   q{Otomi}  => q{classical plural: 'Otomi' --> 'Otomi'};
is noun(q{rhino})->classical->plural,   q{rhinos}  => q{classical plural: 'rhino' --> 'rhinos'};
is noun(q{rhinos})->classical->plural, q{rhinos}  => q{classical plural: 'rhinos' --> 'rhinos'};
is noun(q{Kosovo})->classical->plural,   q{Kosovos}  => q{classical plural: 'Kosovo' --> 'Kosovos'};
is noun(q{Kosovos})->classical->plural, q{Kosovos}  => q{classical plural: 'Kosovos' --> 'Kosovos'};
is noun(q{callus})->classical->plural,   q{calluses}  => q{classical plural: 'callus' --> 'calluses'};
is noun(q{calluses})->classical->plural, q{calluses}  => q{classical plural: 'calluses' --> 'calluses'};
is noun(q{diverticulum})->classical->plural,   q{diverticula}  => q{classical plural: 'diverticulum' --> 'diverticula'};
is noun(q{diverticula})->classical->plural, q{diverticula}  => q{classical plural: 'diverticula' --> 'diverticula'};
is noun(q{atlas})->classical->plural,   q{atlantes}  => q{classical plural: 'atlas' --> 'atlantes'};
is noun(q{atlantes})->classical->plural, q{atlantes}  => q{classical plural: 'atlantes' --> 'atlantes'};
is noun(q{vaginula})->classical->plural,   q{vaginulae}  => q{classical plural: 'vaginula' --> 'vaginulae'};
is noun(q{vaginulae})->classical->plural, q{vaginulae}  => q{classical plural: 'vaginulae' --> 'vaginulae'};
is noun(q{techno})->classical->plural,   q{technos}  => q{classical plural: 'techno' --> 'technos'};
is noun(q{technos})->classical->plural, q{technos}  => q{classical plural: 'technos' --> 'technos'};
is noun(q{agora})->classical->plural,   q{agorae}  => q{classical plural: 'agora' --> 'agorae'};
is noun(q{agorae})->classical->plural, q{agorae}  => q{classical plural: 'agorae' --> 'agorae'};
is noun(q{agent provocateur})->classical->plural,   q{agents provocateurs}  => q{classical plural: 'agent provocateur' --> 'agents provocateurs'};
is noun(q{agents provocateurs})->classical->plural, q{agents provocateurs}  => q{classical plural: 'agents provocateurs' --> 'agents provocateurs'};
is noun(q{idolum})->classical->plural,   q{idola}  => q{classical plural: 'idolum' --> 'idola'};
is noun(q{idola})->classical->plural, q{idola}  => q{classical plural: 'idola' --> 'idola'};
is noun(q{pragma})->classical->plural,   q{pragmata}  => q{classical plural: 'pragma' --> 'pragmata'};
is noun(q{pragmata})->classical->plural, q{pragmata}  => q{classical plural: 'pragmata' --> 'pragmata'};
is noun(q{iter})->classical->plural,   q{itinera}  => q{classical plural: 'iter' --> 'itinera'};
is noun(q{itinera})->classical->plural, q{itinera}  => q{classical plural: 'itinera' --> 'itinera'};
is noun(q{gyrus})->classical->plural,   q{gyri}  => q{classical plural: 'gyrus' --> 'gyri'};
is noun(q{gyri})->classical->plural, q{gyri}  => q{classical plural: 'gyri' --> 'gyri'};
is noun(q{beef})->classical->plural,   q{beeves}  => q{classical plural: 'beef' --> 'beeves'};
is noun(q{beeves})->classical->plural, q{beeves}  => q{classical plural: 'beeves' --> 'beeves'};
is noun(q{hoti})->classical->plural,   q{hoties}  => q{classical plural: 'hoti' --> 'hoties'};
is noun(q{hoties})->classical->plural, q{hoties}  => q{classical plural: 'hoties' --> 'hoties'};
is noun(q{musee imaginaire})->classical->plural,   q{musees imaginaires}  => q{classical plural: 'musee imaginaire' --> 'musees imaginaires'};
is noun(q{musees imaginaires})->classical->plural, q{musees imaginaires}  => q{classical plural: 'musees imaginaires' --> 'musees imaginaires'};
is noun(q{summa})->classical->plural,   q{summae}  => q{classical plural: 'summa' --> 'summae'};
is noun(q{summae})->classical->plural, q{summae}  => q{classical plural: 'summae' --> 'summae'};
is noun(q{lomentum})->classical->plural,   q{lomenta}  => q{classical plural: 'lomentum' --> 'lomenta'};
is noun(q{lomenta})->classical->plural, q{lomenta}  => q{classical plural: 'lomenta' --> 'lomenta'};
is noun(q{Milanese})->classical->plural,   q{Milanese}  => q{classical plural: 'Milanese' --> 'Milanese'};
is noun(q{terp})->classical->plural,   q{terpen}  => q{classical plural: 'terp' --> 'terpen'};
is noun(q{terpen})->classical->plural, q{terpen}  => q{classical plural: 'terpen' --> 'terpen'};
is noun(q{cul de lampe})->classical->plural,   q{culs de lampe}  => q{classical plural: 'cul de lampe' --> 'culs de lampe'};
is noun(q{culs de lampe})->classical->plural, q{culs de lampe}  => q{classical plural: 'culs de lampe' --> 'culs de lampe'};
is noun(q{abortus})->classical->plural,   q{abortuses}  => q{classical plural: 'abortus' --> 'abortuses'};
is noun(q{abortuses})->classical->plural, q{abortuses}  => q{classical plural: 'abortuses' --> 'abortuses'};
is noun(q{zuppa})->classical->plural,   q{zuppe}  => q{classical plural: 'zuppa' --> 'zuppe'};
is noun(q{zuppe})->classical->plural, q{zuppe}  => q{classical plural: 'zuppe' --> 'zuppe'};
is noun(q{fizz})->classical->plural,   q{fizzes}  => q{classical plural: 'fizz' --> 'fizzes'};
is noun(q{fizzes})->classical->plural, q{fizzes}  => q{classical plural: 'fizzes' --> 'fizzes'};
is noun(q{whom})->classical->plural,   q{whom}  => q{classical plural: 'whom' --> 'whom'};
is noun(q{maxilla})->classical->plural,   q{maxillae}  => q{classical plural: 'maxilla' --> 'maxillae'};
is noun(q{maxillae})->classical->plural, q{maxillae}  => q{classical plural: 'maxillae' --> 'maxillae'};
is noun(q{arista})->classical->plural,   q{aristae}  => q{classical plural: 'arista' --> 'aristae'};
is noun(q{aristae})->classical->plural, q{aristae}  => q{classical plural: 'aristae' --> 'aristae'};
is noun(q{Messinese})->classical->plural,   q{Messinese}  => q{classical plural: 'Messinese' --> 'Messinese'};
is noun(q{blastema})->classical->plural,   q{blastemata}  => q{classical plural: 'blastema' --> 'blastemata'};
is noun(q{blastemata})->classical->plural, q{blastemata}  => q{classical plural: 'blastemata' --> 'blastemata'};
is noun(q{heft})->classical->plural,   q{hefte}  => q{classical plural: 'heft' --> 'hefte'};
is noun(q{hefte})->classical->plural, q{hefte}  => q{classical plural: 'hefte' --> 'hefte'};
is noun(q{aureus})->classical->plural,   q{aurei}  => q{classical plural: 'aureus' --> 'aurei'};
is noun(q{aurei})->classical->plural, q{aurei}  => q{classical plural: 'aurei' --> 'aurei'};
is noun(q{archipelago})->classical->plural,   q{archipelagoes}  => q{classical plural: 'archipelago' --> 'archipelagoes'};
is noun(q{archipelagoes})->classical->plural, q{archipelagoes}  => q{classical plural: 'archipelagoes' --> 'archipelagoes'};
is noun(q{rem})->classical->plural,   q{rem}  => q{classical plural: 'rem' --> 'rem'};
is noun(q{rotula})->classical->plural,   q{rotulae}  => q{classical plural: 'rotula' --> 'rotulae'};
is noun(q{rotulae})->classical->plural, q{rotulae}  => q{classical plural: 'rotulae' --> 'rotulae'};
is noun(q{timpano})->classical->plural,   q{timpanos}  => q{classical plural: 'timpano' --> 'timpanos'};
is noun(q{timpanos})->classical->plural, q{timpanos}  => q{classical plural: 'timpanos' --> 'timpanos'};
is noun(q{appressorium})->classical->plural,   q{appressoria}  => q{classical plural: 'appressorium' --> 'appressoria'};
is noun(q{appressoria})->classical->plural, q{appressoria}  => q{classical plural: 'appressoria' --> 'appressoria'};
is noun(q{tomato})->classical->plural,   q{tomatoes}  => q{classical plural: 'tomato' --> 'tomatoes'};
is noun(q{tomatoes})->classical->plural, q{tomatoes}  => q{classical plural: 'tomatoes' --> 'tomatoes'};
is noun(q{messa di voce})->classical->plural,   q{messe di voce}  => q{classical plural: 'messa di voce' --> 'messe di voce'};
is noun(q{messe di voce})->classical->plural, q{messe di voce}  => q{classical plural: 'messe di voce' --> 'messe di voce'};
is noun(q{velamen})->classical->plural,   q{velamina}  => q{classical plural: 'velamen' --> 'velamina'};
is noun(q{velamina})->classical->plural, q{velamina}  => q{classical plural: 'velamina' --> 'velamina'};
is noun(q{louis})->classical->plural,   q{louis}  => q{classical plural: 'louis' --> 'louis'};
is noun(q{Bamako})->classical->plural,   q{Bamakos}  => q{classical plural: 'Bamako' --> 'Bamakos'};
is noun(q{Bamakos})->classical->plural, q{Bamakos}  => q{classical plural: 'Bamakos' --> 'Bamakos'};
is noun(q{prothallium})->classical->plural,   q{prothallia}  => q{classical plural: 'prothallium' --> 'prothallia'};
is noun(q{prothallia})->classical->plural, q{prothallia}  => q{classical plural: 'prothallia' --> 'prothallia'};
is noun(q{colonel general})->classical->plural,   q{colonel generals}  => q{classical plural: 'colonel general' --> 'colonel generals'};
is noun(q{colonel generals})->classical->plural, q{colonel generals}  => q{classical plural: 'colonel generals' --> 'colonel generals'};
is noun(q{nemathecium})->classical->plural,   q{nemathecia}  => q{classical plural: 'nemathecium' --> 'nemathecia'};
is noun(q{nemathecia})->classical->plural, q{nemathecia}  => q{classical plural: 'nemathecia' --> 'nemathecia'};
is noun(q{amphora})->classical->plural,   q{amphorae}  => q{classical plural: 'amphora' --> 'amphorae'};
is noun(q{amphorae})->classical->plural, q{amphorae}  => q{classical plural: 'amphorae' --> 'amphorae'};
is noun(q{tholos})->classical->plural,   q{tholoi}  => q{classical plural: 'tholos' --> 'tholoi'};
is noun(q{tholoi})->classical->plural, q{tholoi}  => q{classical plural: 'tholoi' --> 'tholoi'};
is noun(q{rimon})->classical->plural,   q{rimmonim}  => q{classical plural: 'rimon' --> 'rimmonim'};
is noun(q{rimmonim})->classical->plural, q{rimmonim}  => q{classical plural: 'rimmonim' --> 'rimmonim'};
is noun(q{Torino})->classical->plural,   q{Torinos}  => q{classical plural: 'Torino' --> 'Torinos'};
is noun(q{Torinos})->classical->plural, q{Torinos}  => q{classical plural: 'Torinos' --> 'Torinos'};
is noun(q{Ferrarese})->classical->plural,   q{Ferrarese}  => q{classical plural: 'Ferrarese' --> 'Ferrarese'};
is noun(q{valvula})->classical->plural,   q{valvulae}  => q{classical plural: 'valvula' --> 'valvulae'};
is noun(q{valvulae})->classical->plural, q{valvulae}  => q{classical plural: 'valvulae' --> 'valvulae'};
is noun(q{Angolese})->classical->plural,   q{Angolese}  => q{classical plural: 'Angolese' --> 'Angolese'};
is noun(q{syrphus})->classical->plural,   q{syrphi}  => q{classical plural: 'syrphus' --> 'syrphi'};
is noun(q{syrphi})->classical->plural, q{syrphi}  => q{classical plural: 'syrphi' --> 'syrphi'};
is noun(q{that})->classical->plural,   q{those}  => q{classical plural: 'that' --> 'those'};
is noun(q{those})->classical->plural, q{those}  => q{classical plural: 'those' --> 'those'};
is noun(q{tractatrix})->classical->plural,   q{tractatrices}  => q{classical plural: 'tractatrix' --> 'tractatrices'};
is noun(q{tractatrices})->classical->plural, q{tractatrices}  => q{classical plural: 'tractatrices' --> 'tractatrices'};
is noun(q{lorum})->classical->plural,   q{lora}  => q{classical plural: 'lorum' --> 'lora'};
is noun(q{lora})->classical->plural, q{lora}  => q{classical plural: 'lora' --> 'lora'};
is noun(q{Polonese})->classical->plural,   q{Polonese}  => q{classical plural: 'Polonese' --> 'Polonese'};
is noun(q{substratum})->classical->plural,   q{substrata}  => q{classical plural: 'substratum' --> 'substrata'};
is noun(q{substrata})->classical->plural, q{substrata}  => q{classical plural: 'substrata' --> 'substrata'};
is noun(q{tipula})->classical->plural,   q{tipulae}  => q{classical plural: 'tipula' --> 'tipulae'};
is noun(q{tipulae})->classical->plural, q{tipulae}  => q{classical plural: 'tipulae' --> 'tipulae'};
is noun(q{hetaira})->classical->plural,   q{hetairai}  => q{classical plural: 'hetaira' --> 'hetairai'};
is noun(q{hetairai})->classical->plural, q{hetairai}  => q{classical plural: 'hetairai' --> 'hetairai'};
is noun(q{zoosporangium})->classical->plural,   q{zoosporangia}  => q{classical plural: 'zoosporangium' --> 'zoosporangia'};
is noun(q{zoosporangia})->classical->plural, q{zoosporangia}  => q{classical plural: 'zoosporangia' --> 'zoosporangia'};
is noun(q{jalapeno})->classical->plural,   q{jalapenos}  => q{classical plural: 'jalapeno' --> 'jalapenos'};
is noun(q{jalapenos})->classical->plural, q{jalapenos}  => q{classical plural: 'jalapenos' --> 'jalapenos'};
is noun(q{utricularia})->classical->plural,   q{utriculariae}  => q{classical plural: 'utricularia' --> 'utriculariae'};
is noun(q{utriculariae})->classical->plural, q{utriculariae}  => q{classical plural: 'utriculariae' --> 'utriculariae'};
is noun(q{hemangioma})->classical->plural,   q{hemangiomata}  => q{classical plural: 'hemangioma' --> 'hemangiomata'};
is noun(q{hemangiomata})->classical->plural, q{hemangiomata}  => q{classical plural: 'hemangiomata' --> 'hemangiomata'};
is noun(q{lord-lieutenant})->classical->plural,   q{lords-lieutenant}  => q{classical plural: 'lord-lieutenant' --> 'lords-lieutenant'};
is noun(q{lords-lieutenant})->classical->plural, q{lords-lieutenant}  => q{classical plural: 'lords-lieutenant' --> 'lords-lieutenant'};
is noun(q{souvlaki})->classical->plural,   q{souvlakia}  => q{classical plural: 'souvlaki' --> 'souvlakia'};
is noun(q{souvlakia})->classical->plural, q{souvlakia}  => q{classical plural: 'souvlakia' --> 'souvlakia'};
is noun(q{fish})->classical->plural,   q{fish}  => q{classical plural: 'fish' --> 'fish'};
is noun(q{saffo})->classical->plural,   q{saffi}  => q{classical plural: 'saffo' --> 'saffi'};
is noun(q{saffi})->classical->plural, q{saffi}  => q{classical plural: 'saffi' --> 'saffi'};
is noun(q{scherzando})->classical->plural,   q{scherzandos}  => q{classical plural: 'scherzando' --> 'scherzandos'};
is noun(q{scherzandos})->classical->plural, q{scherzandos}  => q{classical plural: 'scherzandos' --> 'scherzandos'};
is noun(q{stipes})->classical->plural,   q{stipites}  => q{classical plural: 'stipes' --> 'stipites'};
is noun(q{stipites})->classical->plural, q{stipites}  => q{classical plural: 'stipites' --> 'stipites'};
is noun(q{sarissa})->classical->plural,   q{sarissae}  => q{classical plural: 'sarissa' --> 'sarissae'};
is noun(q{sarissae})->classical->plural, q{sarissae}  => q{classical plural: 'sarissae' --> 'sarissae'};
is noun(q{tessella})->classical->plural,   q{tessellae}  => q{classical plural: 'tessella' --> 'tessellae'};
is noun(q{tessellae})->classical->plural, q{tessellae}  => q{classical plural: 'tessellae' --> 'tessellae'};
is noun(q{Lesotho})->classical->plural,   q{Lesothos}  => q{classical plural: 'Lesotho' --> 'Lesothos'};
is noun(q{Lesothos})->classical->plural, q{Lesothos}  => q{classical plural: 'Lesothos' --> 'Lesothos'};
is noun(q{fascia})->classical->plural,   q{fasciae}  => q{classical plural: 'fascia' --> 'fasciae'};
is noun(q{fasciae})->classical->plural, q{fasciae}  => q{classical plural: 'fasciae' --> 'fasciae'};
is noun(q{lowlife})->classical->plural,   q{lowlifes}  => q{classical plural: 'lowlife' --> 'lowlifes'};
is noun(q{lowlifes})->classical->plural, q{lowlifes}  => q{classical plural: 'lowlifes' --> 'lowlifes'};
is noun(q{phoca})->classical->plural,   q{phocae}  => q{classical plural: 'phoca' --> 'phocae'};
is noun(q{phocae})->classical->plural, q{phocae}  => q{classical plural: 'phocae' --> 'phocae'};
is noun(q{aecidium})->classical->plural,   q{aecidia}  => q{classical plural: 'aecidium' --> 'aecidia'};
is noun(q{aecidia})->classical->plural, q{aecidia}  => q{classical plural: 'aecidia' --> 'aecidia'};
is noun(q{Nipponese})->classical->plural,   q{Nipponese}  => q{classical plural: 'Nipponese' --> 'Nipponese'};
is noun(q{tenorino})->classical->plural,   q{tenorini}  => q{classical plural: 'tenorino' --> 'tenorini'};
is noun(q{tenorini})->classical->plural, q{tenorini}  => q{classical plural: 'tenorini' --> 'tenorini'};
is noun(q{plectrum})->classical->plural,   q{plectra}  => q{classical plural: 'plectrum' --> 'plectra'};
is noun(q{plectra})->classical->plural, q{plectra}  => q{classical plural: 'plectra' --> 'plectra'};
is noun(q{ambo})->classical->plural,   q{ambones}  => q{classical plural: 'ambo' --> 'ambones'};
is noun(q{ambones})->classical->plural, q{ambones}  => q{classical plural: 'ambones' --> 'ambones'};
is noun(q{plethron})->classical->plural,   q{plether}  => q{classical plural: 'plethron' --> 'plether'};
is noun(q{plether})->classical->plural, q{plether}  => q{classical plural: 'plether' --> 'plether'};
is noun(q{tabula})->classical->plural,   q{tabulae}  => q{classical plural: 'tabula' --> 'tabulae'};
is noun(q{tabulae})->classical->plural, q{tabulae}  => q{classical plural: 'tabulae' --> 'tabulae'};
is noun(q{opus magnum})->classical->plural,   q{opera magna}  => q{classical plural: 'opus magnum' --> 'opera magna'};
is noun(q{opera magna})->classical->plural, q{opera magna}  => q{classical plural: 'opera magna' --> 'opera magna'};
is noun(q{pajamas})->classical->plural,   q{pajamas}  => q{classical plural: 'pajamas' --> 'pajamas'};
is noun(q{talus})->classical->plural,   q{tali}  => q{classical plural: 'talus' --> 'tali'};
is noun(q{tali})->classical->plural, q{tali}  => q{classical plural: 'tali' --> 'tali'};
is noun(q{patera})->classical->plural,   q{paterae}  => q{classical plural: 'patera' --> 'paterae'};
is noun(q{paterae})->classical->plural, q{paterae}  => q{classical plural: 'paterae' --> 'paterae'};
is noun(q{hydraulicon})->classical->plural,   q{hydraulica}  => q{classical plural: 'hydraulicon' --> 'hydraulica'};
is noun(q{hydraulica})->classical->plural, q{hydraulica}  => q{classical plural: 'hydraulica' --> 'hydraulica'};
is noun(q{pizza})->classical->plural,   q{pizze}  => q{classical plural: 'pizza' --> 'pizze'};
is noun(q{pizze})->classical->plural, q{pizze}  => q{classical plural: 'pizze' --> 'pizze'};
is noun(q{Spaetlese})->classical->plural,   q{Spaetlesen}  => q{classical plural: 'Spaetlese' --> 'Spaetlesen'};
is noun(q{Spaetlesen})->classical->plural, q{Spaetlesen}  => q{classical plural: 'Spaetlesen' --> 'Spaetlesen'};
is noun(q{volcanello})->classical->plural,   q{volcanelli}  => q{classical plural: 'volcanello' --> 'volcanelli'};
is noun(q{volcanelli})->classical->plural, q{volcanelli}  => q{classical plural: 'volcanelli' --> 'volcanelli'};
is noun(q{stigma})->classical->plural,   q{stigmata}  => q{classical plural: 'stigma' --> 'stigmata'};
is noun(q{stigmata})->classical->plural, q{stigmata}  => q{classical plural: 'stigmata' --> 'stigmata'};
is noun(q{bodegon})->classical->plural,   q{bodegones}  => q{classical plural: 'bodegon' --> 'bodegones'};
is noun(q{bodegones})->classical->plural, q{bodegones}  => q{classical plural: 'bodegones' --> 'bodegones'};
is noun(q{samurai})->classical->plural,   q{samurai}  => q{classical plural: 'samurai' --> 'samurai'};
is noun(q{salmon})->classical->plural,   q{salmon}  => q{classical plural: 'salmon' --> 'salmon'};
is noun(q{fermata})->classical->plural,   q{fermate}  => q{classical plural: 'fermata' --> 'fermate'};
is noun(q{fermate})->classical->plural, q{fermate}  => q{classical plural: 'fermate' --> 'fermate'};
is noun(q{manchild})->classical->plural,   q{menchildren}  => q{classical plural: 'manchild' --> 'menchildren'};
is noun(q{menchildren})->classical->plural, q{menchildren}  => q{classical plural: 'menchildren' --> 'menchildren'};
is noun(q{nebenkern})->classical->plural,   q{nebenkerne}  => q{classical plural: 'nebenkern' --> 'nebenkerne'};
is noun(q{nebenkerne})->classical->plural, q{nebenkerne}  => q{classical plural: 'nebenkerne' --> 'nebenkerne'};
is noun(q{Azerbaijanese})->classical->plural,   q{Azerbaijanese}  => q{classical plural: 'Azerbaijanese' --> 'Azerbaijanese'};
is noun(q{set out})->classical->plural,   q{sets out}  => q{classical plural: 'set out' --> 'sets out'};
is noun(q{sets out})->classical->plural, q{sets out}  => q{classical plural: 'sets out' --> 'sets out'};
is noun(q{bubo})->classical->plural,   q{buboes}  => q{classical plural: 'bubo' --> 'buboes'};
is noun(q{buboes})->classical->plural, q{buboes}  => q{classical plural: 'buboes' --> 'buboes'};
is noun(q{lochus})->classical->plural,   q{lochi}  => q{classical plural: 'lochus' --> 'lochi'};
is noun(q{lochi})->classical->plural, q{lochi}  => q{classical plural: 'lochi' --> 'lochi'};
is noun(q{shad})->classical->plural,   q{shad}  => q{classical plural: 'shad' --> 'shad'};
is noun(q{sema})->classical->plural,   q{semata}  => q{classical plural: 'sema' --> 'semata'};
is noun(q{semata})->classical->plural, q{semata}  => q{classical plural: 'semata' --> 'semata'};
is noun(q{libero})->classical->plural,   q{liberos}  => q{classical plural: 'libero' --> 'liberos'};
is noun(q{liberos})->classical->plural, q{liberos}  => q{classical plural: 'liberos' --> 'liberos'};
is noun(q{ricercata})->classical->plural,   q{ricercate}  => q{classical plural: 'ricercata' --> 'ricercate'};
is noun(q{ricercate})->classical->plural, q{ricercate}  => q{classical plural: 'ricercate' --> 'ricercate'};
is noun(q{leprosarium})->classical->plural,   q{leprosaria}  => q{classical plural: 'leprosarium' --> 'leprosaria'};
is noun(q{leprosaria})->classical->plural, q{leprosaria}  => q{classical plural: 'leprosaria' --> 'leprosaria'};
is noun(q{criterion})->classical->plural,   q{criteria}  => q{classical plural: 'criterion' --> 'criteria'};
is noun(q{criteria})->classical->plural, q{criteria}  => q{classical plural: 'criteria' --> 'criteria'};
is noun(q{stria})->classical->plural,   q{striae}  => q{classical plural: 'stria' --> 'striae'};
is noun(q{striae})->classical->plural, q{striae}  => q{classical plural: 'striae' --> 'striae'};
is noun(q{venus})->classical->plural,   q{veneres}  => q{classical plural: 'venus' --> 'veneres'};
is noun(q{veneres})->classical->plural, q{veneres}  => q{classical plural: 'veneres' --> 'veneres'};
is noun(q{streptothrix})->classical->plural,   q{streptothrices}  => q{classical plural: 'streptothrix' --> 'streptothrices'};
is noun(q{streptothrices})->classical->plural, q{streptothrices}  => q{classical plural: 'streptothrices' --> 'streptothrices'};
is noun(q{torus})->classical->plural,   q{tori}  => q{classical plural: 'torus' --> 'tori'};
is noun(q{tori})->classical->plural, q{tori}  => q{classical plural: 'tori' --> 'tori'};
is noun(q{sustentaculum})->classical->plural,   q{sustentacula}  => q{classical plural: 'sustentaculum' --> 'sustentacula'};
is noun(q{sustentacula})->classical->plural, q{sustentacula}  => q{classical plural: 'sustentacula' --> 'sustentacula'};
is noun(q{Monaco})->classical->plural,   q{Monacos}  => q{classical plural: 'Monaco' --> 'Monacos'};
is noun(q{Monacos})->classical->plural, q{Monacos}  => q{classical plural: 'Monacos' --> 'Monacos'};
is noun(q{cuspis})->classical->plural,   q{cuspides}  => q{classical plural: 'cuspis' --> 'cuspides'};
is noun(q{cuspides})->classical->plural, q{cuspides}  => q{classical plural: 'cuspides' --> 'cuspides'};
is noun(q{pollinium})->classical->plural,   q{pollinia}  => q{classical plural: 'pollinium' --> 'pollinia'};
is noun(q{pollinia})->classical->plural, q{pollinia}  => q{classical plural: 'pollinia' --> 'pollinia'};
is noun(q{praecognitum})->classical->plural,   q{praecognita}  => q{classical plural: 'praecognitum' --> 'praecognita'};
is noun(q{praecognita})->classical->plural, q{praecognita}  => q{classical plural: 'praecognita' --> 'praecognita'};
is noun(q{ballata})->classical->plural,   q{ballate}  => q{classical plural: 'ballata' --> 'ballate'};
is noun(q{ballate})->classical->plural, q{ballate}  => q{classical plural: 'ballate' --> 'ballate'};
is noun(q{miasma})->classical->plural,   q{miasmata}  => q{classical plural: 'miasma' --> 'miasmata'};
is noun(q{miasmata})->classical->plural, q{miasmata}  => q{classical plural: 'miasmata' --> 'miasmata'};
is noun(q{lixivium})->classical->plural,   q{lixivia}  => q{classical plural: 'lixivium' --> 'lixivia'};
is noun(q{lixivia})->classical->plural, q{lixivia}  => q{classical plural: 'lixivia' --> 'lixivia'};
is noun(q{vitellarium})->classical->plural,   q{vitellaria}  => q{classical plural: 'vitellarium' --> 'vitellaria'};
is noun(q{vitellaria})->classical->plural, q{vitellaria}  => q{classical plural: 'vitellaria' --> 'vitellaria'};
is noun(q{hsien})->classical->plural,   q{heen}  => q{classical plural: 'hsien' --> 'heen'};
is noun(q{heen})->classical->plural, q{heen}  => q{classical plural: 'heen' --> 'heen'};
is noun(q{triplum})->classical->plural,   q{tripla}  => q{classical plural: 'triplum' --> 'tripla'};
is noun(q{tripla})->classical->plural, q{tripla}  => q{classical plural: 'tripla' --> 'tripla'};
is noun(q{yuo})->classical->plural,   q{yuon}  => q{classical plural: 'yuo' --> 'yuon'};
is noun(q{yuon})->classical->plural, q{yuon}  => q{classical plural: 'yuon' --> 'yuon'};
is noun(q{veduta})->classical->plural,   q{vedute}  => q{classical plural: 'veduta' --> 'vedute'};
is noun(q{vedute})->classical->plural, q{vedute}  => q{classical plural: 'vedute' --> 'vedute'};
is noun(q{hymnarium})->classical->plural,   q{hymnaria}  => q{classical plural: 'hymnarium' --> 'hymnaria'};
is noun(q{hymnaria})->classical->plural, q{hymnaria}  => q{classical plural: 'hymnaria' --> 'hymnaria'};
is noun(q{fibula})->classical->plural,   q{fibulae}  => q{classical plural: 'fibula' --> 'fibulae'};
is noun(q{fibulae})->classical->plural, q{fibulae}  => q{classical plural: 'fibulae' --> 'fibulae'};
is noun(q{strobila})->classical->plural,   q{strobilae}  => q{classical plural: 'strobila' --> 'strobilae'};
is noun(q{strobilae})->classical->plural, q{strobilae}  => q{classical plural: 'strobilae' --> 'strobilae'};
is noun(q{eyas})->classical->plural,   q{eyases}  => q{classical plural: 'eyas' --> 'eyases'};
is noun(q{eyases})->classical->plural, q{eyases}  => q{classical plural: 'eyases' --> 'eyases'};
is noun(q{interstitium})->classical->plural,   q{interstitia}  => q{classical plural: 'interstitium' --> 'interstitia'};
is noun(q{interstitia})->classical->plural, q{interstitia}  => q{classical plural: 'interstitia' --> 'interstitia'};
is noun(q{alluvium})->classical->plural,   q{alluvia}  => q{classical plural: 'alluvium' --> 'alluvia'};
is noun(q{alluvia})->classical->plural, q{alluvia}  => q{classical plural: 'alluvia' --> 'alluvia'};
is noun(q{thebe})->classical->plural,   q{thebe}  => q{classical plural: 'thebe' --> 'thebe'};
is noun(q{Santiago})->classical->plural,   q{Santiagos}  => q{classical plural: 'Santiago' --> 'Santiagos'};
is noun(q{Santiagos})->classical->plural, q{Santiagos}  => q{classical plural: 'Santiagos' --> 'Santiagos'};
is noun(q{monoxylon})->classical->plural,   q{monoxyla}  => q{classical plural: 'monoxylon' --> 'monoxyla'};
is noun(q{monoxyla})->classical->plural, q{monoxyla}  => q{classical plural: 'monoxyla' --> 'monoxyla'};
is noun(q{arboretum})->classical->plural,   q{arboreta}  => q{classical plural: 'arboretum' --> 'arboreta'};
is noun(q{arboreta})->classical->plural, q{arboreta}  => q{classical plural: 'arboreta' --> 'arboreta'};
is noun(q{three-star general})->classical->plural,   q{three-star generals}  => q{classical plural: 'three-star general' --> 'three-star generals'};
is noun(q{three-star generals})->classical->plural, q{three-star generals}  => q{classical plural: 'three-star generals' --> 'three-star generals'};
is noun(q{papyrus})->classical->plural,   q{papyri}  => q{classical plural: 'papyrus' --> 'papyri'};
is noun(q{papyri})->classical->plural, q{papyri}  => q{classical plural: 'papyri' --> 'papyri'};
is noun(q{one})->classical->plural,   q{some}  => q{classical plural: 'one' --> 'some'};
is noun(q{some})->classical->plural, q{some}  => q{classical plural: 'some' --> 'some'};
is noun(q{tetragrammaton})->classical->plural,   q{tetragrammata}  => q{classical plural: 'tetragrammaton' --> 'tetragrammata'};
is noun(q{tetragrammata})->classical->plural, q{tetragrammata}  => q{classical plural: 'tetragrammata' --> 'tetragrammata'};
is noun(q{trapezius})->classical->plural,   q{trapezii}  => q{classical plural: 'trapezius' --> 'trapezii'};
is noun(q{trapezii})->classical->plural, q{trapezii}  => q{classical plural: 'trapezii' --> 'trapezii'};
is noun(q{parenchyma})->classical->plural,   q{parenchymata}  => q{classical plural: 'parenchyma' --> 'parenchymata'};
is noun(q{parenchymata})->classical->plural, q{parenchymata}  => q{classical plural: 'parenchymata' --> 'parenchymata'};
is noun(q{moaks})->classical->plural,   q{moakses}  => q{classical plural: 'moaks' --> 'moakses'};
is noun(q{moakses})->classical->plural, q{moakses}  => q{classical plural: 'moakses' --> 'moakses'};
is noun(q{finger-end})->classical->plural,   q{fingers-ends}  => q{classical plural: 'finger-end' --> 'fingers-ends'};
is noun(q{fingers-ends})->classical->plural, q{fingers-ends}  => q{classical plural: 'fingers-ends' --> 'fingers-ends'};
is noun(q{sedes})->classical->plural,   q{sedes}  => q{classical plural: 'sedes' --> 'sedes'};
is noun(q{favella})->classical->plural,   q{favellae}  => q{classical plural: 'favella' --> 'favellae'};
is noun(q{favellae})->classical->plural, q{favellae}  => q{classical plural: 'favellae' --> 'favellae'};
is noun(q{pastorale})->classical->plural,   q{pastorali}  => q{classical plural: 'pastorale' --> 'pastorali'};
is noun(q{pastorali})->classical->plural, q{pastorali}  => q{classical plural: 'pastorali' --> 'pastorali'};
is noun(q{dreikanter})->classical->plural,   q{dreikanter}  => q{classical plural: 'dreikanter' --> 'dreikanter'};
is noun(q{tetracolon})->classical->plural,   q{tetracola}  => q{classical plural: 'tetracolon' --> 'tetracola'};
is noun(q{tetracola})->classical->plural, q{tetracola}  => q{classical plural: 'tetracola' --> 'tetracola'};
is noun(q{schema})->classical->plural,   q{schemata}  => q{classical plural: 'schema' --> 'schemata'};
is noun(q{schemata})->classical->plural, q{schemata}  => q{classical plural: 'schemata' --> 'schemata'};
is noun(q{paparrazo})->classical->plural,   q{paparrazi}  => q{classical plural: 'paparrazo' --> 'paparrazi'};
is noun(q{paparrazi})->classical->plural, q{paparrazi}  => q{classical plural: 'paparrazi' --> 'paparrazi'};
is noun(q{cactus})->classical->plural,   q{cacti}  => q{classical plural: 'cactus' --> 'cacti'};
is noun(q{cacti})->classical->plural, q{cacti}  => q{classical plural: 'cacti' --> 'cacti'};
is noun(q{geisteswissenschaft})->classical->plural,   q{geisteswissenschaften}  => q{classical plural: 'geisteswissenschaft' --> 'geisteswissenschaften'};
is noun(q{geisteswissenschaften})->classical->plural, q{geisteswissenschaften}  => q{classical plural: 'geisteswissenschaften' --> 'geisteswissenschaften'};
is noun(q{hippopotamus})->classical->plural,   q{hippopotami}  => q{classical plural: 'hippopotamus' --> 'hippopotami'};
is noun(q{hippopotami})->classical->plural, q{hippopotami}  => q{classical plural: 'hippopotami' --> 'hippopotami'};
is noun(q{rhombohedron})->classical->plural,   q{rhombohedra}  => q{classical plural: 'rhombohedron' --> 'rhombohedra'};
is noun(q{rhombohedra})->classical->plural, q{rhombohedra}  => q{classical plural: 'rhombohedra' --> 'rhombohedra'};
is noun(q{six star general})->classical->plural,   q{six star generals}  => q{classical plural: 'six star general' --> 'six star generals'};
is noun(q{six star generals})->classical->plural, q{six star generals}  => q{classical plural: 'six star generals' --> 'six star generals'};
is noun(q{mezzo rilievo})->classical->plural,   q{mezzo rilievos}  => q{classical plural: 'mezzo rilievo' --> 'mezzo rilievos'};
is noun(q{mezzo rilievos})->classical->plural, q{mezzo rilievos}  => q{classical plural: 'mezzo rilievos' --> 'mezzo rilievos'};
is noun(q{shifta})->classical->plural,   q{shifta}  => q{classical plural: 'shifta' --> 'shifta'};
is noun(q{primigravida})->classical->plural,   q{primigravidae}  => q{classical plural: 'primigravida' --> 'primigravidae'};
is noun(q{primigravidae})->classical->plural, q{primigravidae}  => q{classical plural: 'primigravidae' --> 'primigravidae'};
is noun(q{prothallus})->classical->plural,   q{prothalli}  => q{classical plural: 'prothallus' --> 'prothalli'};
is noun(q{prothalli})->classical->plural, q{prothalli}  => q{classical plural: 'prothalli' --> 'prothalli'};
is noun(q{allargando})->classical->plural,   q{allargandi}  => q{classical plural: 'allargando' --> 'allargandi'};
is noun(q{allargandi})->classical->plural, q{allargandi}  => q{classical plural: 'allargandi' --> 'allargandi'};
is noun(q{morceau})->classical->plural,   q{morceaux}  => q{classical plural: 'morceau' --> 'morceaux'};
is noun(q{morceaux})->classical->plural, q{morceaux}  => q{classical plural: 'morceaux' --> 'morceaux'};
is noun(q{felo de se})->classical->plural,   q{felones de se}  => q{classical plural: 'felo de se' --> 'felones de se'};
is noun(q{felones de se})->classical->plural, q{felones de se}  => q{classical plural: 'felones de se' --> 'felones de se'};
is noun(q{cinclis})->classical->plural,   q{cinclides}  => q{classical plural: 'cinclis' --> 'cinclides'};
is noun(q{cinclides})->classical->plural, q{cinclides}  => q{classical plural: 'cinclides' --> 'cinclides'};
is noun(q{chapeau})->classical->plural,   q{chapeaux}  => q{classical plural: 'chapeau' --> 'chapeaux'};
is noun(q{chapeaux})->classical->plural, q{chapeaux}  => q{classical plural: 'chapeaux' --> 'chapeaux'};
is noun(q{murex})->classical->plural,   q{murices}  => q{classical plural: 'murex' --> 'murices'};
is noun(q{murices})->classical->plural, q{murices}  => q{classical plural: 'murices' --> 'murices'};
is noun(q{Indochinese})->classical->plural,   q{Indochinese}  => q{classical plural: 'Indochinese' --> 'Indochinese'};
is noun(q{phyle})->classical->plural,   q{phylae}  => q{classical plural: 'phyle' --> 'phylae'};
is noun(q{phylae})->classical->plural, q{phylae}  => q{classical plural: 'phylae' --> 'phylae'};
is noun(q{pinon})->classical->plural,   q{pinones}  => q{classical plural: 'pinon' --> 'pinones'};
is noun(q{pinones})->classical->plural, q{pinones}  => q{classical plural: 'pinones' --> 'pinones'};
is noun(q{human})->classical->plural,   q{humans}  => q{classical plural: 'human' --> 'humans'};
is noun(q{humans})->classical->plural, q{humans}  => q{classical plural: 'humans' --> 'humans'};
is noun(q{Milano})->classical->plural,   q{Milanos}  => q{classical plural: 'Milano' --> 'Milanos'};
is noun(q{Milanos})->classical->plural, q{Milanos}  => q{classical plural: 'Milanos' --> 'Milanos'};
is noun(q{sgraffiato})->classical->plural,   q{sgraffiati}  => q{classical plural: 'sgraffiato' --> 'sgraffiati'};
is noun(q{sgraffiati})->classical->plural, q{sgraffiati}  => q{classical plural: 'sgraffiati' --> 'sgraffiati'};
is noun(q{indumentum})->classical->plural,   q{indumenta}  => q{classical plural: 'indumentum' --> 'indumenta'};
is noun(q{indumenta})->classical->plural, q{indumenta}  => q{classical plural: 'indumenta' --> 'indumenta'};
is noun(q{datum})->classical->plural,   q{data}  => q{classical plural: 'datum' --> 'data'};
is noun(q{data})->classical->plural, q{data}  => q{classical plural: 'data' --> 'data'};
is noun(q{proscenium})->classical->plural,   q{proscenia}  => q{classical plural: 'proscenium' --> 'proscenia'};
is noun(q{proscenia})->classical->plural, q{proscenia}  => q{classical plural: 'proscenia' --> 'proscenia'};
is noun(q{bream})->classical->plural,   q{bream}  => q{classical plural: 'bream' --> 'bream'};
is noun(q{co})->classical->plural,   q{coes}  => q{classical plural: 'co' --> 'coes'};
is noun(q{coes})->classical->plural, q{coes}  => q{classical plural: 'coes' --> 'coes'};
is noun(q{moroso})->classical->plural,   q{morosi}  => q{classical plural: 'moroso' --> 'morosi'};
is noun(q{morosi})->classical->plural, q{morosi}  => q{classical plural: 'morosi' --> 'morosi'};
is noun(q{zoon})->classical->plural,   q{zoa}  => q{classical plural: 'zoon' --> 'zoa'};
is noun(q{zoa})->classical->plural, q{zoa}  => q{classical plural: 'zoa' --> 'zoa'};
is noun(q{ellipsis})->classical->plural,   q{ellipses}  => q{classical plural: 'ellipsis' --> 'ellipses'};
is noun(q{ellipses})->classical->plural, q{ellipses}  => q{classical plural: 'ellipses' --> 'ellipses'};
is noun(q{cassone})->classical->plural,   q{cassoni}  => q{classical plural: 'cassone' --> 'cassoni'};
is noun(q{cassoni})->classical->plural, q{cassoni}  => q{classical plural: 'cassoni' --> 'cassoni'};
is noun(q{tegmen})->classical->plural,   q{tegmina}  => q{classical plural: 'tegmen' --> 'tegmina'};
is noun(q{tegmina})->classical->plural, q{tegmina}  => q{classical plural: 'tegmina' --> 'tegmina'};
is noun(q{amoretto})->classical->plural,   q{amoretti}  => q{classical plural: 'amoretto' --> 'amoretti'};
is noun(q{amoretti})->classical->plural, q{amoretti}  => q{classical plural: 'amoretti' --> 'amoretti'};
is noun(q{gubernaculum})->classical->plural,   q{gubernacula}  => q{classical plural: 'gubernaculum' --> 'gubernacula'};
is noun(q{gubernacula})->classical->plural, q{gubernacula}  => q{classical plural: 'gubernacula' --> 'gubernacula'};
is noun(q{phyogemmarium})->classical->plural,   q{phyogemmaria}  => q{classical plural: 'phyogemmarium' --> 'phyogemmaria'};
is noun(q{phyogemmaria})->classical->plural, q{phyogemmaria}  => q{classical plural: 'phyogemmaria' --> 'phyogemmaria'};
is noun(q{mausoleum})->classical->plural,   q{mausolea}  => q{classical plural: 'mausoleum' --> 'mausolea'};
is noun(q{mausolea})->classical->plural, q{mausolea}  => q{classical plural: 'mausolea' --> 'mausolea'};
is noun(q{thanatorium})->classical->plural,   q{thanatoria}  => q{classical plural: 'thanatorium' --> 'thanatoria'};
is noun(q{thanatoria})->classical->plural, q{thanatoria}  => q{classical plural: 'thanatoria' --> 'thanatoria'};
is noun(q{soldo})->classical->plural,   q{soldi}  => q{classical plural: 'soldo' --> 'soldi'};
is noun(q{soldi})->classical->plural, q{soldi}  => q{classical plural: 'soldi' --> 'soldi'};
is noun(q{favissa})->classical->plural,   q{favissae}  => q{classical plural: 'favissa' --> 'favissae'};
is noun(q{favissae})->classical->plural, q{favissae}  => q{classical plural: 'favissae' --> 'favissae'};
is noun(q{voeu})->classical->plural,   q{voeux}  => q{classical plural: 'voeu' --> 'voeux'};
is noun(q{voeux})->classical->plural, q{voeux}  => q{classical plural: 'voeux' --> 'voeux'};
is noun(q{Chimango})->classical->plural,   q{Chimangos}  => q{classical plural: 'Chimango' --> 'Chimangos'};
is noun(q{Chimangos})->classical->plural, q{Chimangos}  => q{classical plural: 'Chimangos' --> 'Chimangos'};
is noun(q{obelus})->classical->plural,   q{obeli}  => q{classical plural: 'obelus' --> 'obeli'};
is noun(q{obeli})->classical->plural, q{obeli}  => q{classical plural: 'obeli' --> 'obeli'};
is noun(q{siliqua})->classical->plural,   q{siliquae}  => q{classical plural: 'siliqua' --> 'siliquae'};
is noun(q{siliquae})->classical->plural, q{siliquae}  => q{classical plural: 'siliquae' --> 'siliquae'};
is noun(q{fenestra})->classical->plural,   q{fenestrae}  => q{classical plural: 'fenestra' --> 'fenestrae'};
is noun(q{fenestrae})->classical->plural, q{fenestrae}  => q{classical plural: 'fenestrae' --> 'fenestrae'};
is noun(q{staccato})->classical->plural,   q{staccatos}  => q{classical plural: 'staccato' --> 'staccatos'};
is noun(q{staccatos})->classical->plural, q{staccatos}  => q{classical plural: 'staccatos' --> 'staccatos'};
is noun(q{capataz})->classical->plural,   q{capataces}  => q{classical plural: 'capataz' --> 'capataces'};
is noun(q{capataces})->classical->plural, q{capataces}  => q{classical plural: 'capataces' --> 'capataces'};
is noun(q{lens})->classical->plural,   q{lenses}  => q{classical plural: 'lens' --> 'lenses'};
is noun(q{lenses})->classical->plural, q{lenses}  => q{classical plural: 'lenses' --> 'lenses'};
is noun(q{digitalis})->classical->plural,   q{digitalises}  => q{classical plural: 'digitalis' --> 'digitalises'};
is noun(q{digitalises})->classical->plural, q{digitalises}  => q{classical plural: 'digitalises' --> 'digitalises'};
is noun(q{Torinese})->classical->plural,   q{Torinese}  => q{classical plural: 'Torinese' --> 'Torinese'};
is noun(q{Wenchowese})->classical->plural,   q{Wenchowese}  => q{classical plural: 'Wenchowese' --> 'Wenchowese'};
is noun(q{man})->classical->plural,   q{men}  => q{classical plural: 'man' --> 'men'};
is noun(q{men})->classical->plural, q{men}  => q{classical plural: 'men' --> 'men'};
is noun(q{stillicidium})->classical->plural,   q{stillicidia}  => q{classical plural: 'stillicidium' --> 'stillicidia'};
is noun(q{stillicidia})->classical->plural, q{stillicidia}  => q{classical plural: 'stillicidia' --> 'stillicidia'};
is noun(q{pelvis})->classical->plural,   q{pelves}  => q{classical plural: 'pelvis' --> 'pelves'};
is noun(q{pelves})->classical->plural, q{pelves}  => q{classical plural: 'pelves' --> 'pelves'};
is noun(q{Guaiabero})->classical->plural,   q{Guaiaberos}  => q{classical plural: 'Guaiabero' --> 'Guaiaberos'};
is noun(q{Guaiaberos})->classical->plural, q{Guaiaberos}  => q{classical plural: 'Guaiaberos' --> 'Guaiaberos'};
is noun(q{contralto})->classical->plural,   q{contralti}  => q{classical plural: 'contralto' --> 'contralti'};
is noun(q{contralti})->classical->plural, q{contralti}  => q{classical plural: 'contralti' --> 'contralti'};
is noun(q{serpigo})->classical->plural,   q{serpigines}  => q{classical plural: 'serpigo' --> 'serpigines'};
is noun(q{serpigines})->classical->plural, q{serpigines}  => q{classical plural: 'serpigines' --> 'serpigines'};
is noun(q{retinula})->classical->plural,   q{retinulae}  => q{classical plural: 'retinula' --> 'retinulae'};
is noun(q{retinulae})->classical->plural, q{retinulae}  => q{classical plural: 'retinulae' --> 'retinulae'};
is noun(q{mons})->classical->plural,   q{montes}  => q{classical plural: 'mons' --> 'montes'};
is noun(q{montes})->classical->plural, q{montes}  => q{classical plural: 'montes' --> 'montes'};
is noun(q{tubulus})->classical->plural,   q{tubuli}  => q{classical plural: 'tubulus' --> 'tubuli'};
is noun(q{tubuli})->classical->plural, q{tubuli}  => q{classical plural: 'tubuli' --> 'tubuli'};
is noun(q{impetigo})->classical->plural,   q{impetigos}  => q{classical plural: 'impetigo' --> 'impetigos'};
is noun(q{impetigos})->classical->plural, q{impetigos}  => q{classical plural: 'impetigos' --> 'impetigos'};
is noun(q{man midwife})->classical->plural,   q{men midwives}  => q{classical plural: 'man midwife' --> 'men midwives'};
is noun(q{men midwives})->classical->plural, q{men midwives}  => q{classical plural: 'men midwives' --> 'men midwives'};
is noun(q{grouse})->classical->plural,   q{grouse}  => q{classical plural: 'grouse' --> 'grouse'};
is noun(q{violetta})->classical->plural,   q{violette}  => q{classical plural: 'violetta' --> 'violette'};
is noun(q{violette})->classical->plural, q{violette}  => q{classical plural: 'violette' --> 'violette'};
is noun(q{monimolimnion})->classical->plural,   q{monimolimnia}  => q{classical plural: 'monimolimnion' --> 'monimolimnia'};
is noun(q{monimolimnia})->classical->plural, q{monimolimnia}  => q{classical plural: 'monimolimnia' --> 'monimolimnia'};
is noun(q{siphunculus})->classical->plural,   q{siphunculi}  => q{classical plural: 'siphunculus' --> 'siphunculi'};
is noun(q{siphunculi})->classical->plural, q{siphunculi}  => q{classical plural: 'siphunculi' --> 'siphunculi'};
is noun(q{djinn})->classical->plural,   q{djinn}  => q{classical plural: 'djinn' --> 'djinn'};
is noun(q{puttony})->classical->plural,   q{puttonys}  => q{classical plural: 'puttony' --> 'puttonys'};
is noun(q{puttonys})->classical->plural, q{puttonys}  => q{classical plural: 'puttonys' --> 'puttonys'};
is noun(q{arrha})->classical->plural,   q{arrhae}  => q{classical plural: 'arrha' --> 'arrhae'};
is noun(q{arrhae})->classical->plural, q{arrhae}  => q{classical plural: 'arrhae' --> 'arrhae'};
is noun(q{alumnus})->classical->plural,   q{alumni}  => q{classical plural: 'alumnus' --> 'alumni'};
is noun(q{alumni})->classical->plural, q{alumni}  => q{classical plural: 'alumni' --> 'alumni'};
is noun(q{falsetto})->classical->plural,   q{falsettos}  => q{classical plural: 'falsetto' --> 'falsettos'};
is noun(q{falsettos})->classical->plural, q{falsettos}  => q{classical plural: 'falsettos' --> 'falsettos'};
is noun(q{pyrexia})->classical->plural,   q{pyrexiae}  => q{classical plural: 'pyrexia' --> 'pyrexiae'};
is noun(q{pyrexiae})->classical->plural, q{pyrexiae}  => q{classical plural: 'pyrexiae' --> 'pyrexiae'};
is noun(q{abacus})->classical->plural,   q{abacuses}  => q{classical plural: 'abacus' --> 'abacuses'};
is noun(q{abacuses})->classical->plural, q{abacuses}  => q{classical plural: 'abacuses' --> 'abacuses'};
is noun(q{euporiston})->classical->plural,   q{euporista}  => q{classical plural: 'euporiston' --> 'euporista'};
is noun(q{euporista})->classical->plural, q{euporista}  => q{classical plural: 'euporista' --> 'euporista'};
is noun(q{cul-de-four})->classical->plural,   q{culs-de-four}  => q{classical plural: 'cul-de-four' --> 'culs-de-four'};
is noun(q{culs-de-four})->classical->plural, q{culs-de-four}  => q{classical plural: 'culs-de-four' --> 'culs-de-four'};
is noun(q{rideau})->classical->plural,   q{rideaux}  => q{classical plural: 'rideau' --> 'rideaux'};
is noun(q{rideaux})->classical->plural, q{rideaux}  => q{classical plural: 'rideaux' --> 'rideaux'};
is noun(q{apterium})->classical->plural,   q{apteria}  => q{classical plural: 'apterium' --> 'apteria'};
is noun(q{apteria})->classical->plural, q{apteria}  => q{classical plural: 'apteria' --> 'apteria'};
is noun(q{relatum})->classical->plural,   q{relata}  => q{classical plural: 'relatum' --> 'relata'};
is noun(q{relata})->classical->plural, q{relata}  => q{classical plural: 'relata' --> 'relata'};
is noun(q{franc archer})->classical->plural,   q{francs archers}  => q{classical plural: 'franc archer' --> 'francs archers'};
is noun(q{francs archers})->classical->plural, q{francs archers}  => q{classical plural: 'francs archers' --> 'francs archers'};
is noun(q{strategus})->classical->plural,   q{strategi}  => q{classical plural: 'strategus' --> 'strategi'};
is noun(q{strategi})->classical->plural, q{strategi}  => q{classical plural: 'strategi' --> 'strategi'};
is noun(q{nerita})->classical->plural,   q{neritae}  => q{classical plural: 'nerita' --> 'neritae'};
is noun(q{neritae})->classical->plural, q{neritae}  => q{classical plural: 'neritae' --> 'neritae'};
is noun(q{corpus})->classical->plural,   q{corpora}  => q{classical plural: 'corpus' --> 'corpora'};
is noun(q{corpora})->classical->plural, q{corpora}  => q{classical plural: 'corpora' --> 'corpora'};
is noun(q{limulus})->classical->plural,   q{limuli}  => q{classical plural: 'limulus' --> 'limuli'};
is noun(q{limuli})->classical->plural, q{limuli}  => q{classical plural: 'limuli' --> 'limuli'};
is noun(q{star-fish})->classical->plural,   q{star-fish}  => q{classical plural: 'star-fish' --> 'star-fish'};
is noun(q{nucleolus})->classical->plural,   q{nucleoli}  => q{classical plural: 'nucleolus' --> 'nucleoli'};
is noun(q{nucleoli})->classical->plural, q{nucleoli}  => q{classical plural: 'nucleoli' --> 'nucleoli'};
is noun(q{columbarium})->classical->plural,   q{columbaria}  => q{classical plural: 'columbarium' --> 'columbaria'};
is noun(q{columbaria})->classical->plural, q{columbaria}  => q{classical plural: 'columbaria' --> 'columbaria'};
is noun(q{ballabile})->classical->plural,   q{ballabili}  => q{classical plural: 'ballabile' --> 'ballabili'};
is noun(q{ballabili})->classical->plural, q{ballabili}  => q{classical plural: 'ballabili' --> 'ballabili'};
is noun(q{crafts child})->classical->plural,   q{crafts childer}  => q{classical plural: 'crafts child' --> 'crafts childer'};
is noun(q{crafts childer})->classical->plural, q{crafts childer}  => q{classical plural: 'crafts childer' --> 'crafts childer'};
is noun(q{testes})->classical->plural,   q{testes}  => q{classical plural: 'testes' --> 'testes'};
is noun(q{antefix})->classical->plural,   q{antefixa}  => q{classical plural: 'antefix' --> 'antefixa'};
is noun(q{antefixa})->classical->plural, q{antefixa}  => q{classical plural: 'antefixa' --> 'antefixa'};
is noun(q{pasteurella})->classical->plural,   q{pasteurellae}  => q{classical plural: 'pasteurella' --> 'pasteurellae'};
is noun(q{pasteurellae})->classical->plural, q{pasteurellae}  => q{classical plural: 'pasteurellae' --> 'pasteurellae'};
is noun(q{rhopalium})->classical->plural,   q{rhopalia}  => q{classical plural: 'rhopalium' --> 'rhopalia'};
is noun(q{rhopalia})->classical->plural, q{rhopalia}  => q{classical plural: 'rhopalia' --> 'rhopalia'};
is noun(q{Virgo})->classical->plural,   q{Virgos}  => q{classical plural: 'Virgo' --> 'Virgos'};
is noun(q{Virgos})->classical->plural, q{Virgos}  => q{classical plural: 'Virgos' --> 'Virgos'};
is noun(q{lex humana})->classical->plural,   q{leges humanae}  => q{classical plural: 'lex humana' --> 'leges humanae'};
is noun(q{leges humanae})->classical->plural, q{leges humanae}  => q{classical plural: 'leges humanae' --> 'leges humanae'};
is noun(q{parnass})->classical->plural,   q{parnassim}  => q{classical plural: 'parnass' --> 'parnassim'};
is noun(q{parnassim})->classical->plural, q{parnassim}  => q{classical plural: 'parnassim' --> 'parnassim'};
is noun(q{beau geste})->classical->plural,   q{beaux gestes}  => q{classical plural: 'beau geste' --> 'beaux gestes'};
is noun(q{beaux gestes})->classical->plural, q{beaux gestes}  => q{classical plural: 'beaux gestes' --> 'beaux gestes'};
is noun(q{ligamentum})->classical->plural,   q{ligamenta}  => q{classical plural: 'ligamentum' --> 'ligamenta'};
is noun(q{ligamenta})->classical->plural, q{ligamenta}  => q{classical plural: 'ligamenta' --> 'ligamenta'};
is noun(q{cimex})->classical->plural,   q{cimices}  => q{classical plural: 'cimex' --> 'cimices'};
is noun(q{cimices})->classical->plural, q{cimices}  => q{classical plural: 'cimices' --> 'cimices'};
is noun(q{vasculitis})->classical->plural,   q{vasculitides}  => q{classical plural: 'vasculitis' --> 'vasculitides'};
is noun(q{vasculitides})->classical->plural, q{vasculitides}  => q{classical plural: 'vasculitides' --> 'vasculitides'};
is noun(q{Shawanese})->classical->plural,   q{Shawanese}  => q{classical plural: 'Shawanese' --> 'Shawanese'};
is noun(q{violoncello})->classical->plural,   q{violoncellos}  => q{classical plural: 'violoncello' --> 'violoncellos'};
is noun(q{violoncellos})->classical->plural, q{violoncellos}  => q{classical plural: 'violoncellos' --> 'violoncellos'};
is noun(q{maar})->classical->plural,   q{maare}  => q{classical plural: 'maar' --> 'maare'};
is noun(q{maare})->classical->plural, q{maare}  => q{classical plural: 'maare' --> 'maare'};
is noun(q{auto})->classical->plural,   q{autos}  => q{classical plural: 'auto' --> 'autos'};
is noun(q{autos})->classical->plural, q{autos}  => q{classical plural: 'autos' --> 'autos'};
is noun(q{rype})->classical->plural,   q{ryper}  => q{classical plural: 'rype' --> 'ryper'};
is noun(q{ryper})->classical->plural, q{ryper}  => q{classical plural: 'ryper' --> 'ryper'};
is noun(q{melanoma})->classical->plural,   q{melanomata}  => q{classical plural: 'melanoma' --> 'melanomata'};
is noun(q{melanomata})->classical->plural, q{melanomata}  => q{classical plural: 'melanomata' --> 'melanomata'};
is noun(q{antenna})->classical->plural,   q{antennae}  => q{classical plural: 'antenna' --> 'antennae'};
is noun(q{antennae})->classical->plural, q{antennae}  => q{classical plural: 'antennae' --> 'antennae'};
is noun(q{cathisma})->classical->plural,   q{cathismata}  => q{classical plural: 'cathisma' --> 'cathismata'};
is noun(q{cathismata})->classical->plural, q{cathismata}  => q{classical plural: 'cathismata' --> 'cathismata'};
is noun(q{bechuana})->classical->plural,   q{bechuana}  => q{classical plural: 'bechuana' --> 'bechuana'};
is noun(q{Piedmontese})->classical->plural,   q{Piedmontese}  => q{classical plural: 'Piedmontese' --> 'Piedmontese'};
is noun(q{gorgonia})->classical->plural,   q{gorgoniae}  => q{classical plural: 'gorgonia' --> 'gorgoniae'};
is noun(q{gorgoniae})->classical->plural, q{gorgoniae}  => q{classical plural: 'gorgoniae' --> 'gorgoniae'};
is noun(q{idolon})->classical->plural,   q{idola}  => q{classical plural: 'idolon' --> 'idola'};
is noun(q{idola})->classical->plural, q{idola}  => q{classical plural: 'idola' --> 'idola'};
is noun(q{tetrasporangium})->classical->plural,   q{tetrasporangia}  => q{classical plural: 'tetrasporangium' --> 'tetrasporangia'};
is noun(q{tetrasporangia})->classical->plural, q{tetrasporangia}  => q{classical plural: 'tetrasporangia' --> 'tetrasporangia'};
is noun(q{phragma})->classical->plural,   q{phragmata}  => q{classical plural: 'phragma' --> 'phragmata'};
is noun(q{phragmata})->classical->plural, q{phragmata}  => q{classical plural: 'phragmata' --> 'phragmata'};
is noun(q{cargador})->classical->plural,   q{cargadores}  => q{classical plural: 'cargador' --> 'cargadores'};
is noun(q{cargadores})->classical->plural, q{cargadores}  => q{classical plural: 'cargadores' --> 'cargadores'};
is noun(q{claustrum})->classical->plural,   q{claustra}  => q{classical plural: 'claustrum' --> 'claustra'};
is noun(q{claustra})->classical->plural, q{claustra}  => q{classical plural: 'claustra' --> 'claustra'};
is noun(q{municipium})->classical->plural,   q{municipia}  => q{classical plural: 'municipium' --> 'municipia'};
is noun(q{municipia})->classical->plural, q{municipia}  => q{classical plural: 'municipia' --> 'municipia'};
is noun(q{umbo})->classical->plural,   q{umbones}  => q{classical plural: 'umbo' --> 'umbones'};
is noun(q{umbones})->classical->plural, q{umbones}  => q{classical plural: 'umbones' --> 'umbones'};
is noun(q{line out})->classical->plural,   q{lines out}  => q{classical plural: 'line out' --> 'lines out'};
is noun(q{lines out})->classical->plural, q{lines out}  => q{classical plural: 'lines out' --> 'lines out'};
is noun(q{succubus})->classical->plural,   q{succubi}  => q{classical plural: 'succubus' --> 'succubi'};
is noun(q{succubi})->classical->plural, q{succubi}  => q{classical plural: 'succubi' --> 'succubi'};
is noun(q{tiro})->classical->plural,   q{tiros}  => q{classical plural: 'tiro' --> 'tiros'};
is noun(q{tiros})->classical->plural, q{tiros}  => q{classical plural: 'tiros' --> 'tiros'};
is noun(q{scapus})->classical->plural,   q{scapi}  => q{classical plural: 'scapus' --> 'scapi'};
is noun(q{scapi})->classical->plural, q{scapi}  => q{classical plural: 'scapi' --> 'scapi'};
is noun(q{procoelia})->classical->plural,   q{procoeliae}  => q{classical plural: 'procoelia' --> 'procoeliae'};
is noun(q{procoeliae})->classical->plural, q{procoeliae}  => q{classical plural: 'procoeliae' --> 'procoeliae'};
is noun(q{ballerina})->classical->plural,   q{ballerine}  => q{classical plural: 'ballerina' --> 'ballerine'};
is noun(q{ballerine})->classical->plural, q{ballerine}  => q{classical plural: 'ballerine' --> 'ballerine'};
is noun(q{amphipneust})->classical->plural,   q{amphipneusta}  => q{classical plural: 'amphipneust' --> 'amphipneusta'};
is noun(q{amphipneusta})->classical->plural, q{amphipneusta}  => q{classical plural: 'amphipneusta' --> 'amphipneusta'};
is noun(q{minyan})->classical->plural,   q{minyanim}  => q{classical plural: 'minyan' --> 'minyanim'};
is noun(q{minyanim})->classical->plural, q{minyanim}  => q{classical plural: 'minyanim' --> 'minyanim'};
is noun(q{sestiere})->classical->plural,   q{sestieri}  => q{classical plural: 'sestiere' --> 'sestieri'};
is noun(q{sestieri})->classical->plural, q{sestieri}  => q{classical plural: 'sestieri' --> 'sestieri'};
is noun(q{pipkrake})->classical->plural,   q{pipkraker}  => q{classical plural: 'pipkrake' --> 'pipkraker'};
is noun(q{pipkraker})->classical->plural, q{pipkraker}  => q{classical plural: 'pipkraker' --> 'pipkraker'};
is noun(q{progymnasma})->classical->plural,   q{progymnasmata}  => q{classical plural: 'progymnasma' --> 'progymnasmata'};
is noun(q{progymnasmata})->classical->plural, q{progymnasmata}  => q{classical plural: 'progymnasmata' --> 'progymnasmata'};
is noun(q{lacinia})->classical->plural,   q{laciniae}  => q{classical plural: 'lacinia' --> 'laciniae'};
is noun(q{laciniae})->classical->plural, q{laciniae}  => q{classical plural: 'laciniae' --> 'laciniae'};
is noun(q{metro})->classical->plural,   q{metros}  => q{classical plural: 'metro' --> 'metros'};
is noun(q{metros})->classical->plural, q{metros}  => q{classical plural: 'metros' --> 'metros'};
is noun(q{Sudanese})->classical->plural,   q{Sudanese}  => q{classical plural: 'Sudanese' --> 'Sudanese'};
is noun(q{lobulus})->classical->plural,   q{lobuli}  => q{classical plural: 'lobulus' --> 'lobuli'};
is noun(q{lobuli})->classical->plural, q{lobuli}  => q{classical plural: 'lobuli' --> 'lobuli'};
is noun(q{sarcoma})->classical->plural,   q{sarcomata}  => q{classical plural: 'sarcoma' --> 'sarcomata'};
is noun(q{sarcomata})->classical->plural, q{sarcomata}  => q{classical plural: 'sarcomata' --> 'sarcomata'};
is noun(q{gonidium})->classical->plural,   q{gonidia}  => q{classical plural: 'gonidium' --> 'gonidia'};
is noun(q{gonidia})->classical->plural, q{gonidia}  => q{classical plural: 'gonidia' --> 'gonidia'};
is noun(q{novus homo})->classical->plural,   q{novi homines}  => q{classical plural: 'novus homo' --> 'novi homines'};
is noun(q{novi homines})->classical->plural, q{novi homines}  => q{classical plural: 'novi homines' --> 'novi homines'};
is noun(q{familia})->classical->plural,   q{familiae}  => q{classical plural: 'familia' --> 'familiae'};
is noun(q{familiae})->classical->plural, q{familiae}  => q{classical plural: 'familiae' --> 'familiae'};
is noun(q{dogma})->classical->plural,   q{dogmata}  => q{classical plural: 'dogma' --> 'dogmata'};
is noun(q{dogmata})->classical->plural, q{dogmata}  => q{classical plural: 'dogmata' --> 'dogmata'};
is noun(q{uncus})->classical->plural,   q{unci}  => q{classical plural: 'uncus' --> 'unci'};
is noun(q{unci})->classical->plural, q{unci}  => q{classical plural: 'unci' --> 'unci'};
is noun(q{axon})->classical->plural,   q{axones}  => q{classical plural: 'axon' --> 'axones'};
is noun(q{axones})->classical->plural, q{axones}  => q{classical plural: 'axones' --> 'axones'};
is noun(q{phallos})->classical->plural,   q{phalloi}  => q{classical plural: 'phallos' --> 'phalloi'};
is noun(q{phalloi})->classical->plural, q{phalloi}  => q{classical plural: 'phalloi' --> 'phalloi'};
is noun(q{insula})->classical->plural,   q{insulae}  => q{classical plural: 'insula' --> 'insulae'};
is noun(q{insulae})->classical->plural, q{insulae}  => q{classical plural: 'insulae' --> 'insulae'};
is noun(q{salvo})->classical->plural,   q{salvos}  => q{classical plural: 'salvo' --> 'salvos'};
is noun(q{salvos})->classical->plural, q{salvos}  => q{classical plural: 'salvos' --> 'salvos'};
is noun(q{magneto})->classical->plural,   q{magnetos}  => q{classical plural: 'magneto' --> 'magnetos'};
is noun(q{magnetos})->classical->plural, q{magnetos}  => q{classical plural: 'magnetos' --> 'magnetos'};
is noun(q{differentia})->classical->plural,   q{differentiae}  => q{classical plural: 'differentia' --> 'differentiae'};
is noun(q{differentiae})->classical->plural, q{differentiae}  => q{classical plural: 'differentiae' --> 'differentiae'};
is noun(q{primordium})->classical->plural,   q{primordia}  => q{classical plural: 'primordium' --> 'primordia'};
is noun(q{primordia})->classical->plural, q{primordia}  => q{classical plural: 'primordia' --> 'primordia'};
is noun(q{lumen})->classical->plural,   q{lumina}  => q{classical plural: 'lumen' --> 'lumina'};
is noun(q{lumina})->classical->plural, q{lumina}  => q{classical plural: 'lumina' --> 'lumina'};
is noun(q{Biro})->classical->plural,   q{Biros}  => q{classical plural: 'Biro' --> 'Biros'};
is noun(q{Biros})->classical->plural, q{Biros}  => q{classical plural: 'Biros' --> 'Biros'};
is noun(q{woman-servant})->classical->plural,   q{women-servants}  => q{classical plural: 'woman-servant' --> 'women-servants'};
is noun(q{women-servants})->classical->plural, q{women-servants}  => q{classical plural: 'women-servants' --> 'women-servants'};
is noun(q{grano})->classical->plural,   q{grani}  => q{classical plural: 'grano' --> 'grani'};
is noun(q{grani})->classical->plural, q{grani}  => q{classical plural: 'grani' --> 'grani'};
is noun(q{lieutenant general})->classical->plural,   q{lieutenant generals}  => q{classical plural: 'lieutenant general' --> 'lieutenant generals'};
is noun(q{lieutenant generals})->classical->plural, q{lieutenant generals}  => q{classical plural: 'lieutenant generals' --> 'lieutenant generals'};
is noun(q{offspring})->classical->plural,   q{offspring}  => q{classical plural: 'offspring' --> 'offspring'};
is noun(q{Sapporo})->classical->plural,   q{Sapporos}  => q{classical plural: 'Sapporo' --> 'Sapporos'};
is noun(q{Sapporos})->classical->plural, q{Sapporos}  => q{classical plural: 'Sapporos' --> 'Sapporos'};
is noun(q{Kongolese})->classical->plural,   q{Kongolese}  => q{classical plural: 'Kongolese' --> 'Kongolese'};
is noun(q{Lapponese})->classical->plural,   q{Lapponese}  => q{classical plural: 'Lapponese' --> 'Lapponese'};
is noun(q{baal})->classical->plural,   q{baalim}  => q{classical plural: 'baal' --> 'baalim'};
is noun(q{baalim})->classical->plural, q{baalim}  => q{classical plural: 'baalim' --> 'baalim'};
is noun(q{grissino})->classical->plural,   q{grissini}  => q{classical plural: 'grissino' --> 'grissini'};
is noun(q{grissini})->classical->plural, q{grissini}  => q{classical plural: 'grissini' --> 'grissini'};
is noun(q{zophorus})->classical->plural,   q{zophori}  => q{classical plural: 'zophorus' --> 'zophori'};
is noun(q{zophori})->classical->plural, q{zophori}  => q{classical plural: 'zophori' --> 'zophori'};
is noun(q{abscissa})->classical->plural,   q{abscissae}  => q{classical plural: 'abscissa' --> 'abscissae'};
is noun(q{abscissae})->classical->plural, q{abscissae}  => q{classical plural: 'abscissae' --> 'abscissae'};
is noun(q{pontifex})->classical->plural,   q{pontifices}  => q{classical plural: 'pontifex' --> 'pontifices'};
is noun(q{pontifices})->classical->plural, q{pontifices}  => q{classical plural: 'pontifices' --> 'pontifices'};
is noun(q{spasmus})->classical->plural,   q{spasmi}  => q{classical plural: 'spasmus' --> 'spasmi'};
is noun(q{spasmi})->classical->plural, q{spasmi}  => q{classical plural: 'spasmi' --> 'spasmi'};
is noun(q{zygantrum})->classical->plural,   q{zygantra}  => q{classical plural: 'zygantrum' --> 'zygantra'};
is noun(q{zygantra})->classical->plural, q{zygantra}  => q{classical plural: 'zygantra' --> 'zygantra'};
is noun(q{Romany})->classical->plural,   q{Romanies}  => q{classical plural: 'Romany' --> 'Romanies'};
is noun(q{Romanies})->classical->plural, q{Romanies}  => q{classical plural: 'Romanies' --> 'Romanies'};
is noun(q{Malabo})->classical->plural,   q{Malabos}  => q{classical plural: 'Malabo' --> 'Malabos'};
is noun(q{Malabos})->classical->plural, q{Malabos}  => q{classical plural: 'Malabos' --> 'Malabos'};
is noun(q{aegis})->classical->plural,   q{aegises}  => q{classical plural: 'aegis' --> 'aegises'};
is noun(q{aegises})->classical->plural, q{aegises}  => q{classical plural: 'aegises' --> 'aegises'};
is noun(q{judas})->classical->plural,   q{judases}  => q{classical plural: 'judas' --> 'judases'};
is noun(q{judases})->classical->plural, q{judases}  => q{classical plural: 'judases' --> 'judases'};
is noun(q{osmaterium})->classical->plural,   q{osmateria}  => q{classical plural: 'osmaterium' --> 'osmateria'};
is noun(q{osmateria})->classical->plural, q{osmateria}  => q{classical plural: 'osmateria' --> 'osmateria'};
is noun(q{intichiuma})->classical->plural,   q{intichiuma}  => q{classical plural: 'intichiuma' --> 'intichiuma'};
is noun(q{stryddag})->classical->plural,   q{stryddae}  => q{classical plural: 'stryddag' --> 'stryddae'};
is noun(q{stryddae})->classical->plural, q{stryddae}  => q{classical plural: 'stryddae' --> 'stryddae'};
is noun(q{struma})->classical->plural,   q{strumae}  => q{classical plural: 'struma' --> 'strumae'};
is noun(q{strumae})->classical->plural, q{strumae}  => q{classical plural: 'strumae' --> 'strumae'};
is noun(q{Sarawakese})->classical->plural,   q{Sarawakese}  => q{classical plural: 'Sarawakese' --> 'Sarawakese'};
is noun(q{polo})->classical->plural,   q{polos}  => q{classical plural: 'polo' --> 'polos'};
is noun(q{polos})->classical->plural, q{polos}  => q{classical plural: 'polos' --> 'polos'};
is noun(q{bingo})->classical->plural,   q{bingos}  => q{classical plural: 'bingo' --> 'bingos'};
is noun(q{bingos})->classical->plural, q{bingos}  => q{classical plural: 'bingos' --> 'bingos'};
is noun(q{topos})->classical->plural,   q{topoi}  => q{classical plural: 'topos' --> 'topoi'};
is noun(q{topoi})->classical->plural, q{topoi}  => q{classical plural: 'topoi' --> 'topoi'};
is noun(q{duumvir})->classical->plural,   q{duumviri}  => q{classical plural: 'duumvir' --> 'duumviri'};
is noun(q{duumviri})->classical->plural, q{duumviri}  => q{classical plural: 'duumviri' --> 'duumviri'};
is noun(q{castrato})->classical->plural,   q{castrati}  => q{classical plural: 'castrato' --> 'castrati'};
is noun(q{castrati})->classical->plural, q{castrati}  => q{classical plural: 'castrati' --> 'castrati'};
is noun(q{plasmolyticum})->classical->plural,   q{plasmolytica}  => q{classical plural: 'plasmolyticum' --> 'plasmolytica'};
is noun(q{plasmolytica})->classical->plural, q{plasmolytica}  => q{classical plural: 'plasmolytica' --> 'plasmolytica'};
is noun(q{oregano})->classical->plural,   q{oreganos}  => q{classical plural: 'oregano' --> 'oreganos'};
is noun(q{oreganos})->classical->plural, q{oreganos}  => q{classical plural: 'oreganos' --> 'oreganos'};
is noun(q{apothecium})->classical->plural,   q{apothecia}  => q{classical plural: 'apothecium' --> 'apothecia'};
is noun(q{apothecia})->classical->plural, q{apothecia}  => q{classical plural: 'apothecia' --> 'apothecia'};
is noun(q{fulcrum})->classical->plural,   q{fulcra}  => q{classical plural: 'fulcrum' --> 'fulcra'};
is noun(q{fulcra})->classical->plural, q{fulcra}  => q{classical plural: 'fulcra' --> 'fulcra'};
is noun(q{prototypon})->classical->plural,   q{prototypa}  => q{classical plural: 'prototypon' --> 'prototypa'};
is noun(q{prototypa})->classical->plural, q{prototypa}  => q{classical plural: 'prototypa' --> 'prototypa'};
is noun(q{jambeau})->classical->plural,   q{jambeaux}  => q{classical plural: 'jambeau' --> 'jambeaux'};
is noun(q{jambeaux})->classical->plural, q{jambeaux}  => q{classical plural: 'jambeaux' --> 'jambeaux'};
is noun(q{coe})->classical->plural,   q{coes}  => q{classical plural: 'coe' --> 'coes'};
is noun(q{coes})->classical->plural, q{coes}  => q{classical plural: 'coes' --> 'coes'};
is noun(q{oculus})->classical->plural,   q{oculi}  => q{classical plural: 'oculus' --> 'oculi'};
is noun(q{oculi})->classical->plural, q{oculi}  => q{classical plural: 'oculi' --> 'oculi'};
is noun(q{Veronese})->classical->plural,   q{Veronese}  => q{classical plural: 'Veronese' --> 'Veronese'};
is noun(q{solo})->classical->plural,   q{soli}  => q{classical plural: 'solo' --> 'soli'};
is noun(q{soli})->classical->plural, q{soli}  => q{classical plural: 'soli' --> 'soli'};
is noun(q{xiphopagus})->classical->plural,   q{xiphopagi}  => q{classical plural: 'xiphopagus' --> 'xiphopagi'};
is noun(q{xiphopagi})->classical->plural, q{xiphopagi}  => q{classical plural: 'xiphopagi' --> 'xiphopagi'};
is noun(q{perradius})->classical->plural,   q{perradii}  => q{classical plural: 'perradius' --> 'perradii'};
is noun(q{perradii})->classical->plural, q{perradii}  => q{classical plural: 'perradii' --> 'perradii'};
is noun(q{crescendo})->classical->plural,   q{crescendos}  => q{classical plural: 'crescendo' --> 'crescendos'};
is noun(q{crescendos})->classical->plural, q{crescendos}  => q{classical plural: 'crescendos' --> 'crescendos'};
is noun(q{lido})->classical->plural,   q{lidos}  => q{classical plural: 'lido' --> 'lidos'};
is noun(q{lidos})->classical->plural, q{lidos}  => q{classical plural: 'lidos' --> 'lidos'};
is noun(q{anthemion})->classical->plural,   q{anthemia}  => q{classical plural: 'anthemion' --> 'anthemia'};
is noun(q{anthemia})->classical->plural, q{anthemia}  => q{classical plural: 'anthemia' --> 'anthemia'};
is noun(q{ultimatum})->classical->plural,   q{ultimata}  => q{classical plural: 'ultimatum' --> 'ultimata'};
is noun(q{ultimata})->classical->plural, q{ultimata}  => q{classical plural: 'ultimata' --> 'ultimata'};
is noun(q{zeppole})->classical->plural,   q{zeppoli}  => q{classical plural: 'zeppole' --> 'zeppoli'};
is noun(q{zeppoli})->classical->plural, q{zeppoli}  => q{classical plural: 'zeppoli' --> 'zeppoli'};
is noun(q{rectus})->classical->plural,   q{recti}  => q{classical plural: 'rectus' --> 'recti'};
is noun(q{recti})->classical->plural, q{recti}  => q{classical plural: 'recti' --> 'recti'};
is noun(q{roe})->classical->plural,   q{roe}  => q{classical plural: 'roe' --> 'roe'};
is noun(q{trapezium})->classical->plural,   q{trapezia}  => q{classical plural: 'trapezium' --> 'trapezia'};
is noun(q{trapezia})->classical->plural, q{trapezia}  => q{classical plural: 'trapezia' --> 'trapezia'};
is noun(q{triumvir})->classical->plural,   q{triumviri}  => q{classical plural: 'triumvir' --> 'triumviri'};
is noun(q{triumviri})->classical->plural, q{triumviri}  => q{classical plural: 'triumviri' --> 'triumviri'};
is noun(q{hero})->classical->plural,   q{heroes}  => q{classical plural: 'hero' --> 'heroes'};
is noun(q{heroes})->classical->plural, q{heroes}  => q{classical plural: 'heroes' --> 'heroes'};
is noun(q{vortex})->classical->plural,   q{vortices}  => q{classical plural: 'vortex' --> 'vortices'};
is noun(q{vortices})->classical->plural, q{vortices}  => q{classical plural: 'vortices' --> 'vortices'};
is noun(q{Mary})->classical->plural,   q{Marys}  => q{classical plural: 'Mary' --> 'Marys'};
is noun(q{Marys})->classical->plural, q{Marys}  => q{classical plural: 'Marys' --> 'Marys'};
is noun(q{Cairo})->classical->plural,   q{Cairos}  => q{classical plural: 'Cairo' --> 'Cairos'};
is noun(q{Cairos})->classical->plural, q{Cairos}  => q{classical plural: 'Cairos' --> 'Cairos'};
is noun(q{olfactorium})->classical->plural,   q{olfactoria}  => q{classical plural: 'olfactorium' --> 'olfactoria'};
is noun(q{olfactoria})->classical->plural, q{olfactoria}  => q{classical plural: 'olfactoria' --> 'olfactoria'};
is noun(q{kar})->classical->plural,   q{kare}  => q{classical plural: 'kar' --> 'kare'};
is noun(q{kare})->classical->plural, q{kare}  => q{classical plural: 'kare' --> 'kare'};
is noun(q{drama})->classical->plural,   q{dramas}  => q{classical plural: 'drama' --> 'dramas'};
is noun(q{dramas})->classical->plural, q{dramas}  => q{classical plural: 'dramas' --> 'dramas'};
is noun(q{brachiopod})->classical->plural,   q{brachiopoda}  => q{classical plural: 'brachiopod' --> 'brachiopoda'};
is noun(q{brachiopoda})->classical->plural, q{brachiopoda}  => q{classical plural: 'brachiopoda' --> 'brachiopoda'};
is noun(q{panto})->classical->plural,   q{pantos}  => q{classical plural: 'panto' --> 'pantos'};
is noun(q{pantos})->classical->plural, q{pantos}  => q{classical plural: 'pantos' --> 'pantos'};
is noun(q{valuta})->classical->plural,   q{valuten}  => q{classical plural: 'valuta' --> 'valuten'};
is noun(q{valuten})->classical->plural, q{valuten}  => q{classical plural: 'valuten' --> 'valuten'};
is noun(q{euro})->classical->plural,   q{euros}  => q{classical plural: 'euro' --> 'euros'};
is noun(q{euros})->classical->plural, q{euros}  => q{classical plural: 'euros' --> 'euros'};
is noun(q{spiraculum})->classical->plural,   q{spiracula}  => q{classical plural: 'spiraculum' --> 'spiracula'};
is noun(q{spiracula})->classical->plural, q{spiracula}  => q{classical plural: 'spiracula' --> 'spiracula'};
is noun(q{ataman})->classical->plural,   q{atamans}  => q{classical plural: 'ataman' --> 'atamans'};
is noun(q{atamans})->classical->plural, q{atamans}  => q{classical plural: 'atamans' --> 'atamans'};
is noun(q{alto})->classical->plural,   q{alti}  => q{classical plural: 'alto' --> 'alti'};
is noun(q{alti})->classical->plural, q{alti}  => q{classical plural: 'alti' --> 'alti'};
is noun(q{bifolium})->classical->plural,   q{bifolia}  => q{classical plural: 'bifolium' --> 'bifolia'};
is noun(q{bifolia})->classical->plural, q{bifolia}  => q{classical plural: 'bifolia' --> 'bifolia'};
is noun(q{kletterschuh})->classical->plural,   q{kletterschuhe}  => q{classical plural: 'kletterschuh' --> 'kletterschuhe'};
is noun(q{kletterschuhe})->classical->plural, q{kletterschuhe}  => q{classical plural: 'kletterschuhe' --> 'kletterschuhe'};
is noun(q{bureau})->classical->plural,   q{bureaux}  => q{classical plural: 'bureau' --> 'bureaux'};
is noun(q{bureaux})->classical->plural, q{bureaux}  => q{classical plural: 'bureaux' --> 'bureaux'};
is noun(q{putto})->classical->plural,   q{putti}  => q{classical plural: 'putto' --> 'putti'};
is noun(q{putti})->classical->plural, q{putti}  => q{classical plural: 'putti' --> 'putti'};
is noun(q{alumna})->classical->plural,   q{alumnae}  => q{classical plural: 'alumna' --> 'alumnae'};
is noun(q{alumnae})->classical->plural, q{alumnae}  => q{classical plural: 'alumnae' --> 'alumnae'};
is noun(q{axis})->classical->plural,   q{axes}  => q{classical plural: 'axis' --> 'axes'};
is noun(q{axes})->classical->plural, q{axes}  => q{classical plural: 'axes' --> 'axes'};
is noun(q{deer})->classical->plural,   q{deer}  => q{classical plural: 'deer' --> 'deer'};
is noun(q{sympodium})->classical->plural,   q{sympodia}  => q{classical plural: 'sympodium' --> 'sympodia'};
is noun(q{sympodia})->classical->plural, q{sympodia}  => q{classical plural: 'sympodia' --> 'sympodia'};
is noun(q{vis})->classical->plural,   q{vires}  => q{classical plural: 'vis' --> 'vires'};
is noun(q{vires})->classical->plural, q{vires}  => q{classical plural: 'vires' --> 'vires'};
is noun(q{mukim})->classical->plural,   q{mukim}  => q{classical plural: 'mukim' --> 'mukim'};
is noun(q{megalosaurus})->classical->plural,   q{megalosauri}  => q{classical plural: 'megalosaurus' --> 'megalosauri'};
is noun(q{megalosauri})->classical->plural, q{megalosauri}  => q{classical plural: 'megalosauri' --> 'megalosauri'};
is noun(q{Pistoiese})->classical->plural,   q{Pistoiese}  => q{classical plural: 'Pistoiese' --> 'Pistoiese'};
is noun(q{Bhutanese})->classical->plural,   q{Bhutanese}  => q{classical plural: 'Bhutanese' --> 'Bhutanese'};
is noun(q{Guianese})->classical->plural,   q{Guianese}  => q{classical plural: 'Guianese' --> 'Guianese'};
is noun(q{monseigneur})->classical->plural,   q{messeigneurs}  => q{classical plural: 'monseigneur' --> 'messeigneurs'};
is noun(q{messeigneurs})->classical->plural, q{messeigneurs}  => q{classical plural: 'messeigneurs' --> 'messeigneurs'};
is noun(q{tintinnabulum})->classical->plural,   q{tintinnabula}  => q{classical plural: 'tintinnabulum' --> 'tintinnabula'};
is noun(q{tintinnabula})->classical->plural, q{tintinnabula}  => q{classical plural: 'tintinnabula' --> 'tintinnabula'};
is noun(q{blitz})->classical->plural,   q{blitzes}  => q{classical plural: 'blitz' --> 'blitzes'};
is noun(q{blitzes})->classical->plural, q{blitzes}  => q{classical plural: 'blitzes' --> 'blitzes'};
is noun(q{fibra})->classical->plural,   q{fibrae}  => q{classical plural: 'fibra' --> 'fibrae'};
is noun(q{fibrae})->classical->plural, q{fibrae}  => q{classical plural: 'fibrae' --> 'fibrae'};
is noun(q{matinee musicale})->classical->plural,   q{matinees musicales}  => q{classical plural: 'matinee musicale' --> 'matinees musicales'};
is noun(q{matinees musicales})->classical->plural, q{matinees musicales}  => q{classical plural: 'matinees musicales' --> 'matinees musicales'};
is noun(q{tetanothrum})->classical->plural,   q{tetanother}  => q{classical plural: 'tetanothrum' --> 'tetanother'};
is noun(q{tetanother})->classical->plural, q{tetanother}  => q{classical plural: 'tetanother' --> 'tetanother'};
is noun(q{terzetto})->classical->plural,   q{terzetti}  => q{classical plural: 'terzetto' --> 'terzetti'};
is noun(q{terzetti})->classical->plural, q{terzetti}  => q{classical plural: 'terzetti' --> 'terzetti'};
is noun(q{aphelion})->classical->plural,   q{aphelia}  => q{classical plural: 'aphelion' --> 'aphelia'};
is noun(q{aphelia})->classical->plural, q{aphelia}  => q{classical plural: 'aphelia' --> 'aphelia'};
is noun(q{bravo})->classical->plural,   q{bravoes}  => q{classical plural: 'bravo' --> 'bravoes'};
is noun(q{bravoes})->classical->plural, q{bravoes}  => q{classical plural: 'bravoes' --> 'bravoes'};
is noun(q{senex})->classical->plural,   q{senes}  => q{classical plural: 'senex' --> 'senes'};
is noun(q{senes})->classical->plural, q{senes}  => q{classical plural: 'senes' --> 'senes'};
is noun(q{spermogonium})->classical->plural,   q{spermogonia}  => q{classical plural: 'spermogonium' --> 'spermogonia'};
is noun(q{spermogonia})->classical->plural, q{spermogonia}  => q{classical plural: 'spermogonia' --> 'spermogonia'};
is noun(q{Carlylese})->classical->plural,   q{Carlylese}  => q{classical plural: 'Carlylese' --> 'Carlylese'};
is noun(q{mafioso})->classical->plural,   q{mafiosi}  => q{classical plural: 'mafioso' --> 'mafiosi'};
is noun(q{mafiosi})->classical->plural, q{mafiosi}  => q{classical plural: 'mafiosi' --> 'mafiosi'};
is noun(q{prospectus})->classical->plural,   q{prospectus}  => q{classical plural: 'prospectus' --> 'prospectus'};
is noun(q{grotto})->classical->plural,   q{grottoes}  => q{classical plural: 'grotto' --> 'grottoes'};
is noun(q{grottoes})->classical->plural, q{grottoes}  => q{classical plural: 'grottoes' --> 'grottoes'};
is noun(q{Bostonese})->classical->plural,   q{Bostonese}  => q{classical plural: 'Bostonese' --> 'Bostonese'};
is noun(q{tablinum})->classical->plural,   q{tablina}  => q{classical plural: 'tablinum' --> 'tablina'};
is noun(q{tablina})->classical->plural, q{tablina}  => q{classical plural: 'tablina' --> 'tablina'};
is noun(q{improperium})->classical->plural,   q{improperia}  => q{classical plural: 'improperium' --> 'improperia'};
is noun(q{improperia})->classical->plural, q{improperia}  => q{classical plural: 'improperia' --> 'improperia'};
is noun(q{dichasium})->classical->plural,   q{dichasia}  => q{classical plural: 'dichasium' --> 'dichasia'};
is noun(q{dichasia})->classical->plural, q{dichasia}  => q{classical plural: 'dichasia' --> 'dichasia'};
is noun(q{credo})->classical->plural,   q{credos}  => q{classical plural: 'credo' --> 'credos'};
is noun(q{credos})->classical->plural, q{credos}  => q{classical plural: 'credos' --> 'credos'};
is noun(q{neurula})->classical->plural,   q{neurulae}  => q{classical plural: 'neurula' --> 'neurulae'};
is noun(q{neurulae})->classical->plural, q{neurulae}  => q{classical plural: 'neurulae' --> 'neurulae'};
is noun(q{denotatum})->classical->plural,   q{denotata}  => q{classical plural: 'denotatum' --> 'denotata'};
is noun(q{denotata})->classical->plural, q{denotata}  => q{classical plural: 'denotata' --> 'denotata'};
is noun(q{zooecium})->classical->plural,   q{zooecia}  => q{classical plural: 'zooecium' --> 'zooecia'};
is noun(q{zooecia})->classical->plural, q{zooecia}  => q{classical plural: 'zooecia' --> 'zooecia'};
is noun(q{sforzato})->classical->plural,   q{sforzati}  => q{classical plural: 'sforzato' --> 'sforzati'};
is noun(q{sforzati})->classical->plural, q{sforzati}  => q{classical plural: 'sforzati' --> 'sforzati'};
is noun(q{Auslese})->classical->plural,   q{Auslesen}  => q{classical plural: 'Auslese' --> 'Auslesen'};
is noun(q{Auslesen})->classical->plural, q{Auslesen}  => q{classical plural: 'Auslesen' --> 'Auslesen'};
is noun(q{pecten})->classical->plural,   q{pectines}  => q{classical plural: 'pecten' --> 'pectines'};
is noun(q{pectines})->classical->plural, q{pectines}  => q{classical plural: 'pectines' --> 'pectines'};
is noun(q{mortarium})->classical->plural,   q{mortaria}  => q{classical plural: 'mortarium' --> 'mortaria'};
is noun(q{mortaria})->classical->plural, q{mortaria}  => q{classical plural: 'mortaria' --> 'mortaria'};
is noun(q{mantis})->classical->plural,   q{mantises}  => q{classical plural: 'mantis' --> 'mantises'};
is noun(q{mantises})->classical->plural, q{mantises}  => q{classical plural: 'mantises' --> 'mantises'};
is noun(q{autochthon})->classical->plural,   q{autochthones}  => q{classical plural: 'autochthon' --> 'autochthones'};
is noun(q{autochthones})->classical->plural, q{autochthones}  => q{classical plural: 'autochthones' --> 'autochthones'};
is noun(q{quid})->classical->plural,   q{quid}  => q{classical plural: 'quid' --> 'quid'};
is noun(q{enconium})->classical->plural,   q{enconia}  => q{classical plural: 'enconium' --> 'enconia'};
is noun(q{enconia})->classical->plural, q{enconia}  => q{classical plural: 'enconia' --> 'enconia'};
is noun(q{carte-de-visite})->classical->plural,   q{cartes-de-visite}  => q{classical plural: 'carte-de-visite' --> 'cartes-de-visite'};
is noun(q{cartes-de-visite})->classical->plural, q{cartes-de-visite}  => q{classical plural: 'cartes-de-visite' --> 'cartes-de-visite'};
is noun(q{malum in se})->classical->plural,   q{mala in se}  => q{classical plural: 'malum in se' --> 'mala in se'};
is noun(q{mala in se})->classical->plural, q{mala in se}  => q{classical plural: 'mala in se' --> 'mala in se'};
is noun(q{palus})->classical->plural,   q{pali}  => q{classical plural: 'palus' --> 'pali'};
is noun(q{pali})->classical->plural, q{pali}  => q{classical plural: 'pali' --> 'pali'};
is noun(q{eros})->classical->plural,   q{erotes}  => q{classical plural: 'eros' --> 'erotes'};
is noun(q{erotes})->classical->plural, q{erotes}  => q{classical plural: 'erotes' --> 'erotes'};
is noun(q{trout})->classical->plural,   q{trout}  => q{classical plural: 'trout' --> 'trout'};
is noun(q{hypnum})->classical->plural,   q{hypna}  => q{classical plural: 'hypnum' --> 'hypna'};
is noun(q{hypna})->classical->plural, q{hypna}  => q{classical plural: 'hypna' --> 'hypna'};
is noun(q{interleaf})->classical->plural,   q{leaves}  => q{classical plural: 'interleaf' --> 'leaves'};
is noun(q{leaves})->classical->plural, q{leaves}  => q{classical plural: 'leaves' --> 'leaves'};
is noun(q{Liman})->classical->plural,   q{Limans}  => q{classical plural: 'Liman' --> 'Limans'};
is noun(q{Limans})->classical->plural, q{Limans}  => q{classical plural: 'Limans' --> 'Limans'};
is noun(q{Oklahoman})->classical->plural,   q{Oklahomans}  => q{classical plural: 'Oklahoman' --> 'Oklahomans'};
is noun(q{Oklahomans})->classical->plural, q{Oklahomans}  => q{classical plural: 'Oklahomans' --> 'Oklahomans'};
is noun(q{addendum})->classical->plural,   q{addenda}  => q{classical plural: 'addendum' --> 'addenda'};
is noun(q{addenda})->classical->plural, q{addenda}  => q{classical plural: 'addenda' --> 'addenda'};
is noun(q{set-out})->classical->plural,   q{sets-out}  => q{classical plural: 'set-out' --> 'sets-out'};
is noun(q{sets-out})->classical->plural, q{sets-out}  => q{classical plural: 'sets-out' --> 'sets-out'};
is noun(q{Pluto})->classical->plural,   q{Plutos}  => q{classical plural: 'Pluto' --> 'Plutos'};
is noun(q{Plutos})->classical->plural, q{Plutos}  => q{classical plural: 'Plutos' --> 'Plutos'};
is noun(q{clepsydra})->classical->plural,   q{clepsydrae}  => q{classical plural: 'clepsydra' --> 'clepsydrae'};
is noun(q{clepsydrae})->classical->plural, q{clepsydrae}  => q{classical plural: 'clepsydrae' --> 'clepsydrae'};
is noun(q{lipoma})->classical->plural,   q{lipomata}  => q{classical plural: 'lipoma' --> 'lipomata'};
is noun(q{lipomata})->classical->plural, q{lipomata}  => q{classical plural: 'lipomata' --> 'lipomata'};
is noun(q{entente cordiale})->classical->plural,   q{ententes cordiales}  => q{classical plural: 'entente cordiale' --> 'ententes cordiales'};
is noun(q{ententes cordiales})->classical->plural, q{ententes cordiales}  => q{classical plural: 'ententes cordiales' --> 'ententes cordiales'};
is noun(q{ephelis})->classical->plural,   q{ephelides}  => q{classical plural: 'ephelis' --> 'ephelides'};
is noun(q{ephelides})->classical->plural, q{ephelides}  => q{classical plural: 'ephelides' --> 'ephelides'};
is noun(q{rara avis})->classical->plural,   q{rarae aves}  => q{classical plural: 'rara avis' --> 'rarae aves'};
is noun(q{rarae aves})->classical->plural, q{rarae aves}  => q{classical plural: 'rarae aves' --> 'rarae aves'};
is noun(q{symposium})->classical->plural,   q{symposia}  => q{classical plural: 'symposium' --> 'symposia'};
is noun(q{symposia})->classical->plural, q{symposia}  => q{classical plural: 'symposia' --> 'symposia'};
is noun(q{mumps})->classical->plural,   q{mumps}  => q{classical plural: 'mumps' --> 'mumps'};
is noun(q{stipula})->classical->plural,   q{stipulae}  => q{classical plural: 'stipula' --> 'stipulae'};
is noun(q{stipulae})->classical->plural, q{stipulae}  => q{classical plural: 'stipulae' --> 'stipulae'};
is noun(q{tornus})->classical->plural,   q{torni}  => q{classical plural: 'tornus' --> 'torni'};
is noun(q{torni})->classical->plural, q{torni}  => q{classical plural: 'torni' --> 'torni'};
is noun(q{lapith})->classical->plural,   q{lapithae}  => q{classical plural: 'lapith' --> 'lapithae'};
is noun(q{lapithae})->classical->plural, q{lapithae}  => q{classical plural: 'lapithae' --> 'lapithae'};
is noun(q{Roman})->classical->plural,   q{Romans}  => q{classical plural: 'Roman' --> 'Romans'};
is noun(q{Romans})->classical->plural, q{Romans}  => q{classical plural: 'Romans' --> 'Romans'};
is noun(q{zoophorus})->classical->plural,   q{zoophori}  => q{classical plural: 'zoophorus' --> 'zoophori'};
is noun(q{zoophori})->classical->plural, q{zoophori}  => q{classical plural: 'zoophori' --> 'zoophori'};
is noun(q{unio})->classical->plural,   q{uniones}  => q{classical plural: 'unio' --> 'uniones'};
is noun(q{uniones})->classical->plural, q{uniones}  => q{classical plural: 'uniones' --> 'uniones'};
is noun(q{German})->classical->plural,   q{Germans}  => q{classical plural: 'German' --> 'Germans'};
is noun(q{Germans})->classical->plural, q{Germans}  => q{classical plural: 'Germans' --> 'Germans'};
is noun(q{scarabaeus})->classical->plural,   q{scarabaei}  => q{classical plural: 'scarabaeus' --> 'scarabaei'};
is noun(q{scarabaei})->classical->plural, q{scarabaei}  => q{classical plural: 'scarabaei' --> 'scarabaei'};
is noun(q{simplex})->classical->plural,   q{simplices}  => q{classical plural: 'simplex' --> 'simplices'};
is noun(q{simplices})->classical->plural, q{simplices}  => q{classical plural: 'simplices' --> 'simplices'};
is noun(q{hydra})->classical->plural,   q{hydrae}  => q{classical plural: 'hydra' --> 'hydrae'};
is noun(q{hydrae})->classical->plural, q{hydrae}  => q{classical plural: 'hydrae' --> 'hydrae'};
is noun(q{Orlando})->classical->plural,   q{Orlandos}  => q{classical plural: 'Orlando' --> 'Orlandos'};
is noun(q{Orlandos})->classical->plural, q{Orlandos}  => q{classical plural: 'Orlandos' --> 'Orlandos'};
is noun(q{bylina})->classical->plural,   q{byliny}  => q{classical plural: 'bylina' --> 'byliny'};
is noun(q{byliny})->classical->plural, q{byliny}  => q{classical plural: 'byliny' --> 'byliny'};
is noun(q{gumbo})->classical->plural,   q{gumbos}  => q{classical plural: 'gumbo' --> 'gumbos'};
is noun(q{gumbos})->classical->plural, q{gumbos}  => q{classical plural: 'gumbos' --> 'gumbos'};
is noun(q{woman-child})->classical->plural,   q{women-children}  => q{classical plural: 'woman-child' --> 'women-children'};
is noun(q{women-children})->classical->plural, q{women-children}  => q{classical plural: 'women-children' --> 'women-children'};
is noun(q{opusculum})->classical->plural,   q{opuscula}  => q{classical plural: 'opusculum' --> 'opuscula'};
is noun(q{opuscula})->classical->plural, q{opuscula}  => q{classical plural: 'opuscula' --> 'opuscula'};
is noun(q{mitochondrion})->classical->plural,   q{mitochondria}  => q{classical plural: 'mitochondrion' --> 'mitochondria'};
is noun(q{mitochondria})->classical->plural, q{mitochondria}  => q{classical plural: 'mitochondria' --> 'mitochondria'};
is noun(q{pina colada})->classical->plural,   q{pinas coladas}  => q{classical plural: 'pina colada' --> 'pinas coladas'};
is noun(q{pinas coladas})->classical->plural, q{pinas coladas}  => q{classical plural: 'pinas coladas' --> 'pinas coladas'};
is noun(q{equisetum})->classical->plural,   q{equiseta}  => q{classical plural: 'equisetum' --> 'equiseta'};
is noun(q{equiseta})->classical->plural, q{equiseta}  => q{classical plural: 'equiseta' --> 'equiseta'};
is noun(q{sorus})->classical->plural,   q{sori}  => q{classical plural: 'sorus' --> 'sori'};
is noun(q{sori})->classical->plural, q{sori}  => q{classical plural: 'sori' --> 'sori'};
is noun(q{thesaurus})->classical->plural,   q{thesauri}  => q{classical plural: 'thesaurus' --> 'thesauri'};
is noun(q{thesauri})->classical->plural, q{thesauri}  => q{classical plural: 'thesauri' --> 'thesauri'};
is noun(q{snekkja})->classical->plural,   q{snekkjur}  => q{classical plural: 'snekkja' --> 'snekkjur'};
is noun(q{snekkjur})->classical->plural, q{snekkjur}  => q{classical plural: 'snekkjur' --> 'snekkjur'};
is noun(q{innings})->classical->plural,   q{innings}  => q{classical plural: 'innings' --> 'innings'};
is noun(q{purum})->classical->plural,   q{purum}  => q{classical plural: 'purum' --> 'purum'};
is noun(q{directrix})->classical->plural,   q{directrices}  => q{classical plural: 'directrix' --> 'directrices'};
is noun(q{directrices})->classical->plural, q{directrices}  => q{classical plural: 'directrices' --> 'directrices'};
is noun(q{palpebra})->classical->plural,   q{palpebrae}  => q{classical plural: 'palpebra' --> 'palpebrae'};
is noun(q{palpebrae})->classical->plural, q{palpebrae}  => q{classical plural: 'palpebrae' --> 'palpebrae'};
is noun(q{trullo})->classical->plural,   q{trulli}  => q{classical plural: 'trullo' --> 'trulli'};
is noun(q{trulli})->classical->plural, q{trulli}  => q{classical plural: 'trulli' --> 'trulli'};
is noun(q{haggis})->classical->plural,   q{haggis}  => q{classical plural: 'haggis' --> 'haggis'};
is noun(q{tepidarium})->classical->plural,   q{tepidaria}  => q{classical plural: 'tepidarium' --> 'tepidaria'};
is noun(q{tepidaria})->classical->plural, q{tepidaria}  => q{classical plural: 'tepidaria' --> 'tepidaria'};
is noun(q{lis})->classical->plural,   q{lis}  => q{classical plural: 'lis' --> 'lis'};
is noun(q{basso})->classical->plural,   q{bassi}  => q{classical plural: 'basso' --> 'bassi'};
is noun(q{bassi})->classical->plural, q{bassi}  => q{classical plural: 'bassi' --> 'bassi'};
is noun(q{spectrum})->classical->plural,   q{spectra}  => q{classical plural: 'spectrum' --> 'spectra'};
is noun(q{spectra})->classical->plural, q{spectra}  => q{classical plural: 'spectra' --> 'spectra'};
is noun(q{urodeum})->classical->plural,   q{urodea}  => q{classical plural: 'urodeum' --> 'urodea'};
is noun(q{urodea})->classical->plural, q{urodea}  => q{classical plural: 'urodea' --> 'urodea'};
is noun(q{diporpa})->classical->plural,   q{diporpae}  => q{classical plural: 'diporpa' --> 'diporpae'};
is noun(q{diporpae})->classical->plural, q{diporpae}  => q{classical plural: 'diporpae' --> 'diporpae'};
is noun(q{ascidium})->classical->plural,   q{ascidia}  => q{classical plural: 'ascidium' --> 'ascidia'};
is noun(q{ascidia})->classical->plural, q{ascidia}  => q{classical plural: 'ascidia' --> 'ascidia'};
is noun(q{rejoneador})->classical->plural,   q{rejoneadores}  => q{classical plural: 'rejoneador' --> 'rejoneadores'};
is noun(q{rejoneadores})->classical->plural, q{rejoneadores}  => q{classical plural: 'rejoneadores' --> 'rejoneadores'};
is noun(q{subsellium})->classical->plural,   q{subsellia}  => q{classical plural: 'subsellium' --> 'subsellia'};
is noun(q{subsellia})->classical->plural, q{subsellia}  => q{classical plural: 'subsellia' --> 'subsellia'};
is noun(q{ancona})->classical->plural,   q{ancone}  => q{classical plural: 'ancona' --> 'ancone'};
is noun(q{ancone})->classical->plural, q{ancone}  => q{classical plural: 'ancone' --> 'ancone'};
is noun(q{whomever})->classical->plural,   q{whomever}  => q{classical plural: 'whomever' --> 'whomever'};
is noun(q{spirillum})->classical->plural,   q{spirilla}  => q{classical plural: 'spirillum' --> 'spirilla'};
is noun(q{spirilla})->classical->plural, q{spirilla}  => q{classical plural: 'spirilla' --> 'spirilla'};
is noun(q{coitus})->classical->plural,   q{coitus}  => q{classical plural: 'coitus' --> 'coitus'};
is noun(q{frottola})->classical->plural,   q{frottole}  => q{classical plural: 'frottola' --> 'frottole'};
is noun(q{frottole})->classical->plural, q{frottole}  => q{classical plural: 'frottole' --> 'frottole'};
is noun(q{Selman})->classical->plural,   q{Selmans}  => q{classical plural: 'Selman' --> 'Selmans'};
is noun(q{Selmans})->classical->plural, q{Selmans}  => q{classical plural: 'Selmans' --> 'Selmans'};
is noun(q{jo})->classical->plural,   q{joes}  => q{classical plural: 'jo' --> 'joes'};
is noun(q{joes})->classical->plural, q{joes}  => q{classical plural: 'joes' --> 'joes'};
is noun(q{remous})->classical->plural,   q{remou}  => q{classical plural: 'remous' --> 'remou'};
is noun(q{remou})->classical->plural, q{remou}  => q{classical plural: 'remou' --> 'remou'};
is noun(q{tympanum})->classical->plural,   q{tympana}  => q{classical plural: 'tympanum' --> 'tympana'};
is noun(q{tympana})->classical->plural, q{tympana}  => q{classical plural: 'tympana' --> 'tympana'};
is noun(q{Tocharese})->classical->plural,   q{Tocharese}  => q{classical plural: 'Tocharese' --> 'Tocharese'};
is noun(q{menu})->classical->plural,   q{menus}  => q{classical plural: 'menu' --> 'menus'};
is noun(q{menus})->classical->plural, q{menus}  => q{classical plural: 'menus' --> 'menus'};
is noun(q{switchfoot})->classical->plural,   q{switchfoots}  => q{classical plural: 'switchfoot' --> 'switchfoots'};
is noun(q{switchfoots})->classical->plural, q{switchfoots}  => q{classical plural: 'switchfoots' --> 'switchfoots'};
is noun(q{pangasinan})->classical->plural,   q{pangasinanes}  => q{classical plural: 'pangasinan' --> 'pangasinanes'};
is noun(q{pangasinanes})->classical->plural, q{pangasinanes}  => q{classical plural: 'pangasinanes' --> 'pangasinanes'};
is noun(q{scutum})->classical->plural,   q{scuta}  => q{classical plural: 'scutum' --> 'scuta'};
is noun(q{scuta})->classical->plural, q{scuta}  => q{classical plural: 'scuta' --> 'scuta'};
is noun(q{saxicava})->classical->plural,   q{saxicavae}  => q{classical plural: 'saxicava' --> 'saxicavae'};
is noun(q{saxicavae})->classical->plural, q{saxicavae}  => q{classical plural: 'saxicavae' --> 'saxicavae'};
is noun(q{syntagma})->classical->plural,   q{syntagmata}  => q{classical plural: 'syntagma' --> 'syntagmata'};
is noun(q{syntagmata})->classical->plural, q{syntagmata}  => q{classical plural: 'syntagmata' --> 'syntagmata'};
is noun(q{medico})->classical->plural,   q{medicoes}  => q{classical plural: 'medico' --> 'medicoes'};
is noun(q{medicoes})->classical->plural, q{medicoes}  => q{classical plural: 'medicoes' --> 'medicoes'};
is noun(q{trauma})->classical->plural,   q{traumata}  => q{classical plural: 'trauma' --> 'traumata'};
is noun(q{traumata})->classical->plural, q{traumata}  => q{classical plural: 'traumata' --> 'traumata'};
is noun(q{alto-relievo})->classical->plural,   q{alto-relievos}  => q{classical plural: 'alto-relievo' --> 'alto-relievos'};
is noun(q{alto-relievos})->classical->plural, q{alto-relievos}  => q{classical plural: 'alto-relievos' --> 'alto-relievos'};
is noun(q{tractrix})->classical->plural,   q{tractrices}  => q{classical plural: 'tractrix' --> 'tractrices'};
is noun(q{tractrices})->classical->plural, q{tractrices}  => q{classical plural: 'tractrices' --> 'tractrices'};
is noun(q{eucalyptus})->classical->plural,   q{eucalypti}  => q{classical plural: 'eucalyptus' --> 'eucalypti'};
is noun(q{eucalypti})->classical->plural, q{eucalypti}  => q{classical plural: 'eucalypti' --> 'eucalypti'};
is noun(q{clipper})->classical->plural,   q{clippers}  => q{classical plural: 'clipper' --> 'clippers'};
is noun(q{occiput})->classical->plural,   q{occipita}  => q{classical plural: 'occiput' --> 'occipita'};
is noun(q{occipita})->classical->plural, q{occipita}  => q{classical plural: 'occipita' --> 'occipita'};
is noun(q{lyssa})->classical->plural,   q{lyssae}  => q{classical plural: 'lyssa' --> 'lyssae'};
is noun(q{lyssae})->classical->plural, q{lyssae}  => q{classical plural: 'lyssae' --> 'lyssae'};
is noun(q{leishmania})->classical->plural,   q{leishmaniae}  => q{classical plural: 'leishmania' --> 'leishmaniae'};
is noun(q{leishmaniae})->classical->plural, q{leishmaniae}  => q{classical plural: 'leishmaniae' --> 'leishmaniae'};
is noun(q{mediatrix})->classical->plural,   q{mediatrices}  => q{classical plural: 'mediatrix' --> 'mediatrices'};
is noun(q{mediatrices})->classical->plural, q{mediatrices}  => q{classical plural: 'mediatrices' --> 'mediatrices'};
is noun(q{Sonaman})->classical->plural,   q{Sonamans}  => q{classical plural: 'Sonaman' --> 'Sonamans'};
is noun(q{Sonamans})->classical->plural, q{Sonamans}  => q{classical plural: 'Sonamans' --> 'Sonamans'};
is noun(q{starosta})->classical->plural,   q{starosti}  => q{classical plural: 'starosta' --> 'starosti'};
is noun(q{starosti})->classical->plural, q{starosti}  => q{classical plural: 'starosti' --> 'starosti'};
is noun(q{flag staff})->classical->plural,   q{flag staves}  => q{classical plural: 'flag staff' --> 'flag staves'};
is noun(q{flag staves})->classical->plural, q{flag staves}  => q{classical plural: 'flag staves' --> 'flag staves'};
is noun(q{debris})->classical->plural,   q{debris}  => q{classical plural: 'debris' --> 'debris'};
is noun(q{stichos})->classical->plural,   q{stichoi}  => q{classical plural: 'stichos' --> 'stichoi'};
is noun(q{stichoi})->classical->plural, q{stichoi}  => q{classical plural: 'stichoi' --> 'stichoi'};
is noun(q{cul de sac})->classical->plural,   q{culs de sac}  => q{classical plural: 'cul de sac' --> 'culs de sac'};
is noun(q{culs de sac})->classical->plural, q{culs de sac}  => q{classical plural: 'culs de sac' --> 'culs de sac'};
is noun(q{bratwurst})->classical->plural,   q{bratwurste}  => q{classical plural: 'bratwurst' --> 'bratwurste'};
is noun(q{bratwurste})->classical->plural, q{bratwurste}  => q{classical plural: 'bratwurste' --> 'bratwurste'};
is noun(q{uomo})->classical->plural,   q{uomini}  => q{classical plural: 'uomo' --> 'uomini'};
is noun(q{uomini})->classical->plural, q{uomini}  => q{classical plural: 'uomini' --> 'uomini'};
is noun(q{shear})->classical->plural,   q{shears}  => q{classical plural: 'shear' --> 'shears'};
is noun(q{acroama})->classical->plural,   q{acroamata}  => q{classical plural: 'acroama' --> 'acroamata'};
is noun(q{acroamata})->classical->plural, q{acroamata}  => q{classical plural: 'acroamata' --> 'acroamata'};
is noun(q{serir})->classical->plural,   q{serir}  => q{classical plural: 'serir' --> 'serir'};
is noun(q{ricordo})->classical->plural,   q{ricordi}  => q{classical plural: 'ricordo' --> 'ricordi'};
is noun(q{ricordi})->classical->plural, q{ricordi}  => q{classical plural: 'ricordi' --> 'ricordi'};
is noun(q{plurale tantum})->classical->plural,   q{pluralia tantum}  => q{classical plural: 'plurale tantum' --> 'pluralia tantum'};
is noun(q{pluralia tantum})->classical->plural, q{pluralia tantum}  => q{classical plural: 'pluralia tantum' --> 'pluralia tantum'};
is noun(q{helion})->classical->plural,   q{helia}  => q{classical plural: 'helion' --> 'helia'};
is noun(q{helia})->classical->plural, q{helia}  => q{classical plural: 'helia' --> 'helia'};
is noun(q{funambulus})->classical->plural,   q{funambuli}  => q{classical plural: 'funambulus' --> 'funambuli'};
is noun(q{funambuli})->classical->plural, q{funambuli}  => q{classical plural: 'funambuli' --> 'funambuli'};
is noun(q{coup d'etat})->classical->plural,   q{coups d'etat}  => q{classical plural: 'coup d'etat' --> 'coups d'etat'};
is noun(q{coups d'etat})->classical->plural, q{coups d'etat}  => q{classical plural: 'coups d'etat' --> 'coups d'etat'};
is noun(q{medulloblastoma})->classical->plural,   q{medulloblastomata}  => q{classical plural: 'medulloblastoma' --> 'medulloblastomata'};
is noun(q{medulloblastomata})->classical->plural, q{medulloblastomata}  => q{classical plural: 'medulloblastomata' --> 'medulloblastomata'};
is noun(q{consortium})->classical->plural,   q{consortia}  => q{classical plural: 'consortium' --> 'consortia'};
is noun(q{consortia})->classical->plural, q{consortia}  => q{classical plural: 'consortia' --> 'consortia'};
is noun(q{ixodid})->classical->plural,   q{ixodides}  => q{classical plural: 'ixodid' --> 'ixodides'};
is noun(q{ixodides})->classical->plural, q{ixodides}  => q{classical plural: 'ixodides' --> 'ixodides'};
is noun(q{konditorei})->classical->plural,   q{konditoreien}  => q{classical plural: 'konditorei' --> 'konditoreien'};
is noun(q{konditoreien})->classical->plural, q{konditoreien}  => q{classical plural: 'konditoreien' --> 'konditoreien'};
is noun(q{topaz})->classical->plural,   q{topazes}  => q{classical plural: 'topaz' --> 'topazes'};
is noun(q{topazes})->classical->plural, q{topazes}  => q{classical plural: 'topazes' --> 'topazes'};
is noun(q{corps general})->classical->plural,   q{corps generals}  => q{classical plural: 'corps general' --> 'corps generals'};
is noun(q{corps generals})->classical->plural, q{corps generals}  => q{classical plural: 'corps generals' --> 'corps generals'};
is noun(q{nasutus})->classical->plural,   q{nasuti}  => q{classical plural: 'nasutus' --> 'nasuti'};
is noun(q{nasuti})->classical->plural, q{nasuti}  => q{classical plural: 'nasuti' --> 'nasuti'};
is noun(q{carte de visite})->classical->plural,   q{cartes de visite}  => q{classical plural: 'carte de visite' --> 'cartes de visite'};
is noun(q{cartes de visite})->classical->plural, q{cartes de visite}  => q{classical plural: 'cartes de visite' --> 'cartes de visite'};
is noun(q{onager})->classical->plural,   q{onagri}  => q{classical plural: 'onager' --> 'onagri'};
is noun(q{onagri})->classical->plural, q{onagri}  => q{classical plural: 'onagri' --> 'onagri'};
is noun(q{tentaculum})->classical->plural,   q{tentacula}  => q{classical plural: 'tentaculum' --> 'tentacula'};
is noun(q{tentacula})->classical->plural, q{tentacula}  => q{classical plural: 'tentacula' --> 'tentacula'};
is noun(q{medium})->classical->plural,   q{media}  => q{classical plural: 'medium' --> 'media'};
is noun(q{media})->classical->plural, q{media}  => q{classical plural: 'media' --> 'media'};
is noun(q{placebo})->classical->plural,   q{placeboes}  => q{classical plural: 'placebo' --> 'placeboes'};
is noun(q{placeboes})->classical->plural, q{placeboes}  => q{classical plural: 'placeboes' --> 'placeboes'};
is noun(q{Yunnanese})->classical->plural,   q{Yunnanese}  => q{classical plural: 'Yunnanese' --> 'Yunnanese'};
is noun(q{Taiko})->classical->plural,   q{Taikos}  => q{classical plural: 'Taiko' --> 'Taikos'};
is noun(q{Taikos})->classical->plural, q{Taikos}  => q{classical plural: 'Taikos' --> 'Taikos'};
is noun(q{senarius})->classical->plural,   q{senarii}  => q{classical plural: 'senarius' --> 'senarii'};
is noun(q{senarii})->classical->plural, q{senarii}  => q{classical plural: 'senarii' --> 'senarii'};
is noun(q{clausula})->classical->plural,   q{clausulae}  => q{classical plural: 'clausula' --> 'clausulae'};
is noun(q{clausulae})->classical->plural, q{clausulae}  => q{classical plural: 'clausulae' --> 'clausulae'};
is noun(q{rhododendron})->classical->plural,   q{rhododendra}  => q{classical plural: 'rhododendron' --> 'rhododendra'};
is noun(q{rhododendra})->classical->plural, q{rhododendra}  => q{classical plural: 'rhododendra' --> 'rhododendra'};
is noun(q{mythos})->classical->plural,   q{mythoi}  => q{classical plural: 'mythos' --> 'mythoi'};
is noun(q{mythoi})->classical->plural, q{mythoi}  => q{classical plural: 'mythoi' --> 'mythoi'};
is noun(q{candelabrum})->classical->plural,   q{candelabra}  => q{classical plural: 'candelabrum' --> 'candelabra'};
is noun(q{candelabra})->classical->plural, q{candelabra}  => q{classical plural: 'candelabra' --> 'candelabra'};
is noun(q{burro})->classical->plural,   q{burros}  => q{classical plural: 'burro' --> 'burros'};
is noun(q{burros})->classical->plural, q{burros}  => q{classical plural: 'burros' --> 'burros'};
is noun(q{pyrites})->classical->plural,   q{pirrites}  => q{classical plural: 'pyrites' --> 'pirrites'};
is noun(q{pirrites})->classical->plural, q{pirrites}  => q{classical plural: 'pirrites' --> 'pirrites'};
is noun(q{karakia})->classical->plural,   q{karakia}  => q{classical plural: 'karakia' --> 'karakia'};
is noun(q{superstratum})->classical->plural,   q{superstrata}  => q{classical plural: 'superstratum' --> 'superstrata'};
is noun(q{superstrata})->classical->plural, q{superstrata}  => q{classical plural: 'superstrata' --> 'superstrata'};
is noun(q{sparus})->classical->plural,   q{spari}  => q{classical plural: 'sparus' --> 'spari'};
is noun(q{spari})->classical->plural, q{spari}  => q{classical plural: 'spari' --> 'spari'};
is noun(q{torso})->classical->plural,   q{torsos}  => q{classical plural: 'torso' --> 'torsos'};
is noun(q{torsos})->classical->plural, q{torsos}  => q{classical plural: 'torsos' --> 'torsos'};
is noun(q{die})->classical->plural,   q{dies}  => q{classical plural: 'die' --> 'dies'};
is noun(q{dies})->classical->plural, q{dies}  => q{classical plural: 'dies' --> 'dies'};
is noun(q{synthronus})->classical->plural,   q{synthroni}  => q{classical plural: 'synthronus' --> 'synthroni'};
is noun(q{synthroni})->classical->plural, q{synthroni}  => q{classical plural: 'synthroni' --> 'synthroni'};
is noun(q{asterias})->classical->plural,   q{asteriae}  => q{classical plural: 'asterias' --> 'asteriae'};
is noun(q{asteriae})->classical->plural, q{asteriae}  => q{classical plural: 'asteriae' --> 'asteriae'};
is noun(q{phallus})->classical->plural,   q{phalli}  => q{classical plural: 'phallus' --> 'phalli'};
is noun(q{phalli})->classical->plural, q{phalli}  => q{classical plural: 'phalli' --> 'phalli'};
is noun(q{conversazione})->classical->plural,   q{conversazioni}  => q{classical plural: 'conversazione' --> 'conversazioni'};
is noun(q{conversazioni})->classical->plural, q{conversazioni}  => q{classical plural: 'conversazioni' --> 'conversazioni'};
is noun(q{phototaxis})->classical->plural,   q{phototaxes}  => q{classical plural: 'phototaxis' --> 'phototaxes'};
is noun(q{phototaxes})->classical->plural, q{phototaxes}  => q{classical plural: 'phototaxes' --> 'phototaxes'};
is noun(q{lamella})->classical->plural,   q{lamellae}  => q{classical plural: 'lamella' --> 'lamellae'};
is noun(q{lamellae})->classical->plural, q{lamellae}  => q{classical plural: 'lamellae' --> 'lamellae'};
is noun(q{porion})->classical->plural,   q{poria}  => q{classical plural: 'porion' --> 'poria'};
is noun(q{poria})->classical->plural, q{poria}  => q{classical plural: 'poria' --> 'poria'};
is noun(q{maremma})->classical->plural,   q{maremme}  => q{classical plural: 'maremma' --> 'maremme'};
is noun(q{maremme})->classical->plural, q{maremme}  => q{classical plural: 'maremme' --> 'maremme'};
is noun(q{sagum})->classical->plural,   q{saga}  => q{classical plural: 'sagum' --> 'saga'};
is noun(q{saga})->classical->plural, q{saga}  => q{classical plural: 'saga' --> 'saga'};
is noun(q{swine})->classical->plural,   q{swines}  => q{classical plural: 'swine' --> 'swines'};
is noun(q{swines})->classical->plural, q{swines}  => q{classical plural: 'swines' --> 'swines'};
is noun(q{frustulum})->classical->plural,   q{frustula}  => q{classical plural: 'frustulum' --> 'frustula'};
is noun(q{frustula})->classical->plural, q{frustula}  => q{classical plural: 'frustula' --> 'frustula'};
is noun(q{situla})->classical->plural,   q{situlae}  => q{classical plural: 'situla' --> 'situlae'};
is noun(q{situlae})->classical->plural, q{situlae}  => q{classical plural: 'situlae' --> 'situlae'};
is noun(q{cony})->classical->plural,   q{conies}  => q{classical plural: 'cony' --> 'conies'};
is noun(q{conies})->classical->plural, q{conies}  => q{classical plural: 'conies' --> 'conies'};
is noun(q{Javanese})->classical->plural,   q{Javanese}  => q{classical plural: 'Javanese' --> 'Javanese'};
is noun(q{squama})->classical->plural,   q{squamae}  => q{classical plural: 'squama' --> 'squamae'};
is noun(q{squamae})->classical->plural, q{squamae}  => q{classical plural: 'squamae' --> 'squamae'};
is noun(q{Tornese})->classical->plural,   q{Tornesi}  => q{classical plural: 'Tornese' --> 'Tornesi'};
is noun(q{Tornesi})->classical->plural, q{Tornesi}  => q{classical plural: 'Tornesi' --> 'Tornesi'};
is noun(q{ustilago})->classical->plural,   q{ustilagines}  => q{classical plural: 'ustilago' --> 'ustilagines'};
is noun(q{ustilagines})->classical->plural, q{ustilagines}  => q{classical plural: 'ustilagines' --> 'ustilagines'};
is noun(q{aurora})->classical->plural,   q{aurorae}  => q{classical plural: 'aurora' --> 'aurorae'};
is noun(q{aurorae})->classical->plural, q{aurorae}  => q{classical plural: 'aurorae' --> 'aurorae'};
is noun(q{propositus})->classical->plural,   q{propositi}  => q{classical plural: 'propositus' --> 'propositi'};
is noun(q{propositi})->classical->plural, q{propositi}  => q{classical plural: 'propositi' --> 'propositi'};
is noun(q{breech})->classical->plural,   q{breeches}  => q{classical plural: 'breech' --> 'breeches'};
is noun(q{Portuguese})->classical->plural,   q{Portuguese}  => q{classical plural: 'Portuguese' --> 'Portuguese'};
is noun(q{mango})->classical->plural,   q{mangoes}  => q{classical plural: 'mango' --> 'mangoes'};
is noun(q{mangoes})->classical->plural, q{mangoes}  => q{classical plural: 'mangoes' --> 'mangoes'};
is noun(q{stoa})->classical->plural,   q{stoai}  => q{classical plural: 'stoa' --> 'stoai'};
is noun(q{stoai})->classical->plural, q{stoai}  => q{classical plural: 'stoai' --> 'stoai'};
is noun(q{tete a tete})->classical->plural,   q{tete a tetes}  => q{classical plural: 'tete a tete' --> 'tete a tetes'};
is noun(q{tete a tetes})->classical->plural, q{tete a tetes}  => q{classical plural: 'tete a tetes' --> 'tete a tetes'};
is noun(q{punto blanco})->classical->plural,   q{punti blanchi}  => q{classical plural: 'punto blanco' --> 'punti blanchi'};
is noun(q{punti blanchi})->classical->plural, q{punti blanchi}  => q{classical plural: 'punti blanchi' --> 'punti blanchi'};
is noun(q{diploma})->classical->plural,   q{diplomata}  => q{classical plural: 'diploma' --> 'diplomata'};
is noun(q{diplomata})->classical->plural, q{diplomata}  => q{classical plural: 'diplomata' --> 'diplomata'};
is noun(q{aide de camp})->classical->plural,   q{aides de camp}  => q{classical plural: 'aide de camp' --> 'aides de camp'};
is noun(q{aides de camp})->classical->plural, q{aides de camp}  => q{classical plural: 'aides de camp' --> 'aides de camp'};
is noun(q{agendum})->classical->plural,   q{agenda}  => q{classical plural: 'agendum' --> 'agenda'};
is noun(q{agenda})->classical->plural, q{agenda}  => q{classical plural: 'agenda' --> 'agenda'};
is noun(q{desideratum})->classical->plural,   q{desiderata}  => q{classical plural: 'desideratum' --> 'desiderata'};
is noun(q{desiderata})->classical->plural, q{desiderata}  => q{classical plural: 'desiderata' --> 'desiderata'};
is noun(q{ceriman})->classical->plural,   q{cerimans}  => q{classical plural: 'ceriman' --> 'cerimans'};
is noun(q{cerimans})->classical->plural, q{cerimans}  => q{classical plural: 'cerimans' --> 'cerimans'};
is noun(q{goy})->classical->plural,   q{goyim}  => q{classical plural: 'goy' --> 'goyim'};
is noun(q{goyim})->classical->plural, q{goyim}  => q{classical plural: 'goyim' --> 'goyim'};
is noun(q{he})->classical->plural,   q{they}  => q{classical plural: 'he' --> 'they'};
is noun(q{Galla})->classical->plural,   q{Galla}  => q{classical plural: 'Galla' --> 'Galla'};
is noun(q{flatus})->classical->plural,   q{flatuses}  => q{classical plural: 'flatus' --> 'flatuses'};
is noun(q{flatuses})->classical->plural, q{flatuses}  => q{classical plural: 'flatuses' --> 'flatuses'};
is noun(q{telium})->classical->plural,   q{telia}  => q{classical plural: 'telium' --> 'telia'};
is noun(q{telia})->classical->plural, q{telia}  => q{classical plural: 'telia' --> 'telia'};
is noun(q{anathema})->classical->plural,   q{anathemata}  => q{classical plural: 'anathema' --> 'anathemata'};
is noun(q{anathemata})->classical->plural, q{anathemata}  => q{classical plural: 'anathemata' --> 'anathemata'};
is noun(q{numen})->classical->plural,   q{numina}  => q{classical plural: 'numen' --> 'numina'};
is noun(q{numina})->classical->plural, q{numina}  => q{classical plural: 'numina' --> 'numina'};
is noun(q{adytum})->classical->plural,   q{adyta}  => q{classical plural: 'adytum' --> 'adyta'};
is noun(q{adyta})->classical->plural, q{adyta}  => q{classical plural: 'adyta' --> 'adyta'};
is noun(q{villus})->classical->plural,   q{villi}  => q{classical plural: 'villus' --> 'villi'};
is noun(q{villi})->classical->plural, q{villi}  => q{classical plural: 'villi' --> 'villi'};
is noun(q{zero})->classical->plural,   q{zeros}  => q{classical plural: 'zero' --> 'zeros'};
is noun(q{zeros})->classical->plural, q{zeros}  => q{classical plural: 'zeros' --> 'zeros'};
is noun(q{sceat})->classical->plural,   q{sceattas}  => q{classical plural: 'sceat' --> 'sceattas'};
is noun(q{sceattas})->classical->plural, q{sceattas}  => q{classical plural: 'sceattas' --> 'sceattas'};
is noun(q{buzz})->classical->plural,   q{buzzes}  => q{classical plural: 'buzz' --> 'buzzes'};
is noun(q{buzzes})->classical->plural, q{buzzes}  => q{classical plural: 'buzzes' --> 'buzzes'};
is noun(q{zuz})->classical->plural,   q{zuzim}  => q{classical plural: 'zuz' --> 'zuzim'};
is noun(q{zuzim})->classical->plural, q{zuzim}  => q{classical plural: 'zuzim' --> 'zuzim'};
is noun(q{noxa})->classical->plural,   q{noxae}  => q{classical plural: 'noxa' --> 'noxae'};
is noun(q{noxae})->classical->plural, q{noxae}  => q{classical plural: 'noxae' --> 'noxae'};
is noun(q{Sinhalese})->classical->plural,   q{Sinhalese}  => q{classical plural: 'Sinhalese' --> 'Sinhalese'};
is noun(q{hamadryad})->classical->plural,   q{hamadryades}  => q{classical plural: 'hamadryad' --> 'hamadryades'};
is noun(q{hamadryades})->classical->plural, q{hamadryades}  => q{classical plural: 'hamadryades' --> 'hamadryades'};
is noun(q{Heavenese})->classical->plural,   q{Heavenese}  => q{classical plural: 'Heavenese' --> 'Heavenese'};
is noun(q{three star general})->classical->plural,   q{three star generals}  => q{classical plural: 'three star general' --> 'three star generals'};
is noun(q{three star generals})->classical->plural, q{three star generals}  => q{classical plural: 'three star generals' --> 'three star generals'};
is noun(q{antrum})->classical->plural,   q{antra}  => q{classical plural: 'antrum' --> 'antra'};
is noun(q{antra})->classical->plural, q{antra}  => q{classical plural: 'antra' --> 'antra'};
is noun(q{anti-serum})->classical->plural,   q{anti-sera}  => q{classical plural: 'anti-serum' --> 'anti-sera'};
is noun(q{anti-sera})->classical->plural, q{anti-sera}  => q{classical plural: 'anti-sera' --> 'anti-sera'};
is noun(q{chervonetz})->classical->plural,   q{chervontzi}  => q{classical plural: 'chervonetz' --> 'chervontzi'};
is noun(q{chervontzi})->classical->plural, q{chervontzi}  => q{classical plural: 'chervontzi' --> 'chervontzi'};
is noun(q{pox})->classical->plural,   q{pox}  => q{classical plural: 'pox' --> 'pox'};
is noun(q{obolus})->classical->plural,   q{oboli}  => q{classical plural: 'obolus' --> 'oboli'};
is noun(q{oboli})->classical->plural, q{oboli}  => q{classical plural: 'oboli' --> 'oboli'};
is noun(q{phlegmasia})->classical->plural,   q{phlegmasiae}  => q{classical plural: 'phlegmasia' --> 'phlegmasiae'};
is noun(q{phlegmasiae})->classical->plural, q{phlegmasiae}  => q{classical plural: 'phlegmasiae' --> 'phlegmasiae'};
is noun(q{corpus vile})->classical->plural,   q{corpora vilia}  => q{classical plural: 'corpus vile' --> 'corpora vilia'};
is noun(q{corpora vilia})->classical->plural, q{corpora vilia}  => q{classical plural: 'corpora vilia' --> 'corpora vilia'};
is noun(q{canvas})->classical->plural,   q{canvases}  => q{classical plural: 'canvas' --> 'canvases'};
is noun(q{canvases})->classical->plural, q{canvases}  => q{classical plural: 'canvases' --> 'canvases'};
is noun(q{tete-a-tete})->classical->plural,   q{tete-a-tetes}  => q{classical plural: 'tete-a-tete' --> 'tete-a-tetes'};
is noun(q{tete-a-tetes})->classical->plural, q{tete-a-tetes}  => q{classical plural: 'tete-a-tetes' --> 'tete-a-tetes'};
is noun(q{bema})->classical->plural,   q{bemata}  => q{classical plural: 'bema' --> 'bemata'};
is noun(q{bemata})->classical->plural, q{bemata}  => q{classical plural: 'bemata' --> 'bemata'};
is noun(q{Kanarese})->classical->plural,   q{Kanarese}  => q{classical plural: 'Kanarese' --> 'Kanarese'};
is noun(q{fundamentum divisionis})->classical->plural,   q{fundamenta divisionis}  => q{classical plural: 'fundamentum divisionis' --> 'fundamenta divisionis'};
is noun(q{fundamenta divisionis})->classical->plural, q{fundamenta divisionis}  => q{classical plural: 'fundamenta divisionis' --> 'fundamenta divisionis'};
is noun(q{eland})->classical->plural,   q{eland}  => q{classical plural: 'eland' --> 'eland'};
is noun(q{listerella})->classical->plural,   q{listerellae}  => q{classical plural: 'listerella' --> 'listerellae'};
is noun(q{listerellae})->classical->plural, q{listerellae}  => q{classical plural: 'listerellae' --> 'listerellae'};
is noun(q{omentum})->classical->plural,   q{omenta}  => q{classical plural: 'omentum' --> 'omenta'};
is noun(q{omenta})->classical->plural, q{omenta}  => q{classical plural: 'omenta' --> 'omenta'};
is noun(q{pholas})->classical->plural,   q{pholades}  => q{classical plural: 'pholas' --> 'pholades'};
is noun(q{pholades})->classical->plural, q{pholades}  => q{classical plural: 'pholades' --> 'pholades'};
is noun(q{hallux})->classical->plural,   q{halluces}  => q{classical plural: 'hallux' --> 'halluces'};
is noun(q{halluces})->classical->plural, q{halluces}  => q{classical plural: 'halluces' --> 'halluces'};
is noun(q{teal})->classical->plural,   q{teal}  => q{classical plural: 'teal' --> 'teal'};
is noun(q{me})->classical->plural,   q{us}  => q{classical plural: 'me' --> 'us'};
is noun(q{us})->classical->plural, q{us}  => q{classical plural: 'us' --> 'us'};
is noun(q{five-star general})->classical->plural,   q{five-star generals}  => q{classical plural: 'five-star general' --> 'five-star generals'};
is noun(q{five-star generals})->classical->plural, q{five-star generals}  => q{classical plural: 'five-star generals' --> 'five-star generals'};
is noun(q{semuncia})->classical->plural,   q{semunciae}  => q{classical plural: 'semuncia' --> 'semunciae'};
is noun(q{semunciae})->classical->plural, q{semunciae}  => q{classical plural: 'semunciae' --> 'semunciae'};
is noun(q{turbot})->classical->plural,   q{turbot}  => q{classical plural: 'turbot' --> 'turbot'};
is noun(q{spermarium})->classical->plural,   q{spermaria}  => q{classical plural: 'spermarium' --> 'spermaria'};
is noun(q{spermaria})->classical->plural, q{spermaria}  => q{classical plural: 'spermaria' --> 'spermaria'};
is noun(q{ovum})->classical->plural,   q{ova}  => q{classical plural: 'ovum' --> 'ova'};
is noun(q{ova})->classical->plural, q{ova}  => q{classical plural: 'ova' --> 'ova'};
is noun(q{hiatus})->classical->plural,   q{hiatus}  => q{classical plural: 'hiatus' --> 'hiatus'};
is noun(q{geisha})->classical->plural,   q{geisha}  => q{classical plural: 'geisha' --> 'geisha'};
is noun(q{chaos})->classical->plural,   q{chaoses}  => q{classical plural: 'chaos' --> 'chaoses'};
is noun(q{chaoses})->classical->plural, q{chaoses}  => q{classical plural: 'chaoses' --> 'chaoses'};
is noun(q{fucus})->classical->plural,   q{fuci}  => q{classical plural: 'fucus' --> 'fuci'};
is noun(q{fuci})->classical->plural, q{fuci}  => q{classical plural: 'fuci' --> 'fuci'};
is noun(q{synaxarion})->classical->plural,   q{synaxaria}  => q{classical plural: 'synaxarion' --> 'synaxaria'};
is noun(q{synaxaria})->classical->plural, q{synaxaria}  => q{classical plural: 'synaxaria' --> 'synaxaria'};
is noun(q{Celanese})->classical->plural,   q{Celanese}  => q{classical plural: 'Celanese' --> 'Celanese'};
is noun(q{hyperbola})->classical->plural,   q{hyperbolae}  => q{classical plural: 'hyperbola' --> 'hyperbolae'};
is noun(q{hyperbolae})->classical->plural, q{hyperbolae}  => q{classical plural: 'hyperbolae' --> 'hyperbolae'};
is noun(q{5-star general})->classical->plural,   q{5-star generals}  => q{classical plural: '5-star general' --> '5-star generals'};
is noun(q{5-star generals})->classical->plural, q{5-star generals}  => q{classical plural: '5-star generals' --> '5-star generals'};
is noun(q{storey})->classical->plural,   q{storeys}  => q{classical plural: 'storey' --> 'storeys'};
is noun(q{storeys})->classical->plural, q{storeys}  => q{classical plural: 'storeys' --> 'storeys'};
is noun(q{pollex})->classical->plural,   q{pollices}  => q{classical plural: 'pollex' --> 'pollices'};
is noun(q{pollices})->classical->plural, q{pollices}  => q{classical plural: 'pollices' --> 'pollices'};
is noun(q{hubris})->classical->plural,   q{hubrises}  => q{classical plural: 'hubris' --> 'hubrises'};
is noun(q{hubrises})->classical->plural, q{hubrises}  => q{classical plural: 'hubrises' --> 'hubrises'};
is noun(q{varia lectio})->classical->plural,   q{variae lectiones}  => q{classical plural: 'varia lectio' --> 'variae lectiones'};
is noun(q{variae lectiones})->classical->plural, q{variae lectiones}  => q{classical plural: 'variae lectiones' --> 'variae lectiones'};
is noun(q{seaquarium})->classical->plural,   q{seaquaria}  => q{classical plural: 'seaquarium' --> 'seaquaria'};
is noun(q{seaquaria})->classical->plural, q{seaquaria}  => q{classical plural: 'seaquaria' --> 'seaquaria'};
is noun(q{Romanese})->classical->plural,   q{Romanese}  => q{classical plural: 'Romanese' --> 'Romanese'};
is noun(q{vomitorium})->classical->plural,   q{vomitoria}  => q{classical plural: 'vomitorium' --> 'vomitoria'};
is noun(q{vomitoria})->classical->plural, q{vomitoria}  => q{classical plural: 'vomitoria' --> 'vomitoria'};
is noun(q{pistillidium})->classical->plural,   q{pistillidia}  => q{classical plural: 'pistillidium' --> 'pistillidia'};
is noun(q{pistillidia})->classical->plural, q{pistillidia}  => q{classical plural: 'pistillidia' --> 'pistillidia'};
is noun(q{moratorium})->classical->plural,   q{moratoria}  => q{classical plural: 'moratorium' --> 'moratoria'};
is noun(q{moratoria})->classical->plural, q{moratoria}  => q{classical plural: 'moratoria' --> 'moratoria'};
is noun(q{ocellus})->classical->plural,   q{ocelli}  => q{classical plural: 'ocellus' --> 'ocelli'};
is noun(q{ocelli})->classical->plural, q{ocelli}  => q{classical plural: 'ocelli' --> 'ocelli'};
is noun(q{epimeron})->classical->plural,   q{epimera}  => q{classical plural: 'epimeron' --> 'epimera'};
is noun(q{epimera})->classical->plural, q{epimera}  => q{classical plural: 'epimera' --> 'epimera'};
is noun(q{vena})->classical->plural,   q{venae}  => q{classical plural: 'vena' --> 'venae'};
is noun(q{venae})->classical->plural, q{venae}  => q{classical plural: 'venae' --> 'venae'};
is noun(q{pengo})->classical->plural,   q{pengoes}  => q{classical plural: 'pengo' --> 'pengoes'};
is noun(q{pengoes})->classical->plural, q{pengoes}  => q{classical plural: 'pengoes' --> 'pengoes'};
is noun(q{corrigendum})->classical->plural,   q{corrigenda}  => q{classical plural: 'corrigendum' --> 'corrigenda'};
is noun(q{corrigenda})->classical->plural, q{corrigenda}  => q{classical plural: 'corrigenda' --> 'corrigenda'};
is noun(q{weirdo})->classical->plural,   q{weirdos}  => q{classical plural: 'weirdo' --> 'weirdos'};
is noun(q{weirdos})->classical->plural, q{weirdos}  => q{classical plural: 'weirdos' --> 'weirdos'};
is noun(q{man servant})->classical->plural,   q{men servants}  => q{classical plural: 'man servant' --> 'men servants'};
is noun(q{men servants})->classical->plural, q{men servants}  => q{classical plural: 'men servants' --> 'men servants'};
is noun(q{guttus})->classical->plural,   q{gutti}  => q{classical plural: 'guttus' --> 'gutti'};
is noun(q{gutti})->classical->plural, q{gutti}  => q{classical plural: 'gutti' --> 'gutti'};
is noun(q{Yengeese})->classical->plural,   q{Yengeese}  => q{classical plural: 'Yengeese' --> 'Yengeese'};
is noun(q{volcano})->classical->plural,   q{volcanoes}  => q{classical plural: 'volcano' --> 'volcanoes'};
is noun(q{volcanoes})->classical->plural, q{volcanoes}  => q{classical plural: 'volcanoes' --> 'volcanoes'};
is noun(q{exemplum})->classical->plural,   q{exempla}  => q{classical plural: 'exemplum' --> 'exempla'};
is noun(q{exempla})->classical->plural, q{exempla}  => q{classical plural: 'exempla' --> 'exempla'};
is noun(q{meshummad})->classical->plural,   q{meshummadim}  => q{classical plural: 'meshummad' --> 'meshummadim'};
is noun(q{meshummadim})->classical->plural, q{meshummadim}  => q{classical plural: 'meshummadim' --> 'meshummadim'};
is noun(q{meris})->classical->plural,   q{merides}  => q{classical plural: 'meris' --> 'merides'};
is noun(q{merides})->classical->plural, q{merides}  => q{classical plural: 'merides' --> 'merides'};
is noun(q{nagaika})->classical->plural,   q{nagaiki}  => q{classical plural: 'nagaika' --> 'nagaiki'};
is noun(q{nagaiki})->classical->plural, q{nagaiki}  => q{classical plural: 'nagaiki' --> 'nagaiki'};
is noun(q{flora})->classical->plural,   q{florae}  => q{classical plural: 'flora' --> 'florae'};
is noun(q{florae})->classical->plural, q{florae}  => q{classical plural: 'florae' --> 'florae'};
is noun(q{terminus})->classical->plural,   q{termini}  => q{classical plural: 'terminus' --> 'termini'};
is noun(q{termini})->classical->plural, q{termini}  => q{classical plural: 'termini' --> 'termini'};
is noun(q{wandervogel})->classical->plural,   q{wandervogel}  => q{classical plural: 'wandervogel' --> 'wandervogel'};
is noun(q{otomi})->classical->plural,   q{otomi}  => q{classical plural: 'otomi' --> 'otomi'};
is noun(q{joe})->classical->plural,   q{joes}  => q{classical plural: 'joe' --> 'joes'};
is noun(q{joes})->classical->plural, q{joes}  => q{classical plural: 'joes' --> 'joes'};
is noun(q{tessera})->classical->plural,   q{tesserae}  => q{classical plural: 'tessera' --> 'tesserae'};
is noun(q{tesserae})->classical->plural, q{tesserae}  => q{classical plural: 'tesserae' --> 'tesserae'};
is noun(q{penicillus})->classical->plural,   q{penicilli}  => q{classical plural: 'penicillus' --> 'penicilli'};
is noun(q{penicilli})->classical->plural, q{penicilli}  => q{classical plural: 'penicilli' --> 'penicilli'};
is noun(q{whatsoever})->classical->plural,   q{whatsoever}  => q{classical plural: 'whatsoever' --> 'whatsoever'};
is noun(q{summum genus})->classical->plural,   q{summa genera}  => q{classical plural: 'summum genus' --> 'summa genera'};
is noun(q{summa genera})->classical->plural, q{summa genera}  => q{classical plural: 'summa genera' --> 'summa genera'};
is noun(q{serra})->classical->plural,   q{serrae}  => q{classical plural: 'serra' --> 'serrae'};
is noun(q{serrae})->classical->plural, q{serrae}  => q{classical plural: 'serrae' --> 'serrae'};
is noun(q{herr})->classical->plural,   q{herren}  => q{classical plural: 'herr' --> 'herren'};
is noun(q{herren})->classical->plural, q{herren}  => q{classical plural: 'herren' --> 'herren'};
is noun(q{salita})->classical->plural,   q{salite}  => q{classical plural: 'salita' --> 'salite'};
is noun(q{salite})->classical->plural, q{salite}  => q{classical plural: 'salite' --> 'salite'};
is noun(q{polis})->classical->plural,   q{polises}  => q{classical plural: 'polis' --> 'polises'};
is noun(q{polises})->classical->plural, q{polises}  => q{classical plural: 'polises' --> 'polises'};
is noun(q{prosodiencephalon})->classical->plural,   q{prosodiencephala}  => q{classical plural: 'prosodiencephalon' --> 'prosodiencephala'};
is noun(q{prosodiencephala})->classical->plural, q{prosodiencephala}  => q{classical plural: 'prosodiencephala' --> 'prosodiencephala'};
is noun(q{modulus})->classical->plural,   q{moduli}  => q{classical plural: 'modulus' --> 'moduli'};
is noun(q{moduli})->classical->plural, q{moduli}  => q{classical plural: 'moduli' --> 'moduli'};
is noun(q{Swahilese})->classical->plural,   q{Swahilese}  => q{classical plural: 'Swahilese' --> 'Swahilese'};
is noun(q{torero})->classical->plural,   q{toreros}  => q{classical plural: 'torero' --> 'toreros'};
is noun(q{toreros})->classical->plural, q{toreros}  => q{classical plural: 'toreros' --> 'toreros'};
is noun(q{ibis})->classical->plural,   q{ibises}  => q{classical plural: 'ibis' --> 'ibises'};
is noun(q{ibises})->classical->plural, q{ibises}  => q{classical plural: 'ibises' --> 'ibises'};
is noun(q{theirs})->classical->plural,   q{theirs}  => q{classical plural: 'theirs' --> 'theirs'};
is noun(q{emporium})->classical->plural,   q{emporia}  => q{classical plural: 'emporium' --> 'emporia'};
is noun(q{emporia})->classical->plural, q{emporia}  => q{classical plural: 'emporia' --> 'emporia'};
is noun(q{epyllion})->classical->plural,   q{epyllia}  => q{classical plural: 'epyllion' --> 'epyllia'};
is noun(q{epyllia})->classical->plural, q{epyllia}  => q{classical plural: 'epyllia' --> 'epyllia'};
is noun(q{lingula})->classical->plural,   q{lingulae}  => q{classical plural: 'lingula' --> 'lingulae'};
is noun(q{lingulae})->classical->plural, q{lingulae}  => q{classical plural: 'lingulae' --> 'lingulae'};
is noun(q{blue})->classical->plural,   q{blues}  => q{classical plural: 'blue' --> 'blues'};
is noun(q{surculus})->classical->plural,   q{surculi}  => q{classical plural: 'surculus' --> 'surculi'};
is noun(q{surculi})->classical->plural, q{surculi}  => q{classical plural: 'surculi' --> 'surculi'};
is noun(q{6-star general})->classical->plural,   q{6-star generals}  => q{classical plural: '6-star general' --> '6-star generals'};
is noun(q{6-star generals})->classical->plural, q{6-star generals}  => q{classical plural: '6-star generals' --> '6-star generals'};
is noun(q{scalenus})->classical->plural,   q{scaleni}  => q{classical plural: 'scalenus' --> 'scaleni'};
is noun(q{scaleni})->classical->plural, q{scaleni}  => q{classical plural: 'scaleni' --> 'scaleni'};
is noun(q{troparion})->classical->plural,   q{troparia}  => q{classical plural: 'troparion' --> 'troparia'};
is noun(q{troparia})->classical->plural, q{troparia}  => q{classical plural: 'troparia' --> 'troparia'};
is noun(q{dilettante})->classical->plural,   q{dilettanti}  => q{classical plural: 'dilettante' --> 'dilettanti'};
is noun(q{dilettanti})->classical->plural, q{dilettanti}  => q{classical plural: 'dilettanti' --> 'dilettanti'};
is noun(q{tongs})->classical->plural,   q{tongs}  => q{classical plural: 'tongs' --> 'tongs'};
is noun(q{waltz})->classical->plural,   q{waltzes}  => q{classical plural: 'waltz' --> 'waltzes'};
is noun(q{waltzes})->classical->plural, q{waltzes}  => q{classical plural: 'waltzes' --> 'waltzes'};
is noun(q{child})->classical->plural,   q{children}  => q{classical plural: 'child' --> 'children'};
is noun(q{children})->classical->plural, q{children}  => q{classical plural: 'children' --> 'children'};
is noun(q{delirium})->classical->plural,   q{deliria}  => q{classical plural: 'delirium' --> 'deliria'};
is noun(q{deliria})->classical->plural, q{deliria}  => q{classical plural: 'deliria' --> 'deliria'};
is noun(q{cortex})->classical->plural,   q{cortices}  => q{classical plural: 'cortex' --> 'cortices'};
is noun(q{cortices})->classical->plural, q{cortices}  => q{classical plural: 'cortices' --> 'cortices'};
is noun(q{Balinese})->classical->plural,   q{Balinese}  => q{classical plural: 'Balinese' --> 'Balinese'};
is noun(q{gemma})->classical->plural,   q{gemmae}  => q{classical plural: 'gemma' --> 'gemmae'};
is noun(q{gemmae})->classical->plural, q{gemmae}  => q{classical plural: 'gemmae' --> 'gemmae'};
is noun(q{actinia})->classical->plural,   q{actiniae}  => q{classical plural: 'actinia' --> 'actiniae'};
is noun(q{actiniae})->classical->plural, q{actiniae}  => q{classical plural: 'actiniae' --> 'actiniae'};
is noun(q{bel esprit})->classical->plural,   q{beaux esprits}  => q{classical plural: 'bel esprit' --> 'beaux esprits'};
is noun(q{beaux esprits})->classical->plural, q{beaux esprits}  => q{classical plural: 'beaux esprits' --> 'beaux esprits'};
is noun(q{ski})->classical->plural,   q{skis}  => q{classical plural: 'ski' --> 'skis'};
is noun(q{skis})->classical->plural, q{skis}  => q{classical plural: 'skis' --> 'skis'};
is noun(q{chlamydia})->classical->plural,   q{chlamydiae}  => q{classical plural: 'chlamydia' --> 'chlamydiae'};
is noun(q{chlamydiae})->classical->plural, q{chlamydiae}  => q{classical plural: 'chlamydiae' --> 'chlamydiae'};
is noun(q{cheval de bataille})->classical->plural,   q{chevaux de bataille}  => q{classical plural: 'cheval de bataille' --> 'chevaux de bataille'};
is noun(q{chevaux de bataille})->classical->plural, q{chevaux de bataille}  => q{classical plural: 'chevaux de bataille' --> 'chevaux de bataille'};
is noun(q{set to})->classical->plural,   q{sets to}  => q{classical plural: 'set to' --> 'sets to'};
is noun(q{sets to})->classical->plural, q{sets to}  => q{classical plural: 'sets to' --> 'sets to'};
is noun(q{four star general})->classical->plural,   q{four star generals}  => q{classical plural: 'four star general' --> 'four star generals'};
is noun(q{four star generals})->classical->plural, q{four star generals}  => q{classical plural: 'four star generals' --> 'four star generals'};
is noun(q{calypso})->classical->plural,   q{calypsos}  => q{classical plural: 'calypso' --> 'calypsos'};
is noun(q{calypsos})->classical->plural, q{calypsos}  => q{classical plural: 'calypsos' --> 'calypsos'};
is noun(q{caiman})->classical->plural,   q{caimans}  => q{classical plural: 'caiman' --> 'caimans'};
is noun(q{caimans})->classical->plural, q{caimans}  => q{classical plural: 'caimans' --> 'caimans'};
is noun(q{alula})->classical->plural,   q{alulae}  => q{classical plural: 'alula' --> 'alulae'};
is noun(q{alulae})->classical->plural, q{alulae}  => q{classical plural: 'alulae' --> 'alulae'};
is noun(q{pulveratrix})->classical->plural,   q{pulveratrices}  => q{classical plural: 'pulveratrix' --> 'pulveratrices'};
is noun(q{pulveratrices})->classical->plural, q{pulveratrices}  => q{classical plural: 'pulveratrices' --> 'pulveratrices'};
is noun(q{haemangioma})->classical->plural,   q{haemangiomata}  => q{classical plural: 'haemangioma' --> 'haemangiomata'};
is noun(q{haemangiomata})->classical->plural, q{haemangiomata}  => q{classical plural: 'haemangiomata' --> 'haemangiomata'};
is noun(q{zoea})->classical->plural,   q{zoeae}  => q{classical plural: 'zoea' --> 'zoeae'};
is noun(q{zoeae})->classical->plural, q{zoeae}  => q{classical plural: 'zoeae' --> 'zoeae'};
is noun(q{perikaryon})->classical->plural,   q{perikarya}  => q{classical plural: 'perikaryon' --> 'perikarya'};
is noun(q{perikarya})->classical->plural, q{perikarya}  => q{classical plural: 'perikarya' --> 'perikarya'};
is noun(q{yours})->classical->plural,   q{yours}  => q{classical plural: 'yours' --> 'yours'};
is noun(q{separatrix})->classical->plural,   q{separatrices}  => q{classical plural: 'separatrix' --> 'separatrices'};
is noun(q{separatrices})->classical->plural, q{separatrices}  => q{classical plural: 'separatrices' --> 'separatrices'};
is noun(q{bass})->classical->plural,   q{bass}  => q{classical plural: 'bass' --> 'bass'};
is noun(q{femur})->classical->plural,   q{femora}  => q{classical plural: 'femur' --> 'femora'};
is noun(q{femora})->classical->plural, q{femora}  => q{classical plural: 'femora' --> 'femora'};
is noun(q{supercilium})->classical->plural,   q{supercilia}  => q{classical plural: 'supercilium' --> 'supercilia'};
is noun(q{supercilia})->classical->plural, q{supercilia}  => q{classical plural: 'supercilia' --> 'supercilia'};
is noun(q{contrafactum})->classical->plural,   q{contrafacta}  => q{classical plural: 'contrafactum' --> 'contrafacta'};
is noun(q{contrafacta})->classical->plural, q{contrafacta}  => q{classical plural: 'contrafacta' --> 'contrafacta'};
is noun(q{millennium})->classical->plural,   q{millennia}  => q{classical plural: 'millennium' --> 'millennia'};
is noun(q{millennia})->classical->plural, q{millennia}  => q{classical plural: 'millennia' --> 'millennia'};
is noun(q{sabertooth})->classical->plural,   q{sabertooths}  => q{classical plural: 'sabertooth' --> 'sabertooths'};
is noun(q{sabertooths})->classical->plural, q{sabertooths}  => q{classical plural: 'sabertooths' --> 'sabertooths'};
is noun(q{pecia})->classical->plural,   q{peciae}  => q{classical plural: 'pecia' --> 'peciae'};
is noun(q{peciae})->classical->plural, q{peciae}  => q{classical plural: 'peciae' --> 'peciae'};
is noun(q{cysticercus})->classical->plural,   q{cysticerci}  => q{classical plural: 'cysticercus' --> 'cysticerci'};
is noun(q{cysticerci})->classical->plural, q{cysticerci}  => q{classical plural: 'cysticerci' --> 'cysticerci'};
is noun(q{bajocco})->classical->plural,   q{bajocchi}  => q{classical plural: 'bajocco' --> 'bajocchi'};
is noun(q{bajocchi})->classical->plural, q{bajocchi}  => q{classical plural: 'bajocchi' --> 'bajocchi'};
is noun(q{theca})->classical->plural,   q{thecae}  => q{classical plural: 'theca' --> 'thecae'};
is noun(q{thecae})->classical->plural, q{thecae}  => q{classical plural: 'thecae' --> 'thecae'};
is noun(q{sternebra})->classical->plural,   q{sternebrae}  => q{classical plural: 'sternebra' --> 'sternebrae'};
is noun(q{sternebrae})->classical->plural, q{sternebrae}  => q{classical plural: 'sternebrae' --> 'sternebrae'};
is noun(q{captain general})->classical->plural,   q{captain generals}  => q{classical plural: 'captain general' --> 'captain generals'};
is noun(q{captain generals})->classical->plural, q{captain generals}  => q{classical plural: 'captain generals' --> 'captain generals'};
is noun(q{divisional general})->classical->plural,   q{divisional generals}  => q{classical plural: 'divisional general' --> 'divisional generals'};
is noun(q{divisional generals})->classical->plural, q{divisional generals}  => q{classical plural: 'divisional generals' --> 'divisional generals'};
is noun(q{interrex})->classical->plural,   q{interreges}  => q{classical plural: 'interrex' --> 'interreges'};
is noun(q{interreges})->classical->plural, q{interreges}  => q{classical plural: 'interreges' --> 'interreges'};
is noun(q{Nepalese})->classical->plural,   q{Nepalese}  => q{classical plural: 'Nepalese' --> 'Nepalese'};
is noun(q{solfeggio})->classical->plural,   q{solfeggi}  => q{classical plural: 'solfeggio' --> 'solfeggi'};
is noun(q{solfeggi})->classical->plural, q{solfeggi}  => q{classical plural: 'solfeggi' --> 'solfeggi'};
is noun(q{wildebeest})->classical->plural,   q{wildebeest}  => q{classical plural: 'wildebeest' --> 'wildebeest'};
is noun(q{caryatid})->classical->plural,   q{caryatides}  => q{classical plural: 'caryatid' --> 'caryatides'};
is noun(q{caryatides})->classical->plural, q{caryatides}  => q{classical plural: 'caryatides' --> 'caryatides'};
is noun(q{tergum})->classical->plural,   q{terga}  => q{classical plural: 'tergum' --> 'terga'};
is noun(q{terga})->classical->plural, q{terga}  => q{classical plural: 'terga' --> 'terga'};
is noun(q{trochus})->classical->plural,   q{trochi}  => q{classical plural: 'trochus' --> 'trochi'};
is noun(q{trochi})->classical->plural, q{trochi}  => q{classical plural: 'trochi' --> 'trochi'};
is noun(q{Madurese})->classical->plural,   q{Madurese}  => q{classical plural: 'Madurese' --> 'Madurese'};
is noun(q{terramara})->classical->plural,   q{terremare}  => q{classical plural: 'terramara' --> 'terremare'};
is noun(q{terremare})->classical->plural, q{terremare}  => q{classical plural: 'terremare' --> 'terremare'};
is noun(q{representamen})->classical->plural,   q{representamina}  => q{classical plural: 'representamen' --> 'representamina'};
is noun(q{representamina})->classical->plural, q{representamina}  => q{classical plural: 'representamina' --> 'representamina'};
is noun(q{beau})->classical->plural,   q{beaux}  => q{classical plural: 'beau' --> 'beaux'};
is noun(q{beaux})->classical->plural, q{beaux}  => q{classical plural: 'beaux' --> 'beaux'};
is noun(q{-ox})->classical->plural,   q{-oxen}  => q{classical plural: '-ox' --> '-oxen'};
is noun(q{-oxen})->classical->plural, q{-oxen}  => q{classical plural: '-oxen' --> '-oxen'};
is noun(q{starover})->classical->plural,   q{starovery}  => q{classical plural: 'starover' --> 'starovery'};
is noun(q{starovery})->classical->plural, q{starovery}  => q{classical plural: 'starovery' --> 'starovery'};
is noun(q{tabella})->classical->plural,   q{tabellae}  => q{classical plural: 'tabella' --> 'tabellae'};
is noun(q{tabellae})->classical->plural, q{tabellae}  => q{classical plural: 'tabellae' --> 'tabellae'};
is noun(q{menage a quatre})->classical->plural,   q{menages a quatre}  => q{classical plural: 'menage a quatre' --> 'menages a quatre'};
is noun(q{menages a quatre})->classical->plural, q{menages a quatre}  => q{classical plural: 'menages a quatre' --> 'menages a quatre'};
is noun(q{bona fides})->classical->plural,   q{bonis fidebus}  => q{classical plural: 'bona fides' --> 'bonis fidebus'};
is noun(q{bonis fidebus})->classical->plural, q{bonis fidebus}  => q{classical plural: 'bonis fidebus' --> 'bonis fidebus'};
is noun(q{Congolese})->classical->plural,   q{Congolese}  => q{classical plural: 'Congolese' --> 'Congolese'};
is noun(q{lithophyton})->classical->plural,   q{lithophyta}  => q{classical plural: 'lithophyton' --> 'lithophyta'};
is noun(q{lithophyta})->classical->plural, q{lithophyta}  => q{classical plural: 'lithophyta' --> 'lithophyta'};
is noun(q{naumachia})->classical->plural,   q{naumachiae}  => q{classical plural: 'naumachia' --> 'naumachiae'};
is noun(q{naumachiae})->classical->plural, q{naumachiae}  => q{classical plural: 'naumachiae' --> 'naumachiae'};
is noun(q{simia})->classical->plural,   q{simiae}  => q{classical plural: 'simia' --> 'simiae'};
is noun(q{simiae})->classical->plural, q{simiae}  => q{classical plural: 'simiae' --> 'simiae'};
is noun(q{phren})->classical->plural,   q{phrenes}  => q{classical plural: 'phren' --> 'phrenes'};
is noun(q{phrenes})->classical->plural, q{phrenes}  => q{classical plural: 'phrenes' --> 'phrenes'};
is noun(q{motoscafo})->classical->plural,   q{motoscafi}  => q{classical plural: 'motoscafo' --> 'motoscafi'};
is noun(q{motoscafi})->classical->plural, q{motoscafi}  => q{classical plural: 'motoscafi' --> 'motoscafi'};
is noun(q{rhinoceros})->classical->plural,   q{rhinoceros}  => q{classical plural: 'rhinoceros' --> 'rhinoceros'};
is noun(q{synaxarium})->classical->plural,   q{synaxaria}  => q{classical plural: 'synaxarium' --> 'synaxaria'};
is noun(q{synaxaria})->classical->plural, q{synaxaria}  => q{classical plural: 'synaxaria' --> 'synaxaria'};
is noun(q{kibbutz})->classical->plural,   q{kibbutzim}  => q{classical plural: 'kibbutz' --> 'kibbutzim'};
is noun(q{kibbutzim})->classical->plural, q{kibbutzim}  => q{classical plural: 'kibbutzim' --> 'kibbutzim'};
is noun(q{residuum})->classical->plural,   q{residua}  => q{classical plural: 'residuum' --> 'residua'};
is noun(q{residua})->classical->plural, q{residua}  => q{classical plural: 'residua' --> 'residua'};
is noun(q{stalactite})->classical->plural,   q{stalactitae}  => q{classical plural: 'stalactite' --> 'stalactitae'};
is noun(q{stalactitae})->classical->plural, q{stalactitae}  => q{classical plural: 'stalactitae' --> 'stalactitae'};
is noun(q{clippers})->classical->plural,   q{clippers}  => q{classical plural: 'clippers' --> 'clippers'};
is noun(q{herring})->classical->plural,   q{herring}  => q{classical plural: 'herring' --> 'herring'};
is noun(q{lamina})->classical->plural,   q{laminae}  => q{classical plural: 'lamina' --> 'laminae'};
is noun(q{laminae})->classical->plural, q{laminae}  => q{classical plural: 'laminae' --> 'laminae'};
is noun(q{sacrarium})->classical->plural,   q{sacraria}  => q{classical plural: 'sacrarium' --> 'sacraria'};
is noun(q{sacraria})->classical->plural, q{sacraria}  => q{classical plural: 'sacraria' --> 'sacraria'};
is noun(q{quaesitum})->classical->plural,   q{quaesita}  => q{classical plural: 'quaesitum' --> 'quaesita'};
is noun(q{quaesita})->classical->plural, q{quaesita}  => q{classical plural: 'quaesita' --> 'quaesita'};
is noun(q{vehiculum})->classical->plural,   q{vehicula}  => q{classical plural: 'vehiculum' --> 'vehicula'};
is noun(q{vehicula})->classical->plural, q{vehicula}  => q{classical plural: 'vehicula' --> 'vehicula'};
is noun(q{man child})->classical->plural,   q{men children}  => q{classical plural: 'man child' --> 'men children'};
is noun(q{men children})->classical->plural, q{men children}  => q{classical plural: 'men children' --> 'men children'};
is noun(q{Aragonese})->classical->plural,   q{Aragonese}  => q{classical plural: 'Aragonese' --> 'Aragonese'};
is noun(q{snooze})->classical->plural,   q{snoozes}  => q{classical plural: 'snooze' --> 'snoozes'};
is noun(q{snoozes})->classical->plural, q{snoozes}  => q{classical plural: 'snoozes' --> 'snoozes'};
is noun(q{ellipse})->classical->plural,   q{ellipses}  => q{classical plural: 'ellipse' --> 'ellipses'};
is noun(q{ellipses})->classical->plural, q{ellipses}  => q{classical plural: 'ellipses' --> 'ellipses'};
is noun(q{starets})->classical->plural,   q{startsy}  => q{classical plural: 'starets' --> 'startsy'};
is noun(q{startsy})->classical->plural, q{startsy}  => q{classical plural: 'startsy' --> 'startsy'};
is noun(q{exanthema})->classical->plural,   q{exanthemata}  => q{classical plural: 'exanthema' --> 'exanthemata'};
is noun(q{exanthemata})->classical->plural, q{exanthemata}  => q{classical plural: 'exanthemata' --> 'exanthemata'};
is noun(q{glacis})->classical->plural,   q{glacis}  => q{classical plural: 'glacis' --> 'glacis'};
is noun(q{cumulus})->classical->plural,   q{cumuli}  => q{classical plural: 'cumulus' --> 'cumuli'};
is noun(q{cumuli})->classical->plural, q{cumuli}  => q{classical plural: 'cumuli' --> 'cumuli'};
is noun(q{cicatrix})->classical->plural,   q{cicatrices}  => q{classical plural: 'cicatrix' --> 'cicatrices'};
is noun(q{cicatrices})->classical->plural, q{cicatrices}  => q{classical plural: 'cicatrices' --> 'cicatrices'};
is noun(q{scarus})->classical->plural,   q{scari}  => q{classical plural: 'scarus' --> 'scari'};
is noun(q{scari})->classical->plural, q{scari}  => q{classical plural: 'scari' --> 'scari'};
is noun(q{theologoumenon})->classical->plural,   q{theologoumena}  => q{classical plural: 'theologoumenon' --> 'theologoumena'};
is noun(q{theologoumena})->classical->plural, q{theologoumena}  => q{classical plural: 'theologoumena' --> 'theologoumena'};
is noun(q{phyma})->classical->plural,   q{phymata}  => q{classical plural: 'phyma' --> 'phymata'};
is noun(q{phymata})->classical->plural, q{phymata}  => q{classical plural: 'phymata' --> 'phymata'};
is noun(q{paha})->classical->plural,   q{paha}  => q{classical plural: 'paha' --> 'paha'};
is noun(q{perceptum})->classical->plural,   q{percepta}  => q{classical plural: 'perceptum' --> 'percepta'};
is noun(q{percepta})->classical->plural, q{percepta}  => q{classical plural: 'percepta' --> 'percepta'};
is noun(q{testudo})->classical->plural,   q{testudos}  => q{classical plural: 'testudo' --> 'testudos'};
is noun(q{testudos})->classical->plural, q{testudos}  => q{classical plural: 'testudos' --> 'testudos'};
is noun(q{agrogorod})->classical->plural,   q{agrogoroda}  => q{classical plural: 'agrogorod' --> 'agrogoroda'};
is noun(q{agrogoroda})->classical->plural, q{agrogoroda}  => q{classical plural: 'agrogoroda' --> 'agrogoroda'};
is noun(q{heroum})->classical->plural,   q{heroa}  => q{classical plural: 'heroum' --> 'heroa'};
is noun(q{heroa})->classical->plural, q{heroa}  => q{classical plural: 'heroa' --> 'heroa'};
is noun(q{stylus})->classical->plural,   q{styli}  => q{classical plural: 'stylus' --> 'styli'};
is noun(q{styli})->classical->plural, q{styli}  => q{classical plural: 'styli' --> 'styli'};
is noun(q{Tokyo})->classical->plural,   q{Tokyos}  => q{classical plural: 'Tokyo' --> 'Tokyos'};
is noun(q{Tokyos})->classical->plural, q{Tokyos}  => q{classical plural: 'Tokyos' --> 'Tokyos'};
is noun(q{proceedings})->classical->plural,   q{proceedings}  => q{classical plural: 'proceedings' --> 'proceedings'};
is noun(q{legumen})->classical->plural,   q{legumina}  => q{classical plural: 'legumen' --> 'legumina'};
is noun(q{legumina})->classical->plural, q{legumina}  => q{classical plural: 'legumina' --> 'legumina'};
is noun(q{synaesthesia})->classical->plural,   q{synaesthesiae}  => q{classical plural: 'synaesthesia' --> 'synaesthesiae'};
is noun(q{synaesthesiae})->classical->plural, q{synaesthesiae}  => q{classical plural: 'synaesthesiae' --> 'synaesthesiae'};
is noun(q{shawabti})->classical->plural,   q{shawabtiu}  => q{classical plural: 'shawabti' --> 'shawabtiu'};
is noun(q{shawabtiu})->classical->plural, q{shawabtiu}  => q{classical plural: 'shawabtiu' --> 'shawabtiu'};
is noun(q{sassafras})->classical->plural,   q{sassafrases}  => q{classical plural: 'sassafras' --> 'sassafrases'};
is noun(q{sassafrases})->classical->plural, q{sassafrases}  => q{classical plural: 'sassafrases' --> 'sassafrases'};
is noun(q{tholus})->classical->plural,   q{tholi}  => q{classical plural: 'tholus' --> 'tholi'};
is noun(q{tholi})->classical->plural, q{tholi}  => q{classical plural: 'tholi' --> 'tholi'};
is noun(q{micronucleus})->classical->plural,   q{micronuclei}  => q{classical plural: 'micronucleus' --> 'micronuclei'};
is noun(q{micronuclei})->classical->plural, q{micronuclei}  => q{classical plural: 'micronuclei' --> 'micronuclei'};
is noun(q{propylaeum})->classical->plural,   q{propylaea}  => q{classical plural: 'propylaeum' --> 'propylaea'};
is noun(q{propylaea})->classical->plural, q{propylaea}  => q{classical plural: 'propylaea' --> 'propylaea'};
is noun(q{umbra})->classical->plural,   q{umbrae}  => q{classical plural: 'umbra' --> 'umbrae'};
is noun(q{umbrae})->classical->plural, q{umbrae}  => q{classical plural: 'umbrae' --> 'umbrae'};
is noun(q{port-a-beul})->classical->plural,   q{puirt-a-beul}  => q{classical plural: 'port-a-beul' --> 'puirt-a-beul'};
is noun(q{puirt-a-beul})->classical->plural, q{puirt-a-beul}  => q{classical plural: 'puirt-a-beul' --> 'puirt-a-beul'};
is noun(q{stylo})->classical->plural,   q{stylos}  => q{classical plural: 'stylo' --> 'stylos'};
is noun(q{stylos})->classical->plural, q{stylos}  => q{classical plural: 'stylos' --> 'stylos'};
is noun(q{they})->classical->plural,   q{they}  => q{classical plural: 'they' --> 'they'};
is noun(q{Whitmanese})->classical->plural,   q{Whitmanese}  => q{classical plural: 'Whitmanese' --> 'Whitmanese'};
is noun(q{portrait parle})->classical->plural,   q{portraits parles}  => q{classical plural: 'portrait parle' --> 'portraits parles'};
is noun(q{portraits parles})->classical->plural, q{portraits parles}  => q{classical plural: 'portraits parles' --> 'portraits parles'};
is noun(q{siglos})->classical->plural,   q{sigloi}  => q{classical plural: 'siglos' --> 'sigloi'};
is noun(q{sigloi})->classical->plural, q{sigloi}  => q{classical plural: 'sigloi' --> 'sigloi'};
is noun(q{scissors})->classical->plural,   q{scissors}  => q{classical plural: 'scissors' --> 'scissors'};
is noun(q{musa})->classical->plural,   q{musae}  => q{classical plural: 'musa' --> 'musae'};
is noun(q{musae})->classical->plural, q{musae}  => q{classical plural: 'musae' --> 'musae'};
is noun(q{vacuum})->classical->plural,   q{vacua}  => q{classical plural: 'vacuum' --> 'vacua'};
is noun(q{vacua})->classical->plural, q{vacua}  => q{classical plural: 'vacua' --> 'vacua'};
is noun(q{judicatum})->classical->plural,   q{judicata}  => q{classical plural: 'judicatum' --> 'judicata'};
is noun(q{judicata})->classical->plural, q{judicata}  => q{classical plural: 'judicata' --> 'judicata'};
is noun(q{rad})->classical->plural,   q{rad}  => q{classical plural: 'rad' --> 'rad'};
is noun(q{himself})->classical->plural,   q{themselves}  => q{classical plural: 'himself' --> 'themselves'};
is noun(q{sputum})->classical->plural,   q{sputa}  => q{classical plural: 'sputum' --> 'sputa'};
is noun(q{sputa})->classical->plural, q{sputa}  => q{classical plural: 'sputa' --> 'sputa'};
is noun(q{plenarium})->classical->plural,   q{plenaria}  => q{classical plural: 'plenarium' --> 'plenaria'};
is noun(q{plenaria})->classical->plural, q{plenaria}  => q{classical plural: 'plenaria' --> 'plenaria'};
is noun(q{sistrum})->classical->plural,   q{sistra}  => q{classical plural: 'sistrum' --> 'sistra'};
is noun(q{sistra})->classical->plural, q{sistra}  => q{classical plural: 'sistra' --> 'sistra'};
is noun(q{viscus})->classical->plural,   q{viscera}  => q{classical plural: 'viscus' --> 'viscera'};
is noun(q{viscera})->classical->plural, q{viscera}  => q{classical plural: 'viscera' --> 'viscera'};
is noun(q{aviso})->classical->plural,   q{avisos}  => q{classical plural: 'aviso' --> 'avisos'};
is noun(q{avisos})->classical->plural, q{avisos}  => q{classical plural: 'avisos' --> 'avisos'};
is noun(q{2-star general})->classical->plural,   q{2-star generals}  => q{classical plural: '2-star general' --> '2-star generals'};
is noun(q{2-star generals})->classical->plural, q{2-star generals}  => q{classical plural: '2-star generals' --> '2-star generals'};
is noun(q{hemi-elytrum})->classical->plural,   q{hemi-elytra}  => q{classical plural: 'hemi-elytrum' --> 'hemi-elytra'};
is noun(q{hemi-elytra})->classical->plural, q{hemi-elytra}  => q{classical plural: 'hemi-elytra' --> 'hemi-elytra'};
is noun(q{proavis})->classical->plural,   q{proaves}  => q{classical plural: 'proavis' --> 'proaves'};
is noun(q{proaves})->classical->plural, q{proaves}  => q{classical plural: 'proaves' --> 'proaves'};
is noun(q{it})->classical->plural,   q{they}  => q{classical plural: 'it' --> 'they'};
is noun(q{stirps})->classical->plural,   q{stirpes}  => q{classical plural: 'stirps' --> 'stirpes'};
is noun(q{stirpes})->classical->plural, q{stirpes}  => q{classical plural: 'stirpes' --> 'stirpes'};
is noun(q{whosoever})->classical->plural,   q{whosoever}  => q{classical plural: 'whosoever' --> 'whosoever'};
is noun(q{Bahaman})->classical->plural,   q{Bahamans}  => q{classical plural: 'Bahaman' --> 'Bahamans'};
is noun(q{Bahamans})->classical->plural, q{Bahamans}  => q{classical plural: 'Bahamans' --> 'Bahamans'};
is noun(q{kovsh})->classical->plural,   q{kovshi}  => q{classical plural: 'kovsh' --> 'kovshi'};
is noun(q{kovshi})->classical->plural, q{kovshi}  => q{classical plural: 'kovshi' --> 'kovshi'};
is noun(q{leptomonas})->classical->plural,   q{leptomonas}  => q{classical plural: 'leptomonas' --> 'leptomonas'};
is noun(q{ephemeris})->classical->plural,   q{ephemerides}  => q{classical plural: 'ephemeris' --> 'ephemerides'};
is noun(q{ephemerides})->classical->plural, q{ephemerides}  => q{classical plural: 'ephemerides' --> 'ephemerides'};
is noun(q{desman})->classical->plural,   q{desmans}  => q{classical plural: 'desman' --> 'desmans'};
is noun(q{desmans})->classical->plural, q{desmans}  => q{classical plural: 'desmans' --> 'desmans'};
is noun(q{kuvasz})->classical->plural,   q{kuvaszok}  => q{classical plural: 'kuvasz' --> 'kuvaszok'};
is noun(q{kuvaszok})->classical->plural, q{kuvaszok}  => q{classical plural: 'kuvaszok' --> 'kuvaszok'};
is noun(q{pant})->classical->plural,   q{pants}  => q{classical plural: 'pant' --> 'pants'};
is noun(q{ergastulum})->classical->plural,   q{ergastula}  => q{classical plural: 'ergastulum' --> 'ergastula'};
is noun(q{ergastula})->classical->plural, q{ergastula}  => q{classical plural: 'ergastula' --> 'ergastula'};
is noun(q{bronchitis})->classical->plural,   q{bronchitises}  => q{classical plural: 'bronchitis' --> 'bronchitises'};
is noun(q{bronchitises})->classical->plural, q{bronchitises}  => q{classical plural: 'bronchitises' --> 'bronchitises'};
is noun(q{parapleura})->classical->plural,   q{parapleura}  => q{classical plural: 'parapleura' --> 'parapleura'};
is noun(q{plasmodium})->classical->plural,   q{plasmodia}  => q{classical plural: 'plasmodium' --> 'plasmodia'};
is noun(q{plasmodia})->classical->plural, q{plasmodia}  => q{classical plural: 'plasmodia' --> 'plasmodia'};
is noun(q{portmanteau})->classical->plural,   q{portmanteaux}  => q{classical plural: 'portmanteau' --> 'portmanteaux'};
is noun(q{portmanteaux})->classical->plural, q{portmanteaux}  => q{classical plural: 'portmanteaux' --> 'portmanteaux'};
is noun(q{port a beul})->classical->plural,   q{puirt a beul}  => q{classical plural: 'port a beul' --> 'puirt a beul'};
is noun(q{puirt a beul})->classical->plural, q{puirt a beul}  => q{classical plural: 'puirt a beul' --> 'puirt a beul'};
is noun(q{inhalatorium})->classical->plural,   q{inhalatoria}  => q{classical plural: 'inhalatorium' --> 'inhalatoria'};
is noun(q{inhalatoria})->classical->plural, q{inhalatoria}  => q{classical plural: 'inhalatoria' --> 'inhalatoria'};
is noun(q{corgi})->classical->plural,   q{corgwn}  => q{classical plural: 'corgi' --> 'corgwn'};
is noun(q{corgwn})->classical->plural, q{corgwn}  => q{classical plural: 'corgwn' --> 'corgwn'};
is noun(q{intermedium})->classical->plural,   q{intermedia}  => q{classical plural: 'intermedium' --> 'intermedia'};
is noun(q{intermedia})->classical->plural, q{intermedia}  => q{classical plural: 'intermedia' --> 'intermedia'};
is noun(q{auto-de-fe})->classical->plural,   q{autos-de-fes}  => q{classical plural: 'auto-de-fe' --> 'autos-de-fes'};
is noun(q{autos-de-fes})->classical->plural, q{autos-de-fes}  => q{classical plural: 'autos-de-fes' --> 'autos-de-fes'};
is noun(q{cecidium})->classical->plural,   q{cecidia}  => q{classical plural: 'cecidium' --> 'cecidia'};
is noun(q{cecidia})->classical->plural, q{cecidia}  => q{classical plural: 'cecidia' --> 'cecidia'};
is noun(q{magilus})->classical->plural,   q{magili}  => q{classical plural: 'magilus' --> 'magili'};
is noun(q{magili})->classical->plural, q{magili}  => q{classical plural: 'magili' --> 'magili'};
is noun(q{divertimento})->classical->plural,   q{divertimenti}  => q{classical plural: 'divertimento' --> 'divertimenti'};
is noun(q{divertimenti})->classical->plural, q{divertimenti}  => q{classical plural: 'divertimenti' --> 'divertimenti'};
is noun(q{regulus})->classical->plural,   q{reguli}  => q{classical plural: 'regulus' --> 'reguli'};
is noun(q{reguli})->classical->plural, q{reguli}  => q{classical plural: 'reguli' --> 'reguli'};
is noun(q{solenium})->classical->plural,   q{solenia}  => q{classical plural: 'solenium' --> 'solenia'};
is noun(q{solenia})->classical->plural, q{solenia}  => q{classical plural: 'solenia' --> 'solenia'};
is noun(q{inukshuk})->classical->plural,   q{inukshuit}  => q{classical plural: 'inukshuk' --> 'inukshuit'};
is noun(q{inukshuit})->classical->plural, q{inukshuit}  => q{classical plural: 'inukshuit' --> 'inukshuit'};
is noun(q{umwelt})->classical->plural,   q{umwelten}  => q{classical plural: 'umwelt' --> 'umwelten'};
is noun(q{umwelten})->classical->plural, q{umwelten}  => q{classical plural: 'umwelten' --> 'umwelten'};
is noun(q{vitta})->classical->plural,   q{vittae}  => q{classical plural: 'vitta' --> 'vittae'};
is noun(q{vittae})->classical->plural, q{vittae}  => q{classical plural: 'vittae' --> 'vittae'};
is noun(q{rezidentsia})->classical->plural,   q{rezidentsii}  => q{classical plural: 'rezidentsia' --> 'rezidentsii'};
is noun(q{rezidentsii})->classical->plural, q{rezidentsii}  => q{classical plural: 'rezidentsii' --> 'rezidentsii'};
is noun(q{britches})->classical->plural,   q{britches}  => q{classical plural: 'britches' --> 'britches'};
is noun(q{schizostylis})->classical->plural,   q{schizostylis}  => q{classical plural: 'schizostylis' --> 'schizostylis'};
is noun(q{bhikshu})->classical->plural,   q{bhikshook}  => q{classical plural: 'bhikshu' --> 'bhikshook'};
is noun(q{bhikshook})->classical->plural, q{bhikshook}  => q{classical plural: 'bhikshook' --> 'bhikshook'};
is noun(q{cyathus})->classical->plural,   q{cyathi}  => q{classical plural: 'cyathus' --> 'cyathi'};
is noun(q{cyathi})->classical->plural, q{cyathi}  => q{classical plural: 'cyathi' --> 'cyathi'};
is noun(q{erratum})->classical->plural,   q{errata}  => q{classical plural: 'erratum' --> 'errata'};
is noun(q{errata})->classical->plural, q{errata}  => q{classical plural: 'errata' --> 'errata'};
is noun(q{whiting})->classical->plural,   q{whiting}  => q{classical plural: 'whiting' --> 'whiting'};
is noun(q{coccidium})->classical->plural,   q{coccidia}  => q{classical plural: 'coccidium' --> 'coccidia'};
is noun(q{coccidia})->classical->plural, q{coccidia}  => q{classical plural: 'coccidia' --> 'coccidia'};
is noun(q{route nationale})->classical->plural,   q{routes nationales}  => q{classical plural: 'route nationale' --> 'routes nationales'};
is noun(q{routes nationales})->classical->plural, q{routes nationales}  => q{classical plural: 'routes nationales' --> 'routes nationales'};
is noun(q{asylum})->classical->plural,   q{asyla}  => q{classical plural: 'asylum' --> 'asyla'};
is noun(q{asyla})->classical->plural, q{asyla}  => q{classical plural: 'asyla' --> 'asyla'};
is noun(q{prolabium})->classical->plural,   q{prolabia}  => q{classical plural: 'prolabium' --> 'prolabia'};
is noun(q{prolabia})->classical->plural, q{prolabia}  => q{classical plural: 'prolabia' --> 'prolabia'};
is noun(q{gallows})->classical->plural,   q{gallows}  => q{classical plural: 'gallows' --> 'gallows'};
is noun(q{flocculus})->classical->plural,   q{flocculi}  => q{classical plural: 'flocculus' --> 'flocculi'};
is noun(q{flocculi})->classical->plural, q{flocculi}  => q{classical plural: 'flocculi' --> 'flocculi'};
is noun(q{jeu})->classical->plural,   q{jeux}  => q{classical plural: 'jeu' --> 'jeux'};
is noun(q{jeux})->classical->plural, q{jeux}  => q{classical plural: 'jeux' --> 'jeux'};
is noun(q{bozzetto})->classical->plural,   q{bozzetti}  => q{classical plural: 'bozzetto' --> 'bozzetti'};
is noun(q{bozzetti})->classical->plural, q{bozzetti}  => q{classical plural: 'bozzetti' --> 'bozzetti'};
is noun(q{rabies})->classical->plural,   q{rabies}  => q{classical plural: 'rabies' --> 'rabies'};
is noun(q{set-off})->classical->plural,   q{sets-off}  => q{classical plural: 'set-off' --> 'sets-off'};
is noun(q{sets-off})->classical->plural, q{sets-off}  => q{classical plural: 'sets-off' --> 'sets-off'};
is noun(q{sotch})->classical->plural,   q{sotchs}  => q{classical plural: 'sotch' --> 'sotchs'};
is noun(q{sotchs})->classical->plural, q{sotchs}  => q{classical plural: 'sotchs' --> 'sotchs'};
is noun(q{inferno})->classical->plural,   q{infernos}  => q{classical plural: 'inferno' --> 'infernos'};
is noun(q{infernos})->classical->plural, q{infernos}  => q{classical plural: 'infernos' --> 'infernos'};
is noun(q{glomus})->classical->plural,   q{glomera}  => q{classical plural: 'glomus' --> 'glomera'};
is noun(q{glomera})->classical->plural, q{glomera}  => q{classical plural: 'glomera' --> 'glomera'};
is noun(q{spondylus})->classical->plural,   q{spondyli}  => q{classical plural: 'spondylus' --> 'spondyli'};
is noun(q{spondyli})->classical->plural, q{spondyli}  => q{classical plural: 'spondyli' --> 'spondyli'};
is noun(q{bathos})->classical->plural,   q{bathoses}  => q{classical plural: 'bathos' --> 'bathoses'};
is noun(q{bathoses})->classical->plural, q{bathoses}  => q{classical plural: 'bathoses' --> 'bathoses'};
is noun(q{tuberculum})->classical->plural,   q{tubercula}  => q{classical plural: 'tuberculum' --> 'tubercula'};
is noun(q{tubercula})->classical->plural, q{tubercula}  => q{classical plural: 'tubercula' --> 'tubercula'};
is noun(q{trachea})->classical->plural,   q{tracheae}  => q{classical plural: 'trachea' --> 'tracheae'};
is noun(q{tracheae})->classical->plural, q{tracheae}  => q{classical plural: 'tracheae' --> 'tracheae'};
is noun(q{terebratula})->classical->plural,   q{terebratulae}  => q{classical plural: 'terebratula' --> 'terebratulae'};
is noun(q{terebratulae})->classical->plural, q{terebratulae}  => q{classical plural: 'terebratulae' --> 'terebratulae'};
is noun(q{Colorado})->classical->plural,   q{Colorados}  => q{classical plural: 'Colorado' --> 'Colorados'};
is noun(q{Colorados})->classical->plural, q{Colorados}  => q{classical plural: 'Colorados' --> 'Colorados'};
is noun(q{mafiosa})->classical->plural,   q{mafiose}  => q{classical plural: 'mafiosa' --> 'mafiose'};
is noun(q{mafiose})->classical->plural, q{mafiose}  => q{classical plural: 'mafiose' --> 'mafiose'};
is noun(q{caduceus})->classical->plural,   q{caducei}  => q{classical plural: 'caduceus' --> 'caducei'};
is noun(q{caducei})->classical->plural, q{caducei}  => q{classical plural: 'caducei' --> 'caducei'};
is noun(q{synesthesia})->classical->plural,   q{synesthesiae}  => q{classical plural: 'synesthesia' --> 'synesthesiae'};
is noun(q{synesthesiae})->classical->plural, q{synesthesiae}  => q{classical plural: 'synesthesiae' --> 'synesthesiae'};
is noun(q{clostridium})->classical->plural,   q{clostridia}  => q{classical plural: 'clostridium' --> 'clostridia'};
is noun(q{clostridia})->classical->plural, q{clostridia}  => q{classical plural: 'clostridia' --> 'clostridia'};
is noun(q{lemniscus})->classical->plural,   q{lemnisci}  => q{classical plural: 'lemniscus' --> 'lemnisci'};
is noun(q{lemnisci})->classical->plural, q{lemnisci}  => q{classical plural: 'lemnisci' --> 'lemnisci'};
is noun(q{pullus})->classical->plural,   q{pulli}  => q{classical plural: 'pullus' --> 'pulli'};
is noun(q{pulli})->classical->plural, q{pulli}  => q{classical plural: 'pulli' --> 'pulli'};
is noun(q{limbo})->classical->plural,   q{limbos}  => q{classical plural: 'limbo' --> 'limbos'};
is noun(q{limbos})->classical->plural, q{limbos}  => q{classical plural: 'limbos' --> 'limbos'};
is noun(q{psydracium})->classical->plural,   q{psydracia}  => q{classical plural: 'psydracium' --> 'psydracia'};
is noun(q{psydracia})->classical->plural, q{psydracia}  => q{classical plural: 'psydracia' --> 'psydracia'};
is noun(q{who})->classical->plural,   q{who}  => q{classical plural: 'who' --> 'who'};
is noun(q{aphis})->classical->plural,   q{aphides}  => q{classical plural: 'aphis' --> 'aphides'};
is noun(q{aphides})->classical->plural, q{aphides}  => q{classical plural: 'aphides' --> 'aphides'};
is noun(q{comatula})->classical->plural,   q{comatulae}  => q{classical plural: 'comatula' --> 'comatulae'};
is noun(q{comatulae})->classical->plural, q{comatulae}  => q{classical plural: 'comatulae' --> 'comatulae'};
is noun(q{stemma})->classical->plural,   q{stemmata}  => q{classical plural: 'stemma' --> 'stemmata'};
is noun(q{stemmata})->classical->plural, q{stemmata}  => q{classical plural: 'stemmata' --> 'stemmata'};
is noun(q{septemvir})->classical->plural,   q{septemviri}  => q{classical plural: 'septemvir' --> 'septemviri'};
is noun(q{septemviri})->classical->plural, q{septemviri}  => q{classical plural: 'septemviri' --> 'septemviri'};
is noun(q{figurante})->classical->plural,   q{figuranti}  => q{classical plural: 'figurante' --> 'figuranti'};
is noun(q{figuranti})->classical->plural, q{figuranti}  => q{classical plural: 'figuranti' --> 'figuranti'};
is noun(q{cremaster})->classical->plural,   q{cremasteres}  => q{classical plural: 'cremaster' --> 'cremasteres'};
is noun(q{cremasteres})->classical->plural, q{cremasteres}  => q{classical plural: 'cremasteres' --> 'cremasteres'};
is noun(q{modius})->classical->plural,   q{modii}  => q{classical plural: 'modius' --> 'modii'};
is noun(q{modii})->classical->plural, q{modii}  => q{classical plural: 'modii' --> 'modii'};
is noun(q{micro})->classical->plural,   q{micros}  => q{classical plural: 'micro' --> 'micros'};
is noun(q{micros})->classical->plural, q{micros}  => q{classical plural: 'micros' --> 'micros'};
is noun(q{cabaletta})->classical->plural,   q{cabalette}  => q{classical plural: 'cabaletta' --> 'cabalette'};
is noun(q{cabalette})->classical->plural, q{cabalette}  => q{classical plural: 'cabalette' --> 'cabalette'};
is noun(q{memo})->classical->plural,   q{memos}  => q{classical plural: 'memo' --> 'memos'};
is noun(q{memos})->classical->plural, q{memos}  => q{classical plural: 'memos' --> 'memos'};
is noun(q{espanol})->classical->plural,   q{espanoles}  => q{classical plural: 'espanol' --> 'espanoles'};
is noun(q{espanoles})->classical->plural, q{espanoles}  => q{classical plural: 'espanoles' --> 'espanoles'};
is noun(q{tonneau})->classical->plural,   q{tonneaux}  => q{classical plural: 'tonneau' --> 'tonneaux'};
is noun(q{tonneaux})->classical->plural, q{tonneaux}  => q{classical plural: 'tonneaux' --> 'tonneaux'};
is noun(q{dictum})->classical->plural,   q{dicta}  => q{classical plural: 'dictum' --> 'dicta'};
is noun(q{dicta})->classical->plural, q{dicta}  => q{classical plural: 'dicta' --> 'dicta'};
is noun(q{Lebanese})->classical->plural,   q{Lebanese}  => q{classical plural: 'Lebanese' --> 'Lebanese'};
is noun(q{manservant})->classical->plural,   q{menservants}  => q{classical plural: 'manservant' --> 'menservants'};
is noun(q{menservants})->classical->plural, q{menservants}  => q{classical plural: 'menservants' --> 'menservants'};
is noun(q{themself})->classical->plural,   q{themselves}  => q{classical plural: 'themself' --> 'themselves'};
is noun(q{meretrix})->classical->plural,   q{meretrices}  => q{classical plural: 'meretrix' --> 'meretrices'};
is noun(q{meretrices})->classical->plural, q{meretrices}  => q{classical plural: 'meretrices' --> 'meretrices'};
is noun(q{chorus})->classical->plural,   q{choruses}  => q{classical plural: 'chorus' --> 'choruses'};
is noun(q{choruses})->classical->plural, q{choruses}  => q{classical plural: 'choruses' --> 'choruses'};
is noun(q{trichidium})->classical->plural,   q{trichidia}  => q{classical plural: 'trichidium' --> 'trichidia'};
is noun(q{trichidia})->classical->plural, q{trichidia}  => q{classical plural: 'trichidia' --> 'trichidia'};
is noun(q{gravamen})->classical->plural,   q{gravamina}  => q{classical plural: 'gravamen' --> 'gravamina'};
is noun(q{gravamina})->classical->plural, q{gravamina}  => q{classical plural: 'gravamina' --> 'gravamina'};
is noun(q{Americanese})->classical->plural,   q{Americanese}  => q{classical plural: 'Americanese' --> 'Americanese'};
is noun(q{spermatheca})->classical->plural,   q{spermathecae}  => q{classical plural: 'spermatheca' --> 'spermathecae'};
is noun(q{spermathecae})->classical->plural, q{spermathecae}  => q{classical plural: 'spermathecae' --> 'spermathecae'};
is noun(q{4-star general})->classical->plural,   q{4-star generals}  => q{classical plural: '4-star general' --> '4-star generals'};
is noun(q{4-star generals})->classical->plural, q{4-star generals}  => q{classical plural: '4-star generals' --> '4-star generals'};
is noun(q{cul-de-lampe})->classical->plural,   q{culs-de-lampe}  => q{classical plural: 'cul-de-lampe' --> 'culs-de-lampe'};
is noun(q{culs-de-lampe})->classical->plural, q{culs-de-lampe}  => q{classical plural: 'culs-de-lampe' --> 'culs-de-lampe'};
is noun(q{bandit})->classical->plural,   q{banditti}  => q{classical plural: 'bandit' --> 'banditti'};
is noun(q{banditti})->classical->plural, q{banditti}  => q{classical plural: 'banditti' --> 'banditti'};
is noun(q{synangium})->classical->plural,   q{synangia}  => q{classical plural: 'synangium' --> 'synangia'};
is noun(q{synangia})->classical->plural, q{synangia}  => q{classical plural: 'synangia' --> 'synangia'};
is noun(q{ale wife})->classical->plural,   q{ale wives}  => q{classical plural: 'ale wife' --> 'ale wives'};
is noun(q{ale wives})->classical->plural, q{ale wives}  => q{classical plural: 'ale wives' --> 'ale wives'};
is noun(q{linctus})->classical->plural,   q{linctuses}  => q{classical plural: 'linctus' --> 'linctuses'};
is noun(q{linctuses})->classical->plural, q{linctuses}  => q{classical plural: 'linctuses' --> 'linctuses'};
is noun(q{tsubo})->classical->plural,   q{tsubo}  => q{classical plural: 'tsubo' --> 'tsubo'};
is noun(q{prora})->classical->plural,   q{prorae}  => q{classical plural: 'prora' --> 'prorae'};
is noun(q{prorae})->classical->plural, q{prorae}  => q{classical plural: 'prorae' --> 'prorae'};
is noun(q{soe})->classical->plural,   q{soes}  => q{classical plural: 'soe' --> 'soes'};
is noun(q{soes})->classical->plural, q{soes}  => q{classical plural: 'soes' --> 'soes'};
is noun(q{dumka})->classical->plural,   q{dumky}  => q{classical plural: 'dumka' --> 'dumky'};
is noun(q{dumky})->classical->plural, q{dumky}  => q{classical plural: 'dumky' --> 'dumky'};
is noun(q{infima species})->classical->plural,   q{infimae species}  => q{classical plural: 'infima species' --> 'infimae species'};
is noun(q{infimae species})->classical->plural, q{infimae species}  => q{classical plural: 'infimae species' --> 'infimae species'};
is noun(q{poculum})->classical->plural,   q{pocula}  => q{classical plural: 'poculum' --> 'pocula'};
is noun(q{pocula})->classical->plural, q{pocula}  => q{classical plural: 'pocula' --> 'pocula'};
is noun(q{caecum})->classical->plural,   q{caeca}  => q{classical plural: 'caecum' --> 'caeca'};
is noun(q{caeca})->classical->plural, q{caeca}  => q{classical plural: 'caeca' --> 'caeca'};
is noun(q{razz})->classical->plural,   q{razzes}  => q{classical plural: 'razz' --> 'razzes'};
is noun(q{razzes})->classical->plural, q{razzes}  => q{classical plural: 'razzes' --> 'razzes'};
is noun(q{imago})->classical->plural,   q{imagines}  => q{classical plural: 'imago' --> 'imagines'};
is noun(q{imagines})->classical->plural, q{imagines}  => q{classical plural: 'imagines' --> 'imagines'};
is noun(q{ostium})->classical->plural,   q{ostia}  => q{classical plural: 'ostium' --> 'ostia'};
is noun(q{ostia})->classical->plural, q{ostia}  => q{classical plural: 'ostia' --> 'ostia'};
is noun(q{bijou})->classical->plural,   q{bijoux}  => q{classical plural: 'bijou' --> 'bijoux'};
is noun(q{bijoux})->classical->plural, q{bijoux}  => q{classical plural: 'bijoux' --> 'bijoux'};
is noun(q{craft})->classical->plural,   q{craft}  => q{classical plural: 'craft' --> 'craft'};
is noun(q{epithelioma})->classical->plural,   q{epitheliomata}  => q{classical plural: 'epithelioma' --> 'epitheliomata'};
is noun(q{epitheliomata})->classical->plural, q{epitheliomata}  => q{classical plural: 'epitheliomata' --> 'epitheliomata'};
is noun(q{pifferaro})->classical->plural,   q{pifferari}  => q{classical plural: 'pifferaro' --> 'pifferari'};
is noun(q{pifferari})->classical->plural, q{pifferari}  => q{classical plural: 'pifferari' --> 'pifferari'};
is noun(q{monota})->classical->plural,   q{monotae}  => q{classical plural: 'monota' --> 'monotae'};
is noun(q{monotae})->classical->plural, q{monotae}  => q{classical plural: 'monotae' --> 'monotae'};
is noun(q{internodium})->classical->plural,   q{internodia}  => q{classical plural: 'internodium' --> 'internodia'};
is noun(q{internodia})->classical->plural, q{internodia}  => q{classical plural: 'internodia' --> 'internodia'};
is noun(q{loggia})->classical->plural,   q{loggie}  => q{classical plural: 'loggia' --> 'loggie'};
is noun(q{loggie})->classical->plural, q{loggie}  => q{classical plural: 'loggie' --> 'loggie'};
is noun(q{parapleurum})->classical->plural,   q{parapleura}  => q{classical plural: 'parapleurum' --> 'parapleura'};
is noun(q{cantus})->classical->plural,   q{cantus}  => q{classical plural: 'cantus' --> 'cantus'};
is noun(q{poe})->classical->plural,   q{poes}  => q{classical plural: 'poe' --> 'poes'};
is noun(q{poes})->classical->plural, q{poes}  => q{classical plural: 'poes' --> 'poes'};
is noun(q{cod})->classical->plural,   q{cod}  => q{classical plural: 'cod' --> 'cod'};
is noun(q{pectus})->classical->plural,   q{pectora}  => q{classical plural: 'pectus' --> 'pectora'};
is noun(q{pectora})->classical->plural, q{pectora}  => q{classical plural: 'pectora' --> 'pectora'};
is noun(q{sinfonia})->classical->plural,   q{sinfonie}  => q{classical plural: 'sinfonia' --> 'sinfonie'};
is noun(q{sinfonie})->classical->plural, q{sinfonie}  => q{classical plural: 'sinfonie' --> 'sinfonie'};
is noun(q{torulus})->classical->plural,   q{toruli}  => q{classical plural: 'torulus' --> 'toruli'};
is noun(q{toruli})->classical->plural, q{toruli}  => q{classical plural: 'toruli' --> 'toruli'};
is noun(q{crista})->classical->plural,   q{cristae}  => q{classical plural: 'crista' --> 'cristae'};
is noun(q{cristae})->classical->plural, q{cristae}  => q{classical plural: 'cristae' --> 'cristae'};
is noun(q{adminiculum})->classical->plural,   q{adminicula}  => q{classical plural: 'adminiculum' --> 'adminicula'};
is noun(q{adminicula})->classical->plural, q{adminicula}  => q{classical plural: 'adminicula' --> 'adminicula'};
is noun(q{meshumad})->classical->plural,   q{meshumadim}  => q{classical plural: 'meshumad' --> 'meshumadim'};
is noun(q{meshumadim})->classical->plural, q{meshumadim}  => q{classical plural: 'meshumadim' --> 'meshumadim'};
is noun(q{vila})->classical->plural,   q{vile}  => q{classical plural: 'vila' --> 'vile'};
is noun(q{vile})->classical->plural, q{vile}  => q{classical plural: 'vile' --> 'vile'};
is noun(q{wolf})->classical->plural,   q{wolves}  => q{classical plural: 'wolf' --> 'wolves'};
is noun(q{wolves})->classical->plural, q{wolves}  => q{classical plural: 'wolves' --> 'wolves'};
is noun(q{pediluvium})->classical->plural,   q{pediluvia}  => q{classical plural: 'pediluvium' --> 'pediluvia'};
is noun(q{pediluvia})->classical->plural, q{pediluvia}  => q{classical plural: 'pediluvia' --> 'pediluvia'};
is noun(q{axopodium})->classical->plural,   q{axopodia}  => q{classical plural: 'axopodium' --> 'axopodia'};
is noun(q{axopodia})->classical->plural, q{axopodia}  => q{classical plural: 'axopodia' --> 'axopodia'};
is noun(q{ho})->classical->plural,   q{hoes}  => q{classical plural: 'ho' --> 'hoes'};
is noun(q{hoes})->classical->plural, q{hoes}  => q{classical plural: 'hoes' --> 'hoes'};
is noun(q{sombrero})->classical->plural,   q{sombreros}  => q{classical plural: 'sombrero' --> 'sombreros'};
is noun(q{sombreros})->classical->plural, q{sombreros}  => q{classical plural: 'sombreros' --> 'sombreros'};
is noun(q{Muqdisho})->classical->plural,   q{Muqdishos}  => q{classical plural: 'Muqdisho' --> 'Muqdishos'};
is noun(q{Muqdishos})->classical->plural, q{Muqdishos}  => q{classical plural: 'Muqdishos' --> 'Muqdishos'};
is noun(q{Atlas})->classical->plural,   q{Atlantes}  => q{classical plural: 'Atlas' --> 'Atlantes'};
is noun(q{Atlantes})->classical->plural, q{Atlantes}  => q{classical plural: 'Atlantes' --> 'Atlantes'};
is noun(q{Bolzano})->classical->plural,   q{Bolzanos}  => q{classical plural: 'Bolzano' --> 'Bolzanos'};
is noun(q{Bolzanos})->classical->plural, q{Bolzanos}  => q{classical plural: 'Bolzanos' --> 'Bolzanos'};
is noun(q{rubashka})->classical->plural,   q{rubashki}  => q{classical plural: 'rubashka' --> 'rubashki'};
is noun(q{rubashki})->classical->plural, q{rubashki}  => q{classical plural: 'rubashki' --> 'rubashki'};
is noun(q{protoma})->classical->plural,   q{protomae}  => q{classical plural: 'protoma' --> 'protomae'};
is noun(q{protomae})->classical->plural, q{protomae}  => q{classical plural: 'protomae' --> 'protomae'};
is noun(q{maecenas})->classical->plural,   q{maecenates}  => q{classical plural: 'maecenas' --> 'maecenates'};
is noun(q{maecenates})->classical->plural, q{maecenates}  => q{classical plural: 'maecenates' --> 'maecenates'};
is noun(q{tableau})->classical->plural,   q{tableaux}  => q{classical plural: 'tableau' --> 'tableaux'};
is noun(q{tableaux})->classical->plural, q{tableaux}  => q{classical plural: 'tableaux' --> 'tableaux'};
is noun(q{isthmus})->classical->plural,   q{isthmi}  => q{classical plural: 'isthmus' --> 'isthmi'};
is noun(q{isthmi})->classical->plural, q{isthmi}  => q{classical plural: 'isthmi' --> 'isthmi'};
is noun(q{syphiloma})->classical->plural,   q{syphilomata}  => q{classical plural: 'syphiloma' --> 'syphilomata'};
is noun(q{syphilomata})->classical->plural, q{syphilomata}  => q{classical plural: 'syphilomata' --> 'syphilomata'};
is noun(q{eunuch})->classical->plural,   q{eunuchs}  => q{classical plural: 'eunuch' --> 'eunuchs'};
is noun(q{eunuchs})->classical->plural, q{eunuchs}  => q{classical plural: 'eunuchs' --> 'eunuchs'};
is noun(q{Camaldolese})->classical->plural,   q{Camaldolese}  => q{classical plural: 'Camaldolese' --> 'Camaldolese'};
is noun(q{convolvulus})->classical->plural,   q{convolvuli}  => q{classical plural: 'convolvulus' --> 'convolvuli'};
is noun(q{convolvuli})->classical->plural, q{convolvuli}  => q{classical plural: 'convolvuli' --> 'convolvuli'};
is noun(q{aboiteau})->classical->plural,   q{aboiteaux}  => q{classical plural: 'aboiteau' --> 'aboiteaux'};
is noun(q{aboiteaux})->classical->plural, q{aboiteaux}  => q{classical plural: 'aboiteaux' --> 'aboiteaux'};
is noun(q{Kiplingese})->classical->plural,   q{Kiplingese}  => q{classical plural: 'Kiplingese' --> 'Kiplingese'};
is noun(q{feis})->classical->plural,   q{feiseanna}  => q{classical plural: 'feis' --> 'feiseanna'};
is noun(q{feiseanna})->classical->plural, q{feiseanna}  => q{classical plural: 'feiseanna' --> 'feiseanna'};
is noun(q{canto})->classical->plural,   q{cantos}  => q{classical plural: 'canto' --> 'cantos'};
is noun(q{cantos})->classical->plural, q{cantos}  => q{classical plural: 'cantos' --> 'cantos'};
is noun(q{mortadella})->classical->plural,   q{mortadelle}  => q{classical plural: 'mortadella' --> 'mortadelle'};
is noun(q{mortadelle})->classical->plural, q{mortadelle}  => q{classical plural: 'mortadelle' --> 'mortadelle'};
is noun(q{armadillo})->classical->plural,   q{armadillos}  => q{classical plural: 'armadillo' --> 'armadillos'};
is noun(q{armadillos})->classical->plural, q{armadillos}  => q{classical plural: 'armadillos' --> 'armadillos'};
is noun(q{uredium})->classical->plural,   q{uredia}  => q{classical plural: 'uredium' --> 'uredia'};
is noun(q{uredia})->classical->plural, q{uredia}  => q{classical plural: 'uredia' --> 'uredia'};
is noun(q{stolo})->classical->plural,   q{stolones}  => q{classical plural: 'stolo' --> 'stolones'};
is noun(q{stolones})->classical->plural, q{stolones}  => q{classical plural: 'stolones' --> 'stolones'};
is noun(q{prepenna})->classical->plural,   q{prepennae}  => q{classical plural: 'prepenna' --> 'prepennae'};
is noun(q{prepennae})->classical->plural, q{prepennae}  => q{classical plural: 'prepennae' --> 'prepennae'};
is noun(q{tuna})->classical->plural,   q{tuna}  => q{classical plural: 'tuna' --> 'tuna'};
is noun(q{albergo})->classical->plural,   q{alberghi}  => q{classical plural: 'albergo' --> 'alberghi'};
is noun(q{alberghi})->classical->plural, q{alberghi}  => q{classical plural: 'alberghi' --> 'alberghi'};
is noun(q{nidus})->classical->plural,   q{nidi}  => q{classical plural: 'nidus' --> 'nidi'};
is noun(q{nidi})->classical->plural, q{nidi}  => q{classical plural: 'nidi' --> 'nidi'};
is noun(q{Toronto})->classical->plural,   q{Torontos}  => q{classical plural: 'Toronto' --> 'Torontos'};
is noun(q{Torontos})->classical->plural, q{Torontos}  => q{classical plural: 'Torontos' --> 'Torontos'};
is noun(q{lentigo})->classical->plural,   q{lentigines}  => q{classical plural: 'lentigo' --> 'lentigines'};
is noun(q{lentigines})->classical->plural, q{lentigines}  => q{classical plural: 'lentigines' --> 'lentigines'};
is noun(q{isidium})->classical->plural,   q{isidia}  => q{classical plural: 'isidium' --> 'isidia'};
is noun(q{isidia})->classical->plural, q{isidia}  => q{classical plural: 'isidia' --> 'isidia'};
is noun(q{kobo})->classical->plural,   q{kobo}  => q{classical plural: 'kobo' --> 'kobo'};
is noun(q{graben})->classical->plural,   q{graben}  => q{classical plural: 'graben' --> 'graben'};
is noun(q{opus})->classical->plural,   q{opuses}  => q{classical plural: 'opus' --> 'opuses'};
is noun(q{opuses})->classical->plural, q{opuses}  => q{classical plural: 'opuses' --> 'opuses'};
is noun(q{yoe})->classical->plural,   q{yoes}  => q{classical plural: 'yoe' --> 'yoes'};
is noun(q{yoes})->classical->plural, q{yoes}  => q{classical plural: 'yoes' --> 'yoes'};
is noun(q{herpes})->classical->plural,   q{herpes}  => q{classical plural: 'herpes' --> 'herpes'};
is noun(q{evirato})->classical->plural,   q{evirati}  => q{classical plural: 'evirato' --> 'evirati'};
is noun(q{evirati})->classical->plural, q{evirati}  => q{classical plural: 'evirati' --> 'evirati'};
is noun(q{gens})->classical->plural,   q{gentes}  => q{classical plural: 'gens' --> 'gentes'};
is noun(q{gentes})->classical->plural, q{gentes}  => q{classical plural: 'gentes' --> 'gentes'};
is noun(q{staretz})->classical->plural,   q{startzy}  => q{classical plural: 'staretz' --> 'startzy'};
is noun(q{startzy})->classical->plural, q{startzy}  => q{classical plural: 'startzy' --> 'startzy'};
is noun(q{talisman})->classical->plural,   q{talismans}  => q{classical plural: 'talisman' --> 'talismans'};
is noun(q{talismans})->classical->plural, q{talismans}  => q{classical plural: 'talismans' --> 'talismans'};
is noun(q{limax})->classical->plural,   q{limaces}  => q{classical plural: 'limax' --> 'limaces'};
is noun(q{limaces})->classical->plural, q{limaces}  => q{classical plural: 'limaces' --> 'limaces'};
is noun(q{septarium})->classical->plural,   q{septaria}  => q{classical plural: 'septarium' --> 'septaria'};
is noun(q{septaria})->classical->plural, q{septaria}  => q{classical plural: 'septaria' --> 'septaria'};
is noun(q{flounder})->classical->plural,   q{flounder}  => q{classical plural: 'flounder' --> 'flounder'};
is noun(q{scirrhus})->classical->plural,   q{scirrhi}  => q{classical plural: 'scirrhus' --> 'scirrhi'};
is noun(q{scirrhi})->classical->plural, q{scirrhi}  => q{classical plural: 'scirrhi' --> 'scirrhi'};
is noun(q{leu})->classical->plural,   q{lei}  => q{classical plural: 'leu' --> 'lei'};
is noun(q{lei})->classical->plural, q{lei}  => q{classical plural: 'lei' --> 'lei'};
is noun(q{mo})->classical->plural,   q{moes}  => q{classical plural: 'mo' --> 'moes'};
is noun(q{moes})->classical->plural, q{moes}  => q{classical plural: 'moes' --> 'moes'};
is noun(q{pied a terre})->classical->plural,   q{pieds a terre}  => q{classical plural: 'pied a terre' --> 'pieds a terre'};
is noun(q{pieds a terre})->classical->plural, q{pieds a terre}  => q{classical plural: 'pieds a terre' --> 'pieds a terre'};
is noun(q{karrenfeld})->classical->plural,   q{karrenfelder}  => q{classical plural: 'karrenfeld' --> 'karrenfelder'};
is noun(q{karrenfelder})->classical->plural, q{karrenfelder}  => q{classical plural: 'karrenfelder' --> 'karrenfelder'};
is noun(q{gladiolus})->classical->plural,   q{gladioli}  => q{classical plural: 'gladiolus' --> 'gladioli'};
is noun(q{gladioli})->classical->plural, q{gladioli}  => q{classical plural: 'gladioli' --> 'gladioli'};
is noun(q{reductio})->classical->plural,   q{reductiones}  => q{classical plural: 'reductio' --> 'reductiones'};
is noun(q{reductiones})->classical->plural, q{reductiones}  => q{classical plural: 'reductiones' --> 'reductiones'};
is noun(q{rezident})->classical->plural,   q{rezidenty}  => q{classical plural: 'rezident' --> 'rezidenty'};
is noun(q{rezidenty})->classical->plural, q{rezidenty}  => q{classical plural: 'rezidenty' --> 'rezidenty'};
is noun(q{fungo porcino})->classical->plural,   q{funghi porchini}  => q{classical plural: 'fungo porcino' --> 'funghi porchini'};
is noun(q{funghi porchini})->classical->plural, q{funghi porchini}  => q{classical plural: 'funghi porchini' --> 'funghi porchini'};
is noun(q{uredosorus})->classical->plural,   q{uredosori}  => q{classical plural: 'uredosorus' --> 'uredosori'};
is noun(q{uredosori})->classical->plural, q{uredosori}  => q{classical plural: 'uredosori' --> 'uredosori'};
is noun(q{syrtis})->classical->plural,   q{syrtes}  => q{classical plural: 'syrtis' --> 'syrtes'};
is noun(q{syrtes})->classical->plural, q{syrtes}  => q{classical plural: 'syrtes' --> 'syrtes'};
is noun(q{tarsus})->classical->plural,   q{tarsi}  => q{classical plural: 'tarsus' --> 'tarsi'};
is noun(q{tarsi})->classical->plural, q{tarsi}  => q{classical plural: 'tarsi' --> 'tarsi'};
is noun(q{holothuria})->classical->plural,   q{holothuriae}  => q{classical plural: 'holothuria' --> 'holothuriae'};
is noun(q{holothuriae})->classical->plural, q{holothuriae}  => q{classical plural: 'holothuriae' --> 'holothuriae'};
is noun(q{Shavese})->classical->plural,   q{Shavese}  => q{classical plural: 'Shavese' --> 'Shavese'};
is noun(q{yourself})->classical->plural,   q{yourselves}  => q{classical plural: 'yourself' --> 'yourselves'};
is noun(q{yourselves})->classical->plural, q{yourselves}  => q{classical plural: 'yourselves' --> 'yourselves'};
is noun(q{lepton})->classical->plural,   q{lepta}  => q{classical plural: 'lepton' --> 'lepta'};
is noun(q{lepta})->classical->plural, q{lepta}  => q{classical plural: 'lepta' --> 'lepta'};
is noun(q{centesimo})->classical->plural,   q{centesimi}  => q{classical plural: 'centesimo' --> 'centesimi'};
is noun(q{centesimi})->classical->plural, q{centesimi}  => q{classical plural: 'centesimi' --> 'centesimi'};
is noun(q{cyphella})->classical->plural,   q{cyphellae}  => q{classical plural: 'cyphella' --> 'cyphellae'};
is noun(q{cyphellae})->classical->plural, q{cyphellae}  => q{classical plural: 'cyphellae' --> 'cyphellae'};
is noun(q{branchiopod})->classical->plural,   q{branchiopoda}  => q{classical plural: 'branchiopod' --> 'branchiopoda'};
is noun(q{branchiopoda})->classical->plural, q{branchiopoda}  => q{classical plural: 'branchiopoda' --> 'branchiopoda'};
is noun(q{foot})->classical->plural,   q{feet}  => q{classical plural: 'foot' --> 'feet'};
is noun(q{feet})->classical->plural, q{feet}  => q{classical plural: 'feet' --> 'feet'};
is noun(q{tropaeolum})->classical->plural,   q{tropaeola}  => q{classical plural: 'tropaeolum' --> 'tropaeola'};
is noun(q{tropaeola})->classical->plural, q{tropaeola}  => q{classical plural: 'tropaeola' --> 'tropaeola'};
is noun(q{star fish})->classical->plural,   q{star fish}  => q{classical plural: 'star fish' --> 'star fish'};
is noun(q{hypoderma})->classical->plural,   q{hypodermata}  => q{classical plural: 'hypoderma' --> 'hypodermata'};
is noun(q{hypodermata})->classical->plural, q{hypodermata}  => q{classical plural: 'hypodermata' --> 'hypodermata'};
is noun(q{neuroma})->classical->plural,   q{neuromata}  => q{classical plural: 'neuroma' --> 'neuromata'};
is noun(q{neuromata})->classical->plural, q{neuromata}  => q{classical plural: 'neuromata' --> 'neuromata'};
is noun(q{tetrapleuron})->classical->plural,   q{tetrapleura}  => q{classical plural: 'tetrapleuron' --> 'tetrapleura'};
is noun(q{tetrapleura})->classical->plural, q{tetrapleura}  => q{classical plural: 'tetrapleura' --> 'tetrapleura'};
is noun(q{Senegalese})->classical->plural,   q{Senegalese}  => q{classical plural: 'Senegalese' --> 'Senegalese'};
is noun(q{whatever})->classical->plural,   q{whatever}  => q{classical plural: 'whatever' --> 'whatever'};
is noun(q{podium})->classical->plural,   q{podia}  => q{classical plural: 'podium' --> 'podia'};
is noun(q{podia})->classical->plural, q{podia}  => q{classical plural: 'podia' --> 'podia'};
is noun(q{thalamos})->classical->plural,   q{thalamoi}  => q{classical plural: 'thalamos' --> 'thalamoi'};
is noun(q{thalamoi})->classical->plural, q{thalamoi}  => q{classical plural: 'thalamoi' --> 'thalamoi'};
is noun(q{anlage})->classical->plural,   q{anlagen}  => q{classical plural: 'anlage' --> 'anlagen'};
is noun(q{anlagen})->classical->plural, q{anlagen}  => q{classical plural: 'anlagen' --> 'anlagen'};
is noun(q{chromidium})->classical->plural,   q{chromidia}  => q{classical plural: 'chromidium' --> 'chromidia'};
is noun(q{chromidia})->classical->plural, q{chromidia}  => q{classical plural: 'chromidia' --> 'chromidia'};
is noun(q{spiculum})->classical->plural,   q{spicula}  => q{classical plural: 'spiculum' --> 'spicula'};
is noun(q{spicula})->classical->plural, q{spicula}  => q{classical plural: 'spicula' --> 'spicula'};
is noun(q{frustum})->classical->plural,   q{frusta}  => q{classical plural: 'frustum' --> 'frusta'};
is noun(q{frusta})->classical->plural, q{frusta}  => q{classical plural: 'frusta' --> 'frusta'};
is noun(q{dolman})->classical->plural,   q{dolmans}  => q{classical plural: 'dolman' --> 'dolmans'};
is noun(q{dolmans})->classical->plural, q{dolmans}  => q{classical plural: 'dolmans' --> 'dolmans'};
is noun(q{crafts-child})->classical->plural,   q{crafts-childer}  => q{classical plural: 'crafts-child' --> 'crafts-childer'};
is noun(q{crafts-childer})->classical->plural, q{crafts-childer}  => q{classical plural: 'crafts-childer' --> 'crafts-childer'};
is noun(q{humerus})->classical->plural,   q{humeri}  => q{classical plural: 'humerus' --> 'humeri'};
is noun(q{humeri})->classical->plural, q{humeri}  => q{classical plural: 'humeri' --> 'humeri'};
is noun(q{amicus curiae})->classical->plural,   q{amici curiae}  => q{classical plural: 'amicus curiae' --> 'amici curiae'};
is noun(q{amici curiae})->classical->plural, q{amici curiae}  => q{classical plural: 'amici curiae' --> 'amici curiae'};
is noun(q{prosopium})->classical->plural,   q{prosopia}  => q{classical plural: 'prosopium' --> 'prosopia'};
is noun(q{prosopia})->classical->plural, q{prosopia}  => q{classical plural: 'prosopia' --> 'prosopia'};
is noun(q{columna})->classical->plural,   q{columnae}  => q{classical plural: 'columna' --> 'columnae'};
is noun(q{columnae})->classical->plural, q{columnae}  => q{classical plural: 'columnae' --> 'columnae'};
is noun(q{potato})->classical->plural,   q{potatoes}  => q{classical plural: 'potato' --> 'potatoes'};
is noun(q{potatoes})->classical->plural, q{potatoes}  => q{classical plural: 'potatoes' --> 'potatoes'};
is noun(q{redia})->classical->plural,   q{rediae}  => q{classical plural: 'redia' --> 'rediae'};
is noun(q{rediae})->classical->plural, q{rediae}  => q{classical plural: 'rediae' --> 'rediae'};
is noun(q{treponema})->classical->plural,   q{treponemata}  => q{classical plural: 'treponema' --> 'treponemata'};
is noun(q{treponemata})->classical->plural, q{treponemata}  => q{classical plural: 'treponemata' --> 'treponemata'};
is noun(q{nouvel arrive})->classical->plural,   q{nouveaux arrives}  => q{classical plural: 'nouvel arrive' --> 'nouveaux arrives'};
is noun(q{nouveaux arrives})->classical->plural, q{nouveaux arrives}  => q{classical plural: 'nouveaux arrives' --> 'nouveaux arrives'};
is noun(q{stratum})->classical->plural,   q{strata}  => q{classical plural: 'stratum' --> 'strata'};
is noun(q{strata})->classical->plural, q{strata}  => q{classical plural: 'strata' --> 'strata'};
is noun(q{talea})->classical->plural,   q{taleae}  => q{classical plural: 'talea' --> 'taleae'};
is noun(q{taleae})->classical->plural, q{taleae}  => q{classical plural: 'taleae' --> 'taleae'};
is noun(q{commanding general})->classical->plural,   q{commanding generals}  => q{classical plural: 'commanding general' --> 'commanding generals'};
is noun(q{commanding generals})->classical->plural, q{commanding generals}  => q{classical plural: 'commanding generals' --> 'commanding generals'};
is noun(q{Oslo})->classical->plural,   q{Oslos}  => q{classical plural: 'Oslo' --> 'Oslos'};
is noun(q{Oslos})->classical->plural, q{Oslos}  => q{classical plural: 'Oslos' --> 'Oslos'};
is noun(q{villino})->classical->plural,   q{villini}  => q{classical plural: 'villino' --> 'villini'};
is noun(q{villini})->classical->plural, q{villini}  => q{classical plural: 'villini' --> 'villini'};
is noun(q{mucro})->classical->plural,   q{mucrones}  => q{classical plural: 'mucro' --> 'mucrones'};
is noun(q{mucrones})->classical->plural, q{mucrones}  => q{classical plural: 'mucrones' --> 'mucrones'};
is noun(q{temblor})->classical->plural,   q{temblores}  => q{classical plural: 'temblor' --> 'temblores'};
is noun(q{temblores})->classical->plural, q{temblores}  => q{classical plural: 'temblores' --> 'temblores'};
is noun(q{crusta})->classical->plural,   q{crustae}  => q{classical plural: 'crusta' --> 'crustae'};
is noun(q{crustae})->classical->plural, q{crustae}  => q{classical plural: 'crustae' --> 'crustae'};
is noun(q{pinetum})->classical->plural,   q{pineta}  => q{classical plural: 'pinetum' --> 'pineta'};
is noun(q{pineta})->classical->plural, q{pineta}  => q{classical plural: 'pineta' --> 'pineta'};
is noun(q{endothelioma})->classical->plural,   q{endotheliomata}  => q{classical plural: 'endothelioma' --> 'endotheliomata'};
is noun(q{endotheliomata})->classical->plural, q{endotheliomata}  => q{classical plural: 'endotheliomata' --> 'endotheliomata'};
is noun(q{sternum})->classical->plural,   q{sterna}  => q{classical plural: 'sternum' --> 'sterna'};
is noun(q{sterna})->classical->plural, q{sterna}  => q{classical plural: 'sterna' --> 'sterna'};
is noun(q{bison})->classical->plural,   q{bison}  => q{classical plural: 'bison' --> 'bison'};
is noun(q{furfur})->classical->plural,   q{furfures}  => q{classical plural: 'furfur' --> 'furfures'};
is noun(q{furfures})->classical->plural, q{furfures}  => q{classical plural: 'furfures' --> 'furfures'};
is noun(q{tyro})->classical->plural,   q{tyros}  => q{classical plural: 'tyro' --> 'tyros'};
is noun(q{tyros})->classical->plural, q{tyros}  => q{classical plural: 'tyros' --> 'tyros'};
is noun(q{thaumaturgus})->classical->plural,   q{thaumaturgi}  => q{classical plural: 'thaumaturgus' --> 'thaumaturgi'};
is noun(q{thaumaturgi})->classical->plural, q{thaumaturgi}  => q{classical plural: 'thaumaturgi' --> 'thaumaturgi'};
is noun(q{tortilla espanola})->classical->plural,   q{tortillas espanolas}  => q{classical plural: 'tortilla espanola' --> 'tortillas espanolas'};
is noun(q{tortillas espanolas})->classical->plural, q{tortillas espanolas}  => q{classical plural: 'tortillas espanolas' --> 'tortillas espanolas'};
is noun(q{gastrocnemius})->classical->plural,   q{gastrocnemii}  => q{classical plural: 'gastrocnemius' --> 'gastrocnemii'};
is noun(q{gastrocnemii})->classical->plural, q{gastrocnemii}  => q{classical plural: 'gastrocnemii' --> 'gastrocnemii'};
is noun(q{uraeus})->classical->plural,   q{uraei}  => q{classical plural: 'uraeus' --> 'uraei'};
is noun(q{uraei})->classical->plural, q{uraei}  => q{classical plural: 'uraei' --> 'uraei'};
is noun(q{premier danseur})->classical->plural,   q{premiers danseurs}  => q{classical plural: 'premier danseur' --> 'premiers danseurs'};
is noun(q{premiers danseurs})->classical->plural, q{premiers danseurs}  => q{classical plural: 'premiers danseurs' --> 'premiers danseurs'};
is noun(q{Hunanese})->classical->plural,   q{Hunanese}  => q{classical plural: 'Hunanese' --> 'Hunanese'};
is noun(q{Lucchese})->classical->plural,   q{Lucchese}  => q{classical plural: 'Lucchese' --> 'Lucchese'};
is noun(q{sperma})->classical->plural,   q{spermata}  => q{classical plural: 'sperma' --> 'spermata'};
is noun(q{spermata})->classical->plural, q{spermata}  => q{classical plural: 'spermata' --> 'spermata'};
is noun(q{taxon})->classical->plural,   q{taxa}  => q{classical plural: 'taxon' --> 'taxa'};
is noun(q{taxa})->classical->plural, q{taxa}  => q{classical plural: 'taxa' --> 'taxa'};
is noun(q{chintz})->classical->plural,   q{chintzes}  => q{classical plural: 'chintz' --> 'chintzes'};
is noun(q{chintzes})->classical->plural, q{chintzes}  => q{classical plural: 'chintzes' --> 'chintzes'};
is noun(q{paisa})->classical->plural,   q{paise}  => q{classical plural: 'paisa' --> 'paise'};
is noun(q{paise})->classical->plural, q{paise}  => q{classical plural: 'paise' --> 'paise'};
is noun(q{parapsis})->classical->plural,   q{parapsides}  => q{classical plural: 'parapsis' --> 'parapsides'};
is noun(q{parapsides})->classical->plural, q{parapsides}  => q{classical plural: 'parapsides' --> 'parapsides'};
is noun(q{hemelytrum})->classical->plural,   q{hemelytra}  => q{classical plural: 'hemelytrum' --> 'hemelytra'};
is noun(q{hemelytra})->classical->plural, q{hemelytra}  => q{classical plural: 'hemelytra' --> 'hemelytra'};
is noun(q{terebellum})->classical->plural,   q{terebella}  => q{classical plural: 'terebellum' --> 'terebella'};
is noun(q{terebella})->classical->plural, q{terebella}  => q{classical plural: 'terebella' --> 'terebella'};
is noun(q{improvisatrice})->classical->plural,   q{improvisatrici}  => q{classical plural: 'improvisatrice' --> 'improvisatrici'};
is noun(q{improvisatrici})->classical->plural, q{improvisatrici}  => q{classical plural: 'improvisatrici' --> 'improvisatrici'};
is noun(q{seminium})->classical->plural,   q{seminia}  => q{classical plural: 'seminium' --> 'seminia'};
is noun(q{seminia})->classical->plural, q{seminia}  => q{classical plural: 'seminia' --> 'seminia'};
is noun(q{court-martial})->classical->plural,   q{courts-martial}  => q{classical plural: 'court-martial' --> 'courts-martial'};
is noun(q{courts-martial})->classical->plural, q{courts-martial}  => q{classical plural: 'courts-martial' --> 'courts-martial'};
is noun(q{veg})->classical->plural,   q{veg}  => q{classical plural: 'veg' --> 'veg'};
is noun(q{asbestos})->classical->plural,   q{asbestoses}  => q{classical plural: 'asbestos' --> 'asbestoses'};
is noun(q{asbestoses})->classical->plural, q{asbestoses}  => q{classical plural: 'asbestoses' --> 'asbestoses'};
is noun(q{quadratrix})->classical->plural,   q{quadratrices}  => q{classical plural: 'quadratrix' --> 'quadratrices'};
is noun(q{quadratrices})->classical->plural, q{quadratrices}  => q{classical plural: 'quadratrices' --> 'quadratrices'};
is noun(q{aquarium})->classical->plural,   q{aquaria}  => q{classical plural: 'aquarium' --> 'aquaria'};
is noun(q{aquaria})->classical->plural, q{aquaria}  => q{classical plural: 'aquaria' --> 'aquaria'};
is noun(q{him})->classical->plural,   q{them}  => q{classical plural: 'him' --> 'them'};
is noun(q{palpus})->classical->plural,   q{palpi}  => q{classical plural: 'palpus' --> 'palpi'};
is noun(q{palpi})->classical->plural, q{palpi}  => q{classical plural: 'palpi' --> 'palpi'};
is noun(q{so})->classical->plural,   q{soes}  => q{classical plural: 'so' --> 'soes'};
is noun(q{soes})->classical->plural, q{soes}  => q{classical plural: 'soes' --> 'soes'};
is noun(q{stichidium})->classical->plural,   q{stichidia}  => q{classical plural: 'stichidium' --> 'stichidia'};
is noun(q{stichidia})->classical->plural, q{stichidia}  => q{classical plural: 'stichidia' --> 'stichidia'};
is noun(q{lemur})->classical->plural,   q{lemures}  => q{classical plural: 'lemur' --> 'lemures'};
is noun(q{lemures})->classical->plural, q{lemures}  => q{classical plural: 'lemures' --> 'lemures'};
is noun(q{nebula})->classical->plural,   q{nebulae}  => q{classical plural: 'nebula' --> 'nebulae'};
is noun(q{nebulae})->classical->plural, q{nebulae}  => q{classical plural: 'nebulae' --> 'nebulae'};
is noun(q{vibrio})->classical->plural,   q{vibriones}  => q{classical plural: 'vibrio' --> 'vibriones'};
is noun(q{vibriones})->classical->plural, q{vibriones}  => q{classical plural: 'vibriones' --> 'vibriones'};
is noun(q{ambuscado})->classical->plural,   q{ambuscadoes}  => q{classical plural: 'ambuscado' --> 'ambuscadoes'};
is noun(q{ambuscadoes})->classical->plural, q{ambuscadoes}  => q{classical plural: 'ambuscadoes' --> 'ambuscadoes'};
is noun(q{cyano})->classical->plural,   q{cyanos}  => q{classical plural: 'cyano' --> 'cyanos'};
is noun(q{cyanos})->classical->plural, q{cyanos}  => q{classical plural: 'cyanos' --> 'cyanos'};
is noun(q{gliosarcoma})->classical->plural,   q{gliosarcomata}  => q{classical plural: 'gliosarcoma' --> 'gliosarcomata'};
is noun(q{gliosarcomata})->classical->plural, q{gliosarcomata}  => q{classical plural: 'gliosarcomata' --> 'gliosarcomata'};
is noun(q{Sienese})->classical->plural,   q{Sienese}  => q{classical plural: 'Sienese' --> 'Sienese'};
is noun(q{zygon})->classical->plural,   q{zyga}  => q{classical plural: 'zygon' --> 'zyga'};
is noun(q{zyga})->classical->plural, q{zyga}  => q{classical plural: 'zyga' --> 'zyga'};
is noun(q{Foochowese})->classical->plural,   q{Foochowese}  => q{classical plural: 'Foochowese' --> 'Foochowese'};
is noun(q{stella})->classical->plural,   q{stellae}  => q{classical plural: 'stella' --> 'stellae'};
is noun(q{stellae})->classical->plural, q{stellae}  => q{classical plural: 'stellae' --> 'stellae'};
is noun(q{suggestum})->classical->plural,   q{suggesta}  => q{classical plural: 'suggestum' --> 'suggesta'};
is noun(q{suggesta})->classical->plural, q{suggesta}  => q{classical plural: 'suggesta' --> 'suggesta'};
is noun(q{sterno})->classical->plural,   q{sternos}  => q{classical plural: 'sterno' --> 'sternos'};
is noun(q{sternos})->classical->plural, q{sternos}  => q{classical plural: 'sternos' --> 'sternos'};
is noun(q{one star general})->classical->plural,   q{one star generals}  => q{classical plural: 'one star general' --> 'one star generals'};
is noun(q{one star generals})->classical->plural, q{one star generals}  => q{classical plural: 'one star generals' --> 'one star generals'};
is noun(q{stadium})->classical->plural,   q{stadia}  => q{classical plural: 'stadium' --> 'stadia'};
is noun(q{stadia})->classical->plural, q{stadia}  => q{classical plural: 'stadia' --> 'stadia'};
is noun(q{ado})->classical->plural,   q{ados}  => q{classical plural: 'ado' --> 'ados'};
is noun(q{ados})->classical->plural, q{ados}  => q{classical plural: 'ados' --> 'ados'};
is noun(q{pteryla})->classical->plural,   q{pterylae}  => q{classical plural: 'pteryla' --> 'pterylae'};
is noun(q{pterylae})->classical->plural, q{pterylae}  => q{classical plural: 'pterylae' --> 'pterylae'};
is noun(q{gigolo})->classical->plural,   q{gigolos}  => q{classical plural: 'gigolo' --> 'gigolos'};
is noun(q{gigolos})->classical->plural, q{gigolos}  => q{classical plural: 'gigolos' --> 'gigolos'};
is noun(q{po})->classical->plural,   q{poes}  => q{classical plural: 'po' --> 'poes'};
is noun(q{poes})->classical->plural, q{poes}  => q{classical plural: 'poes' --> 'poes'};
is noun(q{hordeolum})->classical->plural,   q{hordeola}  => q{classical plural: 'hordeolum' --> 'hordeola'};
is noun(q{hordeola})->classical->plural, q{hordeola}  => q{classical plural: 'hordeola' --> 'hordeola'};
is noun(q{lustrum})->classical->plural,   q{lustra}  => q{classical plural: 'lustrum' --> 'lustra'};
is noun(q{lustra})->classical->plural, q{lustra}  => q{classical plural: 'lustra' --> 'lustra'};
is noun(q{stela})->classical->plural,   q{stelae}  => q{classical plural: 'stela' --> 'stelae'};
is noun(q{stelae})->classical->plural, q{stelae}  => q{classical plural: 'stelae' --> 'stelae'};
is noun(q{sententia})->classical->plural,   q{sententiae}  => q{classical plural: 'sententia' --> 'sententiae'};
is noun(q{sententiae})->classical->plural, q{sententiae}  => q{classical plural: 'sententiae' --> 'sententiae'};
is noun(q{carp})->classical->plural,   q{carp}  => q{classical plural: 'carp' --> 'carp'};
is noun(q{torula})->classical->plural,   q{torulae}  => q{classical plural: 'torula' --> 'torulae'};
is noun(q{torulae})->classical->plural, q{torulae}  => q{classical plural: 'torulae' --> 'torulae'};
is noun(q{prosula})->classical->plural,   q{prosulae}  => q{classical plural: 'prosula' --> 'prosulae'};
is noun(q{prosulae})->classical->plural, q{prosulae}  => q{classical plural: 'prosulae' --> 'prosulae'};
is noun(q{Kinkimavo})->classical->plural,   q{Kinkimavos}  => q{classical plural: 'Kinkimavo' --> 'Kinkimavos'};
is noun(q{Kinkimavos})->classical->plural, q{Kinkimavos}  => q{classical plural: 'Kinkimavos' --> 'Kinkimavos'};
is noun(q{breeches})->classical->plural,   q{breeches}  => q{classical plural: 'breeches' --> 'breeches'};
is noun(q{hoe})->classical->plural,   q{hoes}  => q{classical plural: 'hoe' --> 'hoes'};
is noun(q{hoes})->classical->plural, q{hoes}  => q{classical plural: 'hoes' --> 'hoes'};
is noun(q{teredo})->classical->plural,   q{teredines}  => q{classical plural: 'teredo' --> 'teredines'};
is noun(q{teredines})->classical->plural, q{teredines}  => q{classical plural: 'teredines' --> 'teredines'};
is noun(q{interphenomenon})->classical->plural,   q{interphenomena}  => q{classical plural: 'interphenomenon' --> 'interphenomena'};
is noun(q{interphenomena})->classical->plural, q{interphenomena}  => q{classical plural: 'interphenomena' --> 'interphenomena'};
is noun(q{tentamen})->classical->plural,   q{tentamina}  => q{classical plural: 'tentamen' --> 'tentamina'};
is noun(q{tentamina})->classical->plural, q{tentamina}  => q{classical plural: 'tentamina' --> 'tentamina'};
is noun(q{graffito})->classical->plural,   q{graffiti}  => q{classical plural: 'graffito' --> 'graffiti'};
is noun(q{trichoma})->classical->plural,   q{trichomata}  => q{classical plural: 'trichoma' --> 'trichomata'};
is noun(q{trichomata})->classical->plural, q{trichomata}  => q{classical plural: 'trichomata' --> 'trichomata'};
is noun(q{person})->classical->plural,   q{persons}  => q{classical plural: 'person' --> 'persons'};
is noun(q{persons})->classical->plural, q{persons}  => q{classical plural: 'persons' --> 'persons'};
is noun(q{pyjamas})->classical->plural,   q{pyjamas}  => q{classical plural: 'pyjamas' --> 'pyjamas'};
is noun(q{persona})->classical->plural,   q{personae}  => q{classical plural: 'persona' --> 'personae'};
is noun(q{personae})->classical->plural, q{personae}  => q{classical plural: 'personae' --> 'personae'};
is noun(q{jumbo})->classical->plural,   q{jumbos}  => q{classical plural: 'jumbo' --> 'jumbos'};
is noun(q{jumbos})->classical->plural, q{jumbos}  => q{classical plural: 'jumbos' --> 'jumbos'};
is noun(q{proviso})->classical->plural,   q{provisoes}  => q{classical plural: 'proviso' --> 'provisoes'};
is noun(q{provisoes})->classical->plural, q{provisoes}  => q{classical plural: 'provisoes' --> 'provisoes'};
is noun(q{protonema})->classical->plural,   q{protonemata}  => q{classical plural: 'protonema' --> 'protonemata'};
is noun(q{protonemata})->classical->plural, q{protonemata}  => q{classical plural: 'protonemata' --> 'protonemata'};
is noun(q{speculum})->classical->plural,   q{specula}  => q{classical plural: 'speculum' --> 'specula'};
is noun(q{specula})->classical->plural, q{specula}  => q{classical plural: 'specula' --> 'specula'};
is noun(q{purlieu})->classical->plural,   q{purlieux}  => q{classical plural: 'purlieu' --> 'purlieux'};
is noun(q{purlieux})->classical->plural, q{purlieux}  => q{classical plural: 'purlieux' --> 'purlieux'};
is noun(q{minnelied})->classical->plural,   q{minnelieder}  => q{classical plural: 'minnelied' --> 'minnelieder'};
is noun(q{minnelieder})->classical->plural, q{minnelieder}  => q{classical plural: 'minnelieder' --> 'minnelieder'};
is noun(q{virtuoso})->classical->plural,   q{virtuosi}  => q{classical plural: 'virtuoso' --> 'virtuosi'};
is noun(q{virtuosi})->classical->plural, q{virtuosi}  => q{classical plural: 'virtuosi' --> 'virtuosi'};
is noun(q{line-out})->classical->plural,   q{lines-out}  => q{classical plural: 'line-out' --> 'lines-out'};
is noun(q{lines-out})->classical->plural, q{lines-out}  => q{classical plural: 'lines-out' --> 'lines-out'};
is noun(q{codex})->classical->plural,   q{codices}  => q{classical plural: 'codex' --> 'codices'};
is noun(q{codices})->classical->plural, q{codices}  => q{classical plural: 'codices' --> 'codices'};
is noun(q{nodum})->classical->plural,   q{noda}  => q{classical plural: 'nodum' --> 'noda'};
is noun(q{noda})->classical->plural, q{noda}  => q{classical plural: 'noda' --> 'noda'};
is noun(q{this})->classical->plural,   q{these}  => q{classical plural: 'this' --> 'these'};
is noun(q{these})->classical->plural, q{these}  => q{classical plural: 'these' --> 'these'};
is noun(q{lox})->classical->plural,   q{lox}  => q{classical plural: 'lox' --> 'lox'};
is noun(q{Bengalese})->classical->plural,   q{Bengalese}  => q{classical plural: 'Bengalese' --> 'Bengalese'};
is noun(q{caulis})->classical->plural,   q{caules}  => q{classical plural: 'caulis' --> 'caules'};
is noun(q{caules})->classical->plural, q{caules}  => q{classical plural: 'caules' --> 'caules'};
is noun(q{blin})->classical->plural,   q{blini}  => q{classical plural: 'blin' --> 'blini'};
is noun(q{blini})->classical->plural, q{blini}  => q{classical plural: 'blini' --> 'blini'};
is noun(q{Pekingese})->classical->plural,   q{Pekingese}  => q{classical plural: 'Pekingese' --> 'Pekingese'};
is noun(q{seraph})->classical->plural,   q{seraphim}  => q{classical plural: 'seraph' --> 'seraphim'};
is noun(q{seraphim})->classical->plural, q{seraphim}  => q{classical plural: 'seraphim' --> 'seraphim'};
is noun(q{chorda})->classical->plural,   q{chordae}  => q{classical plural: 'chorda' --> 'chordae'};
is noun(q{chordae})->classical->plural, q{chordae}  => q{classical plural: 'chordae' --> 'chordae'};
is noun(q{tibia})->classical->plural,   q{tibiae}  => q{classical plural: 'tibia' --> 'tibiae'};
is noun(q{tibiae})->classical->plural, q{tibiae}  => q{classical plural: 'tibiae' --> 'tibiae'};
is noun(q{themselves})->classical->plural,   q{themselves}  => q{classical plural: 'themselves' --> 'themselves'};
is noun(q{sphinx})->classical->plural,   q{sphinges}  => q{classical plural: 'sphinx' --> 'sphinges'};
is noun(q{sphinges})->classical->plural, q{sphinges}  => q{classical plural: 'sphinges' --> 'sphinges'};
is noun(q{Siamese})->classical->plural,   q{Siamese}  => q{classical plural: 'Siamese' --> 'Siamese'};
is noun(q{superficies})->classical->plural,   q{superficies}  => q{classical plural: 'superficies' --> 'superficies'};
is noun(q{emblema})->classical->plural,   q{emblememata}  => q{classical plural: 'emblema' --> 'emblememata'};
is noun(q{emblememata})->classical->plural, q{emblememata}  => q{classical plural: 'emblememata' --> 'emblememata'};
is noun(q{multigravida})->classical->plural,   q{multigravidae}  => q{classical plural: 'multigravida' --> 'multigravidae'};
is noun(q{multigravidae})->classical->plural, q{multigravidae}  => q{classical plural: 'multigravidae' --> 'multigravidae'};
is noun(q{angustia})->classical->plural,   q{angustiae}  => q{classical plural: 'angustia' --> 'angustiae'};
is noun(q{angustiae})->classical->plural, q{angustiae}  => q{classical plural: 'angustiae' --> 'angustiae'};
is noun(q{congius})->classical->plural,   q{congii}  => q{classical plural: 'congius' --> 'congii'};
is noun(q{congii})->classical->plural, q{congii}  => q{classical plural: 'congii' --> 'congii'};
is noun(q{yo})->classical->plural,   q{yoes}  => q{classical plural: 'yo' --> 'yoes'};
is noun(q{yoes})->classical->plural, q{yoes}  => q{classical plural: 'yoes' --> 'yoes'};
is noun(q{nouveau riche})->classical->plural,   q{nouveaux riches}  => q{classical plural: 'nouveau riche' --> 'nouveaux riches'};
is noun(q{nouveaux riches})->classical->plural, q{nouveaux riches}  => q{classical plural: 'nouveaux riches' --> 'nouveaux riches'};
is noun(q{proglottis})->classical->plural,   q{proglottides}  => q{classical plural: 'proglottis' --> 'proglottides'};
is noun(q{proglottides})->classical->plural, q{proglottides}  => q{classical plural: 'proglottides' --> 'proglottides'};
is noun(q{sensum})->classical->plural,   q{sensa}  => q{classical plural: 'sensum' --> 'sensa'};
is noun(q{sensa})->classical->plural, q{sensa}  => q{classical plural: 'sensa' --> 'sensa'};
is noun(q{moe})->classical->plural,   q{moes}  => q{classical plural: 'moe' --> 'moes'};
is noun(q{moes})->classical->plural, q{moes}  => q{classical plural: 'moes' --> 'moes'};
is noun(q{proprium})->classical->plural,   q{propria}  => q{classical plural: 'proprium' --> 'propria'};
is noun(q{propria})->classical->plural, q{propria}  => q{classical plural: 'propria' --> 'propria'};
is noun(q{cardo})->classical->plural,   q{cardines}  => q{classical plural: 'cardo' --> 'cardines'};
is noun(q{cardines})->classical->plural, q{cardines}  => q{classical plural: 'cardines' --> 'cardines'};
is noun(q{terrazzo})->classical->plural,   q{terrazzos}  => q{classical plural: 'terrazzo' --> 'terrazzos'};
is noun(q{terrazzos})->classical->plural, q{terrazzos}  => q{classical plural: 'terrazzos' --> 'terrazzos'};
is noun(q{ossiculum})->classical->plural,   q{ossicula}  => q{classical plural: 'ossiculum' --> 'ossicula'};
is noun(q{ossicula})->classical->plural, q{ossicula}  => q{classical plural: 'ossicula' --> 'ossicula'};
is noun(q{Sangirese})->classical->plural,   q{Sangirese}  => q{classical plural: 'Sangirese' --> 'Sangirese'};
is noun(q{Rom})->classical->plural,   q{Roma}  => q{classical plural: 'Rom' --> 'Roma'};
is noun(q{Roma})->classical->plural, q{Roma}  => q{classical plural: 'Roma' --> 'Roma'};
is noun(q{adviso})->classical->plural,   q{advisoes}  => q{classical plural: 'adviso' --> 'advisoes'};
is noun(q{advisoes})->classical->plural, q{advisoes}  => q{classical plural: 'advisoes' --> 'advisoes'};
is noun(q{1 star general})->classical->plural,   q{1 star generals}  => q{classical plural: '1 star general' --> '1 star generals'};
is noun(q{1 star generals})->classical->plural, q{1 star generals}  => q{classical plural: '1 star generals' --> '1 star generals'};
is noun(q{Porto})->classical->plural,   q{Portos}  => q{classical plural: 'Porto' --> 'Portos'};
is noun(q{Portos})->classical->plural, q{Portos}  => q{classical plural: 'Portos' --> 'Portos'};
is noun(q{ghetto})->classical->plural,   q{ghettos}  => q{classical plural: 'ghetto' --> 'ghettos'};
is noun(q{ghettos})->classical->plural, q{ghettos}  => q{classical plural: 'ghettos' --> 'ghettos'};
is noun(q{sulcus})->classical->plural,   q{sulci}  => q{classical plural: 'sulcus' --> 'sulci'};
is noun(q{sulci})->classical->plural, q{sulci}  => q{classical plural: 'sulci' --> 'sulci'};
is noun(q{corgy})->classical->plural,   q{corgwn}  => q{classical plural: 'corgy' --> 'corgwn'};
is noun(q{corgwn})->classical->plural, q{corgwn}  => q{classical plural: 'corgwn' --> 'corgwn'};
is noun(q{fomes})->classical->plural,   q{fomites}  => q{classical plural: 'fomes' --> 'fomites'};
is noun(q{fomites})->classical->plural, q{fomites}  => q{classical plural: 'fomites' --> 'fomites'};
is noun(q{you})->classical->plural,   q{you}  => q{classical plural: 'you' --> 'you'};
is noun(q{pickerel})->classical->plural,   q{pickerel}  => q{classical plural: 'pickerel' --> 'pickerel'};
is noun(q{piano})->classical->plural,   q{piani}  => q{classical plural: 'piano' --> 'piani'};
is noun(q{piani})->classical->plural, q{piani}  => q{classical plural: 'piani' --> 'piani'};
is noun(q{Genoese})->classical->plural,   q{Genoese}  => q{classical plural: 'Genoese' --> 'Genoese'};
is noun(q{sertularia})->classical->plural,   q{sertulariae}  => q{classical plural: 'sertularia' --> 'sertulariae'};
is noun(q{sertulariae})->classical->plural, q{sertulariae}  => q{classical plural: 'sertulariae' --> 'sertulariae'};
is noun(q{tooth})->classical->plural,   q{teeth}  => q{classical plural: 'tooth' --> 'teeth'};
is noun(q{teeth})->classical->plural, q{teeth}  => q{classical plural: 'teeth' --> 'teeth'};
is noun(q{lebensform})->classical->plural,   q{lebensformen}  => q{classical plural: 'lebensform' --> 'lebensformen'};
is noun(q{lebensformen})->classical->plural, q{lebensformen}  => q{classical plural: 'lebensformen' --> 'lebensformen'};
is noun(q{xystus})->classical->plural,   q{xysti}  => q{classical plural: 'xystus' --> 'xysti'};
is noun(q{xysti})->classical->plural, q{xysti}  => q{classical plural: 'xysti' --> 'xysti'};
is noun(q{principium})->classical->plural,   q{principia}  => q{classical plural: 'principium' --> 'principia'};
is noun(q{principia})->classical->plural, q{principia}  => q{classical plural: 'principia' --> 'principia'};
is noun(q{Goanese})->classical->plural,   q{Goanese}  => q{classical plural: 'Goanese' --> 'Goanese'};
is noun(q{shaman})->classical->plural,   q{shamans}  => q{classical plural: 'shaman' --> 'shamans'};
is noun(q{shamans})->classical->plural, q{shamans}  => q{classical plural: 'shamans' --> 'shamans'};
is noun(q{zooea})->classical->plural,   q{zooeae}  => q{classical plural: 'zooea' --> 'zooeae'};
is noun(q{zooeae})->classical->plural, q{zooeae}  => q{classical plural: 'zooeae' --> 'zooeae'};
is noun(q{Nankingese})->classical->plural,   q{Nankingese}  => q{classical plural: 'Nankingese' --> 'Nankingese'};
is noun(q{Maracaibo})->classical->plural,   q{Maracaibos}  => q{classical plural: 'Maracaibo' --> 'Maracaibos'};
is noun(q{Maracaibos})->classical->plural, q{Maracaibos}  => q{classical plural: 'Maracaibos' --> 'Maracaibos'};
is noun(q{taxis})->classical->plural,   q{taxes}  => q{classical plural: 'taxis' --> 'taxes'};
is noun(q{taxes})->classical->plural, q{taxes}  => q{classical plural: 'taxes' --> 'taxes'};
is noun(q{lino})->classical->plural,   q{linos}  => q{classical plural: 'lino' --> 'linos'};
is noun(q{linos})->classical->plural, q{linos}  => q{classical plural: 'linos' --> 'linos'};
is noun(q{zemirah})->classical->plural,   q{zemirot}  => q{classical plural: 'zemirah' --> 'zemirot'};
is noun(q{zemirot})->classical->plural, q{zemirot}  => q{classical plural: 'zemirot' --> 'zemirot'};
is noun(q{paraglossa})->classical->plural,   q{paraglossae}  => q{classical plural: 'paraglossa' --> 'paraglossae'};
is noun(q{paraglossae})->classical->plural, q{paraglossae}  => q{classical plural: 'paraglossae' --> 'paraglossae'};
is noun(q{myself})->classical->plural,   q{ourselves}  => q{classical plural: 'myself' --> 'ourselves'};
is noun(q{ourselves})->classical->plural, q{ourselves}  => q{classical plural: 'ourselves' --> 'ourselves'};
is noun(q{cyclops})->classical->plural,   q{cyclopes}  => q{classical plural: 'cyclops' --> 'cyclopes'};
is noun(q{cyclopes})->classical->plural, q{cyclopes}  => q{classical plural: 'cyclopes' --> 'cyclopes'};
is noun(q{pseudostoma})->classical->plural,   q{pseudostomata}  => q{classical plural: 'pseudostoma' --> 'pseudostomata'};
is noun(q{pseudostomata})->classical->plural, q{pseudostomata}  => q{classical plural: 'pseudostomata' --> 'pseudostomata'};
is noun(q{autostrada})->classical->plural,   q{autostrade}  => q{classical plural: 'autostrada' --> 'autostrade'};
is noun(q{autostrade})->classical->plural, q{autostrade}  => q{classical plural: 'autostrade' --> 'autostrade'};
is noun(q{four-star general})->classical->plural,   q{four-star generals}  => q{classical plural: 'four-star general' --> 'four-star generals'};
is noun(q{four-star generals})->classical->plural, q{four-star generals}  => q{classical plural: 'four-star generals' --> 'four-star generals'};
is noun(q{monosyllabon})->classical->plural,   q{monosyllaba}  => q{classical plural: 'monosyllabon' --> 'monosyllaba'};
is noun(q{monosyllaba})->classical->plural, q{monosyllaba}  => q{classical plural: 'monosyllaba' --> 'monosyllaba'};
is noun(q{gaon})->classical->plural,   q{gaonim}  => q{classical plural: 'gaon' --> 'gaonim'};
is noun(q{gaonim})->classical->plural, q{gaonim}  => q{classical plural: 'gaonim' --> 'gaonim'};
is noun(q{uva})->classical->plural,   q{uvae}  => q{classical plural: 'uva' --> 'uvae'};
is noun(q{uvae})->classical->plural, q{uvae}  => q{classical plural: 'uvae' --> 'uvae'};
is noun(q{math})->classical->plural,   q{maths}  => q{classical plural: 'math' --> 'maths'};
is noun(q{maths})->classical->plural, q{maths}  => q{classical plural: 'maths' --> 'maths'};
is noun(q{dolphinarium})->classical->plural,   q{dolphinaria}  => q{classical plural: 'dolphinarium' --> 'dolphinaria'};
is noun(q{dolphinaria})->classical->plural, q{dolphinaria}  => q{classical plural: 'dolphinaria' --> 'dolphinaria'};
is noun(q{verruca})->classical->plural,   q{verrucae}  => q{classical plural: 'verruca' --> 'verrucae'};
is noun(q{verrucae})->classical->plural, q{verrucae}  => q{classical plural: 'verrucae' --> 'verrucae'};
is noun(q{apparatchik})->classical->plural,   q{apparatchiki}  => q{classical plural: 'apparatchik' --> 'apparatchiki'};
is noun(q{apparatchiki})->classical->plural, q{apparatchiki}  => q{classical plural: 'apparatchiki' --> 'apparatchiki'};
is noun(q{trumeau})->classical->plural,   q{trumeaux}  => q{classical plural: 'trumeau' --> 'trumeaux'};
is noun(q{trumeaux})->classical->plural, q{trumeaux}  => q{classical plural: 'trumeaux' --> 'trumeaux'};
is noun(q{granita})->classical->plural,   q{granite}  => q{classical plural: 'granita' --> 'granite'};
is noun(q{granite})->classical->plural, q{granite}  => q{classical plural: 'granite' --> 'granite'};
is noun(q{sandr})->classical->plural,   q{sandr}  => q{classical plural: 'sandr' --> 'sandr'};
is noun(q{conferva})->classical->plural,   q{confervae}  => q{classical plural: 'conferva' --> 'confervae'};
is noun(q{confervae})->classical->plural, q{confervae}  => q{classical plural: 'confervae' --> 'confervae'};
is noun(q{hemangeioma})->classical->plural,   q{hemangeiomata}  => q{classical plural: 'hemangeioma' --> 'hemangeiomata'};
is noun(q{hemangeiomata})->classical->plural, q{hemangeiomata}  => q{classical plural: 'hemangeiomata' --> 'hemangeiomata'};
is noun(q{aelf})->classical->plural,   q{aelfe}  => q{classical plural: 'aelf' --> 'aelfe'};
is noun(q{aelfe})->classical->plural, q{aelfe}  => q{classical plural: 'aelfe' --> 'aelfe'};
is noun(q{satelles})->classical->plural,   q{satellites}  => q{classical plural: 'satelles' --> 'satellites'};
is noun(q{satellites})->classical->plural, q{satellites}  => q{classical plural: 'satellites' --> 'satellites'};
is noun(q{micrococcus})->classical->plural,   q{micrococci}  => q{classical plural: 'micrococcus' --> 'micrococci'};
is noun(q{micrococci})->classical->plural, q{micrococci}  => q{classical plural: 'micrococci' --> 'micrococci'};
is noun(q{confluvium})->classical->plural,   q{confluvia}  => q{classical plural: 'confluvium' --> 'confluvia'};
is noun(q{confluvia})->classical->plural, q{confluvia}  => q{classical plural: 'confluvia' --> 'confluvia'};
is noun(q{nimbus})->classical->plural,   q{nimbi}  => q{classical plural: 'nimbus' --> 'nimbi'};
is noun(q{nimbi})->classical->plural, q{nimbi}  => q{classical plural: 'nimbi' --> 'nimbi'};
is noun(q{optimum})->classical->plural,   q{optima}  => q{classical plural: 'optimum' --> 'optima'};
is noun(q{optima})->classical->plural, q{optima}  => q{classical plural: 'optima' --> 'optima'};
is noun(q{prytanis})->classical->plural,   q{prytan}  => q{classical plural: 'prytanis' --> 'prytan'};
is noun(q{prytan})->classical->plural, q{prytan}  => q{classical plural: 'prytan' --> 'prytan'};
is noun(q{kilo})->classical->plural,   q{kilos}  => q{classical plural: 'kilo' --> 'kilos'};
is noun(q{kilos})->classical->plural, q{kilos}  => q{classical plural: 'kilos' --> 'kilos'};
is noun(q{sequestrum})->classical->plural,   q{sequestra}  => q{classical plural: 'sequestrum' --> 'sequestra'};
is noun(q{sequestra})->classical->plural, q{sequestra}  => q{classical plural: 'sequestra' --> 'sequestra'};
is noun(q{Togo})->classical->plural,   q{Togos}  => q{classical plural: 'Togo' --> 'Togos'};
is noun(q{Togos})->classical->plural, q{Togos}  => q{classical plural: 'Togos' --> 'Togos'};
is noun(q{salpa})->classical->plural,   q{salpae}  => q{classical plural: 'salpa' --> 'salpae'};
is noun(q{salpae})->classical->plural, q{salpae}  => q{classical plural: 'salpae' --> 'salpae'};
is noun(q{caribou})->classical->plural,   q{caribou}  => q{classical plural: 'caribou' --> 'caribou'};
is noun(q{antiserum})->classical->plural,   q{antisera}  => q{classical plural: 'antiserum' --> 'antisera'};
is noun(q{antisera})->classical->plural, q{antisera}  => q{classical plural: 'antisera' --> 'antisera'};
is noun(q{cayman})->classical->plural,   q{caymans}  => q{classical plural: 'cayman' --> 'caymans'};
is noun(q{caymans})->classical->plural, q{caymans}  => q{classical plural: 'caymans' --> 'caymans'};
is noun(q{Panaman})->classical->plural,   q{Panamans}  => q{classical plural: 'Panaman' --> 'Panamans'};
is noun(q{Panamans})->classical->plural, q{Panamans}  => q{classical plural: 'Panamans' --> 'Panamans'};
is noun(q{measles})->classical->plural,   q{measles}  => q{classical plural: 'measles' --> 'measles'};
is noun(q{cherub})->classical->plural,   q{cherubim}  => q{classical plural: 'cherub' --> 'cherubim'};
is noun(q{cherubim})->classical->plural, q{cherubim}  => q{classical plural: 'cherubim' --> 'cherubim'};
is noun(q{braccio})->classical->plural,   q{braccia}  => q{classical plural: 'braccio' --> 'braccia'};
is noun(q{braccia})->classical->plural, q{braccia}  => q{classical plural: 'braccia' --> 'braccia'};
is noun(q{amoeba})->classical->plural,   q{amoebae}  => q{classical plural: 'amoeba' --> 'amoebae'};
is noun(q{amoebae})->classical->plural, q{amoebae}  => q{classical plural: 'amoebae' --> 'amoebae'};
is noun(q{didymis})->classical->plural,   q{didymes}  => q{classical plural: 'didymis' --> 'didymes'};
is noun(q{didymes})->classical->plural, q{didymes}  => q{classical plural: 'didymes' --> 'didymes'};
is noun(q{manubrium})->classical->plural,   q{manubria}  => q{classical plural: 'manubrium' --> 'manubria'};
is noun(q{manubria})->classical->plural, q{manubria}  => q{classical plural: 'manubria' --> 'manubria'};
is noun(q{meningioma})->classical->plural,   q{meningiomata}  => q{classical plural: 'meningioma' --> 'meningiomata'};
is noun(q{meningiomata})->classical->plural, q{meningiomata}  => q{classical plural: 'meningiomata' --> 'meningiomata'};
is noun(q{cognoscente})->classical->plural,   q{cognoscenti}  => q{classical plural: 'cognoscente' --> 'cognoscenti'};
is noun(q{cognoscenti})->classical->plural, q{cognoscenti}  => q{classical plural: 'cognoscenti' --> 'cognoscenti'};
is noun(q{radiale})->classical->plural,   q{radialia}  => q{classical plural: 'radiale' --> 'radialia'};
is noun(q{radialia})->classical->plural, q{radialia}  => q{classical plural: 'radialia' --> 'radialia'};
is noun(q{nachtlokal})->classical->plural,   q{nachtlokale}  => q{classical plural: 'nachtlokal' --> 'nachtlokale'};
is noun(q{nachtlokale})->classical->plural, q{nachtlokale}  => q{classical plural: 'nachtlokale' --> 'nachtlokale'};
is noun(q{ramus})->classical->plural,   q{rami}  => q{classical plural: 'ramus' --> 'rami'};
is noun(q{rami})->classical->plural, q{rami}  => q{classical plural: 'rami' --> 'rami'};
is noun(q{gymnotus})->classical->plural,   q{gymnoti}  => q{classical plural: 'gymnotus' --> 'gymnoti'};
is noun(q{gymnoti})->classical->plural, q{gymnoti}  => q{classical plural: 'gymnoti' --> 'gymnoti'};
is noun(q{go})->classical->plural,   q{goes}  => q{classical plural: 'go' --> 'goes'};
is noun(q{goes})->classical->plural, q{goes}  => q{classical plural: 'goes' --> 'goes'};
is noun(q{mixolimnion})->classical->plural,   q{mixolimnia}  => q{classical plural: 'mixolimnion' --> 'mixolimnia'};
is noun(q{mixolimnia})->classical->plural, q{mixolimnia}  => q{classical plural: 'mixolimnia' --> 'mixolimnia'};
is noun(q{stamen})->classical->plural,   q{stamina}  => q{classical plural: 'stamen' --> 'stamina'};
is noun(q{stamina})->classical->plural, q{stamina}  => q{classical plural: 'stamina' --> 'stamina'};
is noun(q{strobilus})->classical->plural,   q{strobili}  => q{classical plural: 'strobilus' --> 'strobili'};
is noun(q{strobili})->classical->plural, q{strobili}  => q{classical plural: 'strobili' --> 'strobili'};
is noun(q{bordereau})->classical->plural,   q{bordereaux}  => q{classical plural: 'bordereau' --> 'bordereaux'};
is noun(q{bordereaux})->classical->plural, q{bordereaux}  => q{classical plural: 'bordereaux' --> 'bordereaux'};
is noun(q{Bolognese})->classical->plural,   q{Bolognese}  => q{classical plural: 'Bolognese' --> 'Bolognese'};
is noun(q{axe})->classical->plural,   q{axes}  => q{classical plural: 'axe' --> 'axes'};
is noun(q{axes})->classical->plural, q{axes}  => q{classical plural: 'axes' --> 'axes'};
is noun(q{macula})->classical->plural,   q{maculae}  => q{classical plural: 'macula' --> 'maculae'};
is noun(q{maculae})->classical->plural, q{maculae}  => q{classical plural: 'maculae' --> 'maculae'};
is noun(q{sphex})->classical->plural,   q{spheges}  => q{classical plural: 'sphex' --> 'spheges'};
is noun(q{spheges})->classical->plural, q{spheges}  => q{classical plural: 'spheges' --> 'spheges'};
is noun(q{ischium})->classical->plural,   q{ischia}  => q{classical plural: 'ischium' --> 'ischia'};
is noun(q{ischia})->classical->plural, q{ischia}  => q{classical plural: 'ischia' --> 'ischia'};
is noun(q{camera obscura})->classical->plural,   q{camerae obscurae}  => q{classical plural: 'camera obscura' --> 'camerae obscurae'};
is noun(q{camerae obscurae})->classical->plural, q{camerae obscurae}  => q{classical plural: 'camerae obscurae' --> 'camerae obscurae'};
is noun(q{felo})->classical->plural,   q{felones}  => q{classical plural: 'felo' --> 'felones'};
is noun(q{felones})->classical->plural, q{felones}  => q{classical plural: 'felones' --> 'felones'};
is noun(q{hemi elytrum})->classical->plural,   q{hemi elytra}  => q{classical plural: 'hemi elytrum' --> 'hemi elytra'};
is noun(q{hemi elytra})->classical->plural, q{hemi elytra}  => q{classical plural: 'hemi elytra' --> 'hemi elytra'};
is noun(q{two-star general})->classical->plural,   q{two-star generals}  => q{classical plural: 'two-star general' --> 'two-star generals'};
is noun(q{two-star generals})->classical->plural, q{two-star generals}  => q{classical plural: 'two-star generals' --> 'two-star generals'};
is noun(q{voorbok})->classical->plural,   q{voorbokke}  => q{classical plural: 'voorbok' --> 'voorbokke'};
is noun(q{voorbokke})->classical->plural, q{voorbokke}  => q{classical plural: 'voorbokke' --> 'voorbokke'};
is noun(q{non ens})->classical->plural,   q{nonentia}  => q{classical plural: 'non ens' --> 'nonentia'};
is noun(q{nonentia})->classical->plural, q{nonentia}  => q{classical plural: 'nonentia' --> 'nonentia'};
is noun(q{vermiculus})->classical->plural,   q{vermiculi}  => q{classical plural: 'vermiculus' --> 'vermiculi'};
is noun(q{vermiculi})->classical->plural, q{vermiculi}  => q{classical plural: 'vermiculi' --> 'vermiculi'};
is noun(q{conidium})->classical->plural,   q{conidia}  => q{classical plural: 'conidium' --> 'conidia'};
is noun(q{conidia})->classical->plural, q{conidia}  => q{classical plural: 'conidia' --> 'conidia'};
is noun(q{strambotto})->classical->plural,   q{strambotti}  => q{classical plural: 'strambotto' --> 'strambotti'};
is noun(q{strambotti})->classical->plural, q{strambotti}  => q{classical plural: 'strambotti' --> 'strambotti'};
is noun(q{squadrist})->classical->plural,   q{squadristi}  => q{classical plural: 'squadrist' --> 'squadristi'};
is noun(q{squadristi})->classical->plural, q{squadristi}  => q{classical plural: 'squadristi' --> 'squadristi'};
is noun(q{sacellum})->classical->plural,   q{sacella}  => q{classical plural: 'sacellum' --> 'sacella'};
is noun(q{sacella})->classical->plural, q{sacella}  => q{classical plural: 'sacella' --> 'sacella'};
is noun(q{cleithrum})->classical->plural,   q{cleithra}  => q{classical plural: 'cleithrum' --> 'cleithra'};
is noun(q{cleithra})->classical->plural, q{cleithra}  => q{classical plural: 'cleithra' --> 'cleithra'};
is noun(q{ogle})->classical->plural,   q{oglys}  => q{classical plural: 'ogle' --> 'oglys'};
is noun(q{oglys})->classical->plural, q{oglys}  => q{classical plural: 'oglys' --> 'oglys'};
is noun(q{fauna})->classical->plural,   q{faunae}  => q{classical plural: 'fauna' --> 'faunae'};
is noun(q{faunae})->classical->plural, q{faunae}  => q{classical plural: 'faunae' --> 'faunae'};
is noun(q{ulpan})->classical->plural,   q{ulpanim}  => q{classical plural: 'ulpan' --> 'ulpanim'};
is noun(q{ulpanim})->classical->plural, q{ulpanim}  => q{classical plural: 'ulpanim' --> 'ulpanim'};
is noun(q{tondo})->classical->plural,   q{tondi}  => q{classical plural: 'tondo' --> 'tondi'};
is noun(q{tondi})->classical->plural, q{tondi}  => q{classical plural: 'tondi' --> 'tondi'};
is noun(q{precognitum})->classical->plural,   q{precognita}  => q{classical plural: 'precognitum' --> 'precognita'};
is noun(q{precognita})->classical->plural, q{precognita}  => q{classical plural: 'precognita' --> 'precognita'};
is noun(q{bon vivant})->classical->plural,   q{bons vivants}  => q{classical plural: 'bon vivant' --> 'bons vivants'};
is noun(q{bons vivants})->classical->plural, q{bons vivants}  => q{classical plural: 'bons vivants' --> 'bons vivants'};
is noun(q{axilla})->classical->plural,   q{axillae}  => q{classical plural: 'axilla' --> 'axillae'};
is noun(q{axillae})->classical->plural, q{axillae}  => q{classical plural: 'axillae' --> 'axillae'};
is noun(q{tomium})->classical->plural,   q{tomia}  => q{classical plural: 'tomium' --> 'tomia'};
is noun(q{tomia})->classical->plural, q{tomia}  => q{classical plural: 'tomia' --> 'tomia'};
is noun(q{descriptum})->classical->plural,   q{descripta}  => q{classical plural: 'descriptum' --> 'descripta'};
is noun(q{descripta})->classical->plural, q{descripta}  => q{classical plural: 'descripta' --> 'descripta'};
is noun(q{life})->classical->plural,   q{lives}  => q{classical plural: 'life' --> 'lives'};
is noun(q{lives})->classical->plural, q{lives}  => q{classical plural: 'lives' --> 'lives'};
is noun(q{Porto-Novo})->classical->plural,   q{Porto-Novos}  => q{classical plural: 'Porto-Novo' --> 'Porto-Novos'};
is noun(q{Porto-Novos})->classical->plural, q{Porto-Novos}  => q{classical plural: 'Porto-Novos' --> 'Porto-Novos'};
is noun(q{uncinus})->classical->plural,   q{uncini}  => q{classical plural: 'uncinus' --> 'uncini'};
is noun(q{uncini})->classical->plural, q{uncini}  => q{classical plural: 'uncini' --> 'uncini'};
is noun(q{sestertium})->classical->plural,   q{sestertia}  => q{classical plural: 'sestertium' --> 'sestertia'};
is noun(q{sestertia})->classical->plural, q{sestertia}  => q{classical plural: 'sestertia' --> 'sestertia'};
is noun(q{fanfoot})->classical->plural,   q{fanfoots}  => q{classical plural: 'fanfoot' --> 'fanfoots'};
is noun(q{fanfoots})->classical->plural, q{fanfoots}  => q{classical plural: 'fanfoots' --> 'fanfoots'};
is noun(q{medusa})->classical->plural,   q{medusae}  => q{classical plural: 'medusa' --> 'medusae'};
is noun(q{medusae})->classical->plural, q{medusae}  => q{classical plural: 'medusae' --> 'medusae'};
is noun(q{suprascapula})->classical->plural,   q{suprascapulae}  => q{classical plural: 'suprascapula' --> 'suprascapulae'};
is noun(q{suprascapulae})->classical->plural, q{suprascapulae}  => q{classical plural: 'suprascapulae' --> 'suprascapulae'};
is noun(q{stucco})->classical->plural,   q{stuccos}  => q{classical plural: 'stucco' --> 'stuccos'};
is noun(q{stuccos})->classical->plural, q{stuccos}  => q{classical plural: 'stuccos' --> 'stuccos'};
is noun(q{pyla})->classical->plural,   q{pylae}  => q{classical plural: 'pyla' --> 'pylae'};
is noun(q{pylae})->classical->plural, q{pylae}  => q{classical plural: 'pylae' --> 'pylae'};
is noun(q{sis})->classical->plural,   q{ses}  => q{classical plural: 'sis' --> 'ses'};
is noun(q{ses})->classical->plural, q{ses}  => q{classical plural: 'ses' --> 'ses'};
is noun(q{sacculus})->classical->plural,   q{sacculi}  => q{classical plural: 'sacculus' --> 'sacculi'};
is noun(q{sacculi})->classical->plural, q{sacculi}  => q{classical plural: 'sacculi' --> 'sacculi'};
is noun(q{fait accompli})->classical->plural,   q{faits accomplis}  => q{classical plural: 'fait accompli' --> 'faits accomplis'};
is noun(q{faits accomplis})->classical->plural, q{faits accomplis}  => q{classical plural: 'faits accomplis' --> 'faits accomplis'};
is noun(q{hedron})->classical->plural,   q{hedra}  => q{classical plural: 'hedron' --> 'hedra'};
is noun(q{hedra})->classical->plural, q{hedra}  => q{classical plural: 'hedra' --> 'hedra'};
is noun(q{caudex})->classical->plural,   q{caudices}  => q{classical plural: 'caudex' --> 'caudices'};
is noun(q{caudices})->classical->plural, q{caudices}  => q{classical plural: 'caudices' --> 'caudices'};
is noun(q{solstitium})->classical->plural,   q{solstitia}  => q{classical plural: 'solstitium' --> 'solstitia'};
is noun(q{solstitia})->classical->plural, q{solstitia}  => q{classical plural: 'solstitia' --> 'solstitia'};
is noun(q{loculus})->classical->plural,   q{loculi}  => q{classical plural: 'loculus' --> 'loculi'};
is noun(q{loculi})->classical->plural, q{loculi}  => q{classical plural: 'loculi' --> 'loculi'};
is noun(q{papilloma})->classical->plural,   q{papillomata}  => q{classical plural: 'papilloma' --> 'papillomata'};
is noun(q{papillomata})->classical->plural, q{papillomata}  => q{classical plural: 'papillomata' --> 'papillomata'};
is noun(q{poncho})->classical->plural,   q{ponchos}  => q{classical plural: 'poncho' --> 'ponchos'};
is noun(q{ponchos})->classical->plural, q{ponchos}  => q{classical plural: 'ponchos' --> 'ponchos'};
is noun(q{malleolus})->classical->plural,   q{malleoli}  => q{classical plural: 'malleolus' --> 'malleoli'};
is noun(q{malleoli})->classical->plural, q{malleoli}  => q{classical plural: 'malleoli' --> 'malleoli'};
is noun(q{crowfoot})->classical->plural,   q{crowfoots}  => q{classical plural: 'crowfoot' --> 'crowfoots'};
is noun(q{crowfoots})->classical->plural, q{crowfoots}  => q{classical plural: 'crowfoots' --> 'crowfoots'};
is noun(q{sinus})->classical->plural,   q{sinus}  => q{classical plural: 'sinus' --> 'sinus'};
is noun(q{lymphangioma})->classical->plural,   q{lymphangiomata}  => q{classical plural: 'lymphangioma' --> 'lymphangiomata'};
is noun(q{lymphangiomata})->classical->plural, q{lymphangiomata}  => q{classical plural: 'lymphangiomata' --> 'lymphangiomata'};
is noun(q{gena})->classical->plural,   q{genae}  => q{classical plural: 'gena' --> 'genae'};
is noun(q{genae})->classical->plural, q{genae}  => q{classical plural: 'genae' --> 'genae'};
is noun(q{syrinx})->classical->plural,   q{syringes}  => q{classical plural: 'syrinx' --> 'syringes'};
is noun(q{syringes})->classical->plural, q{syringes}  => q{classical plural: 'syringes' --> 'syringes'};
is noun(q{frizz})->classical->plural,   q{frizzes}  => q{classical plural: 'frizz' --> 'frizzes'};
is noun(q{frizzes})->classical->plural, q{frizzes}  => q{classical plural: 'frizzes' --> 'frizzes'};
is noun(q{monsignor})->classical->plural,   q{monsignori}  => q{classical plural: 'monsignor' --> 'monsignori'};
is noun(q{monsignori})->classical->plural, q{monsignori}  => q{classical plural: 'monsignori' --> 'monsignori'};
is noun(q{pike})->classical->plural,   q{pike}  => q{classical plural: 'pike' --> 'pike'};
is noun(q{capo})->classical->plural,   q{capi}  => q{classical plural: 'capo' --> 'capi'};
is noun(q{capi})->classical->plural, q{capi}  => q{classical plural: 'capi' --> 'capi'};
is noun(q{scungille})->classical->plural,   q{scungilli}  => q{classical plural: 'scungille' --> 'scungilli'};
is noun(q{scungilli})->classical->plural, q{scungilli}  => q{classical plural: 'scungilli' --> 'scungilli'};
is noun(q{stomatium})->classical->plural,   q{stomatia}  => q{classical plural: 'stomatium' --> 'stomatia'};
is noun(q{stomatia})->classical->plural, q{stomatia}  => q{classical plural: 'stomatia' --> 'stomatia'};
is noun(q{jazz})->classical->plural,   q{jazzes}  => q{classical plural: 'jazz' --> 'jazzes'};
is noun(q{jazzes})->classical->plural, q{jazzes}  => q{classical plural: 'jazzes' --> 'jazzes'};
is noun(q{cornu})->classical->plural,   q{cornua}  => q{classical plural: 'cornu' --> 'cornua'};
is noun(q{cornua})->classical->plural, q{cornua}  => q{classical plural: 'cornua' --> 'cornua'};
is noun(q{synusia})->classical->plural,   q{synusiae}  => q{classical plural: 'synusia' --> 'synusiae'};
is noun(q{synusiae})->classical->plural, q{synusiae}  => q{classical plural: 'synusiae' --> 'synusiae'};
is noun(q{sphaeridium})->classical->plural,   q{sphaerideum}  => q{classical plural: 'sphaeridium' --> 'sphaerideum'};
is noun(q{sphaerideum})->classical->plural, q{sphaerideum}  => q{classical plural: 'sphaerideum' --> 'sphaerideum'};
is noun(q{squilla})->classical->plural,   q{squillae}  => q{classical plural: 'squilla' --> 'squillae'};
is noun(q{squillae})->classical->plural, q{squillae}  => q{classical plural: 'squillae' --> 'squillae'};
is noun(q{pteroma})->classical->plural,   q{pteromata}  => q{classical plural: 'pteroma' --> 'pteromata'};
is noun(q{pteromata})->classical->plural, q{pteromata}  => q{classical plural: 'pteromata' --> 'pteromata'};
is noun(q{Czech})->classical->plural,   q{Czechs}  => q{classical plural: 'Czech' --> 'Czechs'};
is noun(q{Czechs})->classical->plural, q{Czechs}  => q{classical plural: 'Czechs' --> 'Czechs'};
is noun(q{hijinks})->classical->plural,   q{hijinks}  => q{classical plural: 'hijinks' --> 'hijinks'};
is noun(q{macacus})->classical->plural,   q{macaci}  => q{classical plural: 'macacus' --> 'macaci'};
is noun(q{macaci})->classical->plural, q{macaci}  => q{classical plural: 'macaci' --> 'macaci'};
is noun(q{vallecula})->classical->plural,   q{valleculae}  => q{classical plural: 'vallecula' --> 'valleculae'};
is noun(q{valleculae})->classical->plural, q{valleculae}  => q{classical plural: 'valleculae' --> 'valleculae'};
is noun(q{tuberculoma})->classical->plural,   q{tuberculomata}  => q{classical plural: 'tuberculoma' --> 'tuberculomata'};
is noun(q{tuberculomata})->classical->plural, q{tuberculomata}  => q{classical plural: 'tuberculomata' --> 'tuberculomata'};
is noun(q{stigmaria})->classical->plural,   q{stigmariae}  => q{classical plural: 'stigmaria' --> 'stigmariae'};
is noun(q{stigmariae})->classical->plural, q{stigmariae}  => q{classical plural: 'stigmariae' --> 'stigmariae'};
is noun(q{pithos})->classical->plural,   q{pithoi}  => q{classical plural: 'pithos' --> 'pithoi'};
is noun(q{pithoi})->classical->plural, q{pithoi}  => q{classical plural: 'pithoi' --> 'pithoi'};
is noun(q{orthoceras})->classical->plural,   q{orthocerata}  => q{classical plural: 'orthoceras' --> 'orthocerata'};
is noun(q{orthocerata})->classical->plural, q{orthocerata}  => q{classical plural: 'orthocerata' --> 'orthocerata'};
is noun(q{risotto})->classical->plural,   q{risottos}  => q{classical plural: 'risotto' --> 'risottos'};
is noun(q{risottos})->classical->plural, q{risottos}  => q{classical plural: 'risottos' --> 'risottos'};
is noun(q{scandalum magnatum})->classical->plural,   q{scandala magnatum}  => q{classical plural: 'scandalum magnatum' --> 'scandala magnatum'};
is noun(q{scandala magnatum})->classical->plural, q{scandala magnatum}  => q{classical plural: 'scandala magnatum' --> 'scandala magnatum'};
is noun(q{ ox})->classical->plural,   q{ oxen}  => q{classical plural: ' ox' --> ' oxen'};
is noun(q{ oxen})->classical->plural, q{ oxen}  => q{classical plural: ' oxen' --> ' oxen'};
is noun(q{sum total})->classical->plural,   q{sums total}  => q{classical plural: 'sum total' --> 'sums total'};
is noun(q{sums total})->classical->plural, q{sums total}  => q{classical plural: 'sums total' --> 'sums total'};
is noun(q{promerops})->classical->plural,   q{promeropes}  => q{classical plural: 'promerops' --> 'promeropes'};
is noun(q{promeropes})->classical->plural, q{promeropes}  => q{classical plural: 'promeropes' --> 'promeropes'};
is noun(q{piscina})->classical->plural,   q{piscinae}  => q{classical plural: 'piscina' --> 'piscinae'};
is noun(q{piscinae})->classical->plural, q{piscinae}  => q{classical plural: 'piscinae' --> 'piscinae'};
is noun(q{organon})->classical->plural,   q{organa}  => q{classical plural: 'organon' --> 'organa'};
is noun(q{organa})->classical->plural, q{organa}  => q{classical plural: 'organa' --> 'organa'};
is noun(q{listeria})->classical->plural,   q{listeria}  => q{classical plural: 'listeria' --> 'listeria'};
is noun(q{syllabus})->classical->plural,   q{syllabi}  => q{classical plural: 'syllabus' --> 'syllabi'};
is noun(q{syllabi})->classical->plural, q{syllabi}  => q{classical plural: 'syllabi' --> 'syllabi'};
is noun(q{clitoris})->classical->plural,   q{clitorides}  => q{classical plural: 'clitoris' --> 'clitorides'};
is noun(q{clitorides})->classical->plural, q{clitorides}  => q{classical plural: 'clitorides' --> 'clitorides'};
is noun(q{mycorrhiza})->classical->plural,   q{mycorrhizae}  => q{classical plural: 'mycorrhiza' --> 'mycorrhizae'};
is noun(q{mycorrhizae})->classical->plural, q{mycorrhizae}  => q{classical plural: 'mycorrhizae' --> 'mycorrhizae'};
is noun(q{lumbricus})->classical->plural,   q{lumbrici}  => q{classical plural: 'lumbricus' --> 'lumbrici'};
is noun(q{lumbrici})->classical->plural, q{lumbrici}  => q{classical plural: 'lumbrici' --> 'lumbrici'};
is noun(q{xanthoma})->classical->plural,   q{xanthomata}  => q{classical plural: 'xanthoma' --> 'xanthomata'};
is noun(q{xanthomata})->classical->plural, q{xanthomata}  => q{classical plural: 'xanthomata' --> 'xanthomata'};
is noun(q{casino})->classical->plural,   q{casinos}  => q{classical plural: 'casino' --> 'casinos'};
is noun(q{casinos})->classical->plural, q{casinos}  => q{classical plural: 'casinos' --> 'casinos'};
is noun(q{commando})->classical->plural,   q{commandos}  => q{classical plural: 'commando' --> 'commandos'};
is noun(q{commandos})->classical->plural, q{commandos}  => q{classical plural: 'commandos' --> 'commandos'};
is noun(q{pileus})->classical->plural,   q{pilei}  => q{classical plural: 'pileus' --> 'pilei'};
is noun(q{pilei})->classical->plural, q{pilei}  => q{classical plural: 'pilei' --> 'pilei'};
is noun(q{uredinium})->classical->plural,   q{uredinia}  => q{classical plural: 'uredinium' --> 'uredinia'};
is noun(q{uredinia})->classical->plural, q{uredinia}  => q{classical plural: 'uredinia' --> 'uredinia'};
is noun(q{guano})->classical->plural,   q{guanos}  => q{classical plural: 'guano' --> 'guanos'};
is noun(q{guanos})->classical->plural, q{guanos}  => q{classical plural: 'guanos' --> 'guanos'};
is noun(q{shelf})->classical->plural,   q{shelves}  => q{classical plural: 'shelf' --> 'shelves'};
is noun(q{shelves})->classical->plural, q{shelves}  => q{classical plural: 'shelves' --> 'shelves'};
is noun(q{supracleithrum})->classical->plural,   q{supracleithra}  => q{classical plural: 'supracleithrum' --> 'supracleithra'};
is noun(q{supracleithra})->classical->plural, q{supracleithra}  => q{classical plural: 'supracleithra' --> 'supracleithra'};
is noun(q{lied})->classical->plural,   q{lieder}  => q{classical plural: 'lied' --> 'lieder'};
is noun(q{lieder})->classical->plural, q{lieder}  => q{classical plural: 'lieder' --> 'lieder'};
is noun(q{Leonese})->classical->plural,   q{Leonese}  => q{classical plural: 'Leonese' --> 'Leonese'};
is noun(q{atman})->classical->plural,   q{atmas}  => q{classical plural: 'atman' --> 'atmas'};
is noun(q{atmas})->classical->plural, q{atmas}  => q{classical plural: 'atmas' --> 'atmas'};
is noun(q{decennium})->classical->plural,   q{decennia}  => q{classical plural: 'decennium' --> 'decennia'};
is noun(q{decennia})->classical->plural, q{decennia}  => q{classical plural: 'decennia' --> 'decennia'};
is noun(q{dragoman})->classical->plural,   q{dragomans}  => q{classical plural: 'dragoman' --> 'dragomans'};
is noun(q{dragomans})->classical->plural, q{dragomans}  => q{classical plural: 'dragomans' --> 'dragomans'};
is noun(q{papilla})->classical->plural,   q{papillae}  => q{classical plural: 'papilla' --> 'papillae'};
is noun(q{papillae})->classical->plural, q{papillae}  => q{classical plural: 'papillae' --> 'papillae'};
is noun(q{tsuba})->classical->plural,   q{tsuba}  => q{classical plural: 'tsuba' --> 'tsuba'};
is noun(q{rhythmus})->classical->plural,   q{rhythmi}  => q{classical plural: 'rhythmus' --> 'rhythmi'};
is noun(q{rhythmi})->classical->plural, q{rhythmi}  => q{classical plural: 'rhythmi' --> 'rhythmi'};
is noun(q{lactobacillus})->classical->plural,   q{lactobacilli}  => q{classical plural: 'lactobacillus' --> 'lactobacilli'};
is noun(q{lactobacilli})->classical->plural, q{lactobacilli}  => q{classical plural: 'lactobacilli' --> 'lactobacilli'};
is noun(q{cuniculus})->classical->plural,   q{cuniculi}  => q{classical plural: 'cuniculus' --> 'cuniculi'};
is noun(q{cuniculi})->classical->plural, q{cuniculi}  => q{classical plural: 'cuniculi' --> 'cuniculi'};
is noun(q{lineno})->classical->plural,   q{linenos}  => q{classical plural: 'lineno' --> 'linenos'};
is noun(q{linenos})->classical->plural, q{linenos}  => q{classical plural: 'linenos' --> 'linenos'};
is noun(q{rondeau})->classical->plural,   q{rondeaux}  => q{classical plural: 'rondeau' --> 'rondeaux'};
is noun(q{rondeaux})->classical->plural, q{rondeaux}  => q{classical plural: 'rondeaux' --> 'rondeaux'};
is noun(q{idee fixe})->classical->plural,   q{idees fixes}  => q{classical plural: 'idee fixe' --> 'idees fixes'};
is noun(q{idees fixes})->classical->plural, q{idees fixes}  => q{classical plural: 'idees fixes' --> 'idees fixes'};
is noun(q{sarcophagus})->classical->plural,   q{sarcophagi}  => q{classical plural: 'sarcophagus' --> 'sarcophagi'};
is noun(q{sarcophagi})->classical->plural, q{sarcophagi}  => q{classical plural: 'sarcophagi' --> 'sarcophagi'};
is noun(q{vaquero})->classical->plural,   q{vaqueros}  => q{classical plural: 'vaquero' --> 'vaqueros'};
is noun(q{vaqueros})->classical->plural, q{vaqueros}  => q{classical plural: 'vaqueros' --> 'vaqueros'};
is noun(q{milieu})->classical->plural,   q{milieux}  => q{classical plural: 'milieu' --> 'milieux'};
is noun(q{milieux})->classical->plural, q{milieux}  => q{classical plural: 'milieux' --> 'milieux'};
is noun(q{spermatoon})->classical->plural,   q{spermatoa}  => q{classical plural: 'spermatoon' --> 'spermatoa'};
is noun(q{spermatoa})->classical->plural, q{spermatoa}  => q{classical plural: 'spermatoa' --> 'spermatoa'};
is noun(q{silex})->classical->plural,   q{silices}  => q{classical plural: 'silex' --> 'silices'};
is noun(q{silices})->classical->plural, q{silices}  => q{classical plural: 'silices' --> 'silices'};
is noun(q{pupa})->classical->plural,   q{pupae}  => q{classical plural: 'pupa' --> 'pupae'};
is noun(q{pupae})->classical->plural, q{pupae}  => q{classical plural: 'pupae' --> 'pupae'};
is noun(q{cri de coeur})->classical->plural,   q{cris de coeur}  => q{classical plural: 'cri de coeur' --> 'cris de coeur'};
is noun(q{cris de coeur})->classical->plural, q{cris de coeur}  => q{classical plural: 'cris de coeur' --> 'cris de coeur'};
is noun(q{secretum})->classical->plural,   q{secreta}  => q{classical plural: 'secretum' --> 'secreta'};
is noun(q{secreta})->classical->plural, q{secreta}  => q{classical plural: 'secreta' --> 'secreta'};
is noun(q{schisma})->classical->plural,   q{schismata}  => q{classical plural: 'schisma' --> 'schismata'};
is noun(q{schismata})->classical->plural, q{schismata}  => q{classical plural: 'schismata' --> 'schismata'};
is noun(q{flag-staff})->classical->plural,   q{flag-staves}  => q{classical plural: 'flag-staff' --> 'flag-staves'};
is noun(q{flag-staves})->classical->plural, q{flag-staves}  => q{classical plural: 'flag-staves' --> 'flag-staves'};
is noun(q{miracidium})->classical->plural,   q{miracidia}  => q{classical plural: 'miracidium' --> 'miracidia'};
is noun(q{miracidia})->classical->plural, q{miracidia}  => q{classical plural: 'miracidia' --> 'miracidia'};
is noun(q{agon})->classical->plural,   q{agones}  => q{classical plural: 'agon' --> 'agones'};
is noun(q{agones})->classical->plural, q{agones}  => q{classical plural: 'agones' --> 'agones'};
is noun(q{cranium})->classical->plural,   q{crania}  => q{classical plural: 'cranium' --> 'crania'};
is noun(q{crania})->classical->plural, q{crania}  => q{classical plural: 'crania' --> 'crania'};
is noun(q{bolero})->classical->plural,   q{boleros}  => q{classical plural: 'bolero' --> 'boleros'};
is noun(q{boleros})->classical->plural, q{boleros}  => q{classical plural: 'boleros' --> 'boleros'};
is noun(q{scomber})->classical->plural,   q{scombri}  => q{classical plural: 'scomber' --> 'scombri'};
is noun(q{scombri})->classical->plural, q{scombri}  => q{classical plural: 'scombri' --> 'scombri'};
is noun(q{guardia civil})->classical->plural,   q{guardias civiles}  => q{classical plural: 'guardia civil' --> 'guardias civiles'};
is noun(q{guardias civiles})->classical->plural, q{guardias civiles}  => q{classical plural: 'guardias civiles' --> 'guardias civiles'};
is noun(q{Lapith})->classical->plural,   q{Lapithae}  => q{classical plural: 'Lapith' --> 'Lapithae'};
is noun(q{Lapithae})->classical->plural, q{Lapithae}  => q{classical plural: 'Lapithae' --> 'Lapithae'};
is noun(q{cultellus})->classical->plural,   q{cultelli}  => q{classical plural: 'cultellus' --> 'cultelli'};
is noun(q{cultelli})->classical->plural, q{cultelli}  => q{classical plural: 'cultelli' --> 'cultelli'};
is noun(q{tractellum})->classical->plural,   q{tractella}  => q{classical plural: 'tractellum' --> 'tractella'};
is noun(q{tractella})->classical->plural, q{tractella}  => q{classical plural: 'tractella' --> 'tractella'};
is noun(q{3-star general})->classical->plural,   q{3-star generals}  => q{classical plural: '3-star general' --> '3-star generals'};
is noun(q{3-star generals})->classical->plural, q{3-star generals}  => q{classical plural: '3-star generals' --> '3-star generals'};
is noun(q{mya})->classical->plural,   q{myae}  => q{classical plural: 'mya' --> 'myae'};
is noun(q{myae})->classical->plural, q{myae}  => q{classical plural: 'myae' --> 'myae'};
is noun(q{zoarium})->classical->plural,   q{zoaria}  => q{classical plural: 'zoarium' --> 'zoaria'};
is noun(q{zoaria})->classical->plural, q{zoaria}  => q{classical plural: 'zoaria' --> 'zoaria'};
is noun(q{streptococcus})->classical->plural,   q{streptococci}  => q{classical plural: 'streptococcus' --> 'streptococci'};
is noun(q{streptococci})->classical->plural, q{streptococci}  => q{classical plural: 'streptococci' --> 'streptococci'};
is noun(q{Bernese})->classical->plural,   q{Bernese}  => q{classical plural: 'Bernese' --> 'Bernese'};
is noun(q{Asherah})->classical->plural,   q{Asherim}  => q{classical plural: 'Asherah' --> 'Asherim'};
is noun(q{Asherim})->classical->plural, q{Asherim}  => q{classical plural: 'Asherim' --> 'Asherim'};
is noun(q{pul})->classical->plural,   q{puli}  => q{classical plural: 'pul' --> 'puli'};
is noun(q{puli})->classical->plural, q{puli}  => q{classical plural: 'puli' --> 'puli'};
is noun(q{Genevese})->classical->plural,   q{Genevese}  => q{classical plural: 'Genevese' --> 'Genevese'};
is noun(q{cystidium})->classical->plural,   q{cystidia}  => q{classical plural: 'cystidium' --> 'cystidia'};
is noun(q{cystidia})->classical->plural, q{cystidia}  => q{classical plural: 'cystidia' --> 'cystidia'};
is noun(q{fecula})->classical->plural,   q{feculae}  => q{classical plural: 'fecula' --> 'feculae'};
is noun(q{feculae})->classical->plural, q{feculae}  => q{classical plural: 'feculae' --> 'feculae'};
is noun(q{acicula})->classical->plural,   q{aciculae}  => q{classical plural: 'acicula' --> 'aciculae'};
is noun(q{aciculae})->classical->plural, q{aciculae}  => q{classical plural: 'aciculae' --> 'aciculae'};
is noun(q{Burmese})->classical->plural,   q{Burmese}  => q{classical plural: 'Burmese' --> 'Burmese'};
is noun(q{Achinese})->classical->plural,   q{Achinese}  => q{classical plural: 'Achinese' --> 'Achinese'};
is noun(q{postpubis})->classical->plural,   q{postpubes}  => q{classical plural: 'postpubis' --> 'postpubes'};
is noun(q{postpubes})->classical->plural, q{postpubes}  => q{classical plural: 'postpubes' --> 'postpubes'};
is noun(q{oath})->classical->plural,   q{oaths}  => q{classical plural: 'oath' --> 'oaths'};
is noun(q{oaths})->classical->plural, q{oaths}  => q{classical plural: 'oaths' --> 'oaths'};
is noun(q{man-milliner})->classical->plural,   q{men-milliners}  => q{classical plural: 'man-milliner' --> 'men-milliners'};
is noun(q{men-milliners})->classical->plural, q{men-milliners}  => q{classical plural: 'men-milliners' --> 'men-milliners'};
is noun(q{myeloma})->classical->plural,   q{myelomata}  => q{classical plural: 'myeloma' --> 'myelomata'};
is noun(q{myelomata})->classical->plural, q{myelomata}  => q{classical plural: 'myelomata' --> 'myelomata'};
is noun(q{path})->classical->plural,   q{paths}  => q{classical plural: 'path' --> 'paths'};
is noun(q{paths})->classical->plural, q{paths}  => q{classical plural: 'paths' --> 'paths'};
is noun(q{Maltese})->classical->plural,   q{Maltese}  => q{classical plural: 'Maltese' --> 'Maltese'};
is noun(q{halibut})->classical->plural,   q{halibut}  => q{classical plural: 'halibut' --> 'halibut'};
is noun(q{Assamese})->classical->plural,   q{Assamese}  => q{classical plural: 'Assamese' --> 'Assamese'};
is noun(q{alto relievo})->classical->plural,   q{alto relievos}  => q{classical plural: 'alto relievo' --> 'alto relievos'};
is noun(q{alto relievos})->classical->plural, q{alto relievos}  => q{classical plural: 'alto relievos' --> 'alto relievos'};
is noun(q{ex})->classical->plural,   q{exes}  => q{classical plural: 'ex' --> 'exes'};
is noun(q{exes})->classical->plural, q{exes}  => q{classical plural: 'exes' --> 'exes'};
is noun(q{typo})->classical->plural,   q{typos}  => q{classical plural: 'typo' --> 'typos'};
is noun(q{typos})->classical->plural, q{typos}  => q{classical plural: 'typos' --> 'typos'};
is noun(q{prokaryon})->classical->plural,   q{prokarya}  => q{classical plural: 'prokaryon' --> 'prokarya'};
is noun(q{prokarya})->classical->plural, q{prokarya}  => q{classical plural: 'prokarya' --> 'prokarya'};
is noun(q{vertex})->classical->plural,   q{vertices}  => q{classical plural: 'vertex' --> 'vertices'};
is noun(q{vertices})->classical->plural, q{vertices}  => q{classical plural: 'vertices' --> 'vertices'};
is noun(q{Chinese})->classical->plural,   q{Chinese}  => q{classical plural: 'Chinese' --> 'Chinese'};
is noun(q{minimum})->classical->plural,   q{minima}  => q{classical plural: 'minimum' --> 'minima'};
is noun(q{minima})->classical->plural, q{minima}  => q{classical plural: 'minima' --> 'minima'};
is noun(q{break away})->classical->plural,   q{breaks away}  => q{classical plural: 'break away' --> 'breaks away'};
is noun(q{breaks away})->classical->plural, q{breaks away}  => q{classical plural: 'breaks away' --> 'breaks away'};
is noun(q{zingano})->classical->plural,   q{zingani}  => q{classical plural: 'zingano' --> 'zingani'};
is noun(q{zingani})->classical->plural, q{zingani}  => q{classical plural: 'zingani' --> 'zingani'};
is noun(q{canaliculus})->classical->plural,   q{canaliculi}  => q{classical plural: 'canaliculus' --> 'canaliculi'};
is noun(q{canaliculi})->classical->plural, q{canaliculi}  => q{classical plural: 'canaliculi' --> 'canaliculi'};
is noun(q{xoanon})->classical->plural,   q{xoana}  => q{classical plural: 'xoanon' --> 'xoana'};
is noun(q{xoana})->classical->plural, q{xoana}  => q{classical plural: 'xoana' --> 'xoana'};
is noun(q{memento})->classical->plural,   q{mementoes}  => q{classical plural: 'memento' --> 'mementoes'};
is noun(q{mementoes})->classical->plural, q{mementoes}  => q{classical plural: 'mementoes' --> 'mementoes'};
is noun(q{psammoma})->classical->plural,   q{psammomata}  => q{classical plural: 'psammoma' --> 'psammomata'};
is noun(q{psammomata})->classical->plural, q{psammomata}  => q{classical plural: 'psammomata' --> 'psammomata'};
is noun(q{quartz})->classical->plural,   q{quartzes}  => q{classical plural: 'quartz' --> 'quartzes'};
is noun(q{quartzes})->classical->plural, q{quartzes}  => q{classical plural: 'quartzes' --> 'quartzes'};
is noun(q{flatfoot})->classical->plural,   q{flatfoots}  => q{classical plural: 'flatfoot' --> 'flatfoots'};
is noun(q{flatfoots})->classical->plural, q{flatfoots}  => q{classical plural: 'flatfoots' --> 'flatfoots'};
is noun(q{apparatus})->classical->plural,   q{apparatus}  => q{classical plural: 'apparatus' --> 'apparatus'};
is noun(q{punctum})->classical->plural,   q{puncta}  => q{classical plural: 'punctum' --> 'puncta'};
is noun(q{puncta})->classical->plural, q{puncta}  => q{classical plural: 'puncta' --> 'puncta'};
is noun(q{alga})->classical->plural,   q{algae}  => q{classical plural: 'alga' --> 'algae'};
is noun(q{algae})->classical->plural, q{algae}  => q{classical plural: 'algae' --> 'algae'};
is noun(q{his})->classical->plural,   q{theirs}  => q{classical plural: 'his' --> 'theirs'};
is noun(q{ax})->classical->plural,   q{axes}  => q{classical plural: 'ax' --> 'axes'};
is noun(q{axes})->classical->plural, q{axes}  => q{classical plural: 'axes' --> 'axes'};
is noun(q{mezuza})->classical->plural,   q{mezuzoth}  => q{classical plural: 'mezuza' --> 'mezuzoth'};
is noun(q{mezuzoth})->classical->plural, q{mezuzoth}  => q{classical plural: 'mezuzoth' --> 'mezuzoth'};
is noun(q{subbotnik})->classical->plural,   q{subbotniki}  => q{classical plural: 'subbotnik' --> 'subbotniki'};
is noun(q{subbotniki})->classical->plural, q{subbotniki}  => q{classical plural: 'subbotniki' --> 'subbotniki'};
is noun(q{oto})->classical->plural,   q{otos}  => q{classical plural: 'oto' --> 'otos'};
is noun(q{otos})->classical->plural, q{otos}  => q{classical plural: 'otos' --> 'otos'};
is noun(q{lemma})->classical->plural,   q{lemmata}  => q{classical plural: 'lemma' --> 'lemmata'};
is noun(q{lemmata})->classical->plural, q{lemmata}  => q{classical plural: 'lemmata' --> 'lemmata'};
is noun(q{carabiniere})->classical->plural,   q{carabinieri}  => q{classical plural: 'carabiniere' --> 'carabinieri'};
is noun(q{carabinieri})->classical->plural, q{carabinieri}  => q{classical plural: 'carabinieri' --> 'carabinieri'};
is noun(q{zloty})->classical->plural,   q{zloty}  => q{classical plural: 'zloty' --> 'zloty'};
is noun(q{varella})->classical->plural,   q{varely}  => q{classical plural: 'varella' --> 'varely'};
is noun(q{varely})->classical->plural, q{varely}  => q{classical plural: 'varely' --> 'varely'};
is noun(q{scherzo})->classical->plural,   q{scherzos}  => q{classical plural: 'scherzo' --> 'scherzos'};
is noun(q{scherzos})->classical->plural, q{scherzos}  => q{classical plural: 'scherzos' --> 'scherzos'};
is noun(q{explanandum})->classical->plural,   q{explananda}  => q{classical plural: 'explanandum' --> 'explananda'};
is noun(q{explananda})->classical->plural, q{explananda}  => q{classical plural: 'explananda' --> 'explananda'};
is noun(q{wanderjahr})->classical->plural,   q{wanderjahre}  => q{classical plural: 'wanderjahr' --> 'wanderjahre'};
is noun(q{wanderjahre})->classical->plural, q{wanderjahre}  => q{classical plural: 'wanderjahre' --> 'wanderjahre'};
is noun(q{clavula})->classical->plural,   q{clavulae}  => q{classical plural: 'clavula' --> 'clavulae'};
is noun(q{clavulae})->classical->plural, q{clavulae}  => q{classical plural: 'clavulae' --> 'clavulae'};
is noun(q{romanze})->classical->plural,   q{romanzen}  => q{classical plural: 'romanze' --> 'romanzen'};
is noun(q{romanzen})->classical->plural, q{romanzen}  => q{classical plural: 'romanzen' --> 'romanzen'};
is noun(q{osmeterium})->classical->plural,   q{osmeteria}  => q{classical plural: 'osmeterium' --> 'osmeteria'};
is noun(q{osmeteria})->classical->plural, q{osmeteria}  => q{classical plural: 'osmeteria' --> 'osmeteria'};
is noun(q{nephridium})->classical->plural,   q{nephridia}  => q{classical plural: 'nephridium' --> 'nephridia'};
is noun(q{nephridia})->classical->plural, q{nephridia}  => q{classical plural: 'nephridia' --> 'nephridia'};
is noun(q{udarnik})->classical->plural,   q{udarniki}  => q{classical plural: 'udarnik' --> 'udarniki'};
is noun(q{udarniki})->classical->plural, q{udarniki}  => q{classical plural: 'udarniki' --> 'udarniki'};
is noun(q{inuk})->classical->plural,   q{inuit}  => q{classical plural: 'inuk' --> 'inuit'};
is noun(q{inuit})->classical->plural, q{inuit}  => q{classical plural: 'inuit' --> 'inuit'};
is noun(q{scutulum})->classical->plural,   q{scutula}  => q{classical plural: 'scutulum' --> 'scutula'};
is noun(q{scutula})->classical->plural, q{scutula}  => q{classical plural: 'scutula' --> 'scutula'};
is noun(q{virga})->classical->plural,   q{virgae}  => q{classical plural: 'virga' --> 'virgae'};
is noun(q{virgae})->classical->plural, q{virgae}  => q{classical plural: 'virgae' --> 'virgae'};
is noun(q{parnas})->classical->plural,   q{parnassim}  => q{classical plural: 'parnas' --> 'parnassim'};
is noun(q{parnassim})->classical->plural, q{parnassim}  => q{classical plural: 'parnassim' --> 'parnassim'};
is noun(q{five star general})->classical->plural,   q{five star generals}  => q{classical plural: 'five star general' --> 'five star generals'};
is noun(q{five star generals})->classical->plural, q{five star generals}  => q{classical plural: 'five star generals' --> 'five star generals'};
is noun(q{intermezzo})->classical->plural,   q{intermezzos}  => q{classical plural: 'intermezzo' --> 'intermezzos'};
is noun(q{intermezzos})->classical->plural, q{intermezzos}  => q{classical plural: 'intermezzos' --> 'intermezzos'};
is noun(q{solvus})->classical->plural,   q{solvi}  => q{classical plural: 'solvus' --> 'solvi'};
is noun(q{solvi})->classical->plural, q{solvi}  => q{classical plural: 'solvi' --> 'solvi'};
is noun(q{short})->classical->plural,   q{shorts}  => q{classical plural: 'short' --> 'shorts'};
is noun(q{indigena})->classical->plural,   q{indigenae}  => q{classical plural: 'indigena' --> 'indigenae'};
is noun(q{indigenae})->classical->plural, q{indigenae}  => q{classical plural: 'indigenae' --> 'indigenae'};
is noun(q{testis})->classical->plural,   q{testes}  => q{classical plural: 'testis' --> 'testes'};
is noun(q{Niasese})->classical->plural,   q{Niasese}  => q{classical plural: 'Niasese' --> 'Niasese'};
is noun(q{Dongolese})->classical->plural,   q{Dongolese}  => q{classical plural: 'Dongolese' --> 'Dongolese'};
is noun(q{trabecula})->classical->plural,   q{trabeculae}  => q{classical plural: 'trabecula' --> 'trabeculae'};
is noun(q{trabeculae})->classical->plural, q{trabeculae}  => q{classical plural: 'trabeculae' --> 'trabeculae'};
is noun(q{cornetto})->classical->plural,   q{cornetti}  => q{classical plural: 'cornetto' --> 'cornetti'};
is noun(q{cornetti})->classical->plural, q{cornetti}  => q{classical plural: 'cornetti' --> 'cornetti'};
is noun(q{brother-german})->classical->plural,   q{brethren-german}  => q{classical plural: 'brother-german' --> 'brethren-german'};
is noun(q{brethren-german})->classical->plural, q{brethren-german}  => q{classical plural: 'brethren-german' --> 'brethren-german'};
is noun(q{pedalo})->classical->plural,   q{pedalos}  => q{classical plural: 'pedalo' --> 'pedalos'};
is noun(q{pedalos})->classical->plural, q{pedalos}  => q{classical plural: 'pedalos' --> 'pedalos'};
is noun(q{cheval})->classical->plural,   q{chevaux}  => q{classical plural: 'cheval' --> 'chevaux'};
is noun(q{chevaux})->classical->plural, q{chevaux}  => q{classical plural: 'chevaux' --> 'chevaux'};
is noun(q{interradius})->classical->plural,   q{interradii}  => q{classical plural: 'interradius' --> 'interradii'};
is noun(q{interradii})->classical->plural, q{interradii}  => q{classical plural: 'interradii' --> 'interradii'};
is noun(q{miliola})->classical->plural,   q{miliolae}  => q{classical plural: 'miliola' --> 'miliolae'};
is noun(q{miliolae})->classical->plural, q{miliolae}  => q{classical plural: 'miliolae' --> 'miliolae'};
is noun(q{trockenbeerenauslese})->classical->plural,   q{trockenbeerenauslesen}  => q{classical plural: 'trockenbeerenauslese' --> 'trockenbeerenauslesen'};
is noun(q{trockenbeerenauslesen})->classical->plural, q{trockenbeerenauslesen}  => q{classical plural: 'trockenbeerenauslesen' --> 'trockenbeerenauslesen'};
is noun(q{Buginese})->classical->plural,   q{Buginese}  => q{classical plural: 'Buginese' --> 'Buginese'};
is noun(q{cavea})->classical->plural,   q{caveae}  => q{classical plural: 'cavea' --> 'caveae'};
is noun(q{caveae})->classical->plural, q{caveae}  => q{classical plural: 'caveae' --> 'caveae'};
is noun(q{zita})->classical->plural,   q{zite}  => q{classical plural: 'zita' --> 'zite'};
is noun(q{zite})->classical->plural, q{zite}  => q{classical plural: 'zite' --> 'zite'};
is noun(q{anti serum})->classical->plural,   q{anti sera}  => q{classical plural: 'anti serum' --> 'anti sera'};
is noun(q{anti sera})->classical->plural, q{anti sera}  => q{classical plural: 'anti sera' --> 'anti sera'};
is noun(q{cementoma})->classical->plural,   q{cementomata}  => q{classical plural: 'cementoma' --> 'cementomata'};
is noun(q{cementomata})->classical->plural, q{cementomata}  => q{classical plural: 'cementomata' --> 'cementomata'};
is noun(q{haustrum})->classical->plural,   q{haustra}  => q{classical plural: 'haustrum' --> 'haustra'};
is noun(q{haustra})->classical->plural, q{haustra}  => q{classical plural: 'haustra' --> 'haustra'};
is noun(q{genius})->classical->plural,   q{genii}  => q{classical plural: 'genius' --> 'genii'};
is noun(q{genii})->classical->plural, q{genii}  => q{classical plural: 'genii' --> 'genii'};
is noun(q{pulmonarium})->classical->plural,   q{pulmonaria}  => q{classical plural: 'pulmonarium' --> 'pulmonaria'};
is noun(q{pulmonaria})->classical->plural, q{pulmonaria}  => q{classical plural: 'pulmonaria' --> 'pulmonaria'};
is noun(q{hoof})->classical->plural,   q{hooves}  => q{classical plural: 'hoof' --> 'hooves'};
is noun(q{hooves})->classical->plural, q{hooves}  => q{classical plural: 'hooves' --> 'hooves'};
is noun(q{whosesoever})->classical->plural,   q{whosesoever}  => q{classical plural: 'whosesoever' --> 'whosesoever'};
is noun(q{choana})->classical->plural,   q{choanae}  => q{classical plural: 'choana' --> 'choanae'};
is noun(q{choanae})->classical->plural, q{choanae}  => q{classical plural: 'choanae' --> 'choanae'};
is noun(q{peninsula})->classical->plural,   q{peninsulae}  => q{classical plural: 'peninsula' --> 'peninsulae'};
is noun(q{peninsulae})->classical->plural, q{peninsulae}  => q{classical plural: 'peninsulae' --> 'peninsulae'};
is noun(q{scriptorium})->classical->plural,   q{scriptoria}  => q{classical plural: 'scriptorium' --> 'scriptoria'};
is noun(q{scriptoria})->classical->plural, q{scriptoria}  => q{classical plural: 'scriptoria' --> 'scriptoria'};
is noun(q{regidor})->classical->plural,   q{regidores}  => q{classical plural: 'regidor' --> 'regidores'};
is noun(q{regidores})->classical->plural, q{regidores}  => q{classical plural: 'regidores' --> 'regidores'};
is noun(q{staminidium})->classical->plural,   q{staminidia}  => q{classical plural: 'staminidium' --> 'staminidia'};
is noun(q{staminidia})->classical->plural, q{staminidia}  => q{classical plural: 'staminidia' --> 'staminidia'};
is noun(q{tagma})->classical->plural,   q{tagmata}  => q{classical plural: 'tagma' --> 'tagmata'};
is noun(q{tagmata})->classical->plural, q{tagmata}  => q{classical plural: 'tagmata' --> 'tagmata'};
is noun(q{Colombo})->classical->plural,   q{Colombos}  => q{classical plural: 'Colombo' --> 'Colombos'};
is noun(q{Colombos})->classical->plural, q{Colombos}  => q{classical plural: 'Colombos' --> 'Colombos'};
is noun(q{shomer})->classical->plural,   q{shomrim}  => q{classical plural: 'shomer' --> 'shomrim'};
is noun(q{shomrim})->classical->plural, q{shomrim}  => q{classical plural: 'shomrim' --> 'shomrim'};
is noun(q{siemens})->classical->plural,   q{siemens}  => q{classical plural: 'siemens' --> 'siemens'};
is noun(q{zeitgeber})->classical->plural,   q{zeitgebers}  => q{classical plural: 'zeitgeber' --> 'zeitgebers'};
is noun(q{zeitgebers})->classical->plural, q{zeitgebers}  => q{classical plural: 'zeitgebers' --> 'zeitgebers'};
is noun(q{whomsoever})->classical->plural,   q{whomsoever}  => q{classical plural: 'whomsoever' --> 'whomsoever'};
is noun(q{ammo})->classical->plural,   q{ammos}  => q{classical plural: 'ammo' --> 'ammos'};
is noun(q{ammos})->classical->plural, q{ammos}  => q{classical plural: 'ammos' --> 'ammos'};
is noun(q{rione})->classical->plural,   q{rioni}  => q{classical plural: 'rione' --> 'rioni'};
is noun(q{rioni})->classical->plural, q{rioni}  => q{classical plural: 'rioni' --> 'rioni'};
is noun(q{nautilus})->classical->plural,   q{nautili}  => q{classical plural: 'nautilus' --> 'nautili'};
is noun(q{nautili})->classical->plural, q{nautili}  => q{classical plural: 'nautili' --> 'nautili'};
is noun(q{cappuccino})->classical->plural,   q{cappuccinos}  => q{classical plural: 'cappuccino' --> 'cappuccinos'};
is noun(q{cappuccinos})->classical->plural, q{cappuccinos}  => q{classical plural: 'cappuccinos' --> 'cappuccinos'};
is noun(q{thos})->classical->plural,   q{thoes}  => q{classical plural: 'thos' --> 'thoes'};
is noun(q{thoes})->classical->plural, q{thoes}  => q{classical plural: 'thoes' --> 'thoes'};
is noun(q{oxyuris})->classical->plural,   q{oxyurides}  => q{classical plural: 'oxyuris' --> 'oxyurides'};
is noun(q{oxyurides})->classical->plural, q{oxyurides}  => q{classical plural: 'oxyurides' --> 'oxyurides'};
is noun(q{postnatus})->classical->plural,   q{postnati}  => q{classical plural: 'postnatus' --> 'postnati'};
is noun(q{postnati})->classical->plural, q{postnati}  => q{classical plural: 'postnati' --> 'postnati'};
is noun(q{quarto})->classical->plural,   q{quartos}  => q{classical plural: 'quarto' --> 'quartos'};
is noun(q{quartos})->classical->plural, q{quartos}  => q{classical plural: 'quartos' --> 'quartos'};
is noun(q{carmen})->classical->plural,   q{carmina}  => q{classical plural: 'carmen' --> 'carmina'};
is noun(q{carmina})->classical->plural, q{carmina}  => q{classical plural: 'carmina' --> 'carmina'};
is noun(q{cistophorus})->classical->plural,   q{cistophorori}  => q{classical plural: 'cistophorus' --> 'cistophorori'};
is noun(q{cistophorori})->classical->plural, q{cistophorori}  => q{classical plural: 'cistophorori' --> 'cistophorori'};
is noun(q{asyndeton})->classical->plural,   q{asyndeta}  => q{classical plural: 'asyndeton' --> 'asyndeta'};
is noun(q{asyndeta})->classical->plural, q{asyndeta}  => q{classical plural: 'asyndeta' --> 'asyndeta'};
is noun(q{coelia})->classical->plural,   q{coeliae}  => q{classical plural: 'coelia' --> 'coeliae'};
is noun(q{coeliae})->classical->plural, q{coeliae}  => q{classical plural: 'coeliae' --> 'coeliae'};
is noun(q{glutaeus})->classical->plural,   q{glutaei}  => q{classical plural: 'glutaeus' --> 'glutaei'};
is noun(q{glutaei})->classical->plural, q{glutaei}  => q{classical plural: 'glutaei' --> 'glutaei'};
is noun(q{radix})->classical->plural,   q{radices}  => q{classical plural: 'radix' --> 'radices'};
is noun(q{radices})->classical->plural, q{radices}  => q{classical plural: 'radices' --> 'radices'};
is noun(q{xiphoplastron})->classical->plural,   q{xiphoplastra}  => q{classical plural: 'xiphoplastron' --> 'xiphoplastra'};
is noun(q{xiphoplastra})->classical->plural, q{xiphoplastra}  => q{classical plural: 'xiphoplastra' --> 'xiphoplastra'};
is noun(q{dipsas})->classical->plural,   q{dipsades}  => q{classical plural: 'dipsas' --> 'dipsades'};
is noun(q{dipsades})->classical->plural, q{dipsades}  => q{classical plural: 'dipsades' --> 'dipsades'};
is noun(q{radius})->classical->plural,   q{radii}  => q{classical plural: 'radius' --> 'radii'};
is noun(q{radii})->classical->plural, q{radii}  => q{classical plural: 'radii' --> 'radii'};
is noun(q{nova})->classical->plural,   q{novae}  => q{classical plural: 'nova' --> 'novae'};
is noun(q{novae})->classical->plural, q{novae}  => q{classical plural: 'novae' --> 'novae'};
is noun(q{vaporetto})->classical->plural,   q{vaporetti}  => q{classical plural: 'vaporetto' --> 'vaporetti'};
is noun(q{vaporetti})->classical->plural, q{vaporetti}  => q{classical plural: 'vaporetti' --> 'vaporetti'};
is noun(q{terrarium})->classical->plural,   q{terraria}  => q{classical plural: 'terrarium' --> 'terraria'};
is noun(q{terraria})->classical->plural, q{terraria}  => q{classical plural: 'terraria' --> 'terraria'};
is noun(q{bulimus})->classical->plural,   q{bulimi}  => q{classical plural: 'bulimus' --> 'bulimi'};
is noun(q{bulimi})->classical->plural, q{bulimi}  => q{classical plural: 'bulimi' --> 'bulimi'};
is noun(q{hydria})->classical->plural,   q{hydriae}  => q{classical plural: 'hydria' --> 'hydriae'};
is noun(q{hydriae})->classical->plural, q{hydriae}  => q{classical plural: 'hydriae' --> 'hydriae'};
is noun(q{base})->classical->plural,   q{bases}  => q{classical plural: 'base' --> 'bases'};
is noun(q{bases})->classical->plural, q{bases}  => q{classical plural: 'bases' --> 'bases'};
is noun(q{fiasco})->classical->plural,   q{fiascos}  => q{classical plural: 'fiasco' --> 'fiascos'};
is noun(q{fiascos})->classical->plural, q{fiascos}  => q{classical plural: 'fiascos' --> 'fiascos'};
is noun(q{espresso})->classical->plural,   q{espressos}  => q{classical plural: 'espresso' --> 'espressos'};
is noun(q{espressos})->classical->plural, q{espressos}  => q{classical plural: 'espressos' --> 'espressos'};
is noun(q{toxicum})->classical->plural,   q{toxica}  => q{classical plural: 'toxicum' --> 'toxica'};
is noun(q{toxica})->classical->plural, q{toxica}  => q{classical plural: 'toxica' --> 'toxica'};
is noun(q{squalus})->classical->plural,   q{squali}  => q{classical plural: 'squalus' --> 'squali'};
is noun(q{squali})->classical->plural, q{squali}  => q{classical plural: 'squali' --> 'squali'};
is noun(q{chou})->classical->plural,   q{choux}  => q{classical plural: 'chou' --> 'choux'};
is noun(q{choux})->classical->plural, q{choux}  => q{classical plural: 'choux' --> 'choux'};
is noun(q{silbador})->classical->plural,   q{silbadores}  => q{classical plural: 'silbador' --> 'silbadores'};
is noun(q{silbadores})->classical->plural, q{silbadores}  => q{classical plural: 'silbadores' --> 'silbadores'};
is noun(q{kylix})->classical->plural,   q{kylikes}  => q{classical plural: 'kylix' --> 'kylikes'};
is noun(q{kylikes})->classical->plural, q{kylikes}  => q{classical plural: 'kylikes' --> 'kylikes'};
is noun(q{tumulus})->classical->plural,   q{tumuli}  => q{classical plural: 'tumulus' --> 'tumuli'};
is noun(q{tumuli})->classical->plural, q{tumuli}  => q{classical plural: 'tumuli' --> 'tumuli'};
is noun(q{pliers})->classical->plural,   q{pliers}  => q{classical plural: 'pliers' --> 'pliers'};
is noun(q{curriculum})->classical->plural,   q{curricula}  => q{classical plural: 'curriculum' --> 'curricula'};
is noun(q{curricula})->classical->plural, q{curricula}  => q{classical plural: 'curricula' --> 'curricula'};
is noun(q{pimento})->classical->plural,   q{pimentos}  => q{classical plural: 'pimento' --> 'pimentos'};
is noun(q{pimentos})->classical->plural, q{pimentos}  => q{classical plural: 'pimentos' --> 'pimentos'};
is noun(q{craspedum})->classical->plural,   q{craspeda}  => q{classical plural: 'craspedum' --> 'craspeda'};
is noun(q{craspeda})->classical->plural, q{craspeda}  => q{classical plural: 'craspeda' --> 'craspeda'};
is noun(q{matzah})->classical->plural,   q{matzot}  => q{classical plural: 'matzah' --> 'matzot'};
is noun(q{matzot})->classical->plural, q{matzot}  => q{classical plural: 'matzot' --> 'matzot'};
is noun(q{knife})->classical->plural,   q{knives}  => q{classical plural: 'knife' --> 'knives'};
is noun(q{knives})->classical->plural, q{knives}  => q{classical plural: 'knives' --> 'knives'};
is noun(q{yes})->classical->plural,   q{yeses}  => q{classical plural: 'yes' --> 'yeses'};
is noun(q{yeses})->classical->plural, q{yeses}  => q{classical plural: 'yeses' --> 'yeses'};
is noun(q{curioso})->classical->plural,   q{curiosi}  => q{classical plural: 'curioso' --> 'curiosi'};
is noun(q{curiosi})->classical->plural, q{curiosi}  => q{classical plural: 'curiosi' --> 'curiosi'};
is noun(q{thalamus})->classical->plural,   q{thalami}  => q{classical plural: 'thalamus' --> 'thalami'};
is noun(q{thalami})->classical->plural, q{thalami}  => q{classical plural: 'thalami' --> 'thalami'};
is noun(q{dace})->classical->plural,   q{dace}  => q{classical plural: 'dace' --> 'dace'};
is noun(q{calix})->classical->plural,   q{calices}  => q{classical plural: 'calix' --> 'calices'};
is noun(q{calices})->classical->plural, q{calices}  => q{classical plural: 'calices' --> 'calices'};
is noun(q{Borghese})->classical->plural,   q{Borghese}  => q{classical plural: 'Borghese' --> 'Borghese'};
is noun(q{hake})->classical->plural,   q{hake}  => q{classical plural: 'hake' --> 'hake'};
is noun(q{Zibo})->classical->plural,   q{Zibos}  => q{classical plural: 'Zibo' --> 'Zibos'};
is noun(q{Zibos})->classical->plural, q{Zibos}  => q{classical plural: 'Zibos' --> 'Zibos'};
is noun(q{scholium})->classical->plural,   q{scholia}  => q{classical plural: 'scholium' --> 'scholia'};
is noun(q{scholia})->classical->plural, q{scholia}  => q{classical plural: 'scholia' --> 'scholia'};
is noun(q{oceanarium})->classical->plural,   q{oceanaria}  => q{classical plural: 'oceanarium' --> 'oceanaria'};
is noun(q{oceanaria})->classical->plural, q{oceanaria}  => q{classical plural: 'oceanaria' --> 'oceanaria'};
is noun(q{ichthyosaurus})->classical->plural,   q{ichthyosauri}  => q{classical plural: 'ichthyosaurus' --> 'ichthyosauri'};
is noun(q{ichthyosauri})->classical->plural, q{ichthyosauri}  => q{classical plural: 'ichthyosauri' --> 'ichthyosauri'};
is noun(q{its})->classical->plural,   q{theirs}  => q{classical plural: 'its' --> 'theirs'};
is noun(q{sensoriolum})->classical->plural,   q{sensoriola}  => q{classical plural: 'sensoriolum' --> 'sensoriola'};
is noun(q{sensoriola})->classical->plural, q{sensoriola}  => q{classical plural: 'sensoriola' --> 'sensoriola'};
is noun(q{pycnis})->classical->plural,   q{pycnides}  => q{classical plural: 'pycnis' --> 'pycnides'};
is noun(q{pycnides})->classical->plural, q{pycnides}  => q{classical plural: 'pycnides' --> 'pycnides'};
is noun(q{cannabis})->classical->plural,   q{cannabises}  => q{classical plural: 'cannabis' --> 'cannabises'};
is noun(q{cannabises})->classical->plural, q{cannabises}  => q{classical plural: 'cannabises' --> 'cannabises'};
is noun(q{calzone})->classical->plural,   q{calzoni}  => q{classical plural: 'calzone' --> 'calzoni'};
is noun(q{calzoni})->classical->plural, q{calzoni}  => q{classical plural: 'calzoni' --> 'calzoni'};
is noun(q{cheval-de-bataille})->classical->plural,   q{chevaux-de-bataille}  => q{classical plural: 'cheval-de-bataille' --> 'chevaux-de-bataille'};
is noun(q{chevaux-de-bataille})->classical->plural, q{chevaux-de-bataille}  => q{classical plural: 'chevaux-de-bataille' --> 'chevaux-de-bataille'};
is noun(q{court martial})->classical->plural,   q{courts martial}  => q{classical plural: 'court martial' --> 'courts martial'};
is noun(q{courts martial})->classical->plural, q{courts martial}  => q{classical plural: 'courts martial' --> 'courts martial'};
is noun(q{costa})->classical->plural,   q{costae}  => q{classical plural: 'costa' --> 'costae'};
is noun(q{costae})->classical->plural, q{costae}  => q{classical plural: 'costae' --> 'costae'};
is noun(q{lacuna})->classical->plural,   q{lacunae}  => q{classical plural: 'lacuna' --> 'lacunae'};
is noun(q{lacunae})->classical->plural, q{lacunae}  => q{classical plural: 'lacunae' --> 'lacunae'};
is noun(q{moose})->classical->plural,   q{moose}  => q{classical plural: 'moose' --> 'moose'};
is noun(q{junto})->classical->plural,   q{juntos}  => q{classical plural: 'junto' --> 'juntos'};
is noun(q{juntos})->classical->plural, q{juntos}  => q{classical plural: 'juntos' --> 'juntos'};
is noun(q{blues})->classical->plural,   q{blues}  => q{classical plural: 'blues' --> 'blues'};
is noun(q{lieu})->classical->plural,   q{lieux}  => q{classical plural: 'lieu' --> 'lieux'};
is noun(q{lieux})->classical->plural, q{lieux}  => q{classical plural: 'lieux' --> 'lieux'};
is noun(q{oratrix})->classical->plural,   q{oratrices}  => q{classical plural: 'oratrix' --> 'oratrices'};
is noun(q{oratrices})->classical->plural, q{oratrices}  => q{classical plural: 'oratrices' --> 'oratrices'};
is noun(q{foramen})->classical->plural,   q{foramina}  => q{classical plural: 'foramen' --> 'foramina'};
is noun(q{foramina})->classical->plural, q{foramina}  => q{classical plural: 'foramina' --> 'foramina'};
is noun(q{logion})->classical->plural,   q{logia}  => q{classical plural: 'logion' --> 'logia'};
is noun(q{logia})->classical->plural, q{logia}  => q{classical plural: 'logia' --> 'logia'};
is noun(q{pence})->classical->plural,   q{pence}  => q{classical plural: 'pence' --> 'pence'};
is noun(q{agape})->classical->plural,   q{agapae}  => q{classical plural: 'agape' --> 'agapae'};
is noun(q{agapae})->classical->plural, q{agapae}  => q{classical plural: 'agapae' --> 'agapae'};
is noun(q{miles gloriosus})->classical->plural,   q{milites gloriosi}  => q{classical plural: 'miles gloriosus' --> 'milites gloriosi'};
is noun(q{milites gloriosi})->classical->plural, q{milites gloriosi}  => q{classical plural: 'milites gloriosi' --> 'milites gloriosi'};
is noun(q{pycnium})->classical->plural,   q{pycnia}  => q{classical plural: 'pycnium' --> 'pycnia'};
is noun(q{pycnia})->classical->plural, q{pycnia}  => q{classical plural: 'pycnia' --> 'pycnia'};
is noun(q{pycnidium})->classical->plural,   q{pycnidia}  => q{classical plural: 'pycnidium' --> 'pycnidia'};
is noun(q{pycnidia})->classical->plural, q{pycnidia}  => q{classical plural: 'pycnidia' --> 'pycnidia'};
is noun(q{pes})->classical->plural,   q{pedes}  => q{classical plural: 'pes' --> 'pedes'};
is noun(q{pedes})->classical->plural, q{pedes}  => q{classical plural: 'pedes' --> 'pedes'};
is noun(q{modelletto})->classical->plural,   q{modelletti}  => q{classical plural: 'modelletto' --> 'modelletti'};
is noun(q{modelletti})->classical->plural, q{modelletti}  => q{classical plural: 'modelletti' --> 'modelletti'};
is noun(q{pleurum})->classical->plural,   q{pleura}  => q{classical plural: 'pleurum' --> 'pleura'};
is noun(q{tong})->classical->plural,   q{tongs}  => q{classical plural: 'tong' --> 'tongs'};
is noun(q{Harlemese})->classical->plural,   q{Harlemese}  => q{classical plural: 'Harlemese' --> 'Harlemese'};
is noun(q{syntaxis})->classical->plural,   q{syntaxes}  => q{classical plural: 'syntaxis' --> 'syntaxes'};
is noun(q{syntaxes})->classical->plural, q{syntaxes}  => q{classical plural: 'syntaxes' --> 'syntaxes'};
is noun(q{crazia})->classical->plural,   q{crazie}  => q{classical plural: 'crazia' --> 'crazie'};
is noun(q{crazie})->classical->plural, q{crazie}  => q{classical plural: 'crazie' --> 'crazie'};
is noun(q{hairdo})->classical->plural,   q{hairdos}  => q{classical plural: 'hairdo' --> 'hairdos'};
is noun(q{hairdos})->classical->plural, q{hairdos}  => q{classical plural: 'hairdos' --> 'hairdos'};
is noun(q{mycoplasma})->classical->plural,   q{mycoplasmata}  => q{classical plural: 'mycoplasma' --> 'mycoplasmata'};
is noun(q{mycoplasmata})->classical->plural, q{mycoplasmata}  => q{classical plural: 'mycoplasmata' --> 'mycoplasmata'};
is noun(q{trattoria})->classical->plural,   q{trattorie}  => q{classical plural: 'trattoria' --> 'trattorie'};
is noun(q{trattorie})->classical->plural, q{trattorie}  => q{classical plural: 'trattorie' --> 'trattorie'};
is noun(q{lumbago})->classical->plural,   q{lumbagos}  => q{classical plural: 'lumbago' --> 'lumbagos'};
is noun(q{lumbagos})->classical->plural, q{lumbagos}  => q{classical plural: 'lumbagos' --> 'lumbagos'};
is noun(q{craspedon})->classical->plural,   q{craspeda}  => q{classical plural: 'craspedon' --> 'craspeda'};
is noun(q{craspeda})->classical->plural, q{craspeda}  => q{classical plural: 'craspeda' --> 'craspeda'};
is noun(q{Lilo})->classical->plural,   q{Lilos}  => q{classical plural: 'Lilo' --> 'Lilos'};
is noun(q{Lilos})->classical->plural, q{Lilos}  => q{classical plural: 'Lilos' --> 'Lilos'};
is noun(q{herself})->classical->plural,   q{themselves}  => q{classical plural: 'herself' --> 'themselves'};
is noun(q{microfiche})->classical->plural,   q{microfiche}  => q{classical plural: 'microfiche' --> 'microfiche'};
is noun(q{metalimnion})->classical->plural,   q{metalimnia}  => q{classical plural: 'metalimnion' --> 'metalimnia'};
is noun(q{metalimnia})->classical->plural, q{metalimnia}  => q{classical plural: 'metalimnia' --> 'metalimnia'};
is noun(q{cladus})->classical->plural,   q{cladi}  => q{classical plural: 'cladus' --> 'cladi'};
is noun(q{cladi})->classical->plural, q{cladi}  => q{classical plural: 'cladi' --> 'cladi'};
is noun(q{pro})->classical->plural,   q{pros}  => q{classical plural: 'pro' --> 'pros'};
is noun(q{pros})->classical->plural, q{pros}  => q{classical plural: 'pros' --> 'pros'};
is noun(q{modus})->classical->plural,   q{modi}  => q{classical plural: 'modus' --> 'modi'};
is noun(q{modi})->classical->plural, q{modi}  => q{classical plural: 'modi' --> 'modi'};
is noun(q{womanchild})->classical->plural,   q{womenchildren}  => q{classical plural: 'womanchild' --> 'womenchildren'};
is noun(q{womenchildren})->classical->plural, q{womenchildren}  => q{classical plural: 'womenchildren' --> 'womenchildren'};
is noun(q{vorstellung})->classical->plural,   q{vorstellungen}  => q{classical plural: 'vorstellung' --> 'vorstellungen'};
is noun(q{vorstellungen})->classical->plural, q{vorstellungen}  => q{classical plural: 'vorstellungen' --> 'vorstellungen'};
is noun(q{thema})->classical->plural,   q{themata}  => q{classical plural: 'thema' --> 'themata'};
is noun(q{themata})->classical->plural, q{themata}  => q{classical plural: 'themata' --> 'themata'};
is noun(q{impetus})->classical->plural,   q{impetus}  => q{classical plural: 'impetus' --> 'impetus'};
is noun(q{glasses})->classical->plural,   q{glasses}  => q{classical plural: 'glasses' --> 'glasses'};
is noun(q{proscolla})->classical->plural,   q{proscollae}  => q{classical plural: 'proscolla' --> 'proscollae'};
is noun(q{proscollae})->classical->plural, q{proscollae}  => q{classical plural: 'proscollae' --> 'proscollae'};
is noun(q{saddo})->classical->plural,   q{saddos}  => q{classical plural: 'saddo' --> 'saddos'};
is noun(q{saddos})->classical->plural, q{saddos}  => q{classical plural: 'saddos' --> 'saddos'};
is noun(q{mantelletta})->classical->plural,   q{mantellette}  => q{classical plural: 'mantelletta' --> 'mantellette'};
is noun(q{mantellette})->classical->plural, q{mantellette}  => q{classical plural: 'mantellette' --> 'mantellette'};
is noun(q{blouse})->classical->plural,   q{blouses}  => q{classical plural: 'blouse' --> 'blouses'};
is noun(q{blouses})->classical->plural, q{blouses}  => q{classical plural: 'blouses' --> 'blouses'};
is noun(q{individuum})->classical->plural,   q{individua}  => q{classical plural: 'individuum' --> 'individua'};
is noun(q{individua})->classical->plural, q{individua}  => q{classical plural: 'individua' --> 'individua'};
is noun(q{Montenegro})->classical->plural,   q{Montenegros}  => q{classical plural: 'Montenegro' --> 'Montenegros'};
is noun(q{Montenegros})->classical->plural, q{Montenegros}  => q{classical plural: 'Montenegros' --> 'Montenegros'};
is noun(q{melisma})->classical->plural,   q{melismata}  => q{classical plural: 'melisma' --> 'melismata'};
is noun(q{melismata})->classical->plural, q{melismata}  => q{classical plural: 'melismata' --> 'melismata'};
is noun(q{faecula})->classical->plural,   q{faeculae}  => q{classical plural: 'faecula' --> 'faeculae'};
is noun(q{faeculae})->classical->plural, q{faeculae}  => q{classical plural: 'faeculae' --> 'faeculae'};
is noun(q{Orinoco})->classical->plural,   q{Orinocos}  => q{classical plural: 'Orinoco' --> 'Orinocos'};
is noun(q{Orinocos})->classical->plural, q{Orinocos}  => q{classical plural: 'Orinocos' --> 'Orinocos'};
is noun(q{granula})->classical->plural,   q{granulae}  => q{classical plural: 'granula' --> 'granulae'};
is noun(q{granulae})->classical->plural, q{granulae}  => q{classical plural: 'granulae' --> 'granulae'};
is noun(q{thyrsus})->classical->plural,   q{thyrsi}  => q{classical plural: 'thyrsus' --> 'thyrsi'};
is noun(q{thyrsi})->classical->plural, q{thyrsi}  => q{classical plural: 'thyrsi' --> 'thyrsi'};
is noun(q{meniscus})->classical->plural,   q{menisci}  => q{classical plural: 'meniscus' --> 'menisci'};
is noun(q{menisci})->classical->plural, q{menisci}  => q{classical plural: 'menisci' --> 'menisci'};
is noun(q{two star general})->classical->plural,   q{two star generals}  => q{classical plural: 'two star general' --> 'two star generals'};
is noun(q{two star generals})->classical->plural, q{two star generals}  => q{classical plural: 'two star generals' --> 'two star generals'};
is noun(q{non-ens})->classical->plural,   q{nonentia}  => q{classical plural: 'non-ens' --> 'nonentia'};
is noun(q{nonentia})->classical->plural, q{nonentia}  => q{classical plural: 'nonentia' --> 'nonentia'};
is noun(q{chassis})->classical->plural,   q{chassis}  => q{classical plural: 'chassis' --> 'chassis'};
is noun(q{pyrophorus})->classical->plural,   q{pyrophori}  => q{classical plural: 'pyrophorus' --> 'pyrophori'};
is noun(q{pyrophori})->classical->plural, q{pyrophori}  => q{classical plural: 'pyrophori' --> 'pyrophori'};
is noun(q{lentiscus})->classical->plural,   q{lentisci}  => q{classical plural: 'lentiscus' --> 'lentisci'};
is noun(q{lentisci})->classical->plural, q{lentisci}  => q{classical plural: 'lentisci' --> 'lentisci'};
is noun(q{floccus})->classical->plural,   q{flocci}  => q{classical plural: 'floccus' --> 'flocci'};
is noun(q{flocci})->classical->plural, q{flocci}  => q{classical plural: 'flocci' --> 'flocci'};
is noun(q{sirocco})->classical->plural,   q{siroccos}  => q{classical plural: 'sirocco' --> 'siroccos'};
is noun(q{siroccos})->classical->plural, q{siroccos}  => q{classical plural: 'siroccos' --> 'siroccos'};
is noun(q{ophiophagus})->classical->plural,   q{ophiophagi}  => q{classical plural: 'ophiophagus' --> 'ophiophagi'};
is noun(q{ophiophagi})->classical->plural, q{ophiophagi}  => q{classical plural: 'ophiophagi' --> 'ophiophagi'};
is noun(q{pants})->classical->plural,   q{pants}  => q{classical plural: 'pants' --> 'pants'};
is noun(q{striola})->classical->plural,   q{striolae}  => q{classical plural: 'striola' --> 'striolae'};
is noun(q{striolae})->classical->plural, q{striolae}  => q{classical plural: 'striolae' --> 'striolae'};
is noun(q{odeum})->classical->plural,   q{odea}  => q{classical plural: 'odeum' --> 'odea'};
is noun(q{odea})->classical->plural, q{odea}  => q{classical plural: 'odea' --> 'odea'};
is noun(q{devoto})->classical->plural,   q{devoti}  => q{classical plural: 'devoto' --> 'devoti'};
is noun(q{devoti})->classical->plural, q{devoti}  => q{classical plural: 'devoti' --> 'devoti'};
is noun(q{sensedatum})->classical->plural,   q{sensedata}  => q{classical plural: 'sensedatum' --> 'sensedata'};
is noun(q{sensedata})->classical->plural, q{sensedata}  => q{classical plural: 'sensedata' --> 'sensedata'};
is noun(q{maquereau})->classical->plural,   q{maquereaux}  => q{classical plural: 'maquereau' --> 'maquereaux'};
is noun(q{maquereaux})->classical->plural, q{maquereaux}  => q{classical plural: 'maquereaux' --> 'maquereaux'};
is noun(q{mycorhiza})->classical->plural,   q{mycorhizae}  => q{classical plural: 'mycorhiza' --> 'mycorhizae'};
is noun(q{mycorhizae})->classical->plural, q{mycorhizae}  => q{classical plural: 'mycorhizae' --> 'mycorhizae'};
is noun(q{embryo})->classical->plural,   q{embryos}  => q{classical plural: 'embryo' --> 'embryos'};
is noun(q{embryos})->classical->plural, q{embryos}  => q{classical plural: 'embryos' --> 'embryos'};
is noun(q{propodium})->classical->plural,   q{propodia}  => q{classical plural: 'propodium' --> 'propodia'};
is noun(q{propodia})->classical->plural, q{propodia}  => q{classical plural: 'propodia' --> 'propodia'};
is noun(q{anta})->classical->plural,   q{antae}  => q{classical plural: 'anta' --> 'antae'};
is noun(q{antae})->classical->plural, q{antae}  => q{classical plural: 'antae' --> 'antae'};
is noun(q{mithraeum})->classical->plural,   q{mithraea}  => q{classical plural: 'mithraeum' --> 'mithraea'};
is noun(q{mithraea})->classical->plural, q{mithraea}  => q{classical plural: 'mithraea' --> 'mithraea'};
is noun(q{haustellum})->classical->plural,   q{haustella}  => q{classical plural: 'haustellum' --> 'haustella'};
is noun(q{haustella})->classical->plural, q{haustella}  => q{classical plural: 'haustella' --> 'haustella'};
is noun(q{bacterium})->classical->plural,   q{bacteria}  => q{classical plural: 'bacterium' --> 'bacteria'};
is noun(q{bacteria})->classical->plural, q{bacteria}  => q{classical plural: 'bacteria' --> 'bacteria'};
is noun(q{Macassarese})->classical->plural,   q{Macassarese}  => q{classical plural: 'Macassarese' --> 'Macassarese'};
is noun(q{Ceylonese})->classical->plural,   q{Ceylonese}  => q{classical plural: 'Ceylonese' --> 'Ceylonese'};
is noun(q{juelet})->classical->plural,   q{iueles}  => q{classical plural: 'juelet' --> 'iueles'};
is noun(q{iueles})->classical->plural, q{iueles}  => q{classical plural: 'iueles' --> 'iueles'};
is noun(q{magma})->classical->plural,   q{magmata}  => q{classical plural: 'magma' --> 'magmata'};
is noun(q{magmata})->classical->plural, q{magmata}  => q{classical plural: 'magmata' --> 'magmata'};
is noun(q{coco})->classical->plural,   q{cocos}  => q{classical plural: 'coco' --> 'cocos'};
is noun(q{cocos})->classical->plural, q{cocos}  => q{classical plural: 'cocos' --> 'cocos'};
is noun(q{gyro})->classical->plural,   q{gyros}  => q{classical plural: 'gyro' --> 'gyros'};
is noun(q{gyros})->classical->plural, q{gyros}  => q{classical plural: 'gyros' --> 'gyros'};
is noun(q{nympheum})->classical->plural,   q{nymphaea}  => q{classical plural: 'nympheum' --> 'nymphaea'};
is noun(q{nymphaea})->classical->plural, q{nymphaea}  => q{classical plural: 'nymphaea' --> 'nymphaea'};
is noun(q{microbion})->classical->plural,   q{microbia}  => q{classical plural: 'microbion' --> 'microbia'};
is noun(q{microbia})->classical->plural, q{microbia}  => q{classical plural: 'microbia' --> 'microbia'};
is noun(q{ragazzo})->classical->plural,   q{ragazzi}  => q{classical plural: 'ragazzo' --> 'ragazzi'};
is noun(q{ragazzi})->classical->plural, q{ragazzi}  => q{classical plural: 'ragazzi' --> 'ragazzi'};
is noun(q{vorspiel})->classical->plural,   q{vorspiele}  => q{classical plural: 'vorspiel' --> 'vorspiele'};
is noun(q{vorspiele})->classical->plural, q{vorspiele}  => q{classical plural: 'vorspiele' --> 'vorspiele'};
is noun(q{concerto grosso})->classical->plural,   q{concerti grossi}  => q{classical plural: 'concerto grosso' --> 'concerti grossi'};
is noun(q{concerti grossi})->classical->plural, q{concerti grossi}  => q{classical plural: 'concerti grossi' --> 'concerti grossi'};
is noun(q{sphagnum})->classical->plural,   q{sphagna}  => q{classical plural: 'sphagnum' --> 'sphagna'};
is noun(q{sphagna})->classical->plural, q{sphagna}  => q{classical plural: 'sphagna' --> 'sphagna'};
is noun(q{ottoman})->classical->plural,   q{ottomans}  => q{classical plural: 'ottoman' --> 'ottomans'};
is noun(q{ottomans})->classical->plural, q{ottomans}  => q{classical plural: 'ottomans' --> 'ottomans'};
is noun(q{hetaera})->classical->plural,   q{hetairai}  => q{classical plural: 'hetaera' --> 'hetairai'};
is noun(q{hetairai})->classical->plural, q{hetairai}  => q{classical plural: 'hetairai' --> 'hetairai'};
is noun(q{hormogonium})->classical->plural,   q{hormogonia}  => q{classical plural: 'hormogonium' --> 'hormogonia'};
is noun(q{hormogonia})->classical->plural, q{hormogonia}  => q{classical plural: 'hormogonia' --> 'hormogonia'};
is noun(q{scapula})->classical->plural,   q{scapulae}  => q{classical plural: 'scapula' --> 'scapulae'};
is noun(q{scapulae})->classical->plural, q{scapulae}  => q{classical plural: 'scapulae' --> 'scapulae'};
is noun(q{rhizoma})->classical->plural,   q{rhizomata}  => q{classical plural: 'rhizoma' --> 'rhizomata'};
is noun(q{rhizomata})->classical->plural, q{rhizomata}  => q{classical plural: 'rhizomata' --> 'rhizomata'};
is noun(q{rete})->classical->plural,   q{retia}  => q{classical plural: 'rete' --> 'retia'};
is noun(q{retia})->classical->plural, q{retia}  => q{classical plural: 'retia' --> 'retia'};
is noun(q{vibraculum})->classical->plural,   q{vibracula}  => q{classical plural: 'vibraculum' --> 'vibracula'};
is noun(q{vibracula})->classical->plural, q{vibracula}  => q{classical plural: 'vibracula' --> 'vibracula'};
is noun(q{ri})->classical->plural,   q{ri}  => q{classical plural: 'ri' --> 'ri'};
is noun(q{toxius})->classical->plural,   q{toxii}  => q{classical plural: 'toxius' --> 'toxii'};
is noun(q{toxii})->classical->plural, q{toxii}  => q{classical plural: 'toxii' --> 'toxii'};
is noun(q{bon mot})->classical->plural,   q{bons mots}  => q{classical plural: 'bon mot' --> 'bons mots'};
is noun(q{bons mots})->classical->plural, q{bons mots}  => q{classical plural: 'bons mots' --> 'bons mots'};
is noun(q{mousetrap})->classical->plural,   q{micetraps}  => q{classical plural: 'mousetrap' --> 'micetraps'};
is noun(q{micetraps})->classical->plural, q{micetraps}  => q{classical plural: 'micetraps' --> 'micetraps'};
is noun(q{Londonese})->classical->plural,   q{Londonese}  => q{classical plural: 'Londonese' --> 'Londonese'};
is noun(q{gmina})->classical->plural,   q{gminy}  => q{classical plural: 'gmina' --> 'gminy'};
is noun(q{gminy})->classical->plural, q{gminy}  => q{classical plural: 'gminy' --> 'gminy'};
is noun(q{malleus})->classical->plural,   q{mallei}  => q{classical plural: 'malleus' --> 'mallei'};
is noun(q{mallei})->classical->plural, q{mallei}  => q{classical plural: 'mallei' --> 'mallei'};
is noun(q{mono})->classical->plural,   q{monos}  => q{classical plural: 'mono' --> 'monos'};
is noun(q{monos})->classical->plural, q{monos}  => q{classical plural: 'monos' --> 'monos'};
is noun(q{cercus})->classical->plural,   q{cerci}  => q{classical plural: 'cercus' --> 'cerci'};
is noun(q{cerci})->classical->plural, q{cerci}  => q{classical plural: 'cerci' --> 'cerci'};
is noun(q{rhomboideus})->classical->plural,   q{rhomboidei}  => q{classical plural: 'rhomboideus' --> 'rhomboidei'};
is noun(q{rhomboidei})->classical->plural, q{rhomboidei}  => q{classical plural: 'rhomboidei' --> 'rhomboidei'};
is noun(q{sachverhalt})->classical->plural,   q{sachverhalte}  => q{classical plural: 'sachverhalt' --> 'sachverhalte'};
is noun(q{sachverhalte})->classical->plural, q{sachverhalte}  => q{classical plural: 'sachverhalte' --> 'sachverhalte'};
is noun(q{sheep})->classical->plural,   q{sheep}  => q{classical plural: 'sheep' --> 'sheep'};
is noun(q{mesothelioma})->classical->plural,   q{mesotheliomata}  => q{classical plural: 'mesothelioma' --> 'mesotheliomata'};
is noun(q{mesotheliomata})->classical->plural, q{mesotheliomata}  => q{classical plural: 'mesotheliomata' --> 'mesotheliomata'};
is noun(q{zucca})->classical->plural,   q{zucche}  => q{classical plural: 'zucca' --> 'zucche'};
is noun(q{zucche})->classical->plural, q{zucche}  => q{classical plural: 'zucche' --> 'zucche'};
is noun(q{Yuman})->classical->plural,   q{Yumans}  => q{classical plural: 'Yuman' --> 'Yumans'};
is noun(q{Yumans})->classical->plural, q{Yumans}  => q{classical plural: 'Yumans' --> 'Yumans'};
is noun(q{toril})->classical->plural,   q{toriles}  => q{classical plural: 'toril' --> 'toriles'};
is noun(q{toriles})->classical->plural, q{toriles}  => q{classical plural: 'toriles' --> 'toriles'};
is noun(q{tenderfoot})->classical->plural,   q{tenderfoots}  => q{classical plural: 'tenderfoot' --> 'tenderfoots'};
is noun(q{tenderfoots})->classical->plural, q{tenderfoots}  => q{classical plural: 'tenderfoots' --> 'tenderfoots'};
is noun(q{paraganglion})->classical->plural,   q{paraganglia}  => q{classical plural: 'paraganglion' --> 'paraganglia'};
is noun(q{paraganglia})->classical->plural, q{paraganglia}  => q{classical plural: 'paraganglia' --> 'paraganglia'};
is noun(q{solarium})->classical->plural,   q{solaria}  => q{classical plural: 'solarium' --> 'solaria'};
is noun(q{solaria})->classical->plural, q{solaria}  => q{classical plural: 'solaria' --> 'solaria'};
is noun(q{surimono})->classical->plural,   q{surimonos}  => q{classical plural: 'surimono' --> 'surimonos'};
is noun(q{surimonos})->classical->plural, q{surimonos}  => q{classical plural: 'surimonos' --> 'surimonos'};
is noun(q{sephardi})->classical->plural,   q{sephardin}  => q{classical plural: 'sephardi' --> 'sephardin'};
is noun(q{sephardin})->classical->plural, q{sephardin}  => q{classical plural: 'sephardin' --> 'sephardin'};
is noun(q{naya paisa})->classical->plural,   q{naye paise}  => q{classical plural: 'naya paisa' --> 'naye paise'};
is noun(q{naye paise})->classical->plural, q{naye paise}  => q{classical plural: 'naye paise' --> 'naye paise'};
is noun(q{Silurus})->classical->plural,   q{Siluri}  => q{classical plural: 'Silurus' --> 'Siluri'};
is noun(q{Siluri})->classical->plural, q{Siluri}  => q{classical plural: 'Siluri' --> 'Siluri'};
is noun(q{sum-total})->classical->plural,   q{sums-total}  => q{classical plural: 'sum-total' --> 'sums-total'};
is noun(q{sums-total})->classical->plural, q{sums-total}  => q{classical plural: 'sums-total' --> 'sums-total'};
is noun(q{graffiti})->classical->plural,   q{graffiti}  => q{classical plural: 'graffiti' --> 'graffiti'};
is noun(q{fly})->classical->plural,   q{flys}  => q{classical plural: 'fly' --> 'flys'};
is noun(q{flys})->classical->plural, q{flys}  => q{classical plural: 'flys' --> 'flys'};
is noun(q{exencephalus})->classical->plural,   q{exencephali}  => q{classical plural: 'exencephalus' --> 'exencephali'};
is noun(q{exencephali})->classical->plural, q{exencephali}  => q{classical plural: 'exencephali' --> 'exencephali'};
is noun(q{bandeau})->classical->plural,   q{bandeaux}  => q{classical plural: 'bandeau' --> 'bandeaux'};
is noun(q{bandeaux})->classical->plural, q{bandeaux}  => q{classical plural: 'bandeaux' --> 'bandeaux'};
is noun(q{pernio})->classical->plural,   q{perniones}  => q{classical plural: 'pernio' --> 'perniones'};
is noun(q{perniones})->classical->plural, q{perniones}  => q{classical plural: 'perniones' --> 'perniones'};
is noun(q{rond de jambe})->classical->plural,   q{ronds de jambes}  => q{classical plural: 'rond de jambe' --> 'ronds de jambes'};
is noun(q{ronds de jambes})->classical->plural, q{ronds de jambes}  => q{classical plural: 'ronds de jambes' --> 'ronds de jambes'};
is noun(q{Paramaribo})->classical->plural,   q{Paramaribos}  => q{classical plural: 'Paramaribo' --> 'Paramaribos'};
is noun(q{Paramaribos})->classical->plural, q{Paramaribos}  => q{classical plural: 'Paramaribos' --> 'Paramaribos'};
is noun(q{nomisma})->classical->plural,   q{nomismata}  => q{classical plural: 'nomisma' --> 'nomismata'};
is noun(q{nomismata})->classical->plural, q{nomismata}  => q{classical plural: 'nomismata' --> 'nomismata'};
is noun(q{tempo})->classical->plural,   q{tempi}  => q{classical plural: 'tempo' --> 'tempi'};
is noun(q{tempi})->classical->plural, q{tempi}  => q{classical plural: 'tempi' --> 'tempi'};
is noun(q{Hoosierese})->classical->plural,   q{Hoosierese}  => q{classical plural: 'Hoosierese' --> 'Hoosierese'};
is noun(q{vermicello})->classical->plural,   q{vermicellos}  => q{classical plural: 'vermicello' --> 'vermicellos'};
is noun(q{vermicellos})->classical->plural, q{vermicellos}  => q{classical plural: 'vermicellos' --> 'vermicellos'};
is noun(q{matin})->classical->plural,   q{matins}  => q{classical plural: 'matin' --> 'matins'};
is noun(q{matins})->classical->plural, q{matins}  => q{classical plural: 'matins' --> 'matins'};
is noun(q{portiforium})->classical->plural,   q{portiforia}  => q{classical plural: 'portiforium' --> 'portiforia'};
is noun(q{portiforia})->classical->plural, q{portiforia}  => q{classical plural: 'portiforia' --> 'portiforia'};
is noun(q{crus})->classical->plural,   q{crura}  => q{classical plural: 'crus' --> 'crura'};
is noun(q{crura})->classical->plural, q{crura}  => q{classical plural: 'crura' --> 'crura'};
is noun(q{monas})->classical->plural,   q{monades}  => q{classical plural: 'monas' --> 'monades'};
is noun(q{monades})->classical->plural, q{monades}  => q{classical plural: 'monades' --> 'monades'};
is noun(q{plateau})->classical->plural,   q{plateaux}  => q{classical plural: 'plateau' --> 'plateaux'};
is noun(q{plateaux})->classical->plural, q{plateaux}  => q{classical plural: 'plateaux' --> 'plateaux'};
is noun(q{momentum})->classical->plural,   q{momenta}  => q{classical plural: 'momentum' --> 'momenta'};
is noun(q{momenta})->classical->plural, q{momenta}  => q{classical plural: 'momenta' --> 'momenta'};
is noun(q{leproma})->classical->plural,   q{lepromata}  => q{classical plural: 'leproma' --> 'lepromata'};
is noun(q{lepromata})->classical->plural, q{lepromata}  => q{classical plural: 'lepromata' --> 'lepromata'};
is noun(q{pinax})->classical->plural,   q{pinaces}  => q{classical plural: 'pinax' --> 'pinaces'};
is noun(q{pinaces})->classical->plural, q{pinaces}  => q{classical plural: 'pinaces' --> 'pinaces'};
is noun(q{politico})->classical->plural,   q{politicoes}  => q{classical plural: 'politico' --> 'politicoes'};
is noun(q{politicoes})->classical->plural, q{politicoes}  => q{classical plural: 'politicoes' --> 'politicoes'};
is noun(q{barrico})->classical->plural,   q{barricoes}  => q{classical plural: 'barrico' --> 'barricoes'};
is noun(q{barricoes})->classical->plural, q{barricoes}  => q{classical plural: 'barricoes' --> 'barricoes'};
is noun(q{sensillum})->classical->plural,   q{sensilla}  => q{classical plural: 'sensillum' --> 'sensilla'};
is noun(q{sensilla})->classical->plural, q{sensilla}  => q{classical plural: 'sensilla' --> 'sensilla'};
is noun(q{soshi})->classical->plural,   q{soshi}  => q{classical plural: 'soshi' --> 'soshi'};
is noun(q{pathos})->classical->plural,   q{pathoses}  => q{classical plural: 'pathos' --> 'pathoses'};
is noun(q{pathoses})->classical->plural, q{pathoses}  => q{classical plural: 'pathoses' --> 'pathoses'};
is noun(q{telamon})->classical->plural,   q{telamones}  => q{classical plural: 'telamon' --> 'telamones'};
is noun(q{telamones})->classical->plural, q{telamones}  => q{classical plural: 'telamones' --> 'telamones'};
is noun(q{cilantro})->classical->plural,   q{cilantros}  => q{classical plural: 'cilantro' --> 'cilantros'};
is noun(q{cilantros})->classical->plural, q{cilantros}  => q{classical plural: 'cilantros' --> 'cilantros'};
is noun(q{cantharus})->classical->plural,   q{canthari}  => q{classical plural: 'cantharus' --> 'canthari'};
is noun(q{canthari})->classical->plural, q{canthari}  => q{classical plural: 'canthari' --> 'canthari'};
is noun(q{nucleolonema})->classical->plural,   q{nucleolonemata}  => q{classical plural: 'nucleolonema' --> 'nucleolonemata'};
is noun(q{nucleolonemata})->classical->plural, q{nucleolonemata}  => q{classical plural: 'nucleolonemata' --> 'nucleolonemata'};
is noun(q{Hiroshiman})->classical->plural,   q{Hiroshimans}  => q{classical plural: 'Hiroshiman' --> 'Hiroshimans'};
is noun(q{Hiroshimans})->classical->plural, q{Hiroshimans}  => q{classical plural: 'Hiroshimans' --> 'Hiroshimans'};
is noun(q{sbirro})->classical->plural,   q{sbirri}  => q{classical plural: 'sbirro' --> 'sbirri'};
is noun(q{sbirri})->classical->plural, q{sbirri}  => q{classical plural: 'sbirri' --> 'sbirri'};
is noun(q{scutellum})->classical->plural,   q{scutella}  => q{classical plural: 'scutellum' --> 'scutella'};
is noun(q{scutella})->classical->plural, q{scutella}  => q{classical plural: 'scutella' --> 'scutella'};
is noun(q{albino})->classical->plural,   q{albinos}  => q{classical plural: 'albino' --> 'albinos'};
is noun(q{albinos})->classical->plural, q{albinos}  => q{classical plural: 'albinos' --> 'albinos'};
is noun(q{Boto})->classical->plural,   q{Botos}  => q{classical plural: 'Boto' --> 'Botos'};
is noun(q{Botos})->classical->plural, q{Botos}  => q{classical plural: 'Botos' --> 'Botos'};
is noun(q{condottiere})->classical->plural,   q{condottieri}  => q{classical plural: 'condottiere' --> 'condottieri'};
is noun(q{condottieri})->classical->plural, q{condottieri}  => q{classical plural: 'condottieri' --> 'condottieri'};
is noun(q{nouveau pauvre})->classical->plural,   q{nouveaux pauvres}  => q{classical plural: 'nouveau pauvre' --> 'nouveaux pauvres'};
is noun(q{nouveaux pauvres})->classical->plural, q{nouveaux pauvres}  => q{classical plural: 'nouveaux pauvres' --> 'nouveaux pauvres'};
is noun(q{mimosa})->classical->plural,   q{mimosae}  => q{classical plural: 'mimosa' --> 'mimosae'};
is noun(q{mimosae})->classical->plural, q{mimosae}  => q{classical plural: 'mimosae' --> 'mimosae'};
is noun(q{compendium})->classical->plural,   q{compendia}  => q{classical plural: 'compendium' --> 'compendia'};
is noun(q{compendia})->classical->plural, q{compendia}  => q{classical plural: 'compendia' --> 'compendia'};
is noun(q{Romagnese})->classical->plural,   q{Romagnese}  => q{classical plural: 'Romagnese' --> 'Romagnese'};
is noun(q{basilica})->classical->plural,   q{basilicae}  => q{classical plural: 'basilica' --> 'basilicae'};
is noun(q{basilicae})->classical->plural, q{basilicae}  => q{classical plural: 'basilicae' --> 'basilicae'};
is noun(q{malagma})->classical->plural,   q{malagmata}  => q{classical plural: 'malagma' --> 'malagmata'};
is noun(q{malagmata})->classical->plural, q{malagmata}  => q{classical plural: 'malagmata' --> 'malagmata'};
is noun(q{velarium})->classical->plural,   q{velaria}  => q{classical plural: 'velarium' --> 'velaria'};
is noun(q{velaria})->classical->plural, q{velaria}  => q{classical plural: 'velaria' --> 'velaria'};
is noun(q{Maputo})->classical->plural,   q{Maputos}  => q{classical plural: 'Maputo' --> 'Maputos'};
is noun(q{Maputos})->classical->plural, q{Maputos}  => q{classical plural: 'Maputos' --> 'Maputos'};
is noun(q{ovolo})->classical->plural,   q{ovoli}  => q{classical plural: 'ovolo' --> 'ovoli'};
is noun(q{ovoli})->classical->plural, q{ovoli}  => q{classical plural: 'ovoli' --> 'ovoli'};
is noun(q{mongoose})->classical->plural,   q{mongooses}  => q{classical plural: 'mongoose' --> 'mongooses'};
is noun(q{mongooses})->classical->plural, q{mongooses}  => q{classical plural: 'mongooses' --> 'mongooses'};
is noun(q{Tirolese})->classical->plural,   q{Tirolese}  => q{classical plural: 'Tirolese' --> 'Tirolese'};
is noun(q{them})->classical->plural,   q{them}  => q{classical plural: 'them' --> 'them'};
is noun(q{ricercar})->classical->plural,   q{ricercari}  => q{classical plural: 'ricercar' --> 'ricercari'};
is noun(q{ricercari})->classical->plural, q{ricercari}  => q{classical plural: 'ricercari' --> 'ricercari'};
is noun(q{famulus})->classical->plural,   q{famuli}  => q{classical plural: 'famulus' --> 'famuli'};
is noun(q{famuli})->classical->plural, q{famuli}  => q{classical plural: 'famuli' --> 'famuli'};
is noun(q{rhinophyma})->classical->plural,   q{rhinophymata}  => q{classical plural: 'rhinophyma' --> 'rhinophymata'};
is noun(q{rhinophymata})->classical->plural, q{rhinophymata}  => q{classical plural: 'rhinophymata' --> 'rhinophymata'};
is noun(q{porron})->classical->plural,   q{porrones}  => q{classical plural: 'porron' --> 'porrones'};
is noun(q{porrones})->classical->plural, q{porrones}  => q{classical plural: 'porrones' --> 'porrones'};
is noun(q{angioma})->classical->plural,   q{angiomata}  => q{classical plural: 'angioma' --> 'angiomata'};
is noun(q{angiomata})->classical->plural, q{angiomata}  => q{classical plural: 'angiomata' --> 'angiomata'};
is noun(q{gringo})->classical->plural,   q{gringos}  => q{classical plural: 'gringo' --> 'gringos'};
is noun(q{gringos})->classical->plural, q{gringos}  => q{classical plural: 'gringos' --> 'gringos'};
is noun(q{viaticum})->classical->plural,   q{viatica}  => q{classical plural: 'viaticum' --> 'viatica'};
is noun(q{viatica})->classical->plural, q{viatica}  => q{classical plural: 'viatica' --> 'viatica'};
is noun(q{kimono})->classical->plural,   q{kimonos}  => q{classical plural: 'kimono' --> 'kimonos'};
is noun(q{kimonos})->classical->plural, q{kimonos}  => q{classical plural: 'kimonos' --> 'kimonos'};
is noun(q{thyridium})->classical->plural,   q{thyridia}  => q{classical plural: 'thyridium' --> 'thyridia'};
is noun(q{thyridia})->classical->plural, q{thyridia}  => q{classical plural: 'thyridia' --> 'thyridia'};
is noun(q{mew})->classical->plural,   q{mews}  => q{classical plural: 'mew' --> 'mews'};
is noun(q{afrit})->classical->plural,   q{afriti}  => q{classical plural: 'afrit' --> 'afriti'};
is noun(q{afriti})->classical->plural, q{afriti}  => q{classical plural: 'afriti' --> 'afriti'};
is noun(q{peronium})->classical->plural,   q{peronia}  => q{classical plural: 'peronium' --> 'peronia'};
is noun(q{peronia})->classical->plural, q{peronia}  => q{classical plural: 'peronia' --> 'peronia'};
is noun(q{cul-de-sac})->classical->plural,   q{culs-de-sac}  => q{classical plural: 'cul-de-sac' --> 'culs-de-sac'};
is noun(q{culs-de-sac})->classical->plural, q{culs-de-sac}  => q{classical plural: 'culs-de-sac' --> 'culs-de-sac'};
is noun(q{Muranese})->classical->plural,   q{Muranese}  => q{classical plural: 'Muranese' --> 'Muranese'};
is noun(q{Kongoese})->classical->plural,   q{Kongoese}  => q{classical plural: 'Kongoese' --> 'Kongoese'};
is noun(q{fibrilla})->classical->plural,   q{fibrillae}  => q{classical plural: 'fibrilla' --> 'fibrillae'};
is noun(q{fibrillae})->classical->plural, q{fibrillae}  => q{classical plural: 'fibrillae' --> 'fibrillae'};
is noun(q{Gabunese})->classical->plural,   q{Gabunese}  => q{classical plural: 'Gabunese' --> 'Gabunese'};
is noun(q{Faro})->classical->plural,   q{Faros}  => q{classical plural: 'Faro' --> 'Faros'};
is noun(q{Faros})->classical->plural, q{Faros}  => q{classical plural: 'Faros' --> 'Faros'};
is noun(q{milieu interieur})->classical->plural,   q{milieux interieurs}  => q{classical plural: 'milieu interieur' --> 'milieux interieurs'};
is noun(q{milieux interieurs})->classical->plural, q{milieux interieurs}  => q{classical plural: 'milieux interieurs' --> 'milieux interieurs'};
is noun(q{monsignore})->classical->plural,   q{monsignori}  => q{classical plural: 'monsignore' --> 'monsignori'};
is noun(q{monsignori})->classical->plural, q{monsignori}  => q{classical plural: 'monsignori' --> 'monsignori'};
is noun(q{ephemera})->classical->plural,   q{ephemerae}  => q{classical plural: 'ephemera' --> 'ephemerae'};
is noun(q{ephemerae})->classical->plural, q{ephemerae}  => q{classical plural: 'ephemerae' --> 'ephemerae'};
is noun(q{knopper})->classical->plural,   q{knoppern}  => q{classical plural: 'knopper' --> 'knoppern'};
is noun(q{knoppern})->classical->plural, q{knoppern}  => q{classical plural: 'knoppern' --> 'knoppern'};
is noun(q{brother})->classical->plural,   q{brethren}  => q{classical plural: 'brother' --> 'brethren'};
is noun(q{brethren})->classical->plural, q{brethren}  => q{classical plural: 'brethren' --> 'brethren'};
is noun(q{Tacoman})->classical->plural,   q{Tacomans}  => q{classical plural: 'Tacoman' --> 'Tacomans'};
is noun(q{Tacomans})->classical->plural, q{Tacomans}  => q{classical plural: 'Tacomans' --> 'Tacomans'};
is noun(q{washer up})->classical->plural,   q{washers up}  => q{classical plural: 'washer up' --> 'washers up'};
is noun(q{washers up})->classical->plural, q{washers up}  => q{classical plural: 'washers up' --> 'washers up'};
is noun(q{argumentum})->classical->plural,   q{argumenta}  => q{classical plural: 'argumentum' --> 'argumenta'};
is noun(q{argumenta})->classical->plural, q{argumenta}  => q{classical plural: 'argumenta' --> 'argumenta'};
is noun(q{intermaxilla})->classical->plural,   q{intermaxillae}  => q{classical plural: 'intermaxilla' --> 'intermaxillae'};
is noun(q{intermaxillae})->classical->plural, q{intermaxillae}  => q{classical plural: 'intermaxillae' --> 'intermaxillae'};
is noun(q{man milliner})->classical->plural,   q{men milliners}  => q{classical plural: 'man milliner' --> 'men milliners'};
is noun(q{men milliners})->classical->plural, q{men milliners}  => q{classical plural: 'men milliners' --> 'men milliners'};
is noun(q{rom})->classical->plural,   q{roms}  => q{classical plural: 'rom' --> 'roms'};
is noun(q{roms})->classical->plural, q{roms}  => q{classical plural: 'roms' --> 'roms'};
is noun(q{epidermis})->classical->plural,   q{epidermises}  => q{classical plural: 'epidermis' --> 'epidermises'};
is noun(q{epidermises})->classical->plural, q{epidermises}  => q{classical plural: 'epidermises' --> 'epidermises'};
is noun(q{syndendrium})->classical->plural,   q{syndendria}  => q{classical plural: 'syndendrium' --> 'syndendria'};
is noun(q{syndendria})->classical->plural, q{syndendria}  => q{classical plural: 'syndendria' --> 'syndendria'};
is noun(q{subsidium})->classical->plural,   q{subsidia}  => q{classical plural: 'subsidium' --> 'subsidia'};
is noun(q{subsidia})->classical->plural, q{subsidia}  => q{classical plural: 'subsidia' --> 'subsidia'};
is noun(q{ovarium})->classical->plural,   q{ovaria}  => q{classical plural: 'ovarium' --> 'ovaria'};
is noun(q{ovaria})->classical->plural, q{ovaria}  => q{classical plural: 'ovaria' --> 'ovaria'};
is noun(q{headquarters})->classical->plural,   q{headquarters}  => q{classical plural: 'headquarters' --> 'headquarters'};
is noun(q{larnax})->classical->plural,   q{larnakes}  => q{classical plural: 'larnax' --> 'larnakes'};
is noun(q{larnakes})->classical->plural, q{larnakes}  => q{classical plural: 'larnakes' --> 'larnakes'};
is noun(q{lacunar})->classical->plural,   q{lacunaria}  => q{classical plural: 'lacunar' --> 'lacunaria'};
is noun(q{lacunaria})->classical->plural, q{lacunaria}  => q{classical plural: 'lacunaria' --> 'lacunaria'};
is noun(q{lymphoma})->classical->plural,   q{lymphomata}  => q{classical plural: 'lymphoma' --> 'lymphomata'};
is noun(q{lymphomata})->classical->plural, q{lymphomata}  => q{classical plural: 'lymphomata' --> 'lymphomata'};
is noun(q{synechia})->classical->plural,   q{synechiae}  => q{classical plural: 'synechia' --> 'synechiae'};
is noun(q{synechiae})->classical->plural, q{synechiae}  => q{classical plural: 'synechiae' --> 'synechiae'};
is noun(q{soma})->classical->plural,   q{somata}  => q{classical plural: 'soma' --> 'somata'};
is noun(q{somata})->classical->plural, q{somata}  => q{classical plural: 'somata' --> 'somata'};
is noun(q{Sikkimese})->classical->plural,   q{Sikkimese}  => q{classical plural: 'Sikkimese' --> 'Sikkimese'};
is noun(q{vibrato})->classical->plural,   q{vibratos}  => q{classical plural: 'vibrato' --> 'vibratos'};
is noun(q{vibratos})->classical->plural, q{vibratos}  => q{classical plural: 'vibratos' --> 'vibratos'};
is noun(q{soredium})->classical->plural,   q{soredia}  => q{classical plural: 'soredium' --> 'soredia'};
is noun(q{soredia})->classical->plural, q{soredia}  => q{classical plural: 'soredia' --> 'soredia'};
is noun(q{leman})->classical->plural,   q{lemans}  => q{classical plural: 'leman' --> 'lemans'};
is noun(q{lemans})->classical->plural, q{lemans}  => q{classical plural: 'lemans' --> 'lemans'};
is noun(q{ox})->classical->plural,   q{oxen}  => q{classical plural: 'ox' --> 'oxen'};
is noun(q{oxen})->classical->plural, q{oxen}  => q{classical plural: 'oxen' --> 'oxen'};
is noun(q{suffrutex})->classical->plural,   q{suffrutices}  => q{classical plural: 'suffrutex' --> 'suffrutices'};
is noun(q{suffrutices})->classical->plural, q{suffrutices}  => q{classical plural: 'suffrutices' --> 'suffrutices'};
is noun(q{castrum})->classical->plural,   q{castra}  => q{classical plural: 'castrum' --> 'castra'};
is noun(q{castra})->classical->plural, q{castra}  => q{classical plural: 'castra' --> 'castra'};
is noun(q{Viennese})->classical->plural,   q{Viennese}  => q{classical plural: 'Viennese' --> 'Viennese'};
is noun(q{vasculum})->classical->plural,   q{vascula}  => q{classical plural: 'vasculum' --> 'vascula'};
is noun(q{vascula})->classical->plural, q{vascula}  => q{classical plural: 'vascula' --> 'vascula'};
is noun(q{charisma})->classical->plural,   q{charismata}  => q{classical plural: 'charisma' --> 'charismata'};
is noun(q{charismata})->classical->plural, q{charismata}  => q{classical plural: 'charismata' --> 'charismata'};
is noun(q{synedrion})->classical->plural,   q{synedria}  => q{classical plural: 'synedrion' --> 'synedria'};
is noun(q{synedria})->classical->plural, q{synedria}  => q{classical plural: 'synedria' --> 'synedria'};
is noun(q{nexus})->classical->plural,   q{nexus}  => q{classical plural: 'nexus' --> 'nexus'};
is noun(q{pulsellum})->classical->plural,   q{pulsella}  => q{classical plural: 'pulsellum' --> 'pulsella'};
is noun(q{pulsella})->classical->plural, q{pulsella}  => q{classical plural: 'pulsella' --> 'pulsella'};
is noun(q{lar})->classical->plural,   q{lares}  => q{classical plural: 'lar' --> 'lares'};
is noun(q{lares})->classical->plural, q{lares}  => q{classical plural: 'lares' --> 'lares'};
is noun(q{forum})->classical->plural,   q{fora}  => q{classical plural: 'forum' --> 'fora'};
is noun(q{fora})->classical->plural, q{fora}  => q{classical plural: 'fora' --> 'fora'};
is noun(q{ganglion})->classical->plural,   q{ganglia}  => q{classical plural: 'ganglion' --> 'ganglia'};
is noun(q{ganglia})->classical->plural, q{ganglia}  => q{classical plural: 'ganglia' --> 'ganglia'};
is noun(q{alan})->classical->plural,   q{alani}  => q{classical plural: 'alan' --> 'alani'};
is noun(q{alani})->classical->plural, q{alani}  => q{classical plural: 'alani' --> 'alani'};
is noun(q{coagulum})->classical->plural,   q{coagula}  => q{classical plural: 'coagulum' --> 'coagula'};
is noun(q{coagula})->classical->plural, q{coagula}  => q{classical plural: 'coagula' --> 'coagula'};
is noun(q{thorax})->classical->plural,   q{thoraces}  => q{classical plural: 'thorax' --> 'thoraces'};
is noun(q{thoraces})->classical->plural, q{thoraces}  => q{classical plural: 'thoraces' --> 'thoraces'};
is noun(q{kouros})->classical->plural,   q{kouroi}  => q{classical plural: 'kouros' --> 'kouroi'};
is noun(q{kouroi})->classical->plural, q{kouroi}  => q{classical plural: 'kouroi' --> 'kouroi'};
is noun(q{shochet})->classical->plural,   q{shochetim}  => q{classical plural: 'shochet' --> 'shochetim'};
is noun(q{shochetim})->classical->plural, q{shochetim}  => q{classical plural: 'shochetim' --> 'shochetim'};
is noun(q{dentalium})->classical->plural,   q{dentalia}  => q{classical plural: 'dentalium' --> 'dentalia'};
is noun(q{dentalia})->classical->plural, q{dentalia}  => q{classical plural: 'dentalia' --> 'dentalia'};
is noun(q{gametangium})->classical->plural,   q{gametangia}  => q{classical plural: 'gametangium' --> 'gametangia'};
is noun(q{gametangia})->classical->plural, q{gametangia}  => q{classical plural: 'gametangia' --> 'gametangia'};
is noun(q{bersagliere})->classical->plural,   q{bersaglieri}  => q{classical plural: 'bersagliere' --> 'bersaglieri'};
is noun(q{bersaglieri})->classical->plural, q{bersaglieri}  => q{classical plural: 'bersaglieri' --> 'bersaglieri'};
is noun(q{nubecula})->classical->plural,   q{nubeculae}  => q{classical plural: 'nubecula' --> 'nubeculae'};
is noun(q{nubeculae})->classical->plural, q{nubeculae}  => q{classical plural: 'nubeculae' --> 'nubeculae'};
is noun(q{propleuron})->classical->plural,   q{propleura}  => q{classical plural: 'propleuron' --> 'propleura'};
is noun(q{propleura})->classical->plural, q{propleura}  => q{classical plural: 'propleura' --> 'propleura'};
is noun(q{vestigium})->classical->plural,   q{vestigia}  => q{classical plural: 'vestigium' --> 'vestigia'};
is noun(q{vestigia})->classical->plural, q{vestigia}  => q{classical plural: 'vestigia' --> 'vestigia'};
is noun(q{abstractum})->classical->plural,   q{abstracta}  => q{classical plural: 'abstractum' --> 'abstracta'};
is noun(q{abstracta})->classical->plural, q{abstracta}  => q{classical plural: 'abstracta' --> 'abstracta'};
is noun(q{tragus})->classical->plural,   q{tragi}  => q{classical plural: 'tragus' --> 'tragi'};
is noun(q{tragi})->classical->plural, q{tragi}  => q{classical plural: 'tragi' --> 'tragi'};
is noun(q{hyperbaton})->classical->plural,   q{hyperbata}  => q{classical plural: 'hyperbaton' --> 'hyperbata'};
is noun(q{hyperbata})->classical->plural, q{hyperbata}  => q{classical plural: 'hyperbata' --> 'hyperbata'};
is noun(q{species})->classical->plural,   q{species}  => q{classical plural: 'species' --> 'species'};
is noun(q{psycho})->classical->plural,   q{psychos}  => q{classical plural: 'psycho' --> 'psychos'};
is noun(q{psychos})->classical->plural, q{psychos}  => q{classical plural: 'psychos' --> 'psychos'};
is noun(q{syncytium})->classical->plural,   q{syncytia}  => q{classical plural: 'syncytium' --> 'syncytia'};
is noun(q{syncytia})->classical->plural, q{syncytia}  => q{classical plural: 'syncytia' --> 'syncytia'};
is noun(q{basis})->classical->plural,   q{bases}  => q{classical plural: 'basis' --> 'bases'};
is noun(q{bases})->classical->plural, q{bases}  => q{classical plural: 'bases' --> 'bases'};
is noun(q{quinquennium})->classical->plural,   q{quinquennia}  => q{classical plural: 'quinquennium' --> 'quinquennia'};
is noun(q{quinquennia})->classical->plural, q{quinquennia}  => q{classical plural: 'quinquennia' --> 'quinquennia'};
is noun(q{snipe})->classical->plural,   q{snipe}  => q{classical plural: 'snipe' --> 'snipe'};
is noun(q{mondo})->classical->plural,   q{mondi}  => q{classical plural: 'mondo' --> 'mondi'};
is noun(q{mondi})->classical->plural, q{mondi}  => q{classical plural: 'mondi' --> 'mondi'};
is noun(q{tenia})->classical->plural,   q{teniae}  => q{classical plural: 'tenia' --> 'teniae'};
is noun(q{teniae})->classical->plural, q{teniae}  => q{classical plural: 'teniae' --> 'teniae'};
is noun(q{silo})->classical->plural,   q{silos}  => q{classical plural: 'silo' --> 'silos'};
is noun(q{silos})->classical->plural, q{silos}  => q{classical plural: 'silos' --> 'silos'};
is noun(q{yo-yo})->classical->plural,   q{yo-yos}  => q{classical plural: 'yo-yo' --> 'yo-yos'};
is noun(q{yo-yos})->classical->plural, q{yo-yos}  => q{classical plural: 'yo-yos' --> 'yo-yos'};
is noun(q{coney})->classical->plural,   q{conies}  => q{classical plural: 'coney' --> 'conies'};
is noun(q{conies})->classical->plural, q{conies}  => q{classical plural: 'conies' --> 'conies'};
is noun(q{info})->classical->plural,   q{infos}  => q{classical plural: 'info' --> 'infos'};
is noun(q{infos})->classical->plural, q{infos}  => q{classical plural: 'infos' --> 'infos'};
is noun(q{latex})->classical->plural,   q{latices}  => q{classical plural: 'latex' --> 'latices'};
is noun(q{latices})->classical->plural, q{latices}  => q{classical plural: 'latices' --> 'latices'};
is noun(q{gonimium})->classical->plural,   q{gonimia}  => q{classical plural: 'gonimium' --> 'gonimia'};
is noun(q{gonimia})->classical->plural, q{gonimia}  => q{classical plural: 'gonimia' --> 'gonimia'};
is noun(q{bias})->classical->plural,   q{biases}  => q{classical plural: 'bias' --> 'biases'};
is noun(q{biases})->classical->plural, q{biases}  => q{classical plural: 'biases' --> 'biases'};
is noun(q{squadra})->classical->plural,   q{squadre}  => q{classical plural: 'squadra' --> 'squadre'};
is noun(q{squadre})->classical->plural, q{squadre}  => q{classical plural: 'squadre' --> 'squadre'};
is noun(q{hers})->classical->plural,   q{theirs}  => q{classical plural: 'hers' --> 'theirs'};
is noun(q{chaeta})->classical->plural,   q{chaetae}  => q{classical plural: 'chaeta' --> 'chaetae'};
is noun(q{chaetae})->classical->plural, q{chaetae}  => q{classical plural: 'chaetae' --> 'chaetae'};
is noun(q{whoever})->classical->plural,   q{whoever}  => q{classical plural: 'whoever' --> 'whoever'};
is noun(q{tolkach})->classical->plural,   q{tolkachi}  => q{classical plural: 'tolkach' --> 'tolkachi'};
is noun(q{tolkachi})->classical->plural, q{tolkachi}  => q{classical plural: 'tolkachi' --> 'tolkachi'};
is noun(q{corps})->classical->plural,   q{corps}  => q{classical plural: 'corps' --> 'corps'};
is noun(q{motto})->classical->plural,   q{mottoes}  => q{classical plural: 'motto' --> 'mottoes'};
is noun(q{mottoes})->classical->plural, q{mottoes}  => q{classical plural: 'mottoes' --> 'mottoes'};
is noun(q{major general})->classical->plural,   q{major generals}  => q{classical plural: 'major general' --> 'major generals'};
is noun(q{major generals})->classical->plural, q{major generals}  => q{classical plural: 'major generals' --> 'major generals'};
is noun(q{striatum})->classical->plural,   q{striata}  => q{classical plural: 'striatum' --> 'striata'};
is noun(q{striata})->classical->plural, q{striata}  => q{classical plural: 'striata' --> 'striata'};
is noun(q{fro})->classical->plural,   q{froes}  => q{classical plural: 'fro' --> 'froes'};
is noun(q{froes})->classical->plural, q{froes}  => q{classical plural: 'froes' --> 'froes'};
is noun(q{succus})->classical->plural,   q{succi}  => q{classical plural: 'succus' --> 'succi'};
is noun(q{succi})->classical->plural, q{succi}  => q{classical plural: 'succi' --> 'succi'};
is noun(q{syllabarium})->classical->plural,   q{syllabaria}  => q{classical plural: 'syllabarium' --> 'syllabaria'};
is noun(q{syllabaria})->classical->plural, q{syllabaria}  => q{classical plural: 'syllabaria' --> 'syllabaria'};
is noun(q{Kokako})->classical->plural,   q{Kokakos}  => q{classical plural: 'Kokako' --> 'Kokakos'};
is noun(q{Kokakos})->classical->plural, q{Kokakos}  => q{classical plural: 'Kokakos' --> 'Kokakos'};
is noun(q{formula})->classical->plural,   q{formulae}  => q{classical plural: 'formula' --> 'formulae'};
is noun(q{formulae})->classical->plural, q{formulae}  => q{classical plural: 'formulae' --> 'formulae'};
is noun(q{corpusculum})->classical->plural,   q{corpuscula}  => q{classical plural: 'corpusculum' --> 'corpuscula'};
is noun(q{corpuscula})->classical->plural, q{corpuscula}  => q{classical plural: 'corpuscula' --> 'corpuscula'};
is noun(q{apex})->classical->plural,   q{apices}  => q{classical plural: 'apex' --> 'apices'};
is noun(q{apices})->classical->plural, q{apices}  => q{classical plural: 'apices' --> 'apices'};
is noun(q{politbureau})->classical->plural,   q{politbureaux}  => q{classical plural: 'politbureau' --> 'politbureaux'};
is noun(q{politbureaux})->classical->plural, q{politbureaux}  => q{classical plural: 'politbureaux' --> 'politbureaux'};
is noun(q{imbrex})->classical->plural,   q{imbrices}  => q{classical plural: 'imbrex' --> 'imbrices'};
is noun(q{imbrices})->classical->plural, q{imbrices}  => q{classical plural: 'imbrices' --> 'imbrices'};
is noun(q{oxymoron})->classical->plural,   q{oxymora}  => q{classical plural: 'oxymoron' --> 'oxymora'};
is noun(q{oxymora})->classical->plural, q{oxymora}  => q{classical plural: 'oxymora' --> 'oxymora'};
is noun(q{platypus})->classical->plural,   q{platypodes}  => q{classical plural: 'platypus' --> 'platypodes'};
is noun(q{platypodes})->classical->plural, q{platypodes}  => q{classical plural: 'platypodes' --> 'platypodes'};
is noun(q{embryoma})->classical->plural,   q{embryomata}  => q{classical plural: 'embryoma' --> 'embryomata'};
is noun(q{embryomata})->classical->plural, q{embryomata}  => q{classical plural: 'embryomata' --> 'embryomata'};
is noun(q{synedrium})->classical->plural,   q{synedria}  => q{classical plural: 'synedrium' --> 'synedria'};
is noun(q{synedria})->classical->plural, q{synedria}  => q{classical plural: 'synedria' --> 'synedria'};
is noun(q{bongo})->classical->plural,   q{bongoes}  => q{classical plural: 'bongo' --> 'bongoes'};
is noun(q{bongoes})->classical->plural, q{bongoes}  => q{classical plural: 'bongoes' --> 'bongoes'};
is noun(q{pollinarium})->classical->plural,   q{pollinaria}  => q{classical plural: 'pollinarium' --> 'pollinaria'};
is noun(q{pollinaria})->classical->plural, q{pollinaria}  => q{classical plural: 'pollinaria' --> 'pollinaria'};
is noun(q{pharmakos})->classical->plural,   q{pharmakoi}  => q{classical plural: 'pharmakos' --> 'pharmakoi'};
is noun(q{pharmakoi})->classical->plural, q{pharmakoi}  => q{classical plural: 'pharmakoi' --> 'pharmakoi'};
is noun(q{fossa})->classical->plural,   q{fossae}  => q{classical plural: 'fossa' --> 'fossae'};
is noun(q{fossae})->classical->plural, q{fossae}  => q{classical plural: 'fossae' --> 'fossae'};
is noun(q{nse})->classical->plural,   q{nses}  => q{classical plural: 'nse' --> 'nses'};
is noun(q{nses})->classical->plural, q{nses}  => q{classical plural: 'nses' --> 'nses'};
is noun(q{stasimon})->classical->plural,   q{stasima}  => q{classical plural: 'stasimon' --> 'stasima'};
is noun(q{stasima})->classical->plural, q{stasima}  => q{classical plural: 'stasima' --> 'stasima'};
is noun(q{precis})->classical->plural,   q{precis}  => q{classical plural: 'precis' --> 'precis'};
is noun(q{wreath})->classical->plural,   q{wreaths}  => q{classical plural: 'wreath' --> 'wreaths'};
is noun(q{wreaths})->classical->plural, q{wreaths}  => q{classical plural: 'wreaths' --> 'wreaths'};
is noun(q{collegium})->classical->plural,   q{collegia}  => q{classical plural: 'collegium' --> 'collegia'};
is noun(q{collegia})->classical->plural, q{collegia}  => q{classical plural: 'collegia' --> 'collegia'};
is noun(q{libretto})->classical->plural,   q{libretti}  => q{classical plural: 'libretto' --> 'libretti'};
is noun(q{libretti})->classical->plural, q{libretti}  => q{classical plural: 'libretti' --> 'libretti'};
is noun(q{hamulus})->classical->plural,   q{hamuli}  => q{classical plural: 'hamulus' --> 'hamuli'};
is noun(q{hamuli})->classical->plural, q{hamuli}  => q{classical plural: 'hamuli' --> 'hamuli'};
is noun(q{tobacco})->classical->plural,   q{tobaccos}  => q{classical plural: 'tobacco' --> 'tobaccos'};
is noun(q{tobaccos})->classical->plural, q{tobaccos}  => q{classical plural: 'tobaccos' --> 'tobaccos'};
is noun(q{toxoplasma})->classical->plural,   q{toxoplasmata}  => q{classical plural: 'toxoplasma' --> 'toxoplasmata'};
is noun(q{toxoplasmata})->classical->plural, q{toxoplasmata}  => q{classical plural: 'toxoplasmata' --> 'toxoplasmata'};
is noun(q{carex})->classical->plural,   q{carices}  => q{classical plural: 'carex' --> 'carices'};
is noun(q{carices})->classical->plural, q{carices}  => q{classical plural: 'carices' --> 'carices'};
is noun(q{ens rationis})->classical->plural,   q{entia rationis}  => q{classical plural: 'ens rationis' --> 'entia rationis'};
is noun(q{entia rationis})->classical->plural, q{entia rationis}  => q{classical plural: 'entia rationis' --> 'entia rationis'};
is noun(q{news})->classical->plural,   q{news}  => q{classical plural: 'news' --> 'news'};
is noun(q{operculum})->classical->plural,   q{opercula}  => q{classical plural: 'operculum' --> 'opercula'};
is noun(q{opercula})->classical->plural, q{opercula}  => q{classical plural: 'opercula' --> 'opercula'};
is noun(q{Amboinese})->classical->plural,   q{Amboinese}  => q{classical plural: 'Amboinese' --> 'Amboinese'};
is noun(q{trichina})->classical->plural,   q{trichinae}  => q{classical plural: 'trichina' --> 'trichinae'};
is noun(q{trichinae})->classical->plural, q{trichinae}  => q{classical plural: 'trichinae' --> 'trichinae'};
is noun(q{auto de fe})->classical->plural,   q{autos de fes}  => q{classical plural: 'auto de fe' --> 'autos de fes'};
is noun(q{autos de fes})->classical->plural, q{autos de fes}  => q{classical plural: 'autos de fes' --> 'autos de fes'};
is noun(q{centumvir})->classical->plural,   q{centumviri}  => q{classical plural: 'centumvir' --> 'centumviri'};
is noun(q{centumviri})->classical->plural, q{centumviri}  => q{classical plural: 'centumviri' --> 'centumviri'};
is noun(q{Calabrese})->classical->plural,   q{Calabrese}  => q{classical plural: 'Calabrese' --> 'Calabrese'};
is noun(q{protococcus})->classical->plural,   q{protococci}  => q{classical plural: 'protococcus' --> 'protococci'};
is noun(q{protococci})->classical->plural, q{protococci}  => q{classical plural: 'protococci' --> 'protococci'};
is noun(q{Gilbertese})->classical->plural,   q{Gilbertese}  => q{classical plural: 'Gilbertese' --> 'Gilbertese'};
is noun(q{potestas})->classical->plural,   q{potestates}  => q{classical plural: 'potestas' --> 'potestates'};
is noun(q{potestates})->classical->plural, q{potestates}  => q{classical plural: 'potestates' --> 'potestates'};
is noun(q{haruspex})->classical->plural,   q{haruspices}  => q{classical plural: 'haruspex' --> 'haruspices'};
is noun(q{haruspices})->classical->plural, q{haruspices}  => q{classical plural: 'haruspices' --> 'haruspices'};
is noun(q{areola})->classical->plural,   q{areolae}  => q{classical plural: 'areola' --> 'areolae'};
is noun(q{areolae})->classical->plural, q{areolae}  => q{classical plural: 'areolae' --> 'areolae'};
is noun(q{myo})->classical->plural,   q{myos}  => q{classical plural: 'myo' --> 'myos'};
is noun(q{myos})->classical->plural, q{myos}  => q{classical plural: 'myos' --> 'myos'};
is noun(q{auslese})->classical->plural,   q{auslesen}  => q{classical plural: 'auslese' --> 'auslesen'};
is noun(q{auslesen})->classical->plural, q{auslesen}  => q{classical plural: 'auslesen' --> 'auslesen'};
is noun(q{urodaeum})->classical->plural,   q{urodaea}  => q{classical plural: 'urodaeum' --> 'urodaea'};
is noun(q{urodaea})->classical->plural, q{urodaea}  => q{classical plural: 'urodaea' --> 'urodaea'};
is noun(q{parabola})->classical->plural,   q{parabolae}  => q{classical plural: 'parabola' --> 'parabolae'};
is noun(q{parabolae})->classical->plural, q{parabolae}  => q{classical plural: 'parabolae' --> 'parabolae'};
is noun(q{hymenium})->classical->plural,   q{hymenia}  => q{classical plural: 'hymenium' --> 'hymenia'};
is noun(q{hymenia})->classical->plural, q{hymenia}  => q{classical plural: 'hymenia' --> 'hymenia'};
is noun(q{solidus})->classical->plural,   q{solidos}  => q{classical plural: 'solidus' --> 'solidos'};
is noun(q{solidos})->classical->plural, q{solidos}  => q{classical plural: 'solidos' --> 'solidos'};
is noun(q{meliceris})->classical->plural,   q{melicerides}  => q{classical plural: 'meliceris' --> 'melicerides'};
is noun(q{melicerides})->classical->plural, q{melicerides}  => q{classical plural: 'melicerides' --> 'melicerides'};
is noun(q{plesiosaurus})->classical->plural,   q{plesiosauri}  => q{classical plural: 'plesiosaurus' --> 'plesiosauri'};
is noun(q{plesiosauri})->classical->plural, q{plesiosauri}  => q{classical plural: 'plesiosauri' --> 'plesiosauri'};
is noun(q{jackanapes})->classical->plural,   q{jackanapes}  => q{classical plural: 'jackanapes' --> 'jackanapes'};
is noun(q{break-away})->classical->plural,   q{breaks-away}  => q{classical plural: 'break-away' --> 'breaks-away'};
is noun(q{breaks-away})->classical->plural, q{breaks-away}  => q{classical plural: 'breaks-away' --> 'breaks-away'};
is noun(q{megatherium})->classical->plural,   q{megatheria}  => q{classical plural: 'megatherium' --> 'megatheria'};
is noun(q{megatheria})->classical->plural, q{megatheria}  => q{classical plural: 'megatheria' --> 'megatheria'};
is noun(q{ilium})->classical->plural,   q{ilia}  => q{classical plural: 'ilium' --> 'ilia'};
is noun(q{ilia})->classical->plural, q{ilia}  => q{classical plural: 'ilia' --> 'ilia'};
is noun(q{set off})->classical->plural,   q{sets off}  => q{classical plural: 'set off' --> 'sets off'};
is noun(q{sets off})->classical->plural, q{sets off}  => q{classical plural: 'sets off' --> 'sets off'};
is noun(q{editio princeps})->classical->plural,   q{editiones principes}  => q{classical plural: 'editio princeps' --> 'editiones principes'};
is noun(q{editiones principes})->classical->plural, q{editiones principes}  => q{classical plural: 'editiones principes' --> 'editiones principes'};
is noun(q{adieu})->classical->plural,   q{adieux}  => q{classical plural: 'adieu' --> 'adieux'};
is noun(q{adieux})->classical->plural, q{adieux}  => q{classical plural: 'adieux' --> 'adieux'};
is noun(q{phalangium})->classical->plural,   q{phalangia}  => q{classical plural: 'phalangium' --> 'phalangia'};
is noun(q{phalangia})->classical->plural, q{phalangia}  => q{classical plural: 'phalangia' --> 'phalangia'};
is noun(q{signum})->classical->plural,   q{signa}  => q{classical plural: 'signum' --> 'signa'};
is noun(q{signa})->classical->plural, q{signa}  => q{classical plural: 'signa' --> 'signa'};
is noun(q{nockerl})->classical->plural,   q{nockerln}  => q{classical plural: 'nockerl' --> 'nockerln'};
is noun(q{nockerln})->classical->plural, q{nockerln}  => q{classical plural: 'nockerln' --> 'nockerln'};
is noun(q{stomodaeum})->classical->plural,   q{stomodaea}  => q{classical plural: 'stomodaeum' --> 'stomodaea'};
is noun(q{stomodaea})->classical->plural, q{stomodaea}  => q{classical plural: 'stomodaea' --> 'stomodaea'};
is noun(q{prima ballerina})->classical->plural,   q{prime ballerine}  => q{classical plural: 'prima ballerina' --> 'prime ballerine'};
is noun(q{prime ballerine})->classical->plural, q{prime ballerine}  => q{classical plural: 'prime ballerine' --> 'prime ballerine'};
is noun(q{bath})->classical->plural,   q{baths}  => q{classical plural: 'bath' --> 'baths'};
is noun(q{baths})->classical->plural, q{baths}  => q{classical plural: 'baths' --> 'baths'};
is noun(q{avicularium})->classical->plural,   q{avicularia}  => q{classical plural: 'avicularium' --> 'avicularia'};
is noun(q{avicularia})->classical->plural, q{avicularia}  => q{classical plural: 'avicularia' --> 'avicularia'};
is noun(q{podere})->classical->plural,   q{poderi}  => q{classical plural: 'podere' --> 'poderi'};
is noun(q{poderi})->classical->plural, q{poderi}  => q{classical plural: 'poderi' --> 'poderi'};
is noun(q{triclinium})->classical->plural,   q{triclinia}  => q{classical plural: 'triclinium' --> 'triclinia'};
is noun(q{triclinia})->classical->plural, q{triclinia}  => q{classical plural: 'triclinia' --> 'triclinia'};
is noun(q{hapteron})->classical->plural,   q{haptera}  => q{classical plural: 'hapteron' --> 'haptera'};
is noun(q{haptera})->classical->plural, q{haptera}  => q{classical plural: 'haptera' --> 'haptera'};
is noun(q{loco})->classical->plural,   q{locos}  => q{classical plural: 'loco' --> 'locos'};
is noun(q{locos})->classical->plural, q{locos}  => q{classical plural: 'locos' --> 'locos'};
is noun(q{triens})->classical->plural,   q{trientes}  => q{classical plural: 'triens' --> 'trientes'};
is noun(q{trientes})->classical->plural, q{trientes}  => q{classical plural: 'trientes' --> 'trientes'};
is noun(q{libido})->classical->plural,   q{libidos}  => q{classical plural: 'libido' --> 'libidos'};
is noun(q{libidos})->classical->plural, q{libidos}  => q{classical plural: 'libidos' --> 'libidos'};
is noun(q{2 star general})->classical->plural,   q{2 star generals}  => q{classical plural: '2 star general' --> '2 star generals'};
is noun(q{2 star generals})->classical->plural, q{2 star generals}  => q{classical plural: '2 star generals' --> '2 star generals'};
is noun(q{Nicobarese})->classical->plural,   q{Nicobarese}  => q{classical plural: 'Nicobarese' --> 'Nicobarese'};
is noun(q{ethos})->classical->plural,   q{ethoses}  => q{classical plural: 'ethos' --> 'ethoses'};
is noun(q{ethoses})->classical->plural, q{ethoses}  => q{classical plural: 'ethoses' --> 'ethoses'};
is noun(q{cystoma})->classical->plural,   q{cystomata}  => q{classical plural: 'cystoma' --> 'cystomata'};
is noun(q{cystomata})->classical->plural, q{cystomata}  => q{classical plural: 'cystomata' --> 'cystomata'};
is noun(q{rhynchodaeum})->classical->plural,   q{rhynchodaea}  => q{classical plural: 'rhynchodaeum' --> 'rhynchodaea'};
is noun(q{rhynchodaea})->classical->plural, q{rhynchodaea}  => q{classical plural: 'rhynchodaea' --> 'rhynchodaea'};
is noun(q{erf})->classical->plural,   q{erven}  => q{classical plural: 'erf' --> 'erven'};
is noun(q{erven})->classical->plural, q{erven}  => q{classical plural: 'erven' --> 'erven'};
is noun(q{manteau})->classical->plural,   q{manteaux}  => q{classical plural: 'manteau' --> 'manteaux'};
is noun(q{manteaux})->classical->plural, q{manteaux}  => q{classical plural: 'manteaux' --> 'manteaux'};
is noun(q{amorino})->classical->plural,   q{amorini}  => q{classical plural: 'amorino' --> 'amorini'};
is noun(q{amorini})->classical->plural, q{amorini}  => q{classical plural: 'amorini' --> 'amorini'};
is noun(q{tarantata})->classical->plural,   q{tarantate}  => q{classical plural: 'tarantata' --> 'tarantate'};
is noun(q{tarantate})->classical->plural, q{tarantate}  => q{classical plural: 'tarantate' --> 'tarantate'};
is noun(q{bruschetta})->classical->plural,   q{bruschette}  => q{classical plural: 'bruschetta' --> 'bruschette'};
is noun(q{bruschette})->classical->plural, q{bruschette}  => q{classical plural: 'bruschette' --> 'bruschette'};
is noun(q{thelycum})->classical->plural,   q{thelyca}  => q{classical plural: 'thelycum' --> 'thelyca'};
is noun(q{thelyca})->classical->plural, q{thelyca}  => q{classical plural: 'thelyca' --> 'thelyca'};
is noun(q{harman})->classical->plural,   q{harmans}  => q{classical plural: 'harman' --> 'harmans'};
is noun(q{harmans})->classical->plural, q{harmans}  => q{classical plural: 'harmans' --> 'harmans'};
is noun(q{Sacramento})->classical->plural,   q{Sacramentos}  => q{classical plural: 'Sacramento' --> 'Sacramentos'};
is noun(q{Sacramentos})->classical->plural, q{Sacramentos}  => q{classical plural: 'Sacramentos' --> 'Sacramentos'};
is noun(q{neutrino})->classical->plural,   q{neutrinos}  => q{classical plural: 'neutrino' --> 'neutrinos'};
is noun(q{neutrinos})->classical->plural, q{neutrinos}  => q{classical plural: 'neutrinos' --> 'neutrinos'};
is noun(q{Kakapo})->classical->plural,   q{Kakapos}  => q{classical plural: 'Kakapo' --> 'Kakapos'};
is noun(q{Kakapos})->classical->plural, q{Kakapos}  => q{classical plural: 'Kakapos' --> 'Kakapos'};
is noun(q{altorelievo})->classical->plural,   q{altorelievos}  => q{classical plural: 'altorelievo' --> 'altorelievos'};
is noun(q{altorelievos})->classical->plural, q{altorelievos}  => q{classical plural: 'altorelievos' --> 'altorelievos'};
is noun(q{wadi})->classical->plural,   q{wadis}  => q{classical plural: 'wadi' --> 'wadis'};
is noun(q{wadis})->classical->plural, q{wadis}  => q{classical plural: 'wadis' --> 'wadis'};
is noun(q{extispex})->classical->plural,   q{extispices}  => q{classical plural: 'extispex' --> 'extispices'};
is noun(q{extispices})->classical->plural, q{extispices}  => q{classical plural: 'extispices' --> 'extispices'};
is noun(q{dais})->classical->plural,   q{daises}  => q{classical plural: 'dais' --> 'daises'};
is noun(q{daises})->classical->plural, q{daises}  => q{classical plural: 'daises' --> 'daises'};
is noun(q{octavo})->classical->plural,   q{octavos}  => q{classical plural: 'octavo' --> 'octavos'};
is noun(q{octavos})->classical->plural, q{octavos}  => q{classical plural: 'octavos' --> 'octavos'};
is noun(q{Havanese})->classical->plural,   q{Havanese}  => q{classical plural: 'Havanese' --> 'Havanese'};
is noun(q{glioma})->classical->plural,   q{gliomata}  => q{classical plural: 'glioma' --> 'gliomata'};
is noun(q{gliomata})->classical->plural, q{gliomata}  => q{classical plural: 'gliomata' --> 'gliomata'};
is noun(q{sequela})->classical->plural,   q{sequelae}  => q{classical plural: 'sequela' --> 'sequelae'};
is noun(q{sequelae})->classical->plural, q{sequelae}  => q{classical plural: 'sequelae' --> 'sequelae'};
is noun(q{statera})->classical->plural,   q{staterae}  => q{classical plural: 'statera' --> 'staterae'};
is noun(q{staterae})->classical->plural, q{staterae}  => q{classical plural: 'staterae' --> 'staterae'};
is noun(q{arcanum})->classical->plural,   q{arcana}  => q{classical plural: 'arcanum' --> 'arcana'};
is noun(q{arcana})->classical->plural, q{arcana}  => q{classical plural: 'arcana' --> 'arcana'};
is noun(q{corona})->classical->plural,   q{coronae}  => q{classical plural: 'corona' --> 'coronae'};
is noun(q{coronae})->classical->plural, q{coronae}  => q{classical plural: 'coronae' --> 'coronae'};
is noun(q{rococo})->classical->plural,   q{rococos}  => q{classical plural: 'rococo' --> 'rococos'};
is noun(q{rococos})->classical->plural, q{rococos}  => q{classical plural: 'rococos' --> 'rococos'};
is noun(q{froe})->classical->plural,   q{froes}  => q{classical plural: 'froe' --> 'froes'};
is noun(q{froes})->classical->plural, q{froes}  => q{classical plural: 'froes' --> 'froes'};
is noun(q{parhelion})->classical->plural,   q{parhelia}  => q{classical plural: 'parhelion' --> 'parhelia'};
is noun(q{parhelia})->classical->plural, q{parhelia}  => q{classical plural: 'parhelia' --> 'parhelia'};
is noun(q{refugium})->classical->plural,   q{refugia}  => q{classical plural: 'refugium' --> 'refugia'};
is noun(q{refugia})->classical->plural, q{refugia}  => q{classical plural: 'refugia' --> 'refugia'};
is noun(q{corno})->classical->plural,   q{corni}  => q{classical plural: 'corno' --> 'corni'};
is noun(q{corni})->classical->plural, q{corni}  => q{classical plural: 'corni' --> 'corni'};
is noun(q{breakaway})->classical->plural,   q{breaksaway}  => q{classical plural: 'breakaway' --> 'breaksaway'};
is noun(q{breaksaway})->classical->plural, q{breaksaway}  => q{classical plural: 'breaksaway' --> 'breaksaway'};
is noun(q{hetman})->classical->plural,   q{hetmans}  => q{classical plural: 'hetman' --> 'hetmans'};
is noun(q{hetmans})->classical->plural, q{hetmans}  => q{classical plural: 'hetmans' --> 'hetmans'};
is noun(q{somaten})->classical->plural,   q{somatenes}  => q{classical plural: 'somaten' --> 'somatenes'};
is noun(q{somatenes})->classical->plural, q{somatenes}  => q{classical plural: 'somatenes' --> 'somatenes'};
is noun(q{bulla})->classical->plural,   q{bullae}  => q{classical plural: 'bulla' --> 'bullae'};
is noun(q{bullae})->classical->plural, q{bullae}  => q{classical plural: 'bullae' --> 'bullae'};
is noun(q{felsenmeer})->classical->plural,   q{felsenmeere}  => q{classical plural: 'felsenmeer' --> 'felsenmeere'};
is noun(q{felsenmeere})->classical->plural, q{felsenmeere}  => q{classical plural: 'felsenmeere' --> 'felsenmeere'};
is noun(q{gonangium})->classical->plural,   q{gonangia}  => q{classical plural: 'gonangium' --> 'gonangia'};
is noun(q{gonangia})->classical->plural, q{gonangia}  => q{classical plural: 'gonangia' --> 'gonangia'};
is noun(q{caffe macchiato})->classical->plural,   q{caffe macchiati}  => q{classical plural: 'caffe macchiato' --> 'caffe macchiati'};
is noun(q{caffe macchiati})->classical->plural, q{caffe macchiati}  => q{classical plural: 'caffe macchiati' --> 'caffe macchiati'};
is noun(q{Amoyese})->classical->plural,   q{Amoyese}  => q{classical plural: 'Amoyese' --> 'Amoyese'};
is noun(q{chitarrone})->classical->plural,   q{chitarroni}  => q{classical plural: 'chitarrone' --> 'chitarroni'};
is noun(q{chitarroni})->classical->plural, q{chitarroni}  => q{classical plural: 'chitarroni' --> 'chitarroni'};
is noun(q{Vermontese})->classical->plural,   q{Vermontese}  => q{classical plural: 'Vermontese' --> 'Vermontese'};
is noun(q{toe})->classical->plural,   q{toes}  => q{classical plural: 'toe' --> 'toes'};
is noun(q{toes})->classical->plural, q{toes}  => q{classical plural: 'toes' --> 'toes'};
is noun(q{doe})->classical->plural,   q{does}  => q{classical plural: 'doe' --> 'does'};
is noun(q{does})->classical->plural, q{does}  => q{classical plural: 'does' --> 'does'};
is noun(q{6 star general})->classical->plural,   q{6 star generals}  => q{classical plural: '6 star general' --> '6 star generals'};
is noun(q{6 star generals})->classical->plural, q{6 star generals}  => q{classical plural: '6 star generals' --> '6 star generals'};
is noun(q{ovulum})->classical->plural,   q{ovula}  => q{classical plural: 'ovulum' --> 'ovula'};
is noun(q{ovula})->classical->plural, q{ovula}  => q{classical plural: 'ovula' --> 'ovula'};
is noun(q{mouth})->classical->plural,   q{mouths}  => q{classical plural: 'mouth' --> 'mouths'};
is noun(q{mouths})->classical->plural, q{mouths}  => q{classical plural: 'mouths' --> 'mouths'};
is noun(q{meta})->classical->plural,   q{metae}  => q{classical plural: 'meta' --> 'metae'};
is noun(q{metae})->classical->plural, q{metae}  => q{classical plural: 'metae' --> 'metae'};
is noun(q{competent})->classical->plural,   q{competentes}  => q{classical plural: 'competent' --> 'competentes'};
is noun(q{competentes})->classical->plural, q{competentes}  => q{classical plural: 'competentes' --> 'competentes'};
is noun(q{ale-wife})->classical->plural,   q{ale-wives}  => q{classical plural: 'ale-wife' --> 'ale-wives'};
is noun(q{ale-wives})->classical->plural, q{ale-wives}  => q{classical plural: 'ale-wives' --> 'ale-wives'};
is noun(q{xiphiplastron})->classical->plural,   q{xiphiplastra}  => q{classical plural: 'xiphiplastron' --> 'xiphiplastra'};
is noun(q{xiphiplastra})->classical->plural, q{xiphiplastra}  => q{classical plural: 'xiphiplastra' --> 'xiphiplastra'};
is noun(q{gousblom})->classical->plural,   q{gousblomme}  => q{classical plural: 'gousblom' --> 'gousblomme'};
is noun(q{gousblomme})->classical->plural, q{gousblomme}  => q{classical plural: 'gousblomme' --> 'gousblomme'};
is noun(q{podion})->classical->plural,   q{podia}  => q{classical plural: 'podion' --> 'podia'};
is noun(q{podia})->classical->plural, q{podia}  => q{classical plural: 'podia' --> 'podia'};
is noun(q{patagium})->classical->plural,   q{patagia}  => q{classical plural: 'patagium' --> 'patagia'};
is noun(q{patagia})->classical->plural, q{patagia}  => q{classical plural: 'patagia' --> 'patagia'};
is noun(q{sacrum})->classical->plural,   q{sacra}  => q{classical plural: 'sacrum' --> 'sacra'};
is noun(q{sacra})->classical->plural, q{sacra}  => q{classical plural: 'sacra' --> 'sacra'};
is noun(q{finger end})->classical->plural,   q{fingers ends}  => q{classical plural: 'finger end' --> 'fingers ends'};
is noun(q{fingers ends})->classical->plural, q{fingers ends}  => q{classical plural: 'fingers ends' --> 'fingers ends'};
is noun(q{arf})->classical->plural,   q{arves}  => q{classical plural: 'arf' --> 'arves'};
is noun(q{arves})->classical->plural, q{arves}  => q{classical plural: 'arves' --> 'arves'};
is noun(q{carcinoma})->classical->plural,   q{carcinomata}  => q{classical plural: 'carcinoma' --> 'carcinomata'};
is noun(q{carcinomata})->classical->plural, q{carcinomata}  => q{classical plural: 'carcinomata' --> 'carcinomata'};
is noun(q{paraselene})->classical->plural,   q{paraselenae}  => q{classical plural: 'paraselene' --> 'paraselenae'};
is noun(q{paraselenae})->classical->plural, q{paraselenae}  => q{classical plural: 'paraselenae' --> 'paraselenae'};
is noun(q{galla})->classical->plural,   q{galla}  => q{classical plural: 'galla' --> 'galla'};
is noun(q{ambulacrum})->classical->plural,   q{ambulacra}  => q{classical plural: 'ambulacrum' --> 'ambulacra'};
is noun(q{ambulacra})->classical->plural, q{ambulacra}  => q{classical plural: 'ambulacra' --> 'ambulacra'};
is noun(q{trilby})->classical->plural,   q{trilbys}  => q{classical plural: 'trilby' --> 'trilbys'};
is noun(q{trilbys})->classical->plural, q{trilbys}  => q{classical plural: 'trilbys' --> 'trilbys'};
is noun(q{pyxidium})->classical->plural,   q{pyxidia}  => q{classical plural: 'pyxidium' --> 'pyxidia'};
is noun(q{pyxidia})->classical->plural, q{pyxidia}  => q{classical plural: 'pyxidia' --> 'pyxidia'};
is noun(q{vibex})->classical->plural,   q{vibices}  => q{classical plural: 'vibex' --> 'vibices'};
is noun(q{vibices})->classical->plural, q{vibices}  => q{classical plural: 'vibices' --> 'vibices'};
is noun(q{tortrix})->classical->plural,   q{tortrices}  => q{classical plural: 'tortrix' --> 'tortrices'};
is noun(q{tortrices})->classical->plural, q{tortrices}  => q{classical plural: 'tortrices' --> 'tortrices'};
is noun(q{kernos})->classical->plural,   q{kernoi}  => q{classical plural: 'kernos' --> 'kernoi'};
is noun(q{kernoi})->classical->plural, q{kernoi}  => q{classical plural: 'kernoi' --> 'kernoi'};
is noun(q{placitum})->classical->plural,   q{placita}  => q{classical plural: 'placitum' --> 'placita'};
is noun(q{placita})->classical->plural, q{placita}  => q{classical plural: 'placita' --> 'placita'};
is noun(q{goose})->classical->plural,   q{geese}  => q{classical plural: 'goose' --> 'geese'};
is noun(q{geese})->classical->plural, q{geese}  => q{classical plural: 'geese' --> 'geese'};
is noun(q{triradius})->classical->plural,   q{triradii}  => q{classical plural: 'triradius' --> 'triradii'};
is noun(q{triradii})->classical->plural, q{triradii}  => q{classical plural: 'triradii' --> 'triradii'};
is noun(q{hypolimnion})->classical->plural,   q{hypolimnia}  => q{classical plural: 'hypolimnion' --> 'hypolimnia'};
is noun(q{hypolimnia})->classical->plural, q{hypolimnia}  => q{classical plural: 'hypolimnia' --> 'hypolimnia'};
is noun(q{polythecium})->classical->plural,   q{polythecia}  => q{classical plural: 'polythecium' --> 'polythecia'};
is noun(q{polythecia})->classical->plural, q{polythecia}  => q{classical plural: 'polythecia' --> 'polythecia'};
is noun(q{Hainanese})->classical->plural,   q{Hainanese}  => q{classical plural: 'Hainanese' --> 'Hainanese'};
is noun(q{parergon})->classical->plural,   q{parerga}  => q{classical plural: 'parergon' --> 'parerga'};
is noun(q{parerga})->classical->plural, q{parerga}  => q{classical plural: 'parerga' --> 'parerga'};
is noun(q{auspex})->classical->plural,   q{auspices}  => q{classical plural: 'auspex' --> 'auspices'};
is noun(q{auspices})->classical->plural, q{auspices}  => q{classical plural: 'auspices' --> 'auspices'};
is noun(q{status})->classical->plural,   q{status}  => q{classical plural: 'status' --> 'status'};
is noun(q{phylum})->classical->plural,   q{phyla}  => q{classical plural: 'phylum' --> 'phyla'};
is noun(q{phyla})->classical->plural, q{phyla}  => q{classical plural: 'phyla' --> 'phyla'};
is noun(q{musique concrete})->classical->plural,   q{musiques concretes}  => q{classical plural: 'musique concrete' --> 'musiques concretes'};
is noun(q{musiques concretes})->classical->plural, q{musiques concretes}  => q{classical plural: 'musiques concretes' --> 'musiques concretes'};
is noun(q{neurinoma})->classical->plural,   q{neurinomata}  => q{classical plural: 'neurinoma' --> 'neurinomata'};
is noun(q{neurinomata})->classical->plural, q{neurinomata}  => q{classical plural: 'neurinomata' --> 'neurinomata'};
is noun(q{leaf})->classical->plural,   q{leaves}  => q{classical plural: 'leaf' --> 'leaves'};
is noun(q{leaves})->classical->plural, q{leaves}  => q{classical plural: 'leaves' --> 'leaves'};
is noun(q{ens reale})->classical->plural,   q{entia realia}  => q{classical plural: 'ens reale' --> 'entia realia'};
is noun(q{entia realia})->classical->plural, q{entia realia}  => q{classical plural: 'entia realia' --> 'entia realia'};
is noun(q{farman})->classical->plural,   q{farmans}  => q{classical plural: 'farman' --> 'farmans'};
is noun(q{farmans})->classical->plural, q{farmans}  => q{classical plural: 'farmans' --> 'farmans'};
is noun(q{plankter})->classical->plural,   q{plankton}  => q{classical plural: 'plankter' --> 'plankton'};
is noun(q{plankton})->classical->plural, q{plankton}  => q{classical plural: 'plankton' --> 'plankton'};
is noun(q{peridium})->classical->plural,   q{peridia}  => q{classical plural: 'peridium' --> 'peridia'};
is noun(q{peridia})->classical->plural, q{peridia}  => q{classical plural: 'peridia' --> 'peridia'};
is noun(q{beerenauslese})->classical->plural,   q{beerenauslesen}  => q{classical plural: 'beerenauslese' --> 'beerenauslesen'};
is noun(q{beerenauslesen})->classical->plural, q{beerenauslesen}  => q{classical plural: 'beerenauslesen' --> 'beerenauslesen'};
is noun(q{busto})->classical->plural,   q{bustoes}  => q{classical plural: 'busto' --> 'bustoes'};
is noun(q{bustoes})->classical->plural, q{bustoes}  => q{classical plural: 'bustoes' --> 'bustoes'};
is noun(q{lord lieutenant})->classical->plural,   q{lords lieutenant}  => q{classical plural: 'lord lieutenant' --> 'lords lieutenant'};
is noun(q{lords lieutenant})->classical->plural, q{lords lieutenant}  => q{classical plural: 'lords lieutenant' --> 'lords lieutenant'};
is noun(q{Filipino})->classical->plural,   q{Filipinos}  => q{classical plural: 'Filipino' --> 'Filipinos'};
is noun(q{Filipinos})->classical->plural, q{Filipinos}  => q{classical plural: 'Filipinos' --> 'Filipinos'};
is noun(q{monochasium})->classical->plural,   q{monochasia}  => q{classical plural: 'monochasium' --> 'monochasia'};
is noun(q{monochasia})->classical->plural, q{monochasia}  => q{classical plural: 'monochasia' --> 'monochasia'};
is noun(q{parvenu})->classical->plural,   q{parvenus}  => q{classical plural: 'parvenu' --> 'parvenus'};
is noun(q{parvenus})->classical->plural, q{parvenus}  => q{classical plural: 'parvenus' --> 'parvenus'};
is noun(q{fricandeau})->classical->plural,   q{fricandeaux}  => q{classical plural: 'fricandeau' --> 'fricandeaux'};
is noun(q{fricandeaux})->classical->plural, q{fricandeaux}  => q{classical plural: 'fricandeaux' --> 'fricandeaux'};
is noun(q{secundagravida})->classical->plural,   q{secundagravidae}  => q{classical plural: 'secundagravida' --> 'secundagravidae'};
is noun(q{secundagravidae})->classical->plural, q{secundagravidae}  => q{classical plural: 'secundagravidae' --> 'secundagravidae'};
is noun(q{Congoese})->classical->plural,   q{Congoese}  => q{classical plural: 'Congoese' --> 'Congoese'};
is noun(q{panino})->classical->plural,   q{panini}  => q{classical plural: 'panino' --> 'panini'};
is noun(q{panini})->classical->plural, q{panini}  => q{classical plural: 'panini' --> 'panini'};
is noun(q{iris})->classical->plural,   q{irides}  => q{classical plural: 'iris' --> 'irides'};
is noun(q{irides})->classical->plural, q{irides}  => q{classical plural: 'irides' --> 'irides'};
is noun(q{Nenets})->classical->plural,   q{Nentsi}  => q{classical plural: 'Nenets' --> 'Nentsi'};
is noun(q{Nentsi})->classical->plural, q{Nentsi}  => q{classical plural: 'Nentsi' --> 'Nentsi'};
is noun(q{magus})->classical->plural,   q{magi}  => q{classical plural: 'magus' --> 'magi'};
is noun(q{magi})->classical->plural, q{magi}  => q{classical plural: 'magi' --> 'magi'};
is noun(q{ritardando})->classical->plural,   q{ritardandi}  => q{classical plural: 'ritardando' --> 'ritardandi'};
is noun(q{ritardandi})->classical->plural, q{ritardandi}  => q{classical plural: 'ritardandi' --> 'ritardandi'};
is noun(q{sumo})->classical->plural,   q{sumos}  => q{classical plural: 'sumo' --> 'sumos'};
is noun(q{sumos})->classical->plural, q{sumos}  => q{classical plural: 'sumos' --> 'sumos'};
is noun(q{bacillus})->classical->plural,   q{bacilli}  => q{classical plural: 'bacillus' --> 'bacilli'};
is noun(q{bacilli})->classical->plural, q{bacilli}  => q{classical plural: 'bacilli' --> 'bacilli'};
is noun(q{versiculus})->classical->plural,   q{versiculi}  => q{classical plural: 'versiculus' --> 'versiculi'};
is noun(q{versiculi})->classical->plural, q{versiculi}  => q{classical plural: 'versiculi' --> 'versiculi'};
is noun(q{appendix})->classical->plural,   q{appendices}  => q{classical plural: 'appendix' --> 'appendices'};
is noun(q{appendices})->classical->plural, q{appendices}  => q{classical plural: 'appendices' --> 'appendices'};
is noun(q{pyralis})->classical->plural,   q{pyralides}  => q{classical plural: 'pyralis' --> 'pyralides'};
is noun(q{pyralides})->classical->plural, q{pyralides}  => q{classical plural: 'pyralides' --> 'pyralides'};
is noun(q{celia})->classical->plural,   q{celiae}  => q{classical plural: 'celia' --> 'celiae'};
is noun(q{celiae})->classical->plural, q{celiae}  => q{classical plural: 'celiae' --> 'celiae'};
is noun(q{fraenum})->classical->plural,   q{fraena}  => q{classical plural: 'fraenum' --> 'fraena'};
is noun(q{fraena})->classical->plural, q{fraena}  => q{classical plural: 'fraena' --> 'fraena'};
is noun(q{macaroni})->classical->plural,   q{macaronies}  => q{classical plural: 'macaroni' --> 'macaronies'};
is noun(q{macaronies})->classical->plural, q{macaronies}  => q{classical plural: 'macaronies' --> 'macaronies'};
is noun(q{pallium})->classical->plural,   q{pallia}  => q{classical plural: 'pallium' --> 'pallia'};
is noun(q{pallia})->classical->plural, q{pallia}  => q{classical plural: 'pallia' --> 'pallia'};
is noun(q{afreet})->classical->plural,   q{afreeti}  => q{classical plural: 'afreet' --> 'afreeti'};
is noun(q{afreeti})->classical->plural, q{afreeti}  => q{classical plural: 'afreeti' --> 'afreeti'};
is noun(q{ngwee})->classical->plural,   q{ngwee}  => q{classical plural: 'ngwee' --> 'ngwee'};
is noun(q{palea})->classical->plural,   q{paleae}  => q{classical plural: 'palea' --> 'paleae'};
is noun(q{paleae})->classical->plural, q{paleae}  => q{classical plural: 'paleae' --> 'paleae'};
is noun(q{demo})->classical->plural,   q{demos}  => q{classical plural: 'demo' --> 'demos'};
is noun(q{demos})->classical->plural, q{demos}  => q{classical plural: 'demos' --> 'demos'};
is noun(q{focus})->classical->plural,   q{foci}  => q{classical plural: 'focus' --> 'foci'};
is noun(q{foci})->classical->plural, q{foci}  => q{classical plural: 'foci' --> 'foci'};
is noun(q{synapticula})->classical->plural,   q{synapticulae}  => q{classical plural: 'synapticula' --> 'synapticulae'};
is noun(q{synapticulae})->classical->plural, q{synapticulae}  => q{classical plural: 'synapticulae' --> 'synapticulae'};
is noun(q{linea})->classical->plural,   q{lineae}  => q{classical plural: 'linea' --> 'lineae'};
is noun(q{lineae})->classical->plural, q{lineae}  => q{classical plural: 'lineae' --> 'lineae'};
is noun(q{stomion})->classical->plural,   q{stomia}  => q{classical plural: 'stomion' --> 'stomia'};
is noun(q{stomia})->classical->plural, q{stomia}  => q{classical plural: 'stomia' --> 'stomia'};
is noun(q{flagellum})->classical->plural,   q{flagella}  => q{classical plural: 'flagellum' --> 'flagella'};
is noun(q{flagella})->classical->plural, q{flagella}  => q{classical plural: 'flagella' --> 'flagella'};
is noun(q{stiletto})->classical->plural,   q{stilettoes}  => q{classical plural: 'stiletto' --> 'stilettoes'};
is noun(q{stilettoes})->classical->plural, q{stilettoes}  => q{classical plural: 'stilettoes' --> 'stilettoes'};
is noun(q{studium generale})->classical->plural,   q{studia generali}  => q{classical plural: 'studium generale' --> 'studia generali'};
is noun(q{studia generali})->classical->plural, q{studia generali}  => q{classical plural: 'studia generali' --> 'studia generali'};
is noun(q{myxoma})->classical->plural,   q{myxomata}  => q{classical plural: 'myxoma' --> 'myxomata'};
is noun(q{myxomata})->classical->plural, q{myxomata}  => q{classical plural: 'myxomata' --> 'myxomata'};
is noun(q{tombarolo})->classical->plural,   q{tombaroli}  => q{classical plural: 'tombarolo' --> 'tombaroli'};
is noun(q{tombaroli})->classical->plural, q{tombaroli}  => q{classical plural: 'tombaroli' --> 'tombaroli'};
is noun(q{legomenon})->classical->plural,   q{legomena}  => q{classical plural: 'legomenon' --> 'legomena'};
is noun(q{legomena})->classical->plural, q{legomena}  => q{classical plural: 'legomena' --> 'legomena'};
is noun(q{ommatidium})->classical->plural,   q{ommatidia}  => q{classical plural: 'ommatidium' --> 'ommatidia'};
is noun(q{ommatidia})->classical->plural, q{ommatidia}  => q{classical plural: 'ommatidia' --> 'ommatidia'};
is noun(q{cul de four})->classical->plural,   q{culs de four}  => q{classical plural: 'cul de four' --> 'culs de four'};
is noun(q{culs de four})->classical->plural, q{culs de four}  => q{classical plural: 'culs de four' --> 'culs de four'};
is noun(q{pogo})->classical->plural,   q{pogos}  => q{classical plural: 'pogo' --> 'pogos'};
is noun(q{pogos})->classical->plural, q{pogos}  => q{classical plural: 'pogos' --> 'pogos'};
is noun(q{noumenon})->classical->plural,   q{noumena}  => q{classical plural: 'noumenon' --> 'noumena'};
is noun(q{noumena})->classical->plural, q{noumena}  => q{classical plural: 'noumena' --> 'noumena'};
is noun(q{spadix})->classical->plural,   q{spadices}  => q{classical plural: 'spadix' --> 'spadices'};
is noun(q{spadices})->classical->plural, q{spadices}  => q{classical plural: 'spadices' --> 'spadices'};
is noun(q{Faroese})->classical->plural,   q{Faroese}  => q{classical plural: 'Faroese' --> 'Faroese'};
is noun(q{replum})->classical->plural,   q{repla}  => q{classical plural: 'replum' --> 'repla'};
is noun(q{repla})->classical->plural, q{repla}  => q{classical plural: 'repla' --> 'repla'};
is noun(q{vagina})->classical->plural,   q{vaginae}  => q{classical plural: 'vagina' --> 'vaginae'};
is noun(q{vaginae})->classical->plural, q{vaginae}  => q{classical plural: 'vaginae' --> 'vaginae'};
is noun(q{scoria})->classical->plural,   q{scoriae}  => q{classical plural: 'scoria' --> 'scoriae'};
is noun(q{scoriae})->classical->plural, q{scoriae}  => q{classical plural: 'scoriae' --> 'scoriae'};
is noun(q{spermatium})->classical->plural,   q{spermatia}  => q{classical plural: 'spermatium' --> 'spermatia'};
is noun(q{spermatia})->classical->plural, q{spermatia}  => q{classical plural: 'spermatia' --> 'spermatia'};
is noun(q{jugum})->classical->plural,   q{juga}  => q{classical plural: 'jugum' --> 'juga'};
is noun(q{juga})->classical->plural, q{juga}  => q{classical plural: 'juga' --> 'juga'};
is noun(q{cynocephalus})->classical->plural,   q{cynocephali}  => q{classical plural: 'cynocephalus' --> 'cynocephali'};
is noun(q{cynocephali})->classical->plural, q{cynocephali}  => q{classical plural: 'cynocephali' --> 'cynocephali'};
is noun(q{bursa})->classical->plural,   q{bursae}  => q{classical plural: 'bursa' --> 'bursae'};
is noun(q{bursae})->classical->plural, q{bursae}  => q{classical plural: 'bursae' --> 'bursae'};
is noun(q{anthodium})->classical->plural,   q{anthodia}  => q{classical plural: 'anthodium' --> 'anthodia'};
is noun(q{anthodia})->classical->plural, q{anthodia}  => q{classical plural: 'anthodia' --> 'anthodia'};
is noun(q{sipunculus})->classical->plural,   q{sipunculi}  => q{classical plural: 'sipunculus' --> 'sipunculi'};
is noun(q{sipunculi})->classical->plural, q{sipunculi}  => q{classical plural: 'sipunculi' --> 'sipunculi'};
is noun(q{planctus})->classical->plural,   q{planctus}  => q{classical plural: 'planctus' --> 'planctus'};
is noun(q{prolegomenon})->classical->plural,   q{prolegomena}  => q{classical plural: 'prolegomenon' --> 'prolegomena'};
is noun(q{prolegomena})->classical->plural, q{prolegomena}  => q{classical plural: 'prolegomena' --> 'prolegomena'};
is noun(q{manifesto})->classical->plural,   q{manifestos}  => q{classical plural: 'manifesto' --> 'manifestos'};
is noun(q{manifestos})->classical->plural, q{manifestos}  => q{classical plural: 'manifestos' --> 'manifestos'};
is noun(q{enema})->classical->plural,   q{enemata}  => q{classical plural: 'enema' --> 'enemata'};
is noun(q{enemata})->classical->plural, q{enemata}  => q{classical plural: 'enemata' --> 'enemata'};
is noun(q{uterus})->classical->plural,   q{uteri}  => q{classical plural: 'uterus' --> 'uteri'};
is noun(q{uteri})->classical->plural, q{uteri}  => q{classical plural: 'uteri' --> 'uteri'};
is noun(q{parison})->classical->plural,   q{parisa}  => q{classical plural: 'parison' --> 'parisa'};
is noun(q{parisa})->classical->plural, q{parisa}  => q{classical plural: 'parisa' --> 'parisa'};
is noun(q{5 star general})->classical->plural,   q{5 star generals}  => q{classical plural: '5 star general' --> '5 star generals'};
is noun(q{5 star generals})->classical->plural, q{5 star generals}  => q{classical plural: '5 star generals' --> '5 star generals'};
is noun(q{Idaho})->classical->plural,   q{Idahos}  => q{classical plural: 'Idaho' --> 'Idahos'};
is noun(q{Idahos})->classical->plural, q{Idahos}  => q{classical plural: 'Idahos' --> 'Idahos'};
is noun(q{pendulum})->classical->plural,   q{pendula}  => q{classical plural: 'pendulum' --> 'pendula'};
is noun(q{pendula})->classical->plural, q{pendula}  => q{classical plural: 'pendula' --> 'pendula'};
is noun(q{cubiculum})->classical->plural,   q{cubicula}  => q{classical plural: 'cubiculum' --> 'cubicula'};
is noun(q{cubicula})->classical->plural, q{cubicula}  => q{classical plural: 'cubicula' --> 'cubicula'};
is noun(q{contagium})->classical->plural,   q{contagia}  => q{classical plural: 'contagium' --> 'contagia'};
is noun(q{contagia})->classical->plural, q{contagia}  => q{classical plural: 'contagia' --> 'contagia'};
is noun(q{vesicula})->classical->plural,   q{vesiculae}  => q{classical plural: 'vesicula' --> 'vesiculae'};
is noun(q{vesiculae})->classical->plural, q{vesiculae}  => q{classical plural: 'vesiculae' --> 'vesiculae'};
is noun(q{mackerel})->classical->plural,   q{mackerel}  => q{classical plural: 'mackerel' --> 'mackerel'};
is noun(q{sezession})->classical->plural,   q{sezessionen}  => q{classical plural: 'sezession' --> 'sezessionen'};
is noun(q{sezessionen})->classical->plural, q{sezessionen}  => q{classical plural: 'sezessionen' --> 'sezessionen'};
is noun(q{lingo})->classical->plural,   q{lingos}  => q{classical plural: 'lingo' --> 'lingos'};
is noun(q{lingos})->classical->plural, q{lingos}  => q{classical plural: 'lingos' --> 'lingos'};
is noun(q{reich})->classical->plural,   q{reiche}  => q{classical plural: 'reich' --> 'reiche'};
is noun(q{reiche})->classical->plural, q{reiche}  => q{classical plural: 'reiche' --> 'reiche'};
is noun(q{globigerina})->classical->plural,   q{globigerinae}  => q{classical plural: 'globigerina' --> 'globigerinae'};
is noun(q{globigerinae})->classical->plural, q{globigerinae}  => q{classical plural: 'globigerinae' --> 'globigerinae'};
is noun(q{vaalpens})->classical->plural,   q{vaalpensen}  => q{classical plural: 'vaalpens' --> 'vaalpensen'};
is noun(q{vaalpensen})->classical->plural, q{vaalpensen}  => q{classical plural: 'vaalpensen' --> 'vaalpensen'};
is noun(q{explicandum})->classical->plural,   q{explicanda}  => q{classical plural: 'explicandum' --> 'explicanda'};
is noun(q{explicanda})->classical->plural, q{explicanda}  => q{classical plural: 'explicanda' --> 'explicanda'};
is noun(q{guy})->classical->plural,   q{guys}  => q{classical plural: 'guy' --> 'guys'};
is noun(q{guys})->classical->plural, q{guys}  => q{classical plural: 'guys' --> 'guys'};
is noun(q{zoaea})->classical->plural,   q{zoaeae}  => q{classical plural: 'zoaea' --> 'zoaeae'};
is noun(q{zoaeae})->classical->plural, q{zoaeae}  => q{classical plural: 'zoaeae' --> 'zoaeae'};
is noun(q{bursitis})->classical->plural,   q{bursitises}  => q{classical plural: 'bursitis' --> 'bursitises'};
is noun(q{bursitises})->classical->plural, q{bursitises}  => q{classical plural: 'bursitises' --> 'bursitises'};
is noun(q{sporodochium})->classical->plural,   q{sporodochia}  => q{classical plural: 'sporodochium' --> 'sporodochia'};
is noun(q{sporodochia})->classical->plural, q{sporodochia}  => q{classical plural: 'sporodochia' --> 'sporodochia'};
is noun(q{pinna})->classical->plural,   q{pinnae}  => q{classical plural: 'pinna' --> 'pinnae'};
is noun(q{pinnae})->classical->plural, q{pinnae}  => q{classical plural: 'pinnae' --> 'pinnae'};
is noun(q{shorts})->classical->plural,   q{shorts}  => q{classical plural: 'shorts' --> 'shorts'};
is noun(q{pelta})->classical->plural,   q{peltae}  => q{classical plural: 'pelta' --> 'peltae'};
is noun(q{peltae})->classical->plural, q{peltae}  => q{classical plural: 'peltae' --> 'peltae'};
is noun(q{canzonetta})->classical->plural,   q{canzonette}  => q{classical plural: 'canzonetta' --> 'canzonette'};
is noun(q{canzonette})->classical->plural, q{canzonette}  => q{classical plural: 'canzonette' --> 'canzonette'};
is noun(q{stomach})->classical->plural,   q{stomachs}  => q{classical plural: 'stomach' --> 'stomachs'};
is noun(q{stomachs})->classical->plural, q{stomachs}  => q{classical plural: 'stomachs' --> 'stomachs'};
is noun(q{plexus})->classical->plural,   q{plexus}  => q{classical plural: 'plexus' --> 'plexus'};
is noun(q{sanctum sanctorum})->classical->plural,   q{sancta sanctorum}  => q{classical plural: 'sanctum sanctorum' --> 'sancta sanctorum'};
is noun(q{sancta sanctorum})->classical->plural, q{sancta sanctorum}  => q{classical plural: 'sancta sanctorum' --> 'sancta sanctorum'};
is noun(q{whose})->classical->plural,   q{whose}  => q{classical plural: 'whose' --> 'whose'};
is noun(q{poise})->classical->plural,   q{poise}  => q{classical plural: 'poise' --> 'poise'};
is noun(q{penni})->classical->plural,   q{pennia}  => q{classical plural: 'penni' --> 'pennia'};
is noun(q{pennia})->classical->plural, q{pennia}  => q{classical plural: 'pennia' --> 'pennia'};
is noun(q{incubus})->classical->plural,   q{incubi}  => q{classical plural: 'incubus' --> 'incubi'};
is noun(q{incubi})->classical->plural, q{incubi}  => q{classical plural: 'incubi' --> 'incubi'};
is noun(q{intertrigo})->classical->plural,   q{intertrigos}  => q{classical plural: 'intertrigo' --> 'intertrigos'};
is noun(q{intertrigos})->classical->plural, q{intertrigos}  => q{classical plural: 'intertrigos' --> 'intertrigos'};
is noun(q{involucrum})->classical->plural,   q{involucra}  => q{classical plural: 'involucrum' --> 'involucra'};
is noun(q{involucra})->classical->plural, q{involucra}  => q{classical plural: 'involucra' --> 'involucra'};
is noun(q{elk})->classical->plural,   q{elk}  => q{classical plural: 'elk' --> 'elk'};
is noun(q{gizmo})->classical->plural,   q{gizmos}  => q{classical plural: 'gizmo' --> 'gizmos'};
is noun(q{gizmos})->classical->plural, q{gizmos}  => q{classical plural: 'gizmos' --> 'gizmos'};
is noun(q{wife})->classical->plural,   q{wives}  => q{classical plural: 'wife' --> 'wives'};
is noun(q{wives})->classical->plural, q{wives}  => q{classical plural: 'wives' --> 'wives'};
is noun(q{sanatorium})->classical->plural,   q{sanatoria}  => q{classical plural: 'sanatorium' --> 'sanatoria'};
is noun(q{sanatoria})->classical->plural, q{sanatoria}  => q{classical plural: 'sanatoria' --> 'sanatoria'};
is noun(q{labrum})->classical->plural,   q{labra}  => q{classical plural: 'labrum' --> 'labra'};
is noun(q{labra})->classical->plural, q{labra}  => q{classical plural: 'labra' --> 'labra'};
is noun(q{rilievo})->classical->plural,   q{rilievos}  => q{classical plural: 'rilievo' --> 'rilievos'};
is noun(q{rilievos})->classical->plural, q{rilievos}  => q{classical plural: 'rilievos' --> 'rilievos'};
is noun(q{one-star general})->classical->plural,   q{one-star generals}  => q{classical plural: 'one-star general' --> 'one-star generals'};
is noun(q{one-star generals})->classical->plural, q{one-star generals}  => q{classical plural: 'one-star generals' --> 'one-star generals'};
is noun(q{Yakiman})->classical->plural,   q{Yakimans}  => q{classical plural: 'Yakiman' --> 'Yakimans'};
is noun(q{Yakimans})->classical->plural, q{Yakimans}  => q{classical plural: 'Yakimans' --> 'Yakimans'};
is noun(q{astrocytoma})->classical->plural,   q{astrocytomata}  => q{classical plural: 'astrocytoma' --> 'astrocytomata'};
is noun(q{astrocytomata})->classical->plural, q{astrocytomata}  => q{classical plural: 'astrocytomata' --> 'astrocytomata'};
is noun(q{macro})->classical->plural,   q{macros}  => q{classical plural: 'macro' --> 'macros'};
is noun(q{macros})->classical->plural, q{macros}  => q{classical plural: 'macros' --> 'macros'};
is noun(q{denkmal})->classical->plural,   q{denkmaler}  => q{classical plural: 'denkmal' --> 'denkmaler'};
is noun(q{denkmaler})->classical->plural, q{denkmaler}  => q{classical plural: 'denkmaler' --> 'denkmaler'};
is noun(q{thief})->classical->plural,   q{thieves}  => q{classical plural: 'thief' --> 'thieves'};
is noun(q{thieves})->classical->plural, q{thieves}  => q{classical plural: 'thieves' --> 'thieves'};
is noun(q{Hottentotese})->classical->plural,   q{Hottentotese}  => q{classical plural: 'Hottentotese' --> 'Hottentotese'};
is noun(q{Navarrese})->classical->plural,   q{Navarrese}  => q{classical plural: 'Navarrese' --> 'Navarrese'};
is noun(q{Johnsonese})->classical->plural,   q{Johnsonese}  => q{classical plural: 'Johnsonese' --> 'Johnsonese'};
is noun(q{Sarajevo})->classical->plural,   q{Sarajevos}  => q{classical plural: 'Sarajevo' --> 'Sarajevos'};
is noun(q{Sarajevos})->classical->plural, q{Sarajevos}  => q{classical plural: 'Sarajevos' --> 'Sarajevos'};
is noun(q{Tonkinese})->classical->plural,   q{Tonkinese}  => q{classical plural: 'Tonkinese' --> 'Tonkinese'};
is noun(q{to})->classical->plural,   q{toes}  => q{classical plural: 'to' --> 'toes'};
is noun(q{toes})->classical->plural, q{toes}  => q{classical plural: 'toes' --> 'toes'};
is noun(q{do})->classical->plural,   q{does}  => q{classical plural: 'do' --> 'does'};
is noun(q{does})->classical->plural, q{does}  => q{classical plural: 'does' --> 'does'};
is noun(q{prima donna})->classical->plural,   q{prime donne}  => q{classical plural: 'prima donna' --> 'prime donne'};
is noun(q{prime donne})->classical->plural, q{prime donne}  => q{classical plural: 'prime donne' --> 'prime donne'};
is noun(q{Parmese})->classical->plural,   q{Parmese}  => q{classical plural: 'Parmese' --> 'Parmese'};
is noun(q{archegonium})->classical->plural,   q{archegonia}  => q{classical plural: 'archegonium' --> 'archegonia'};
is noun(q{archegonia})->classical->plural, q{archegonia}  => q{classical plural: 'archegonia' --> 'archegonia'};
is noun(q{pillie})->classical->plural,   q{pilleis}  => q{classical plural: 'pillie' --> 'pilleis'};
is noun(q{pilleis})->classical->plural, q{pilleis}  => q{classical plural: 'pilleis' --> 'pilleis'};
is noun(q{vomica})->classical->plural,   q{vomicae}  => q{classical plural: 'vomica' --> 'vomicae'};
is noun(q{vomicae})->classical->plural, q{vomicae}  => q{classical plural: 'vomicae' --> 'vomicae'};
is noun(q{bolus})->classical->plural,   q{boluses}  => q{classical plural: 'bolus' --> 'boluses'};
is noun(q{boluses})->classical->plural, q{boluses}  => q{classical plural: 'boluses' --> 'boluses'};
is noun(q{magnum opus})->classical->plural,   q{magna opera}  => q{classical plural: 'magnum opus' --> 'magna opera'};
is noun(q{magna opera})->classical->plural, q{magna opera}  => q{classical plural: 'magna opera' --> 'magna opera'};
is noun(q{tuber})->classical->plural,   q{tuberes}  => q{classical plural: 'tuber' --> 'tuberes'};
is noun(q{tuberes})->classical->plural, q{tuberes}  => q{classical plural: 'tuberes' --> 'tuberes'};
is noun(q{tropis})->classical->plural,   q{tropides}  => q{classical plural: 'tropis' --> 'tropides'};
is noun(q{tropides})->classical->plural, q{tropides}  => q{classical plural: 'tropides' --> 'tropides'};
is noun(q{lithodomus})->classical->plural,   q{lithodomi}  => q{classical plural: 'lithodomus' --> 'lithodomi'};
is noun(q{lithodomi})->classical->plural, q{lithodomi}  => q{classical plural: 'lithodomi' --> 'lithodomi'};
is noun(q{cow})->classical->plural,   q{kine}  => q{classical plural: 'cow' --> 'kine'};
is noun(q{kine})->classical->plural, q{kine}  => q{classical plural: 'kine' --> 'kine'};
is noun(q{contango})->classical->plural,   q{contangos}  => q{classical plural: 'contango' --> 'contangos'};
is noun(q{contangos})->classical->plural, q{contangos}  => q{classical plural: 'contangos' --> 'contangos'};
is noun(q{apsis})->classical->plural,   q{apsides}  => q{classical plural: 'apsis' --> 'apsides'};
is noun(q{apsides})->classical->plural, q{apsides}  => q{classical plural: 'apsides' --> 'apsides'};
is noun(q{schistosomulum})->classical->plural,   q{schistosomula}  => q{classical plural: 'schistosomulum' --> 'schistosomula'};
is noun(q{schistosomula})->classical->plural, q{schistosomula}  => q{classical plural: 'schistosomula' --> 'schistosomula'};
is noun(q{plasmoma})->classical->plural,   q{plasmomata}  => q{classical plural: 'plasmoma' --> 'plasmomata'};
is noun(q{plasmomata})->classical->plural, q{plasmomata}  => q{classical plural: 'plasmomata' --> 'plasmomata'};
is noun(q{acinus})->classical->plural,   q{acini}  => q{classical plural: 'acinus' --> 'acini'};
is noun(q{acini})->classical->plural, q{acini}  => q{classical plural: 'acini' --> 'acini'};
is noun(q{gymnasium})->classical->plural,   q{gymnasia}  => q{classical plural: 'gymnasium' --> 'gymnasia'};
is noun(q{gymnasia})->classical->plural, q{gymnasia}  => q{classical plural: 'gymnasia' --> 'gymnasia'};
is noun(q{Burman})->classical->plural,   q{Burmans}  => q{classical plural: 'Burman' --> 'Burmans'};
is noun(q{Burmans})->classical->plural, q{Burmans}  => q{classical plural: 'Burmans' --> 'Burmans'};
is noun(q{haustorium})->classical->plural,   q{haustoria}  => q{classical plural: 'haustorium' --> 'haustoria'};
is noun(q{haustoria})->classical->plural, q{haustoria}  => q{classical plural: 'haustoria' --> 'haustoria'};
is noun(q{hemera})->classical->plural,   q{hemerae}  => q{classical plural: 'hemera' --> 'hemerae'};
is noun(q{hemerae})->classical->plural, q{hemerae}  => q{classical plural: 'hemerae' --> 'hemerae'};
is noun(q{modello})->classical->plural,   q{modelli}  => q{classical plural: 'modello' --> 'modelli'};
is noun(q{modelli})->classical->plural, q{modelli}  => q{classical plural: 'modelli' --> 'modelli'};
is noun(q{stornello})->classical->plural,   q{stornelli}  => q{classical plural: 'stornello' --> 'stornelli'};
is noun(q{stornelli})->classical->plural, q{stornelli}  => q{classical plural: 'stornelli' --> 'stornelli'};
is noun(q{mouse})->classical->plural,   q{mice}  => q{classical plural: 'mouse' --> 'mice'};
is noun(q{mice})->classical->plural, q{mice}  => q{classical plural: 'mice' --> 'mice'};
is noun(q{arango})->classical->plural,   q{arangoes}  => q{classical plural: 'arango' --> 'arangoes'};
is noun(q{arangoes})->classical->plural, q{arangoes}  => q{classical plural: 'arangoes' --> 'arangoes'};
is noun(q{prodromus})->classical->plural,   q{prodromi}  => q{classical plural: 'prodromus' --> 'prodromi'};
is noun(q{prodromi})->classical->plural, q{prodromi}  => q{classical plural: 'prodromi' --> 'prodromi'};
is noun(q{sedile})->classical->plural,   q{sedilia}  => q{classical plural: 'sedile' --> 'sedilia'};
is noun(q{sedilia})->classical->plural, q{sedilia}  => q{classical plural: 'sedilia' --> 'sedilia'};
is noun(q{umbilicus})->classical->plural,   q{umbilici}  => q{classical plural: 'umbilicus' --> 'umbilici'};
is noun(q{umbilici})->classical->plural, q{umbilici}  => q{classical plural: 'umbilici' --> 'umbilici'};
is noun(q{limes})->classical->plural,   q{limites}  => q{classical plural: 'limes' --> 'limites'};
is noun(q{limites})->classical->plural, q{limites}  => q{classical plural: 'limites' --> 'limites'};
is noun(q{army corps general})->classical->plural,   q{army corps generals}  => q{classical plural: 'army corps general' --> 'army corps generals'};
is noun(q{army corps generals})->classical->plural, q{army corps generals}  => q{classical plural: 'army corps generals' --> 'army corps generals'};
is noun(q{memorandum})->classical->plural,   q{memoranda}  => q{classical plural: 'memorandum' --> 'memoranda'};
is noun(q{memoranda})->classical->plural, q{memoranda}  => q{classical plural: 'memoranda' --> 'memoranda'};
is noun(q{trapezohedron})->classical->plural,   q{trapezohedra}  => q{classical plural: 'trapezohedron' --> 'trapezohedra'};
is noun(q{trapezohedra})->classical->plural, q{trapezohedra}  => q{classical plural: 'trapezohedra' --> 'trapezohedra'};
is noun(q{laika})->classical->plural,   q{laiki}  => q{classical plural: 'laika' --> 'laiki'};
is noun(q{laiki})->classical->plural, q{laiki}  => q{classical plural: 'laiki' --> 'laiki'};
is noun(q{prosencephalon})->classical->plural,   q{prosencephala}  => q{classical plural: 'prosencephalon' --> 'prosencephala'};
is noun(q{prosencephala})->classical->plural, q{prosencephala}  => q{classical plural: 'prosencephala' --> 'prosencephala'};
is noun(q{what})->classical->plural,   q{what}  => q{classical plural: 'what' --> 'what'};
is noun(q{genus})->classical->plural,   q{genera}  => q{classical plural: 'genus' --> 'genera'};
is noun(q{genera})->classical->plural, q{genera}  => q{classical plural: 'genera' --> 'genera'};
is noun(q{thymiaterion})->classical->plural,   q{thymiateria}  => q{classical plural: 'thymiaterion' --> 'thymiateria'};
is noun(q{thymiateria})->classical->plural, q{thymiateria}  => q{classical plural: 'thymiateria' --> 'thymiateria'};
is noun(q{pincers})->classical->plural,   q{pincers}  => q{classical plural: 'pincers' --> 'pincers'};
is noun(q{spatha})->classical->plural,   q{spathae}  => q{classical plural: 'spatha' --> 'spathae'};
is noun(q{spathae})->classical->plural, q{spathae}  => q{classical plural: 'spathae' --> 'spathae'};
is noun(q{parabolanus})->classical->plural,   q{parabolani}  => q{classical plural: 'parabolanus' --> 'parabolani'};
is noun(q{parabolani})->classical->plural, q{parabolani}  => q{classical plural: 'parabolani' --> 'parabolani'};
is noun(q{raggare})->classical->plural,   q{raggare}  => q{classical plural: 'raggare' --> 'raggare'};
is noun(q{blemya})->classical->plural,   q{blemyae}  => q{classical plural: 'blemya' --> 'blemyae'};
is noun(q{blemyae})->classical->plural, q{blemyae}  => q{classical plural: 'blemyae' --> 'blemyae'};
is noun(q{seta})->classical->plural,   q{setae}  => q{classical plural: 'seta' --> 'setae'};
is noun(q{setae})->classical->plural, q{setae}  => q{classical plural: 'setae' --> 'setae'};
is noun(q{Porto Novo})->classical->plural,   q{Porto Novos}  => q{classical plural: 'Porto Novo' --> 'Porto Novos'};
is noun(q{Porto Novos})->classical->plural, q{Porto Novos}  => q{classical plural: 'Porto Novos' --> 'Porto Novos'};
is noun(q{noema})->classical->plural,   q{noemata}  => q{classical plural: 'noema' --> 'noemata'};
is noun(q{noemata})->classical->plural, q{noemata}  => q{classical plural: 'noemata' --> 'noemata'};
is noun(q{territorium})->classical->plural,   q{territoria}  => q{classical plural: 'territorium' --> 'territoria'};
is noun(q{territoria})->classical->plural, q{territoria}  => q{classical plural: 'territoria' --> 'territoria'};
is noun(q{serpula})->classical->plural,   q{serpulae}  => q{classical plural: 'serpula' --> 'serpulae'};
is noun(q{serpulae})->classical->plural, q{serpulae}  => q{classical plural: 'serpulae' --> 'serpulae'};
is noun(q{jacobus})->classical->plural,   q{jacobus}  => q{classical plural: 'jacobus' --> 'jacobus'};
is noun(q{pteropus})->classical->plural,   q{pteropi}  => q{classical plural: 'pteropus' --> 'pteropi'};
is noun(q{pteropi})->classical->plural, q{pteropi}  => q{classical plural: 'pteropi' --> 'pteropi'};
is noun(q{pied noir})->classical->plural,   q{pieds noirs}  => q{classical plural: 'pied noir' --> 'pieds noirs'};
is noun(q{pieds noirs})->classical->plural, q{pieds noirs}  => q{classical plural: 'pieds noirs' --> 'pieds noirs'};
is noun(q{enigma})->classical->plural,   q{enigmata}  => q{classical plural: 'enigma' --> 'enigmata'};
is noun(q{enigmata})->classical->plural, q{enigmata}  => q{classical plural: 'enigmata' --> 'enigmata'};
is noun(q{contadina})->classical->plural,   q{contadine}  => q{classical plural: 'contadina' --> 'contadine'};
is noun(q{contadine})->classical->plural, q{contadine}  => q{classical plural: 'contadine' --> 'contadine'};
is noun(q{bierstube})->classical->plural,   q{bierstuben}  => q{classical plural: 'bierstube' --> 'bierstuben'};
is noun(q{bierstuben})->classical->plural, q{bierstuben}  => q{classical plural: 'bierstuben' --> 'bierstuben'};
is noun(q{Yamoussoukro})->classical->plural,   q{Yamoussoukros}  => q{classical plural: 'Yamoussoukro' --> 'Yamoussoukros'};
is noun(q{Yamoussoukros})->classical->plural, q{Yamoussoukros}  => q{classical plural: 'Yamoussoukros' --> 'Yamoussoukros'};
is noun(q{conoscente})->classical->plural,   q{conoscenti}  => q{classical plural: 'conoscente' --> 'conoscenti'};
is noun(q{conoscenti})->classical->plural, q{conoscenti}  => q{classical plural: 'conoscenti' --> 'conoscenti'};
is noun(q{efreet})->classical->plural,   q{efreeti}  => q{classical plural: 'efreet' --> 'efreeti'};
is noun(q{efreeti})->classical->plural, q{efreeti}  => q{classical plural: 'efreeti' --> 'efreeti'};

done_testing();
